import * as hookable from 'hookable';
import { FetchOptions, ResponseType, FetchResponse, FetchContext } from 'ofetch';

/**
 * Source: https://github.com/shopware/shopware/blob/trunk/src/Core/PlatformRequest.php#L16
 */
type RequestHeaderName = "sw-context-token" | "sw-access-key" | "sw-language-id" | "sw-currency-id" | "sw-inheritance" | "sw-version-id" | "sw-include-seo-urls" | "sw-skip-trigger-flow" | "sw-app-integration-id" | "indexing-behavior" | "indexing-skip";
type RequestHeader = "content-type" | "accept";
type LiteralUnion<T extends U, U = string> = T | (U & {
    _x?: never;
});
type ClientHeaders = Partial<Record<LiteralUnion<RequestHeaderName | RequestHeader>, string>>;
type ClientHeadersProxy = ClientHeaders & {
    /**
     * Set default headers for the client.
     * Default headers are added to every request.
     * If the header value is falsy, it will be removed from the headers.
     *
     * @example
     * ```ts
     * apiClient.defaultHeaders.apply({
     *  "sw-language-id": "my-language-id",
     * });
     * ```
     */
    readonly apply: (headers: ClientHeaders) => void;
};

/**
 * This file is auto-generated. Do not make direct changes to the file.
 * Instead override it in your shopware.d.ts file.
 *
 * Shopware API version: 6.6.10.0
 *
 */
type GenericRecord$1 =
  | never
  | null
  | string
  | string[]
  | number
  | {
      [key: string]: GenericRecord$1;
    };
type components$1 = {
  schemas: Schemas$1;
};
type Schemas$1 = {
  AbstractDynamicPageOpenedPayload: {
    /** @default true */
    opened?: boolean;
    /** The id of the current dynamic page */
    pageId: string;
    /** The position of the dynamic page in the list of dynamic pages */
    position?: number;
    /** The type of the current dynamic page */
    type: string;
  };
  AccountNewsletterRecipient: {
    /** @enum {string} */
    apiAlias: "account_newsletter_recipient";
    /** @enum {string} */
    status: "undefined" | "notSet" | "direct" | "optIn" | "optOut";
  };
  AclRole: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  AdvancedSearchAction: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  AdvancedSearchActionSearchTerm: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  AdvancedSearchBoosting: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  AdvancedSearchConfig: {
    /** Format: date-time */
    readonly createdAt?: string;
    hitCount?: {
      category?: {
        /** Format: int64 */
        maxSearchCount?: number;
        /** Format: int64 */
        maxSuggestCount?: number;
      };
      product?: {
        /** Format: int64 */
        maxSearchCount?: number;
        /** Format: int64 */
        maxSuggestCount?: number;
      };
      product_manufacturer?: {
        /** Format: int64 */
        maxSearchCount?: number;
        /** Format: int64 */
        maxSuggestCount?: number;
      };
    };
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  AdvancedSearchConfigField: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  AdvancedSearchEntityStream: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  AdvancedSearchEntityStreamFilter: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  AdvancedSearchSynonym: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  Aggregation:
    | components$1["schemas"]["AggregationMetrics"]
    | (components$1["schemas"]["AggregationEntity"] &
        components$1["schemas"]["SubAggregations"])
    | (components$1["schemas"]["AggregationFilter"] &
        components$1["schemas"]["SubAggregations"])
    | (components$1["schemas"]["AggregationTerms"] &
        components$1["schemas"]["SubAggregations"])
    | (components$1["schemas"]["AggregationHistogram"] &
        components$1["schemas"]["SubAggregations"])
    | (components$1["schemas"]["AggregationRange"] &
        components$1["schemas"]["SubAggregations"]);
  AggregationEntity: {
    /** The entity definition e.g "product_manufacturer". */
    definition: string;
    /** The field you want to aggregate over. */
    field: string;
    /** Give your aggregation an identifier, so you can find it easier */
    name: string;
    /**
     * The type of aggregation
     * @enum {string}
     */
    type: "entity";
  };
  AggregationFilter: {
    filter: components$1["schemas"]["Filters"][];
    /** Give your aggregation an identifier, so you can find it easier */
    name: string;
    /**
     * The type of aggregation
     * @enum {string}
     */
    type: "filter";
  };
  AggregationHistogram: {
    /** The field you want to aggregate over. */
    field: string;
    /** The format of the histogram */
    format?: string;
    /** The interval of the histogram */
    interval?: number;
    /** Give your aggregation an identifier, so you can find it easier */
    name: string;
    /** The timezone of the histogram */
    timeZone?: string;
    /**
     * The type of aggregation
     * @enum {string}
     */
    type: "histogram";
  };
  AggregationMetrics: {
    field: string;
    name: string;
    /** @enum {string} */
    type: "avg" | "count" | "max" | "min" | "stats" | "sum";
  };
  AggregationRange: {
    /** The field you want to aggregate over. */
    field: string;
    /** Give your aggregation an identifier, so you can find it easier */
    name: string;
    /** The ranges of the aggregation */
    ranges: (
      | {
          /** The lower bound of the range */
          from: number;
          /** The upper bound of the range */
          to: number;
        }
      | {
          /** The lower bound of the range */
          from: string;
        }
      | {
          /** The upper bound of the range */
          to: string;
        }
    )[];
    /**
     * The type of aggregation
     * @enum {string}
     */
    type: "range";
  };
  AggregationTerms: {
    /** The field you want to aggregate over. */
    field: string;
    /** The number of terms to return */
    limit?: number;
    /** Give your aggregation an identifier, so you can find it easier */
    name: string;
    /** Sorting the aggregation result. */
    sort?: components$1["schemas"]["Sort"][];
    /**
     * The type of aggregation
     * @enum {string}
     */
    type: "terms";
  };
  App: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  AppActionButton: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  AppAdministrationSnippet: {
    appId: string;
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    localeId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    value: string;
  };
  AppCmsBlock: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  AppFlowAction: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  AppFlowEvent: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  AppPaymentMethod: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  AppScriptCondition: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  AppShippingMethod: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  AppTemplate: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  AppointmentBasicSettingResponse: {
    /** The API alias of the appointment basic setting */
    apiAlias?: string;
    /** The name of the appointment */
    appointmentName?: string;
    /**
     * The type of attendee restriction
     * @enum {string}
     */
    attendeeRestrictionType?: "open" | "customer" | "rules";
    /** The booking link */
    bookingLink?: string | null;
    /**
     * Indicates if appointments can be booked
     * @default false
     */
    canBookAppointment?: boolean;
    /**
     * Indicates if request emails can be sent
     * @default false
     */
    canSendRequestEmail?: boolean;
    /**
     * The mode of the interaction
     * @enum {string}
     */
    mode?: "guided" | "self";
    /** The name of the sales channel */
    salesChannelName?: string;
    /**
     * The video and audio settings
     * @enum {string}
     */
    videoAudioSettings?: "none" | "both" | "audio-only";
  };
  ApprovalRule: {
    active?: boolean;
    businessPartnerCustomerId?: string;
    conditions?: {
      type?: string;
      value?: string;
    }[];
    description?: string;
    /** Format: uuid */
    id?: string;
    name?: string;
    priority?: number;
  };
  Association: {
    [key: string]: components$1["schemas"]["Association"];
  };
  Associations: {
    [key: string]: components$1["schemas"]["Criteria"];
  };
  AttendeeProductCollectionLastSeenResponse: {
    collection?: {
      lastSeen?: string[];
    };
  };
  AttendeeProductCollectionResponse: {
    collection?:
      | {
          liked?: string[];
        }
      | {
          disliked?: string[];
        };
  };
  AttendeeRespondInvitationResponse: {
    /**
     * The invitation status that client responded to
     * @enum {string}
     */
    answer?: "accepted" | "maybe" | "declined";
    appointment?: {
      /**
       * Format: date-time
       * The time the client can access the appointment
       */
      accessibleFrom?: string;
      /**
       * Format: date-time
       * The time the appointment will be closed, the client can not access
       */
      accessibleTo?: string;
      /** The appointment id */
      id?: string;
      /** The appointment status */
      status?: ("started" | "ended") | null;
    };
  };
  B2bBusinessPartner: {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  B2bComponentsApprovalRule: {
    affectedRole?: components$1["schemas"]["B2bComponentsRole"];
    affectedRoleId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    reviewerRole?: components$1["schemas"]["B2bComponentsRole"];
    reviewerRoleId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  B2bComponentsApprovalRuleAppScriptCondition: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  B2bComponentsPendingOrder: {
    addresses?: components$1["schemas"]["B2bComponentsPendingOrderAddress"][];
    /** Format: float */
    readonly amountNet?: number;
    /** Format: float */
    readonly amountTotal?: number;
    approvalRule?: components$1["schemas"]["B2bComponentsApprovalRule"];
    approvalRuleId?: string;
    billingAddress?: components$1["schemas"]["B2bComponentsPendingOrderAddress"];
    billingAddressId: string;
    country?: components$1["schemas"]["Country"];
    countryId: string;
    /** Format: date-time */
    readonly createdAt?: string;
    currency?: components$1["schemas"]["Currency"];
    currencyId: string;
    customer?: components$1["schemas"]["Customer"];
    customerId: string;
    customFields?: GenericRecord$1;
    decidedBy?: components$1["schemas"]["B2bEmployee"];
    decidedById?: string;
    employee?: components$1["schemas"]["B2bEmployee"];
    employeeId: string;
    id?: string;
    language?: components$1["schemas"]["Language"];
    languageId: string;
    order?: components$1["schemas"]["Order"];
    orderId?: string;
    /** Format: float */
    originalPrice?: number;
    paymentMethod?: components$1["schemas"]["PaymentMethod"];
    paymentMethodId: string;
    price?: {
      calculatedTaxes?: GenericRecord$1;
      /** Format: float */
      netPrice: number;
      /** Format: float */
      positionPrice: number;
      /** Format: float */
      rawTotal: number;
      taxRules?: GenericRecord$1;
      taxStatus: string;
      /** Format: float */
      totalPrice: number;
    };
    reason?: string;
    salesChannelId: string;
    shippingMethod?: components$1["schemas"]["ShippingMethod"];
    shippingMethodId: string;
    stateId: string;
    stateMachineState?: components$1["schemas"]["StateMachineState"];
    readonly taxStatus?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  B2bComponentsPendingOrderAddress: {
    additionalAddressLine1?: string;
    additionalAddressLine2?: string;
    city: string;
    company?: string;
    country?: components$1["schemas"]["Country"];
    countryId: string;
    countryState?: components$1["schemas"]["CountryState"];
    countryStateId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    department?: string;
    firstName: string;
    id: string;
    lastName: string;
    pendingOrder?: components$1["schemas"]["B2bComponentsPendingOrder"];
    phoneNumber?: string;
    salutation?: components$1["schemas"]["Salutation"];
    street: string;
    title?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    vatId?: string;
    zipcode?: string;
  };
  B2bComponentsRole: {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    /** Runtime field, cannot be used as part of the criteria. */
    default?: boolean;
    id: string;
    name: string;
    permissions?: GenericRecord$1[];
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  B2bComponentsShoppingList: {
    active?: boolean;
    /** Format: date-time */
    readonly createdAt?: string;
    createdById?: string;
    customer?: components$1["schemas"]["Customer"];
    customerId: string;
    customFields?: GenericRecord$1;
    employee?: components$1["schemas"]["B2bEmployee"];
    employeeId?: string;
    id: string;
    lineItems?: components$1["schemas"]["B2bComponentsShoppingListLineItem"][];
    name?: string;
    price?: components$1["schemas"]["Price"][];
    salesChannelId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    updatedById?: string;
  };
  B2bComponentsShoppingListJsonApi: components$1["schemas"]["resource"] & {
    active?: boolean;
    /** Format: date-time */
    readonly createdAt?: string;
    createdById?: string;
    customerId: string;
    customFields?: GenericRecord$1;
    employeeId?: string;
    id: string;
    name?: string;
    price?: components$1["schemas"]["Price"][];
    relationships?: {
      customer?: {
        data?: {
          /** @example 91ec1f9324753048c0096d036a694f86 */
          id?: string;
          /** @example customer */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /b2b-components-shopping-list/23cb3bfda723e05b43cb25a427ee5a25/customer
           */
          related?: string;
        };
      };
      employee?: {
        data?: {
          /** @example fa5473530e4d1a5a1e1eb53d2fedb10c */
          id?: string;
          /** @example b2b_employee */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /b2b-components-shopping-list/23cb3bfda723e05b43cb25a427ee5a25/employee
           */
          related?: string;
        };
      };
      lineItems?: {
        data?: {
          /** @example a042af1aa9f3853fe3cd7dabc065568f */
          id?: string;
          /** @example b2b_components_shopping_list_line_item */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /b2b-components-shopping-list/23cb3bfda723e05b43cb25a427ee5a25/lineItems
           */
          related?: string;
        };
      };
    };
    salesChannelId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    updatedById?: string;
  };
  B2bComponentsShoppingListLineItem: {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    price?: components$1["schemas"]["Price"][];
    product?: components$1["schemas"]["Product"];
    productId?: string;
    productVersionId?: string;
    /** Format: int64 */
    quantity: number;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  B2bComponentsShoppingListLineItemJsonApi: components$1["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    price?: components$1["schemas"]["Price"][];
    productId?: string;
    productVersionId?: string;
    /** Format: int64 */
    quantity: number;
    relationships?: {
      product?: {
        data?: {
          /** @example f5bf48aa40cad7891eb709fcf1fde128 */
          id?: string;
          /** @example product */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /b2b-components-shopping-list-line-item/30d48c8d92682de24e11d3f72c5dd1ea/product
           */
          related?: string;
        };
      };
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  B2bEmployee: {
    active?: boolean;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    email: string;
    firstName: string;
    id: string;
    language?: components$1["schemas"]["Language"];
    languageId: string;
    lastName: string;
    role?: components$1["schemas"]["B2bComponentsRole"];
    status?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  B2bOrderEmployee: {
    /** Format: date-time */
    readonly createdAt?: string;
    firstName: string;
    id?: string;
    lastName: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  B2bPermission: {
    /** Format: date-time */
    readonly createdAt?: string;
    dependencies?: string[];
    group: string;
    id: string;
    name: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  BaseInteraction: {
    /**
     * The time in seconds how long the interaction should be stored in the database
     * @default -1
     */
    lifeTimeInSeconds?: number;
    /**
     * The time when the interaction was triggered
     * @default now
     */
    triggeredAt?: string;
  };
  BasePresentationSlideData: {
    cmsPage?: components$1["schemas"]["CmsPage"];
    extensions?: {
      cmsPageRelation?: components$1["schemas"]["PresentationCmsPage"];
    };
  };
  Breadcrumb: {
    /** @enum {string} */
    apiAlias: "breadcrumb";
    categoryId: string;
    name: string;
    path: string;
    seoUrls?: components$1["schemas"]["SeoUrl"][];
    translated: {
      categoryId: string;
      customFields?: GenericRecord$1;
      description?: string;
      externalLink?: string;
      internalLink?: string;
      keywords?: string;
      linkNewTab?: boolean;
      /** @enum {string} */
      linkType?: "category" | "external" | "landing_page" | "product";
      metaDescription?: string;
      metaTitle?: string;
      name: string;
      path: string;
      slotConfig?: GenericRecord$1;
      type: string;
    };
    /** @enum {string} */
    type: "page" | "link" | "folder";
  };
  BreadcrumbCollection: components$1["schemas"]["Breadcrumb"][];
  CalculatedPrice: {
    /** @enum {string} */
    apiAlias: "calculated_price";
    calculatedTaxes: {
      /** @enum {string} */
      apiAlias: "cart_tax_calculated";
      price: number;
      tax: number;
      taxRate: number;
    }[];
    hasRange: boolean;
    listPrice: components$1["schemas"]["CartListPrice"] | null;
    netPrice: number;
    positionPrice: number;
    quantity: number;
    rawTotal: number;
    referencePrice: components$1["schemas"]["CartPriceReference"] | null;
    regulationPrice: {
      /** @enum {string} */
      apiAlias?: "cart_regulation_price";
      price?: number;
    } | null;
    /** Currently active tax rules and/or rates */
    taxRules: {
      name?: string;
      /** Format: float */
      taxRate?: number;
    }[];
    /** @enum {string} */
    taxStatus: "net" | "tax-free";
    totalPrice: number;
    unitPrice: number;
    /** Format: ^[0-9a-f]{32}$ */
    variantId?: string | null;
  };
  Cart: {
    /** An affiliate tracking code */
    affiliateCode?: string | null;
    /** @enum {string} */
    apiAlias: "cart";
    /** A campaign tracking code */
    campaignCode?: string | null;
    /** A comment that can be added to the cart. */
    customerComment?: string | null;
    deliveries?: components$1["schemas"]["CartDelivery"][];
    /** A list of all cart errors, such as insufficient stocks, invalid addresses or vouchers. */
    errors?:
      | components$1["schemas"]["CartError"][]
      | {
          [key: string]: {
            code: number;
            key: string;
            level: number;
            message: string;
            messageKey: string;
          };
        };
    /** All items within the cart */
    lineItems?: components$1["schemas"]["LineItem"][];
    modified?: boolean;
    /** Name of the cart - for example `guest-cart` */
    name?: string;
    price: components$1["schemas"]["CalculatedPrice"];
    /** Context token identifying the cart and the user session */
    token?: string;
    /** A list of all payment transactions associated with the current cart. */
    transactions?: {
      amount?: components$1["schemas"]["CalculatedPrice"];
      paymentMethodId?: string;
    }[];
  };
  CartDelivery: {
    deliveryDate?: {
      /** Format: date-time */
      earliest?: string;
      /** Format: date-time */
      latest?: string;
    };
    location?: {
      address?: components$1["schemas"]["CustomerAddress"];
      /** @enum {string} */
      apiAlias?: "cart_delivery_shipping_location";
      country?: components$1["schemas"]["Country"];
      state?: components$1["schemas"]["CountryState"];
    };
    positions?: components$1["schemas"]["CartDeliveryPosition"][];
    shippingCosts?: components$1["schemas"]["CalculatedPrice"];
    shippingMethod?: components$1["schemas"]["ShippingMethod"];
  };
  CartDeliveryInformation: {
    /** @enum {string} */
    apiAlias: "cart_delivery_information";
    deliveryTime?: {
      /** @enum {string} */
      apiAlias?: "cart_delivery_time";
      max?: number;
      min?: number;
      name?: string;
      unit?: string;
    };
    freeDelivery?: boolean;
    height?: number;
    length?: number;
    restockTime?: number;
    stock?: number;
    weight?: number;
    width?: number;
  };
  CartDeliveryPosition: {
    deliveryDate?: {
      /** Format: date-time */
      earliest?: string;
      /** Format: date-time */
      latest?: string;
    };
    identifier?: string;
    lineItem?: components$1["schemas"]["LineItem"];
    price?: components$1["schemas"]["CalculatedPrice"];
  };
  CartError: {
    key: string;
    /**
     * * `0` - notice,
     *     * `10` - warning,
     *     * `20` - error
     * @enum {number}
     */
    level: 0 | 10 | 20;
    message: string;
    messageKey: string;
  };
  CartItems: {
    items: components$1["schemas"]["LineItem"][];
  };
  CartListPrice: {
    /** @enum {string} */
    apiAlias: "cart_list_price";
    discount?: number;
    percentage?: number;
    price?: number;
  };
  CartPriceQuantity: {
    /** @enum {string} */
    apiAlias: "cart_price_quantity";
    isCalculated?: boolean;
    listPrice?: components$1["schemas"]["CartListPrice"];
    price?: number;
    quantity?: number;
    regulationPrice?: {
      /** Format: float */
      price?: number;
    };
    taxRules?: {
      name?: string;
      /** Format: float */
      taxRate?: number;
    }[];
    type?: string;
  };
  CartPriceReference: {
    /** @enum {string} */
    apiAlias: "cart_price_reference";
    hasRange: boolean;
    listPrice: components$1["schemas"]["CartListPrice"] | null;
    price?: number;
    purchaseUnit?: number;
    referenceUnit?: number;
    regulationPrice: {
      /** @enum {string} */
      apiAlias?: "cart_regulation_price";
      price?: number;
    } | null;
    unitName: string;
    /** Format: ^[0-9a-f]{32}$ */
    variantId?: string | null;
  };
  Category: {
    active?: boolean;
    afterCategoryId?: string;
    afterCategoryVersionId?: string;
    /** @enum {string} */
    apiAlias: "category";
    breadcrumb: string[];
    /** Format: int64 */
    readonly childCount: number;
    children: components$1["schemas"]["Category"][];
    cmsPage?: components$1["schemas"]["CmsPage"];
    cmsPageId?: string;
    /** Runtime field, cannot be used as part of the criteria. */
    cmsPageIdSwitched?: boolean;
    cmsPageVersionId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customEntityTypeId?: string;
    customFields?: GenericRecord$1;
    description?: string;
    displayNestedProducts?: boolean;
    externalLink?: string;
    id: string;
    internalLink?: string;
    keywords?: string;
    /** Format: int64 */
    readonly level?: number;
    linkNewTab?: boolean;
    linkType?: string;
    media?: components$1["schemas"]["Media"];
    mediaId?: string;
    metaDescription?: string;
    metaTitle?: string;
    name: string;
    parent?: components$1["schemas"]["Category"];
    parentId?: string;
    parentVersionId?: string;
    readonly path?: string;
    productAssignmentType?: string;
    seoUrls?: components$1["schemas"]["SeoUrl"][];
    tags?: components$1["schemas"]["Tag"][];
    translated: {
      afterCategoryId: string;
      afterCategoryVersionId: string;
      breadcrumb: string[];
      cmsPageId: string;
      cmsPageVersionId: string;
      customEntityTypeId: string;
      description: string;
      externalLink: string;
      internalLink: string;
      keywords: string;
      linkType: string;
      mediaId: string;
      metaDescription: string;
      metaTitle: string;
      name: string;
      parentId: string;
      parentVersionId: string;
      path: string;
      productAssignmentType: string;
      type: string;
      versionId: string;
    };
    /** @enum {string} */
    type: "page" | "link";
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
    visible?: boolean;
    /**
     * Format: int64
     * Runtime field, cannot be used as part of the criteria.
     */
    visibleChildCount?: number;
  };
  CategoryJsonApi: components$1["schemas"]["resource"] & {
    active?: boolean;
    afterCategoryId?: string;
    afterCategoryVersionId?: string;
    readonly breadcrumb?: GenericRecord$1[];
    /** Format: int64 */
    readonly childCount?: number;
    cmsPageId?: string;
    /** Runtime field, cannot be used as part of the criteria. */
    cmsPageIdSwitched?: boolean;
    cmsPageVersionId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customEntityTypeId?: string;
    customFields?: GenericRecord$1;
    description?: string;
    displayNestedProducts?: boolean;
    externalLink?: string;
    id: string;
    internalLink?: string;
    keywords?: string;
    /** Format: int64 */
    readonly level?: number;
    linkNewTab?: boolean;
    linkType?: string;
    mediaId?: string;
    metaDescription?: string;
    metaTitle?: string;
    name: string;
    parentId?: string;
    parentVersionId?: string;
    readonly path?: string;
    productAssignmentType?: string;
    relationships?: {
      children?: {
        data?: {
          /** @example 268184c12df027f536154d099d497b31 */
          id?: string;
          /** @example category */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /category/3adbdb3ac060038aa0e6e6c138ef9873/children
           */
          related?: string;
        };
      };
      cmsPage?: {
        data?: {
          /** @example 7b1460918b1abb93311108f3dc021c9b */
          id?: string;
          /** @example cms_page */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /category/3adbdb3ac060038aa0e6e6c138ef9873/cmsPage
           */
          related?: string;
        };
      };
      media?: {
        data?: {
          /** @example 62933a2951ef01f4eafd9bdf4d3cd2f0 */
          id?: string;
          /** @example media */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /category/3adbdb3ac060038aa0e6e6c138ef9873/media
           */
          related?: string;
        };
      };
      parent?: {
        data?: {
          /** @example d0e45878043844ffc41aac437e86b602 */
          id?: string;
          /** @example category */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /category/3adbdb3ac060038aa0e6e6c138ef9873/parent
           */
          related?: string;
        };
      };
      seoUrls?: {
        data?: {
          /** @example 5321b5a71127b8b98cdd4b068ad56c4c */
          id?: string;
          /** @example seo_url */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /category/3adbdb3ac060038aa0e6e6c138ef9873/seoUrls
           */
          related?: string;
        };
      };
      tags?: {
        data?: {
          /** @example d57ac45256849d9b13e2422d91580fb9 */
          id?: string;
          /** @example tag */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /category/3adbdb3ac060038aa0e6e6c138ef9873/tags
           */
          related?: string;
        };
      };
    };
    translated: {
      afterCategoryId: string;
      afterCategoryVersionId: string;
      cmsPageId: string;
      cmsPageVersionId: string;
      customEntityTypeId: string;
      description: string;
      externalLink: string;
      internalLink: string;
      keywords: string;
      linkType: string;
      mediaId: string;
      metaDescription: string;
      metaTitle: string;
      name: string;
      parentId: string;
      parentVersionId: string;
      path: string;
      productAssignmentType: string;
      type: string;
      versionId: string;
    };
    type?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
    visible?: boolean;
    /**
     * Format: int64
     * Runtime field, cannot be used as part of the criteria.
     */
    visibleChildCount?: number;
  };
  ClientPresentationStateResponse: {
    stateForAll?: components$1["schemas"]["StateForAll"];
    stateForClients?: components$1["schemas"]["StateForClients"];
  };
  CmsBlock: {
    /** @enum {string} */
    apiAlias: "cms_block";
    backgroundColor?: string;
    backgroundMedia?: components$1["schemas"]["Media"];
    backgroundMediaId?: string;
    backgroundMediaMode?: string;
    cmsSectionVersionId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    cssClass?: string;
    customFields?: GenericRecord$1;
    extensions?: {
      swagCmsExtensionsBlockRule?: {
        data?: {
          /** @example c426e9e5d9031b933f89682d49bb02b1 */
          id?: string;
          /** @example swag_cms_extensions_block_rule */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /cms-block/9c16ffe823ddccc710bfb336c2ef30b6/swagCmsExtensionsBlockRule
           */
          related?: string;
        };
      };
      swagCmsExtensionsQuickview?: {
        data?: {
          /** @example fae098a43df8714eda5249176ffcf26c */
          id?: string;
          /** @example swag_cms_extensions_quickview */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /cms-block/9c16ffe823ddccc710bfb336c2ef30b6/swagCmsExtensionsQuickview
           */
          related?: string;
        };
      };
    };
    id?: string;
    marginBottom?: string;
    marginLeft?: string;
    marginRight?: string;
    marginTop?: string;
    name?: string;
    /** Format: int64 */
    position: number;
    sectionId: string;
    sectionPosition?: string;
    slots: components$1["schemas"]["CmsSlot"][];
    type: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
    visibility?: {
      desktop?: boolean;
      mobile?: boolean;
      tablet?: boolean;
    };
  };
  CmsPage: {
    /** @enum {string} */
    apiAlias: "cms_page";
    config?: {
      backgroundColor?: string;
    };
    /** Format: date-time */
    readonly createdAt?: string;
    cssClass?: string;
    customFields?: GenericRecord$1;
    entity?: string;
    extensions?: {
      swagCmsExtensionsScrollNavigationPageSettings?: {
        data?: {
          /** @example 8b835206d09f3dec1b733f6a78c7ba33 */
          id?: string;
          /** @example swag_cms_extensions_scroll_navigation_page_settings */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /cms-page/64bf107168bcd03626208c1764ce6890/swagCmsExtensionsScrollNavigationPageSettings
           */
          related?: string;
        };
      };
    };
    id: string;
    landingPages?: components$1["schemas"]["LandingPage"][];
    name?: string;
    previewMedia?: components$1["schemas"]["Media"];
    previewMediaId?: string;
    sections: components$1["schemas"]["CmsSection"][];
    translated: {
      cssClass: string;
      entity: string;
      name: string;
      previewMediaId: string;
      type: string;
      versionId: string;
    };
    type: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  CmsPageActivity: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  CmsPageDraft: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  CmsSection: {
    /** @enum {string} */
    apiAlias: "cms_section";
    backgroundColor?: string;
    backgroundMedia?: components$1["schemas"]["Media"];
    backgroundMediaId?: string;
    backgroundMediaMode?: string;
    blocks: components$1["schemas"]["CmsBlock"][];
    cmsPageVersionId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    cssClass?: string;
    customFields?: GenericRecord$1;
    extensions?: {
      swagCmsExtensionsScrollNavigation?: {
        data?: {
          /** @example 425b8d6ec722d74191c6d39370af19dc */
          id?: string;
          /** @example swag_cms_extensions_scroll_navigation */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /cms-section/d08def49fa8924d6f4a32bdb448d5fba/swagCmsExtensionsScrollNavigation
           */
          related?: string;
        };
      };
    };
    id?: string;
    mobileBehavior?: string;
    name?: string;
    page?: components$1["schemas"]["CmsPage"];
    pageId: string;
    /** Format: int64 */
    position: number;
    sizingMode?: string;
    /** @enum {string} */
    type: "default" | "sidebar";
    /** Format: date-time */
    readonly updatedAt?: string;
    visibility?: {
      desktop?: boolean;
      mobile?: boolean;
      tablet?: boolean;
    };
  };
  CmsSlot: {
    /** @enum {string} */
    apiAlias: "cms_slot";
    block?: components$1["schemas"]["CmsBlock"];
    blockId: string;
    cmsBlockVersionId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: {
      _uniqueIdentifier?: string;
    };
    extensions?: {
      swagCmsExtensionsForm?: {
        data?: {
          /** @example 0654ad514da002e9d77fa24ee33acd95 */
          id?: string;
          /** @example swag_cms_extensions_form */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /cms-slot/ac5ca6960137c6b8a97c90c11b71d4bb/swagCmsExtensionsForm
           */
          related?: string;
        };
      };
    };
    fieldConfig?: GenericRecord$1;
    id: string;
    locked?: boolean;
    slot: string;
    translated: {
      blockId: string;
      cmsBlockVersionId: string;
      config?: {
        content?: {
          value?: string;
        };
      };
      slot: string;
      type: string;
      versionId: string;
    };
    type: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  Country: {
    active?: boolean;
    addressFormat: GenericRecord$1;
    advancedPostalCodePattern?: string;
    checkAdvancedPostalCodePattern?: boolean;
    checkPostalCodePattern?: boolean;
    checkVatIdPattern?: boolean;
    companyTax?: {
      /** Format: float */
      amount: number;
      currencyId: string;
      enabled: boolean;
    };
    /** Format: date-time */
    readonly createdAt?: string;
    customerTax?: {
      /** Format: float */
      amount: number;
      currencyId: string;
      enabled: boolean;
    };
    customFields?: GenericRecord$1;
    defaultPostalCodePattern?: string;
    displayStateInRegistration?: boolean;
    forceStateInRegistration?: boolean;
    id: string;
    isEu?: boolean;
    iso?: string;
    iso3?: string;
    name: string;
    /** Format: int64 */
    position?: number;
    postalCodeRequired?: boolean;
    shippingAvailable?: boolean;
    states?: components$1["schemas"]["CountryState"][];
    translated: {
      advancedPostalCodePattern: string;
      defaultPostalCodePattern: string;
      iso: string;
      iso3: string;
      name: string;
      vatIdPattern: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    vatIdPattern?: string;
    vatIdRequired?: boolean;
  };
  CountryJsonApi: components$1["schemas"]["resource"] & {
    active?: boolean;
    addressFormat: GenericRecord$1;
    advancedPostalCodePattern?: string;
    checkAdvancedPostalCodePattern?: boolean;
    checkPostalCodePattern?: boolean;
    checkVatIdPattern?: boolean;
    companyTax?: {
      /** Format: float */
      amount: number;
      currencyId: string;
      enabled: boolean;
    };
    /** Format: date-time */
    readonly createdAt?: string;
    customerTax?: {
      /** Format: float */
      amount: number;
      currencyId: string;
      enabled: boolean;
    };
    customFields?: GenericRecord$1;
    defaultPostalCodePattern?: string;
    displayStateInRegistration?: boolean;
    forceStateInRegistration?: boolean;
    id: string;
    isEu?: boolean;
    iso?: string;
    iso3?: string;
    name: string;
    /** Format: int64 */
    position?: number;
    postalCodeRequired?: boolean;
    relationships?: {
      states?: {
        data?: {
          /** @example 34d955a0df5f7af9c9b4e4dccb3c3564 */
          id?: string;
          /** @example country_state */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /country/59716c97497eb9694541f7c3d37b1a4d/states
           */
          related?: string;
        };
      };
    };
    shippingAvailable?: boolean;
    translated: {
      advancedPostalCodePattern: string;
      defaultPostalCodePattern: string;
      iso: string;
      iso3: string;
      name: string;
      vatIdPattern: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    vatIdPattern?: string;
    vatIdRequired?: boolean;
  };
  CountryState: {
    active?: boolean;
    countryId: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    id: string;
    name: string;
    /** Format: int64 */
    position?: number;
    shortCode: string;
    translated: {
      countryId: string;
      name: string;
      shortCode: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  CountryStateJsonApi: components$1["schemas"]["resource"] & {
    active?: boolean;
    countryId: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    id: string;
    name: string;
    /** Format: int64 */
    position?: number;
    shortCode: string;
    translated: {
      countryId: string;
      name: string;
      shortCode: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  CreateAppointmentRequestBody: {
    /** The company name of the requester */
    companyName?: string;
    /**
     * Format: email
     * The email address of the requester
     */
    emailAddress: string;
    /** The first name of the requester */
    firstName: string;
    /** The last name of the requester */
    lastName: string;
    /** The message of the appointment */
    message?: string;
    /** The phone number of the requester */
    phoneNumber?: string;
    /** The id of the salutation */
    salutationId: string;
    /** The subject of the appointment */
    subject: string;
  };
  CreateInteractionRequestBody: components$1["schemas"]["DynamicInteractionBody"];
  Criteria: {
    aggregations?: components$1["schemas"]["Aggregation"][];
    associations?: components$1["schemas"]["Association"];
    /** Fields which should be returned in the search result. */
    fields?: string[];
    /** List of filters to restrict the search result. For more information, see [Search Queries > Filter](https://shopware.stoplight.io/docs/store-api/docs/concepts/search-queries.md#filter) */
    filter?: (
      | components$1["schemas"]["SimpleFilter"]
      | components$1["schemas"]["EqualsFilter"]
      | components$1["schemas"]["MultiNotFilter"]
      | components$1["schemas"]["RangeFilter"]
    )[];
    /** Perform groupings over certain fields */
    grouping?: string[];
    /** List of ids to search for */
    ids?: string[];
    includes?: components$1["schemas"]["Includes"];
    /** Number of items per result page */
    limit?: number;
    /** Search result page */
    page?: number;
    /** Filters that applied without affecting aggregations. For more information, see [Search Queries > Post Filter](https://shopware.stoplight.io/docs/store-api/docs/concepts/search-queries.md#post-filter) */
    "post-filter"?: (
      | components$1["schemas"]["SimpleFilter"]
      | components$1["schemas"]["EqualsFilter"]
      | components$1["schemas"]["MultiNotFilter"]
      | components$1["schemas"]["RangeFilter"]
    )[];
    /** The query string to search for */
    query?: string;
    /** Sorting in the search result. */
    sort?: components$1["schemas"]["Sort"][];
    /** Search term */
    term?: string;
    "total-count-mode"?: components$1["schemas"]["TotalCountMode"];
  };
  CrossSellingElement: {
    /** @enum {string} */
    apiAlias: "cross_selling_element";
    crossSelling: components$1["schemas"]["ProductCrossSelling"];
    products: components$1["schemas"]["Product"][];
    /** Format: uuid */
    streamId?: string;
    /** Format: int32 */
    total: number;
  };
  CrossSellingElementCollection: components$1["schemas"]["CrossSellingElement"][];
  Currency: {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    /** Format: float */
    factor: number;
    id: string;
    isoCode: string;
    /** Runtime field, cannot be used as part of the criteria. */
    isSystemDefault?: boolean;
    itemRounding: {
      /** Format: int64 */
      decimals: number;
      /** Format: float */
      interval: number;
      roundForNet: boolean;
    };
    name: string;
    /** Format: int64 */
    position?: number;
    shortName: string;
    symbol: string;
    /** Format: float */
    taxFreeFrom?: number;
    totalRounding: {
      /** Format: int64 */
      decimals: number;
      /** Format: float */
      interval: number;
      roundForNet: boolean;
    };
    translated: {
      isoCode: string;
      name: string;
      shortName: string;
      symbol: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  CurrencyCountryRounding: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  CurrencyJsonApi: components$1["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    /** Format: float */
    factor: number;
    id: string;
    isoCode: string;
    /** Runtime field, cannot be used as part of the criteria. */
    isSystemDefault?: boolean;
    itemRounding: {
      /** Format: int64 */
      decimals: number;
      /** Format: float */
      interval: number;
      roundForNet: boolean;
    };
    name: string;
    /** Format: int64 */
    position?: number;
    shortName: string;
    symbol: string;
    /** Format: float */
    taxFreeFrom?: number;
    totalRounding: {
      /** Format: int64 */
      decimals: number;
      /** Format: float */
      interval: number;
      roundForNet: boolean;
    };
    translated: {
      isoCode: string;
      name: string;
      shortName: string;
      symbol: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  CustomEntity: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  CustomField: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  CustomFieldSet: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  CustomFieldSetRelation: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  CustomPrice: {
    /** Format: date-time */
    readonly createdAt?: string;
    customer?: components$1["schemas"]["Customer"];
    customerGroup?: components$1["schemas"]["CustomerGroup"];
    customerGroupId?: string;
    customerId?: string;
    id: string;
    price: GenericRecord$1;
    product?: components$1["schemas"]["Product"];
    productId: string;
    productVersionId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  Customer: {
    active?: boolean;
    activeBillingAddress: components$1["schemas"]["CustomerAddress"];
    activeShippingAddress: components$1["schemas"]["CustomerAddress"];
    addresses?: components$1["schemas"]["CustomerAddress"][];
    affiliateCode?: string;
    /** @enum {string} */
    apiAlias: "customer";
    birthday?: string;
    campaignCode?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    createdById?: string;
    customerNumber: string;
    customFields?: GenericRecord$1;
    defaultBillingAddress?: components$1["schemas"]["CustomerAddress"];
    defaultBillingAddressId: string;
    defaultPaymentMethod?: components$1["schemas"]["PaymentMethod"];
    defaultPaymentMethodId: string;
    defaultShippingAddress?: components$1["schemas"]["CustomerAddress"];
    defaultShippingAddressId: string;
    /** Format: date-time */
    doubleOptInConfirmDate?: string;
    /** Format: date-time */
    doubleOptInEmailSentDate?: string;
    doubleOptInRegistration?: boolean;
    email: string;
    extensions?: {
      specificFeatures?: {
        data?: {
          /** @example 5cfb6fcb7542e25892e1a35cd6a06c54 */
          id?: string;
          /** @example customer_specific_features */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /customer/ce26601dac0dea138b7295f02b7620a7/specificFeatures
           */
          related?: string;
        };
      };
    };
    /** Format: date-time */
    firstLogin?: string;
    firstName: string;
    group?: components$1["schemas"]["CustomerGroup"];
    groupId: string;
    guest?: boolean;
    hash?: string;
    id: string;
    language?: components$1["schemas"]["Language"];
    languageId: string;
    /** Format: date-time */
    lastLogin?: string;
    lastName: string;
    /** Format: date-time */
    readonly lastOrderDate?: string;
    lastPaymentMethod?: components$1["schemas"]["PaymentMethod"];
    lastPaymentMethodId?: string;
    /** Format: int64 */
    readonly orderCount?: number;
    /** Format: float */
    readonly orderTotalAmount?: number;
    /** Format: int64 */
    readonly reviewCount?: number;
    salesChannelId: string;
    salutation?: components$1["schemas"]["Salutation"];
    salutationId?: string;
    readonly tagIds?: string[];
    tags?: components$1["schemas"]["Tag"][];
    title?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    updatedById?: string;
  } & (
    | {
        /** @enum {string} */
        accountType: "private";
      }
    | {
        /** @enum {string} */
        accountType: "business";
        company: string;
        vatIds: [string, ...string[]];
      }
    | {
        /** @enum {string} */
        accountType: "private";
      }
    | {
        /** @enum {string} */
        accountType: "business";
        company: string;
        vatIds: [string, ...string[]];
      }
  );
  CustomerAddress: {
    additionalAddressLine1?: string;
    additionalAddressLine2?: string;
    city: string;
    company?: string;
    country?: components$1["schemas"]["Country"];
    countryId: string;
    countryState?: components$1["schemas"]["CountryState"];
    countryStateId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customerId: string;
    customFields?: GenericRecord$1;
    department?: string;
    firstName: string;
    id: string;
    lastName: string;
    phoneNumber?: string;
    salutation?: components$1["schemas"]["Salutation"];
    salutationId?: string;
    street: string;
    title?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    zipcode?: string;
  };
  CustomerAddressBody: {
    additionalAddressLine1?: string;
    additionalAddressLine2?: string;
    city: string;
    company?: string;
    country?: components$1["schemas"]["Country"];
    countryId: string;
    countryState?: components$1["schemas"]["CountryState"];
    countryStateId?: string;
    customFields?: GenericRecord$1;
    department?: string;
    firstName: string;
    lastName: string;
    phoneNumber?: string;
    salutation?: components$1["schemas"]["Salutation"];
    salutationId?: string;
    street: string;
    title?: string;
    zipcode?: string;
  };
  CustomerAddressRead: {
    country: components$1["schemas"]["Country"];
    countryState?: components$1["schemas"]["CountryState"];
    /** Format: date-time */
    createdAt: string;
    readonly customerId: string;
    readonly id?: string;
    salutation: components$1["schemas"]["Salutation"];
    /** Format: date-time */
    updatedAt: string | null;
  };
  CustomerGroup: {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    displayGross?: boolean;
    id: string;
    name: string;
    registrationActive?: boolean;
    registrationIntroduction?: string;
    registrationOnlyCompanyRegistration?: boolean;
    registrationSeoMetaDescription?: string;
    registrationTitle?: string;
    translated: {
      name: string;
      registrationIntroduction: string;
      registrationSeoMetaDescription: string;
      registrationTitle: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  CustomerRecovery: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  CustomerSpecificFeatures: {
    /** Format: date-time */
    readonly createdAt?: string;
    customer?: components$1["schemas"]["Customer"];
    customerId: string;
    features: GenericRecord$1;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  CustomerTag: {
    customerId: string;
    id?: string;
    tag?: components$1["schemas"]["Tag"];
    tagId: string;
  };
  CustomerWishlist: {
    /** Format: date-time */
    readonly createdAt?: string;
    customerId: string;
    customFields?: GenericRecord$1;
    id: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  CustomerWishlistProduct: {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    productId: string;
    productVersionId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  DeliveryInformation: unknown;
  DeliveryTime: {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    id: string;
    /** Format: int64 */
    max: number;
    /** Format: int64 */
    min: number;
    name: string;
    translated: {
      name: string;
      unit: string;
    };
    unit: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  DiscountLineItemPayload: {
    /** Format: float */
    discountPrice?: number;
    /** @enum {string} */
    discountType?: "percentage" | "absolute";
    /** Format: float */
    discountValue?: number;
  };
  Document: {
    config: {
      name: string;
      title: string;
    };
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    deepLinkCode: string;
    dependentDocuments?: components$1["schemas"]["Document"][];
    documentA11yMediaFile?: components$1["schemas"]["Media"];
    documentA11yMediaFileId?: string;
    documentMediaFile?: components$1["schemas"]["Media"];
    documentMediaFileId?: string;
    documentNumber?: string;
    documentType?: components$1["schemas"]["DocumentType"];
    documentTypeId: string;
    fileType: string;
    id: string;
    order?: components$1["schemas"]["Order"];
    orderId: string;
    orderVersionId?: string;
    referencedDocument?: components$1["schemas"]["Document"];
    referencedDocumentId?: string;
    sent?: boolean;
    static?: boolean;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  DocumentBaseConfig: {
    config?: GenericRecord$1;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    documentNumber?: string;
    documentTypeId: string;
    filenamePrefix?: string;
    filenameSuffix?: string;
    global?: boolean;
    id: string;
    logo?: components$1["schemas"]["Media"];
    logoId?: string;
    name: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  DocumentBaseConfigSalesChannel: {
    /** Format: date-time */
    readonly createdAt?: string;
    documentBaseConfigId: string;
    documentTypeId?: string;
    id: string;
    salesChannelId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  DocumentType: {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    id: string;
    name: string;
    technicalName: string;
    translated: {
      name: string;
      technicalName: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  DsrAppointment: {
    /** Format: date-time */
    accessibleFrom?: string;
    /** Format: date-time */
    accessibleTo?: string;
    active?: boolean;
    attendeeRuleIds?: GenericRecord$1;
    /** Format: date-time */
    readonly createdAt?: string;
    createdById: string;
    customFields?: GenericRecord$1;
    default?: boolean;
    dsrPresentationVersionId?: string;
    /** Format: date-time */
    endedAt?: string;
    guideUserId?: string;
    id?: string;
    isPreview?: boolean;
    name: string;
    presentationId: string;
    salesChannelDomainId: string;
    /** Format: date-time */
    startedAt?: string;
    translated: {
      accessibleFrom: string;
      accessibleTo: string;
      createdById: string;
      dsrPresentationVersionId: string;
      endedAt: string;
      guideUserId: string;
      name: string;
      presentationId: string;
      salesChannelDomainId: string;
      startedAt: string;
      updatedById: string;
      videoAudioSettings: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    updatedById?: string;
    videoAudioSettings?: string;
    videoChat?: components$1["schemas"]["DsrAppointmentVideoChat"];
  };
  DsrAppointmentAttendee: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    isBlocked?: boolean;
    /** Format: date-time */
    joinedAt?: string;
    /** Format: date-time */
    lastActive?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  DsrAppointmentRequest: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  DsrAppointmentVideoChat: {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    id?: string;
    name?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    url?: string;
  };
  DsrAttendeeProductCollection: {
    attendeeId: string;
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    productId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  DsrCmsSlide: {
    cmsSection?: components$1["schemas"]["CmsSection"];
    cmsSectionId: string;
    cmsSectionVersionId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    slideName: string;
    translated: {
      cmsSectionId: string;
      cmsSectionVersionId: string;
      slideName: string;
      versionId: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  DsrInteraction: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  DsrPresentation: {
    active?: boolean;
    appointments?: components$1["schemas"]["DsrAppointment"][];
    cmsPages?: components$1["schemas"]["DsrPresentationCmsPage"][];
    /** Format: date-time */
    readonly createdAt?: string;
    createdById: string;
    customFields?: GenericRecord$1;
    id: string;
    name: string;
    parent?: components$1["schemas"]["DsrPresentation"];
    parentId?: string;
    parentVersionId?: string;
    translated: {
      createdById: string;
      name: string;
      parentId: string;
      parentVersionId: string;
      updatedById: string;
      versionId: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    updatedById?: string;
    versionId?: string;
  };
  DsrPresentationCmsPage: {
    cmsPage?: components$1["schemas"]["CmsPage"];
    cmsPageId: string;
    cmsPageVersionId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    dsrPresentationVersionId?: string;
    id: string;
    isInstantListing?: boolean;
    pickedProductIds?: GenericRecord$1;
    /** Format: int64 */
    position?: number;
    presentationId: string;
    productId?: string;
    productStreamId?: string;
    productVersionId?: string;
    title?: string;
    translated: {
      cmsPageId: string;
      cmsPageVersionId: string;
      dsrPresentationVersionId: string;
      presentationId: string;
      productId: string;
      productStreamId: string;
      productVersionId: string;
      title: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  DynamicInteractionBody:
    | components$1["schemas"]["EmptyInteraction"]
    | components$1["schemas"]["ProductInteraction"]
    | components$1["schemas"]["DynamicPageOpenedInteraction"]
    | components$1["schemas"]["DynamicPageClosedInteraction"]
    | components$1["schemas"]["DynamicProductPageOpenedInteraction"]
    | components$1["schemas"]["PageViewedInteraction"]
    | components$1["schemas"]["GuideHoveredInteraction"]
    | components$1["schemas"]["ToggleBroadcastModeInteraction"]
    | components$1["schemas"]["ViewModeChangedInteraction"]
    | components$1["schemas"]["ScreenSharingToggledInteraction"];
  DynamicPageClosedInteraction: components$1["schemas"]["BaseInteraction"] & {
    name: string;
    payload: components$1["schemas"]["DynamicPageClosedPayload"];
  } & {
    /**
     * discriminator enum property added by openapi-typescript
     * @enum {string}
     */
    name: "dynamicPage.closed";
  };
  DynamicPageClosedPayload: {
    /**
     * Whether all pages were closed
     * @default false
     */
    all?: boolean;
    /** The id of the page that was closed */
    pageId?: string | null;
  };
  DynamicPageOpenedInteraction: components$1["schemas"]["BaseInteraction"] & {
    name: string;
    payload: components$1["schemas"]["DynamicPageOpenedPayload"];
  } & {
    /**
     * discriminator enum property added by openapi-typescript
     * @enum {string}
     */
    name: "dynamicPage.opened";
  };
  DynamicPageOpenedPayload: components$1["schemas"]["AbstractDynamicPageOpenedPayload"];
  DynamicProductListingPageOpenedPayload: {
    /** Current page position in the pagination */
    page: number;
  };
  DynamicProductPageOpenedInteraction: components$1["schemas"]["BaseInteraction"] & {
    name: string;
    payload: components$1["schemas"]["DynamicProductPageOpenedPayload"];
  } & {
    /**
     * discriminator enum property added by openapi-typescript
     * @enum {string}
     */
    name: "dynamicProductPage.opened";
  };
  DynamicProductPageOpenedPayload: {
    /** the id from the product which is shown on the dynamic page */
    productId: string;
  } & components$1["schemas"]["AbstractDynamicPageOpenedPayload"];
  EmptyInteraction: components$1["schemas"]["BaseInteraction"] & {
    name: string;
    payload: GenericRecord$1;
  } & {
    /**
     * discriminator enum property added by openapi-typescript
     * @enum {string}
     */
    name:
      | "keep.alive"
      | "quickview.opened"
      | "quickview.closed"
      | "attendee.leave"
      | "remote.checkout.accepted"
      | "remote.checkout.denied";
  };
  EmptyPayload: Record<string, never>;
  EntitySearchResult: {
    /** Contains aggregated data. A simple example is the determination of the average price from a product search query. */
    aggregations?: GenericRecord$1[];
    entity?: string;
    /** The actual limit. This is used for pagination and goes together with the page. */
    limit?: number;
    /** The actual page. This can be used for pagination. */
    page?: number;
    /** The total number of found entities */
    total?: number;
  };
  EqualsFilter: {
    field: string;
    /** @enum {string} */
    type: "equals";
    value: string | number | boolean | null;
  };
  Filters: (
    | components$1["schemas"]["SimpleFilter"]
    | components$1["schemas"]["EqualsFilter"]
    | components$1["schemas"]["MultiNotFilter"]
    | components$1["schemas"]["RangeFilter"]
  )[];
  FindProductVariantRouteResponse: {
    foundCombination?: {
      options?: string[];
      variantId?: string;
    };
  };
  Flow: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  FlowSequence: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  FlowTemplate: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  GuideHoveredInteraction: components$1["schemas"]["BaseInteraction"] & {
    name: string;
    payload: components$1["schemas"]["GuideHoveredPayload"];
  } & {
    /**
     * discriminator enum property added by openapi-typescript
     * @enum {string}
     */
    name: "guide.hovered";
  };
  GuideHoveredPayload: {
    hoveredElementId?: string | null;
  };
  ImportExportFile: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  ImportExportLog: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  ImportExportProfile: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  Includes: {
    [key: string]: string[];
  };
  Integration: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  JoinAppointmentResponse: {
    /** The name of the appointment */
    appointmentName?: string;
    /** The created Id for the attendee */
    attendeeId?: string;
    /** The name of the attendee */
    attendeeName?: string | null;
    /** The b2b features that available for the appointment */
    b2bFeatures?: {
      /** To know if the quote management is enabled for current customer */
      quoteManagement?: boolean;
    };
    /** The appointment id */
    id?: string;
    /** To see if it's a preview appointment */
    isPreview?: boolean;
    /** The JWT mercure token to subscribe for updates */
    JWTMercurePublisherToken?: string | null;
    /** The JWT mercure token to publish updates */
    JWTMercureSubscriberToken?: string | null;
    /** The mercure hub url to connect for subscribing and updating */
    mercureHubPublicUrl?: string | null;
    /** The topic to which the attendee/guide can send updates */
    mercurePublisherTopic?: string | null;
    /** The topics to which the attendee/guide can subscribe for */
    mercureSubscriberTopics?: string[];
    /** The new context token will be used in the header (sw-context-token) for calling the other routes */
    newContextToken?: string;
    /**
     * The type of the appointment
     * @enum {string}
     */
    presentationGuideMode?: "self" | "guided";
    /** The id of the current sales channel */
    salesChannelId?: string;
    /** The name of the current sales channel */
    salesChannelName?: string;
    /** The video user id that attendee could use */
    videoUserId?: string | null;
  };
  LandingPage: {
    active?: boolean;
    /** @enum {string} */
    apiAlias: "landing_page";
    cmsPage?: components$1["schemas"]["CmsPage"];
    cmsPageId?: string;
    cmsPageVersionId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    id: string;
    keywords?: string;
    metaDescription?: string;
    metaTitle?: string;
    name: string;
    seoUrls?: components$1["schemas"]["SeoUrl"][];
    slotConfig?: GenericRecord$1;
    translated: {
      cmsPageId: string;
      cmsPageVersionId: string;
      keywords: string;
      metaDescription: string;
      metaTitle: string;
      name: string;
      url: string;
      versionId: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    url: string;
    versionId?: string;
  };
  LandingPageJsonApi: components$1["schemas"]["resource"] & {
    active?: boolean;
    cmsPageId?: string;
    cmsPageVersionId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    id: string;
    keywords?: string;
    metaDescription?: string;
    metaTitle?: string;
    name: string;
    relationships?: {
      cmsPage?: {
        data?: {
          /** @example 7b1460918b1abb93311108f3dc021c9b */
          id?: string;
          /** @example cms_page */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /landing-page/815c27537bec3b60c50a2ae4d2ce875d/cmsPage
           */
          related?: string;
        };
      };
      seoUrls?: {
        data?: {
          /** @example 5321b5a71127b8b98cdd4b068ad56c4c */
          id?: string;
          /** @example seo_url */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /landing-page/815c27537bec3b60c50a2ae4d2ce875d/seoUrls
           */
          related?: string;
        };
      };
    };
    slotConfig?: GenericRecord$1;
    translated: {
      cmsPageId: string;
      cmsPageVersionId: string;
      keywords: string;
      metaDescription: string;
      metaTitle: string;
      name: string;
      url: string;
      versionId: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    url: string;
    versionId?: string;
  };
  Language: {
    children?: components$1["schemas"]["Language"][];
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    id: string;
    locale?: components$1["schemas"]["Locale"];
    localeId: string;
    name: string;
    parent?: components$1["schemas"]["Language"];
    parentId?: string;
    translationCode?: components$1["schemas"]["Locale"];
    translationCodeId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  LanguageJsonApi: components$1["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    id: string;
    localeId: string;
    name: string;
    parentId?: string;
    relationships?: {
      children?: {
        data?: {
          /** @example 268184c12df027f536154d099d497b31 */
          id?: string;
          /** @example language */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /language/4994a8ffeba4ac3140beb89e8d41f174/children
           */
          related?: string;
        };
      };
      locale?: {
        data?: {
          /** @example fb216d9e8791e63c8d12bdc420956839 */
          id?: string;
          /** @example locale */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /language/4994a8ffeba4ac3140beb89e8d41f174/locale
           */
          related?: string;
        };
      };
      parent?: {
        data?: {
          /** @example d0e45878043844ffc41aac437e86b602 */
          id?: string;
          /** @example language */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /language/4994a8ffeba4ac3140beb89e8d41f174/parent
           */
          related?: string;
        };
      };
      translationCode?: {
        data?: {
          /** @example 6ef2035242b8fcb7b61c3a41850e60b3 */
          id?: string;
          /** @example locale */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /language/4994a8ffeba4ac3140beb89e8d41f174/translationCode
           */
          related?: string;
        };
      };
    };
    translationCodeId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  LineItem: {
    children?: components$1["schemas"]["LineItem"][];
    cover?: components$1["schemas"]["ProductMedia"];
    dataContextHash?: string;
    dataTimestamp?: string;
    deliveryInformation: components$1["schemas"]["CartDeliveryInformation"];
    description?: string;
    extensions?: {
      meta?: {
        attendees?: {
          id: string;
          name: string;
        }[];
      };
    };
    good?: boolean;
    id: string;
    label?: string;
    modified?: boolean;
    modifiedByApp?: boolean;
    payload: components$1["schemas"]["ProductJsonApi"];
    price?: {
      /** @enum {string} */
      apiAlias: "calculated_price";
      calculatedTaxes?: {
        /** @enum {string} */
        apiAlias: "cart_tax_calculated";
        price: number;
        tax: number;
        taxRate: number;
      }[];
      listPrice?: components$1["schemas"]["CartListPrice"] | null;
      quantity: number;
      referencePrice?: components$1["schemas"]["CartPriceReference"] | null;
      regulationPrice?: {
        /** @enum {string} */
        apiAlias?: "cart_regulation_price";
        price?: number;
      } | null;
      /** Currently active tax rules and/or rates */
      taxRules?: {
        name?: string;
        /** Format: float */
        taxRate?: number;
      }[];
      totalPrice: number;
      unitPrice: number;
    };
    priceDefinition?: components$1["schemas"]["CartPriceQuantity"];
    quantity: number;
    quantityInformation?: {
      maxPurchase?: number;
      minPurchase?: number;
      purchaseSteps?: number;
    };
    referencedId?: string;
    removable?: boolean;
    stackable?: boolean;
    states: ("is-physical" | "is-download")[];
    type: components$1["schemas"]["LineItemType"];
    uniqueIdentifier?: string;
  };
  LineItemType:
    | "product"
    | "credit"
    | "custom"
    | "promotion"
    | "discount"
    | "container"
    | "quantity"
    | "dsr-line-item-discount"
    | "dsr-cart-discount";
  ListPrice: {
    /** @enum {string} */
    apiAlias: "cart_list_price";
    discount?: number;
    percentage?: number;
    price?: number;
  };
  Locale: {
    code: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    id: string;
    name: string;
    territory: string;
    translated: {
      code: string;
      name: string;
      territory: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  LogEntry: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  MailHeaderFooter: {
    /** Format: date-time */
    readonly createdAt?: string;
    description?: string;
    footerHtml?: string;
    footerPlain?: string;
    headerHtml?: string;
    headerPlain?: string;
    id?: string;
    name: string;
    systemDefault?: boolean;
    translated: {
      description: string;
      footerHtml: string;
      footerPlain: string;
      headerHtml: string;
      headerPlain: string;
      name: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  MailTemplate: {
    contentHtml: string;
    contentPlain: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    extensions?: {
      swagCmsExtensionsForms?: {
        data?: {
          /** @example a08561237fe1e2a012502c820a08405d */
          id?: string;
          /** @example swag_cms_extensions_form */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /mail-template/901aa1bf1715ad482f037eaa8b9cdc3a/swagCmsExtensionsForms
           */
          related?: string;
        };
      };
    };
    id?: string;
    mailTemplateType?: components$1["schemas"]["MailTemplateType"];
    media?: components$1["schemas"]["MailTemplateMedia"][];
    senderName?: string;
    systemDefault?: boolean;
    translated: {
      contentHtml: string;
      contentPlain: string;
      senderName: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  MailTemplateMedia: {
    id: string;
    languageId: string;
    mailTemplateId: string;
    media?: components$1["schemas"]["Media"];
    mediaId: string;
    /** Format: int64 */
    position?: number;
  };
  MailTemplateType: {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    id: string;
    name: string;
    technicalName: string;
    translated: {
      name: string;
      technicalName: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  MainCategory: {
    categoryId: string;
    categoryVersionId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    productId: string;
    productVersionId?: string;
    salesChannelId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  MainCategoryJsonApi: components$1["schemas"]["resource"] & {
    categoryId: string;
    categoryVersionId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    productId: string;
    productVersionId?: string;
    salesChannelId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  Media: {
    alt?: string;
    /** @enum {string} */
    apiAlias: "media";
    config?: GenericRecord$1;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    extensions?: {
      mediaAiTag?: {
        data?: {
          /** @example 3c88197809d464216a8c40a8db191b38 */
          id?: string;
          /** @example media_ai_tag */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /media/3b563524fdb17b4a86590470d40bef74/mediaAiTag
           */
          related?: string;
        };
      };
    };
    readonly fileExtension: string;
    fileName: string;
    /** Format: int64 */
    readonly fileSize?: number;
    /** Runtime field, cannot be used as part of the criteria. */
    hasFile: boolean;
    id: string;
    metaData?: {
      /** Format: int64 */
      height?: number;
      /** Format: int64 */
      width?: number;
    };
    mimeType?: string;
    path: string;
    private: boolean;
    thumbnails?: components$1["schemas"]["MediaThumbnail"][];
    title?: string;
    translated: {
      alt: string;
      fileExtension: string;
      fileName: string;
      mimeType: string;
      path: string;
      title: string;
      uploadedAt: string;
      url: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    /** Format: date-time */
    readonly uploadedAt?: string;
    /** Runtime field, cannot be used as part of the criteria. */
    url: string;
  };
  MediaAiTag: {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    media?: components$1["schemas"]["Media"];
    tags?: GenericRecord$1[];
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  MediaDefaultFolder: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  MediaFolder: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  MediaFolderConfiguration: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  MediaTag: {
    id?: string;
    media?: components$1["schemas"]["Media"];
    mediaId: string;
    tag?: components$1["schemas"]["Tag"];
    tagId: string;
  };
  MediaThumbnail: {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    /** Format: int64 */
    readonly height: number;
    id: string;
    mediaId: string;
    path?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    /** Runtime field, cannot be used as part of the criteria. */
    url: string;
    /** Format: int64 */
    readonly width: number;
  };
  MediaThumbnailSize: {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    /** Format: int64 */
    height: number;
    id: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    /** Format: int64 */
    width: number;
  };
  MultiNotFilter: {
    /** @enum {string} */
    operator: "and" | "or" | "nor" | "nand";
    queries: components$1["schemas"]["Filters"];
    /** @enum {string} */
    type: "multi" | "not";
  };
  NaturalLanguageSearchTermResponse: {
    /** @enum {string} */
    apiAlias: "product_natural_language_search_term";
    reason: string;
    term: string;
  }[];
  NavigationRouteResponse: components$1["schemas"]["Category"][];
  NavigationType:
    | "main-navigation"
    | "footer-navigation"
    | "service-navigation";
  NewsletterRecipient: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  NewsletterRecipientJsonApi: components$1["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  Notification: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  NumberRange: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  NumberRangeSalesChannel: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  NumberRangeState: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  NumberRangeType: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  Order: {
    addresses?: components$1["schemas"]["OrderAddress"][];
    affiliateCode?: string;
    /** Format: float */
    readonly amountNet?: number;
    /** Format: float */
    readonly amountTotal?: number;
    billingAddress?: components$1["schemas"]["OrderAddress"];
    billingAddressId: string;
    billingAddressVersionId?: string;
    campaignCode?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    createdById?: string;
    currency?: components$1["schemas"]["Currency"];
    /** Format: float */
    currencyFactor: number;
    currencyId: string;
    customerComment?: string;
    customFields?: GenericRecord$1;
    deepLinkCode?: string;
    deliveries?: components$1["schemas"]["OrderDelivery"][];
    documents: components$1["schemas"]["Document"][];
    extensions?: {
      orderEmployee?: {
        data?: {
          /** @example 5ea451c08a87db806089c4031601c29a */
          id?: string;
          /** @example b2b_order_employee */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /order/a240fa27925a635b08dc28c9e4f9216d/orderEmployee
           */
          related?: string;
        };
      };
      quote?: {
        data?: {
          /** @example 7a674c327bfa07f7c1204fb38ca6ef3b */
          id?: string;
          /** @example quote */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /order/a240fa27925a635b08dc28c9e4f9216d/quote
           */
          related?: string;
        };
      };
      returns?: {
        data?: {
          /** @example 7fff84525c6516919851a9005373f87e */
          id?: string;
          /** @example order_return */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /order/a240fa27925a635b08dc28c9e4f9216d/returns
           */
          related?: string;
        };
      };
      subscription?: {
        data?: {
          /** @example b48b13e73a6ac2a86dc54425dd24d9ff */
          id?: string;
          /** @example subscription */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /order/a240fa27925a635b08dc28c9e4f9216d/subscription
           */
          related?: string;
        };
      };
    };
    id: string;
    language?: components$1["schemas"]["Language"];
    languageId: string;
    lineItems?: components$1["schemas"]["OrderLineItem"][];
    orderCustomer?: components$1["schemas"]["OrderCustomer"];
    readonly orderDate: string;
    /** Format: date-time */
    orderDateTime: string;
    orderNumber?: string;
    /** Format: float */
    readonly positionPrice?: number;
    price: components$1["schemas"]["CalculatedPrice"];
    salesChannelId: string;
    shippingCosts?: {
      calculatedTaxes?: GenericRecord$1;
      listPrice?: {
        /** Format: float */
        discount?: number;
        /** Format: float */
        percentage?: number;
        /** Format: float */
        price?: number;
      };
      /** Format: int64 */
      quantity: number;
      referencePrice?: GenericRecord$1;
      regulationPrice?: {
        /** Format: float */
        price?: number;
      };
      taxRules?: GenericRecord$1;
      /** Format: float */
      totalPrice: number;
      /** Format: float */
      unitPrice: number;
    };
    /** Format: float */
    readonly shippingTotal?: number;
    source?: string;
    stateMachineState: components$1["schemas"]["StateMachineState"];
    tags?: components$1["schemas"]["Tag"][];
    readonly taxStatus?: string;
    transactions?: components$1["schemas"]["OrderTransaction"][];
    /** Format: date-time */
    readonly updatedAt?: string;
    updatedById?: string;
    versionId?: string;
  };
  OrderAddress: {
    additionalAddressLine1?: string;
    additionalAddressLine2?: string;
    city: string;
    company?: string;
    country?: components$1["schemas"]["Country"];
    countryId: string;
    countryState?: components$1["schemas"]["CountryState"];
    countryStateId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    department?: string;
    firstName: string;
    id: string;
    lastName: string;
    phoneNumber?: string;
    salutation?: components$1["schemas"]["Salutation"];
    street: string;
    title?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    vatId?: string;
    versionId?: string;
    zipcode?: string;
  };
  OrderCustomer: {
    company?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customerNumber?: string;
    customFields?: GenericRecord$1;
    email: string;
    firstName: string;
    id: string;
    lastName: string;
    salutation?: components$1["schemas"]["Salutation"];
    salutationId?: string;
    title?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    vatIds?: string[];
    versionId?: string;
  };
  OrderDelivery: {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    id: string;
    orderId: string;
    orderVersionId?: string;
    positions?: components$1["schemas"]["OrderDeliveryPosition"][];
    shippingCosts?: {
      calculatedTaxes?: GenericRecord$1;
      listPrice?: {
        /** Format: float */
        discount?: number;
        /** Format: float */
        percentage?: number;
        /** Format: float */
        price?: number;
      };
      /** Format: int64 */
      quantity: number;
      referencePrice?: GenericRecord$1;
      regulationPrice?: {
        /** Format: float */
        price?: number;
      };
      taxRules?: GenericRecord$1;
      /** Format: float */
      totalPrice: number;
      /** Format: float */
      unitPrice: number;
    };
    /** Format: date-time */
    shippingDateEarliest: string;
    /** Format: date-time */
    shippingDateLatest: string;
    shippingMethod?: components$1["schemas"]["ShippingMethod"];
    shippingMethodId: string;
    shippingOrderAddress?: components$1["schemas"]["OrderAddress"];
    shippingOrderAddressId: string;
    shippingOrderAddressVersionId?: string;
    stateId: string;
    stateMachineState?: components$1["schemas"]["StateMachineState"];
    trackingCodes?: string[];
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  OrderDeliveryPosition: {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    id: string;
    orderDeliveryId: string;
    orderDeliveryVersionId?: string;
    orderLineItemId: string;
    orderLineItemVersionId?: string;
    price?: {
      calculatedTaxes?: GenericRecord$1;
      listPrice?: {
        /** Format: float */
        discount?: number;
        /** Format: float */
        percentage?: number;
        /** Format: float */
        price?: number;
      };
      /** Format: int64 */
      quantity: number;
      referencePrice?: GenericRecord$1;
      regulationPrice?: {
        /** Format: float */
        price?: number;
      };
      taxRules?: GenericRecord$1;
      /** Format: float */
      totalPrice: number;
      /** Format: float */
      unitPrice: number;
    };
    /** Format: int64 */
    quantity?: number;
    /** Format: float */
    totalPrice?: number;
    /** Format: float */
    unitPrice?: number;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  OrderLineItem: {
    /** @enum {string} */
    apiAlias: "order_line_item";
    children: components$1["schemas"]["OrderLineItem"][];
    cover?: components$1["schemas"]["Media"];
    coverId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    description?: string;
    downloads?: components$1["schemas"]["OrderLineItemDownload"][];
    extensions?: {
      returns?: {
        data?: {
          /** @example 7fff84525c6516919851a9005373f87e */
          id?: string;
          /** @example order_return_line_item */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /order-line-item/40b401ac0b29ac5c5c8ffce649fdef62/returns
           */
          related?: string;
        };
      };
      state?: {
        data?: {
          /** @example 9ed39e2ea931586b6a985a6942ef573e */
          id?: string;
          /** @example state_machine_state */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /order-line-item/40b401ac0b29ac5c5c8ffce649fdef62/state
           */
          related?: string;
        };
      };
    };
    good?: boolean;
    id: string;
    identifier: string;
    label: string;
    orderDeliveryPositions?: components$1["schemas"]["OrderDeliveryPosition"][];
    orderId: string;
    orderVersionId?: string;
    parent?: components$1["schemas"]["OrderLineItem"];
    parentId?: string;
    parentVersionId?: string;
    payload?: {
      readonly categoryIds?: string[];
      /** Format: date-time */
      readonly createdAt?: string;
      customFields?: GenericRecord$1;
      features?: unknown[];
      isCloseout?: boolean;
      isNew?: boolean;
      manufacturerId?: string;
      markAsTopseller?: boolean;
      readonly optionIds?: string[];
      options?: components$1["schemas"]["PropertyGroupOption"][];
      parentId?: string;
      productNumber?: string;
      readonly propertyIds?: string[];
      purchasePrices?: string;
      /** Format: date-time */
      releaseDate?: string;
      /** Format: int64 */
      stock?: number;
      readonly streamIds?: string[];
      readonly tagIds?: string[];
      taxId?: string;
    };
    /** Format: int64 */
    position?: number;
    priceDefinition?: components$1["schemas"]["CartPriceQuantity"];
    productId?: string;
    productVersionId?: string;
    promotionId?: string;
    /** Format: int64 */
    quantity: number;
    referencedId?: string;
    removable?: boolean;
    stackable?: boolean;
    states: string[];
    /** Format: float */
    totalPrice?: number;
    translated: {
      coverId: string;
      description: string;
      identifier: string;
      label: string;
      orderId: string;
      orderVersionId: string;
      parentId: string;
      parentVersionId: string;
      productId: string;
      productVersionId: string;
      promotionId: string;
      referencedId: string;
      type: string;
      versionId: string;
    };
    type?: string;
    /** Format: float */
    unitPrice?: number;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  OrderLineItemDownload: {
    accessGranted: boolean;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    id: string;
    media: components$1["schemas"]["Media"];
    mediaId: string;
    orderLineItem?: components$1["schemas"]["OrderLineItem"];
    orderLineItemId: string;
    orderLineItemVersionId?: string;
    /** Format: int64 */
    position: number;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  OrderProductWarehouse: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  OrderReturn: {
    /** Format: float */
    amountNet?: number;
    /** Format: float */
    amountTotal?: number;
    /** Format: date-time */
    readonly createdAt?: string;
    createdById?: string;
    id: string;
    lineItems?: components$1["schemas"]["OrderReturnLineItem"][];
    orderId: string;
    orderVersionId?: string;
    price?: {
      calculatedTaxes?: GenericRecord$1;
      /** Format: float */
      netPrice: number;
      /** Format: float */
      positionPrice: number;
      /** Format: float */
      rawTotal: number;
      taxRules?: GenericRecord$1;
      taxStatus: string;
      /** Format: float */
      totalPrice: number;
    };
    /** Format: date-time */
    requestedAt: string;
    returnNumber: string;
    shippingCosts?: {
      calculatedTaxes?: GenericRecord$1;
      listPrice?: {
        /** Format: float */
        discount?: number;
        /** Format: float */
        percentage?: number;
        /** Format: float */
        price?: number;
      };
      /** Format: int64 */
      quantity: number;
      referencePrice?: GenericRecord$1;
      regulationPrice?: {
        /** Format: float */
        price?: number;
      };
      taxRules?: GenericRecord$1;
      /** Format: float */
      totalPrice: number;
      /** Format: float */
      unitPrice: number;
    };
    state?: components$1["schemas"]["StateMachineState"];
    stateId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    updatedById?: string;
    versionId?: string;
  };
  OrderReturnLineItem: {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    id: string;
    orderLineItemId: string;
    orderLineItemVersionId?: string;
    orderReturnId: string;
    orderReturnVersionId?: string;
    /** Format: int64 */
    quantity: number;
    reason?: components$1["schemas"]["OrderReturnLineItemReason"];
    reasonId: string;
    /** Format: float */
    refundAmount?: number;
    /** Format: int64 */
    restockQuantity?: number;
    state?: components$1["schemas"]["StateMachineState"];
    stateId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  OrderReturnLineItemReason: {
    content: string;
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    reasonKey: string;
    translated: {
      content: string;
      reasonKey: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  OrderRouteResponse: {
    orders: {
      elements: components$1["schemas"]["Order"][];
    } & components$1["schemas"]["EntitySearchResult"];
    /** The key-value pairs contain the uuid of the order as key and a boolean as value, indicating that the payment method can still be changed. */
    paymentChangeable?: {
      [key: string]: boolean;
    };
  };
  OrderTag: {
    id?: string;
    order?: components$1["schemas"]["Order"];
    orderId: string;
    orderVersionId?: string;
    tag?: components$1["schemas"]["Tag"];
    tagId: string;
  };
  OrderTransaction: {
    amount: {
      calculatedTaxes?: GenericRecord$1;
      listPrice?: {
        /** Format: float */
        discount?: number;
        /** Format: float */
        percentage?: number;
        /** Format: float */
        price?: number;
      };
      /** Format: int64 */
      quantity: number;
      referencePrice?: GenericRecord$1;
      regulationPrice?: {
        /** Format: float */
        price?: number;
      };
      taxRules?: GenericRecord$1;
      /** Format: float */
      totalPrice: number;
      /** Format: float */
      unitPrice: number;
    };
    captures?: components$1["schemas"]["OrderTransactionCapture"][];
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    id: string;
    orderId: string;
    orderVersionId?: string;
    paymentMethod?: components$1["schemas"]["PaymentMethod"];
    paymentMethodId: string;
    stateId: string;
    stateMachineState?: components$1["schemas"]["StateMachineState"];
    /** Format: date-time */
    readonly updatedAt?: string;
    validationData?: GenericRecord$1;
    versionId?: string;
  };
  OrderTransactionCapture: {
    amount: {
      calculatedTaxes?: GenericRecord$1;
      listPrice?: {
        /** Format: float */
        discount?: number;
        /** Format: float */
        percentage?: number;
        /** Format: float */
        price?: number;
      };
      /** Format: int64 */
      quantity: number;
      referencePrice?: GenericRecord$1;
      regulationPrice?: {
        /** Format: float */
        price?: number;
      };
      taxRules?: GenericRecord$1;
      /** Format: float */
      totalPrice: number;
      /** Format: float */
      unitPrice: number;
    };
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    externalReference?: string;
    id: string;
    orderTransactionId: string;
    orderTransactionVersionId?: string;
    refunds?: components$1["schemas"]["OrderTransactionCaptureRefund"][];
    stateId: string;
    stateMachineState?: components$1["schemas"]["StateMachineState"];
    transaction?: components$1["schemas"]["OrderTransaction"];
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  OrderTransactionCaptureRefund: {
    amount: {
      calculatedTaxes?: GenericRecord$1;
      listPrice?: {
        /** Format: float */
        discount?: number;
        /** Format: float */
        percentage?: number;
        /** Format: float */
        price?: number;
      };
      /** Format: int64 */
      quantity: number;
      referencePrice?: GenericRecord$1;
      regulationPrice?: {
        /** Format: float */
        price?: number;
      };
      taxRules?: GenericRecord$1;
      /** Format: float */
      totalPrice: number;
      /** Format: float */
      unitPrice: number;
    };
    captureId: string;
    captureVersionId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    externalReference?: string;
    id: string;
    positions?: components$1["schemas"]["OrderTransactionCaptureRefundPosition"][];
    reason?: string;
    stateId: string;
    stateMachineState?: components$1["schemas"]["StateMachineState"];
    transactionCapture?: components$1["schemas"]["OrderTransactionCapture"];
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  OrderTransactionCaptureRefundPosition: {
    amount: {
      calculatedTaxes?: GenericRecord$1;
      listPrice?: {
        /** Format: float */
        discount?: number;
        /** Format: float */
        percentage?: number;
        /** Format: float */
        price?: number;
      };
      /** Format: int64 */
      quantity: number;
      referencePrice?: GenericRecord$1;
      regulationPrice?: {
        /** Format: float */
        price?: number;
      };
      taxRules?: GenericRecord$1;
      /** Format: float */
      totalPrice: number;
      /** Format: float */
      unitPrice: number;
    };
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    externalReference?: string;
    id: string;
    orderLineItem?: components$1["schemas"]["OrderLineItem"];
    orderLineItemId: string;
    orderLineItemVersionId?: string;
    orderTransactionCaptureRefund?: components$1["schemas"]["OrderTransactionCaptureRefund"];
    /** Format: int64 */
    quantity?: number;
    reason?: string;
    refundId: string;
    refundVersionId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  OrderWarehouseGroup: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  PageViewedInteraction: components$1["schemas"]["BaseInteraction"] & {
    name: string;
    payload: components$1["schemas"]["PageViewedPayload"];
  } & {
    /**
     * discriminator enum property added by openapi-typescript
     * @enum {string}
     */
    name: "page.viewed";
  };
  PageViewedPayload: {
    /** the id from the page which was viewed */
    pageId: string;
    pageNumber?: number | null;
    /** the id from the section within the page which was viewed */
    sectionId: string;
    /** the alias of the slide which was viewed */
    slideAlias: number;
  };
  PaymentMethod: {
    active?: boolean;
    afterOrderEnabled?: boolean;
    /** Runtime field, cannot be used as part of the criteria. */
    readonly asynchronous?: boolean;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    description?: string;
    readonly distinguishableName?: string;
    id: string;
    media?: components$1["schemas"]["Media"];
    mediaId?: string;
    name: string;
    /** Format: int64 */
    position?: number;
    /** Runtime field, cannot be used as part of the criteria. */
    readonly prepared?: boolean;
    /** Runtime field, cannot be used as part of the criteria. */
    readonly recurring?: boolean;
    /** Runtime field, cannot be used as part of the criteria. */
    readonly refundable?: boolean;
    /** Runtime field, cannot be used as part of the criteria. */
    shortName?: string;
    /** Runtime field, cannot be used as part of the criteria. */
    readonly synchronous?: boolean;
    technicalName?: string;
    translated: {
      description: string;
      distinguishableName: string;
      mediaId: string;
      name: string;
      shortName: string;
      technicalName: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  PaymentMethodJsonApi: components$1["schemas"]["resource"] & {
    active?: boolean;
    afterOrderEnabled?: boolean;
    /** Runtime field, cannot be used as part of the criteria. */
    readonly asynchronous?: boolean;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    description?: string;
    readonly distinguishableName?: string;
    id: string;
    mediaId?: string;
    name: string;
    /** Format: int64 */
    position?: number;
    /** Runtime field, cannot be used as part of the criteria. */
    readonly prepared?: boolean;
    /** Runtime field, cannot be used as part of the criteria. */
    readonly recurring?: boolean;
    /** Runtime field, cannot be used as part of the criteria. */
    readonly refundable?: boolean;
    relationships?: {
      media?: {
        data?: {
          /** @example 62933a2951ef01f4eafd9bdf4d3cd2f0 */
          id?: string;
          /** @example media */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /payment-method/da8da1569e6bef3249a7064261df833f/media
           */
          related?: string;
        };
      };
    };
    /** Runtime field, cannot be used as part of the criteria. */
    shortName?: string;
    /** Runtime field, cannot be used as part of the criteria. */
    readonly synchronous?: boolean;
    technicalName?: string;
    translated: {
      description: string;
      distinguishableName: string;
      mediaId: string;
      name: string;
      shortName: string;
      technicalName: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  PendingOrder: {
    amountNet?: number | null;
    amountTotal?: number | null;
    approvalRuleId?: string;
    billingAddress?: GenericRecord$1;
    cartPayload?: GenericRecord$1 | string;
    country?: GenericRecord$1;
    countryId?: string;
    currency?: GenericRecord$1;
    currencyId?: string;
    customerId?: string;
    decidedById?: string;
    employeeId?: string;
    /** Format: uuid */
    id?: string;
    itemRounding?: GenericRecord$1;
    language?: GenericRecord$1;
    languageId?: string;
    lineItemCount?: number;
    number?: string;
    originalPrice?: number | null;
    paymentMethodId?: string;
    price?: GenericRecord$1;
    reason?: string;
    salesChannel?: GenericRecord$1;
    salesChannelId?: string;
    shippingMethodId?: string;
    stateId?: string;
    taxStatus?: string;
    totalRounding?: GenericRecord$1;
  };
  Plugin: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  PresentationCmsPage: components$1["schemas"]["DsrPresentationCmsPage"] & {
    /** The product id is assigned to presentation if it's product listing or instant listing */
    pickedProductIds?: string[] | null;
  };
  PresentationSlideData: {
    category?: components$1["schemas"]["Category"];
    cmsPage?: components$1["schemas"]["CmsPage"];
    configurator?: components$1["schemas"]["PropertyGroup"][];
    extensions?: {
      cmsPageRelation?: components$1["schemas"]["PresentationCmsPage"];
    };
    product?: components$1["schemas"]["Product"];
  };
  PresentationStructure: {
    cmsPageResults: {
      cmsPage?: components$1["schemas"]["CmsPage"];
      /** The presentation id */
      resourceIdentifier?: string;
      /**
       * The type of presentation page
       * @default frontend.presentation.page
       */
      resourceType?: string;
    }[];
    navigation: {
      /** The CMS page id */
      cmsPageId: string;
      /** The presentation CMS page id */
      groupId: string;
      /** The slide name */
      groupName: string;
      /** The slide position */
      index: number;
      /** If the slide is an instant listing */
      isInstantListing?: boolean;
      /** @default [] */
      notes?: components$1["schemas"]["CmsSlot"][];
      /** The number of picked products of the instant listing */
      pickedProductsCount?: number;
      /** The section id */
      sectionId: string;
      /** The section name */
      sectionName: string | null;
    }[];
  };
  Price: {
    currencyId: string;
    gross: number;
    linked?: boolean;
    listPrice?: {
      currencyId?: string;
      gross: number;
      linked?: boolean;
      net: number;
    };
    net: number;
    regulationPrice?: {
      currencyId?: string;
      gross: number;
      linked?: boolean;
      net: number;
    };
  };
  Product: {
    active?: boolean;
    /** @enum {string} */
    apiAlias: "product";
    readonly available?: boolean;
    /** Format: int64 */
    readonly availableStock?: number;
    calculatedCheapestPrice?: {
      /** @enum {string} */
      apiAlias?: "calculated_cheapest_price";
      hasRange?: boolean;
      listPrice?: components$1["schemas"]["ListPrice"] | null;
      quantity?: number;
      referencePrice?: components$1["schemas"]["ReferencePrice"] | null;
      regulationPrice?: {
        price: number;
      } | null;
      totalPrice?: number;
      unitPrice?: number;
      variantId?: string | null;
    };
    /**
     * Format: int64
     * Runtime field, cannot be used as part of the criteria.
     */
    calculatedMaxPurchase?: number;
    calculatedPrice: components$1["schemas"]["CalculatedPrice"];
    calculatedPrices: components$1["schemas"]["CalculatedPrice"][];
    canonicalProduct?: components$1["schemas"]["Product"];
    canonicalProductId?: string;
    canonicalProductVersionId?: string;
    categories?: components$1["schemas"]["Category"][];
    categoriesRo?: components$1["schemas"]["Category"][];
    readonly categoryIds?: string[];
    readonly categoryTree?: string[];
    /** Format: int64 */
    readonly childCount?: number;
    children?: components$1["schemas"]["Product"][];
    cmsPage?: components$1["schemas"]["CmsPage"];
    cmsPageId?: string;
    cmsPageVersionId?: string;
    configuratorSettings?: components$1["schemas"]["ProductConfiguratorSetting"][];
    cover?: components$1["schemas"]["ProductMedia"];
    coverId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    crossSellings?: components$1["schemas"]["ProductCrossSelling"][];
    customFields?: GenericRecord$1;
    deliveryTime?: components$1["schemas"]["DeliveryTime"];
    deliveryTimeId?: string;
    description?: string;
    readonly displayGroup?: string;
    downloads?: components$1["schemas"]["ProductDownload"][];
    ean?: string;
    extensions?: {
      attendeeProductCollections?: {
        data?: {
          /** @example 0a7b3b2f4b81f36910a74f22826f35df */
          id?: string;
          /** @example dsr_attendee_product_collection */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/attendeeProductCollections
           */
          related?: string;
        };
      };
      reviewSummaries?: {
        data?: {
          /** @example c9c718522e64ffa5effb26cef94f4849 */
          id?: string;
          /** @example product_review_summary */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/reviewSummaries
           */
          related?: string;
        };
      };
      swagCustomizedProductsTemplate?: {
        data?: {
          /** @example 6e9fad30dd3cb84748a01bb8152f4769 */
          id?: string;
          /** @example swag_customized_products_template */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/swagCustomizedProductsTemplate
           */
          related?: string;
        };
      };
    };
    /** Format: float */
    height?: number;
    id: string;
    isCloseout?: boolean;
    /** Runtime field, cannot be used as part of the criteria. */
    isNew?: boolean;
    keywords?: string;
    /** Format: float */
    length?: number;
    mainCategories?: components$1["schemas"]["MainCategory"][];
    manufacturer?: components$1["schemas"]["ProductManufacturer"];
    manufacturerId?: string;
    manufacturerNumber?: string;
    markAsTopseller?: boolean;
    /** Format: int64 */
    maxPurchase?: number;
    media?: components$1["schemas"]["ProductMedia"][];
    metaDescription?: string;
    metaTitle?: string;
    /** Format: int64 */
    minPurchase?: number;
    name: string;
    readonly optionIds?: string[];
    options?: components$1["schemas"]["PropertyGroupOption"][];
    packUnit?: string;
    packUnitPlural?: string;
    parent?: components$1["schemas"]["Product"];
    parentId?: string;
    parentVersionId?: string;
    productManufacturerVersionId?: string;
    productMediaVersionId?: string;
    productNumber: string;
    productReviews?: components$1["schemas"]["ProductReview"][];
    properties?: components$1["schemas"]["PropertyGroupOption"][];
    readonly propertyIds?: string[];
    /** Format: int64 */
    purchaseSteps?: number;
    /** Format: float */
    purchaseUnit?: number;
    /** Format: float */
    readonly ratingAverage?: number;
    /** Format: float */
    referenceUnit?: number;
    /** Format: date-time */
    releaseDate?: string;
    /** Format: int64 */
    restockTime?: number;
    /** Format: int64 */
    readonly sales?: number;
    seoCategory: components$1["schemas"]["Category"];
    seoUrls?: components$1["schemas"]["SeoUrl"][];
    shippingFree?: boolean;
    sortedProperties?: GenericRecord$1;
    readonly states?: string[];
    /** Format: int64 */
    stock: number;
    readonly streamIds?: string[];
    streams?: components$1["schemas"]["ProductStream"][];
    readonly tagIds?: string[];
    tags?: components$1["schemas"]["Tag"][];
    tax?: components$1["schemas"]["Tax"];
    taxId: string;
    translated: {
      canonicalProductId: string;
      canonicalProductVersionId: string;
      cmsPageId: string;
      cmsPageVersionId: string;
      coverId: string;
      deliveryTimeId: string;
      description: string;
      displayGroup: string;
      ean: string;
      keywords: string;
      manufacturerId: string;
      manufacturerNumber: string;
      metaDescription: string;
      metaTitle: string;
      name: string;
      packUnit: string;
      packUnitPlural: string;
      parentId: string;
      parentVersionId: string;
      productManufacturerVersionId: string;
      productMediaVersionId: string;
      productNumber: string;
      releaseDate: string;
      taxId: string;
      unitId: string;
      versionId: string;
    };
    unit?: components$1["schemas"]["Unit"];
    unitId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    variantListingConfig?: {
      displayParent?: boolean;
    } | null;
    versionId?: string;
    /** Format: float */
    weight?: number;
    /** Format: float */
    width?: number;
  };
  ProductConfiguratorSetting: {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    id: string;
    media?: components$1["schemas"]["Media"];
    mediaId?: string;
    option?: components$1["schemas"]["PropertyGroupOption"];
    optionId: string;
    /** Format: int64 */
    position?: number;
    productId: string;
    productVersionId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  ProductCrossSelling: {
    active?: boolean;
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    /** Format: int64 */
    limit?: number;
    name: string;
    /** Format: int64 */
    position?: number;
    sortBy?: string;
    sortDirection?: string;
    translated: {
      name: string;
      sortBy: string;
      sortDirection: string;
      type: string;
    };
    type?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  ProductCrossSellingAssignedProducts: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  ProductDetailResponse: {
    /** List of property groups with their corresponding options and information on how to display them. */
    configurator?: components$1["schemas"]["PropertyGroup"][];
    product: components$1["schemas"]["Product"];
  };
  ProductDownload: {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    id: string;
    media?: components$1["schemas"]["Media"];
    mediaId: string;
    /** Format: int64 */
    position?: number;
    product?: components$1["schemas"]["Product"];
    productId: string;
    productVersionId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  ProductExport: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  ProductFeatureSet: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  ProductInteraction: components$1["schemas"]["BaseInteraction"] & {
    name: string;
    payload: components$1["schemas"]["ProductPayload"];
  } & {
    /**
     * discriminator enum property added by openapi-typescript
     * @enum {string}
     */
    name:
      | "product.viewed"
      | "attendee.product.collection.liked"
      | "attendee.product.collection.disliked"
      | "attendee.product.collection.removed";
  };
  ProductJsonApi: components$1["schemas"]["resource"] & {
    active?: boolean;
    readonly available?: boolean;
    /** Format: int64 */
    readonly availableStock?: number;
    calculatedCheapestPrice?: GenericRecord$1;
    /**
     * Format: int64
     * Runtime field, cannot be used as part of the criteria.
     */
    calculatedMaxPurchase?: number;
    calculatedPrice?: GenericRecord$1;
    calculatedPrices?: GenericRecord$1[];
    canonicalProductId?: string;
    canonicalProductVersionId?: string;
    readonly categoryIds?: string[];
    readonly categoryTree?: string[];
    /** Format: int64 */
    readonly childCount?: number;
    cmsPageId?: string;
    cmsPageVersionId?: string;
    coverId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    deliveryTimeId?: string;
    description?: string;
    readonly displayGroup?: string;
    ean?: string;
    extensions?: {
      attendeeProductCollections?: {
        data?: {
          /** @example 0a7b3b2f4b81f36910a74f22826f35df */
          id?: string;
          /** @example dsr_attendee_product_collection */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/attendeeProductCollections
           */
          related?: string;
        };
      };
      reviewSummaries?: {
        data?: {
          /** @example c9c718522e64ffa5effb26cef94f4849 */
          id?: string;
          /** @example product_review_summary */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/reviewSummaries
           */
          related?: string;
        };
      };
      swagCustomizedProductsTemplate?: {
        data?: {
          /** @example 6e9fad30dd3cb84748a01bb8152f4769 */
          id?: string;
          /** @example swag_customized_products_template */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/swagCustomizedProductsTemplate
           */
          related?: string;
        };
      };
    };
    /** Format: float */
    height?: number;
    id: string;
    isCloseout?: boolean;
    /** Runtime field, cannot be used as part of the criteria. */
    isNew?: boolean;
    keywords?: string;
    /** Format: float */
    length?: number;
    manufacturerId?: string;
    manufacturerNumber?: string;
    markAsTopseller?: boolean;
    /** Format: int64 */
    maxPurchase?: number;
    metaDescription?: string;
    metaTitle?: string;
    /** Format: int64 */
    minPurchase?: number;
    name: string;
    readonly optionIds?: string[];
    packUnit?: string;
    packUnitPlural?: string;
    parentId?: string;
    parentVersionId?: string;
    productManufacturerVersionId?: string;
    productMediaVersionId?: string;
    productNumber: string;
    readonly propertyIds?: string[];
    /** Format: int64 */
    purchaseSteps?: number;
    /** Format: float */
    purchaseUnit?: number;
    /** Format: float */
    readonly ratingAverage?: number;
    /** Format: float */
    referenceUnit?: number;
    relationships?: {
      canonicalProduct?: {
        data?: {
          /** @example 023995a50b56c0de077323e958b2bbcd */
          id?: string;
          /** @example product */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/canonicalProduct
           */
          related?: string;
        };
      };
      categories?: {
        data?: {
          /** @example b0b5ccb4a195a07fd3eed14affb8695f */
          id?: string;
          /** @example category */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/categories
           */
          related?: string;
        };
      };
      categoriesRo?: {
        data?: {
          /** @example 7f0702d3a90d965b8c9158c451f43fdb */
          id?: string;
          /** @example category */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/categoriesRo
           */
          related?: string;
        };
      };
      children?: {
        data?: {
          /** @example 268184c12df027f536154d099d497b31 */
          id?: string;
          /** @example product */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/children
           */
          related?: string;
        };
      };
      cmsPage?: {
        data?: {
          /** @example 7b1460918b1abb93311108f3dc021c9b */
          id?: string;
          /** @example cms_page */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/cmsPage
           */
          related?: string;
        };
      };
      configuratorSettings?: {
        data?: {
          /** @example c0827fee13725d41f1fd7e292243f5aa */
          id?: string;
          /** @example product_configurator_setting */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/configuratorSettings
           */
          related?: string;
        };
      };
      cover?: {
        data?: {
          /** @example 41d0e299ca1abeb2094852da042165c7 */
          id?: string;
          /** @example product_media */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/cover
           */
          related?: string;
        };
      };
      crossSellings?: {
        data?: {
          /** @example 89936e14544d1b403cecef938101b6b0 */
          id?: string;
          /** @example product_cross_selling */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/crossSellings
           */
          related?: string;
        };
      };
      deliveryTime?: {
        data?: {
          /** @example 8c888ae25a7bd42057370e31f7e01044 */
          id?: string;
          /** @example delivery_time */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/deliveryTime
           */
          related?: string;
        };
      };
      downloads?: {
        data?: {
          /** @example d07d50a751bc6ddf12bf3af0efee9b45 */
          id?: string;
          /** @example product_download */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/downloads
           */
          related?: string;
        };
      };
      mainCategories?: {
        data?: {
          /** @example 1fb731fc4139cbb575429e28846f0c39 */
          id?: string;
          /** @example main_category */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/mainCategories
           */
          related?: string;
        };
      };
      manufacturer?: {
        data?: {
          /** @example c2904bca62b22443d6cf5e9d89cab204 */
          id?: string;
          /** @example product_manufacturer */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/manufacturer
           */
          related?: string;
        };
      };
      media?: {
        data?: {
          /** @example 62933a2951ef01f4eafd9bdf4d3cd2f0 */
          id?: string;
          /** @example product_media */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/media
           */
          related?: string;
        };
      };
      options?: {
        data?: {
          /** @example 93da65a9fd0004d9477aeac024e08e15 */
          id?: string;
          /** @example property_group_option */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/options
           */
          related?: string;
        };
      };
      parent?: {
        data?: {
          /** @example d0e45878043844ffc41aac437e86b602 */
          id?: string;
          /** @example product */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/parent
           */
          related?: string;
        };
      };
      productReviews?: {
        data?: {
          /** @example 01e78541ea343ed72424a5222796a4cd */
          id?: string;
          /** @example product_review */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/productReviews
           */
          related?: string;
        };
      };
      properties?: {
        data?: {
          /** @example 74693d2fc58b46bd06410f278e39aa71 */
          id?: string;
          /** @example property_group_option */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/properties
           */
          related?: string;
        };
      };
      seoCategory?: {
        data?: {
          /** @example 9354d004d12e03d35ad8292bf0bb234d */
          id?: string;
          /** @example category */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/seoCategory
           */
          related?: string;
        };
      };
      seoUrls?: {
        data?: {
          /** @example 5321b5a71127b8b98cdd4b068ad56c4c */
          id?: string;
          /** @example seo_url */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/seoUrls
           */
          related?: string;
        };
      };
      streams?: {
        data?: {
          /** @example 2f6f4768f1c2d7c8f1f54823723f1a70 */
          id?: string;
          /** @example product_stream */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/streams
           */
          related?: string;
        };
      };
      tags?: {
        data?: {
          /** @example d57ac45256849d9b13e2422d91580fb9 */
          id?: string;
          /** @example tag */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/tags
           */
          related?: string;
        };
      };
      tax?: {
        data?: {
          /** @example 06565e5611f23fdf8cc43e5077b92b54 */
          id?: string;
          /** @example tax */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/tax
           */
          related?: string;
        };
      };
      unit?: {
        data?: {
          /** @example 3e34bdebd9bd5edda27e8728904a2552 */
          id?: string;
          /** @example unit */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/unit
           */
          related?: string;
        };
      };
    };
    /** Format: date-time */
    releaseDate?: string;
    /** Format: int64 */
    restockTime?: number;
    /** Format: int64 */
    readonly sales?: number;
    shippingFree?: boolean;
    sortedProperties?: GenericRecord$1;
    readonly states?: string[];
    /** Format: int64 */
    stock: number;
    readonly streamIds?: string[];
    readonly tagIds?: string[];
    taxId: string;
    translated: {
      canonicalProductId: string;
      canonicalProductVersionId: string;
      cmsPageId: string;
      cmsPageVersionId: string;
      coverId: string;
      deliveryTimeId: string;
      description: string;
      displayGroup: string;
      ean: string;
      keywords: string;
      manufacturerId: string;
      manufacturerNumber: string;
      metaDescription: string;
      metaTitle: string;
      name: string;
      packUnit: string;
      packUnitPlural: string;
      parentId: string;
      parentVersionId: string;
      productManufacturerVersionId: string;
      productMediaVersionId: string;
      productNumber: string;
      releaseDate: string;
      taxId: string;
      unitId: string;
      versionId: string;
    };
    unitId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
    /** Format: float */
    weight?: number;
    /** Format: float */
    width?: number;
  } & components$1["schemas"]["DiscountLineItemPayload"] & {
      options: {
        group: string;
        option: string;
        translated: {
          group: string;
          option: string;
        };
      }[];
    };
  ProductKeywordDictionary: {
    id?: string;
    keyword: string;
    languageId: string;
  };
  ProductListingCriteria: components$1["schemas"]["Criteria"] & {
    /** Number of items per result page. If not set, the limit will be set according to the default products per page, defined in the system settings. */
    limit?: number;
    /** Filter by manufacturers. List of manufacturer identifiers separated by a `|`. */
    manufacturer?: string;
    /**
     * Enables/disabled filtering by manufacturer. If set to false, the `manufacturer` filter will be ignored. Also the `aggregations[manufacturer]` key will be removed from the response.
     * @default true
     */
    "manufacturer-filter"?: boolean;
    /**
     * Filters by a maximum product price. Has to be higher than the `min-price` filter.
     * @default 0
     */
    "max-price"?: number;
    /**
     * Filters by a minimum product price. Has to be lower than the `max-price` filter.
     * @default 0
     */
    "min-price"?: number;
    /** Specifies the sorting of the products by `availableSortings`. If not set, the default sorting will be set according to the shop settings. The available sorting options are sent within the response under the `availableSortings` key. In order to sort by a field, consider using the `sort` parameter from the listing criteria. Do not use both parameters together, as it might lead to unexpected results. */
    order?: string;
    /**
     * Search result page
     * @default 1
     */
    p?: number;
    /**
     * Enables/disabled filtering by price. If set to false, the `min-price` and `max-price` filter will be ignored. Also the `aggregations[price]` key will be removed from the response.
     * @default true
     */
    "price-filter"?: boolean;
    /** Filters products by their properties. List of property identifiers separated by a `|`. */
    properties?: string;
    /**
     * Enables/disabled filtering by properties products. If set to false, the `properties` filter will be ignored. Also the `aggregations[properties]` key will be removed from the response.
     * @default true
     */
    "property-filter"?: boolean;
    /** A whitelist of property identifiers which can be used for filtering. List of property identifiers separated by a `|`. The `property-filter` must be `true`, otherwise the whitelist has no effect. */
    "property-whitelist"?: string;
    /** Filter products with a minimum average rating. */
    rating?: number;
    /**
     * Enables/disabled filtering by rating. If set to false, the `rating` filter will be ignored. Also the `aggregations[rating]` key will be removed from the response.
     * @default true
     */
    "rating-filter"?: boolean;
    /** By sending the parameter `reduce-aggregations` , the post-filters that were applied by the customer, are also applied to the aggregations. This has the consequence that only values are returned in the aggregations that would lead to further filter results. This parameter is a flag, the value has no effect. */
    "reduce-aggregations"?: string | null;
    /**
     * Filters products that are marked as shipping-free.
     * @default false
     */
    "shipping-free"?: boolean;
    /**
     * Enables/disabled filtering by shipping-free products. If set to false, the `shipping-free` filter will be ignored. Also the `aggregations[shipping-free]` key will be removed from the response.
     * @default true
     */
    "shipping-free-filter"?: boolean;
  };
  ProductListingFlags: {
    /** Resets all aggregations in the criteria. This parameter is a flag, the value has no effect. */
    "no-aggregations"?: string | null;
    /** If this flag is set, no products are fetched. Sorting and associations are also ignored. This parameter is a flag, the value has no effect. */
    "only-aggregations"?: string | null;
  };
  ProductListingResult: components$1["schemas"]["EntitySearchResult"] & {
    /** @enum {string} */
    apiAlias: "product_listing";
    /** Contains the available sorting. These can be used to show a sorting select-box in the product listing. */
    availableSortings: {
      /** @enum {string} */
      apiAlias: "product_sorting";
      key: string;
      label: string;
      priority: number;
      translated: {
        apiAlias?: string;
        key?: string;
        label: string;
      };
    }[];
    /** Contains the state of the filters. These can be used to create listing filters. */
    currentFilters: {
      manufacturer: string[];
      navigationId: string;
      price: {
        /** @default 0 */
        max: number;
        /** @default 0 */
        min: number;
      };
      properties: string[];
      rating?: number; // TODO: [OpenAPI][ProductListingResult] - rating should be defined the same as in body of the request
      search: string; // TODO: [OpenAPI][ProductListingResult] - search should be required as is required in body of the request, otherwise everywhere optional
      /** @default false */
      "shipping-free": boolean;
    };
    elements: components$1["schemas"]["Product"][];
    /** @enum {string} */
    entity?: "product";
    sorting?: string;
  };
  ProductManufacturer: {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    description?: string;
    id: string;
    link?: string;
    media?: components$1["schemas"]["Media"];
    mediaId?: string;
    name: string;
    translated: {
      description: string;
      link: string;
      mediaId: string;
      name: string;
      versionId: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  ProductMedia: {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    id: string;
    media: components$1["schemas"]["Media"];
    mediaId: string;
    /** Format: int64 */
    position?: number;
    productId: string;
    productVersionId?: string;
    thumbnails?: components$1["schemas"]["MediaThumbnail"][];
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  ProductPageResult: {
    apiAlias?: string;
    cmsPage?: components$1["schemas"]["CmsPage"];
    configurator?: components$1["schemas"]["PropertyGroup"] | null;
    product?: components$1["schemas"]["Product"];
  };
  ProductPayload: {
    /** the id from the product which is used in the interaction */
    productId: string;
  };
  ProductPrice: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  ProductReview: {
    comment?: string;
    content: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customerId?: string;
    customFields?: GenericRecord$1;
    externalUser?: string;
    id: string;
    languageId: string;
    /** Format: float */
    points: number;
    productId: string;
    productVersionId?: string;
    salesChannelId: string;
    status?: boolean;
    title: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  ProductReviewSummary: {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    product?: components$1["schemas"]["Product"];
    productId: string;
    salesChannel?: components$1["schemas"]["SalesChannel"];
    salesChannelId: string;
    summary?: string;
    translated: {
      productId: string;
      salesChannelId: string;
      summary: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    visible?: boolean;
  };
  ProductSearchConfig: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  ProductSearchConfigField: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  ProductSearchKeyword: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  ProductSorting: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    key: string;
    label: string;
    /** Format: int64 */
    priority: number;
    translated: {
      key: string;
      label: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  ProductStream: {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    description?: string;
    id: string;
    name: string;
    translated: {
      description: string;
      name: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  ProductStreamFilter: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  ProductVisibility: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  ProductWarehouse: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  Promotion: {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  PromotionDiscount: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  PromotionDiscountPrices: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  PromotionIndividualCode: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  PromotionSalesChannel: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  PromotionSetgroup: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  PropertyGroup: {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    description?: string;
    displayType?: string;
    filterable?: boolean;
    id: string;
    name: string;
    options?: components$1["schemas"]["PropertyGroupOption"][];
    /** Format: int64 */
    position?: number;
    sortingType?: string;
    translated: {
      description: string;
      displayType: string;
      name: string;
      sortingType: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    visibleOnProductDetailPage?: boolean;
  };
  PropertyGroupOption: {
    colorHexCode?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    group: components$1["schemas"]["PropertyGroup"];
    groupId: string;
    id: string;
    media?: components$1["schemas"]["Media"];
    mediaId?: string;
    name: string;
    option: string;
    /** Format: int64 */
    position?: number;
    translated: {
      colorHexCode: string;
      groupId: string;
      mediaId: string;
      name: string;
      option: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  Query: {
    query?:
      | components$1["schemas"]["SimpleFilter"]
      | components$1["schemas"]["EqualsFilter"]
      | components$1["schemas"]["MultiNotFilter"]
      | components$1["schemas"]["RangeFilter"];
    score?: number;
  } & {
    [key: string]: unknown;
  };
  Quote: {
    /** Format: float */
    readonly amountNet?: number;
    /** Format: float */
    readonly amountTotal?: number;
    comments?: components$1["schemas"]["QuoteComment"][];
    /** Format: date-time */
    readonly createdAt?: string;
    createdById?: string;
    currency?: components$1["schemas"]["Currency"];
    currencyId: string;
    customerId: string;
    customFields?: GenericRecord$1;
    deliveries?: components$1["schemas"]["QuoteDelivery"][];
    discount?: {
      type?: string;
      /** Format: float */
      value?: number;
    };
    documents?: components$1["schemas"]["QuoteDocument"][];
    /** Format: date-time */
    expirationDate?: string;
    id: string;
    language?: components$1["schemas"]["Language"];
    languageId: string;
    lineItems?: components$1["schemas"]["QuoteLineItem"][];
    orderId?: string;
    orderVersionId?: string;
    price: {
      calculatedTaxes?: GenericRecord$1;
      /** Format: float */
      netPrice: number;
      /** Format: float */
      positionPrice: number;
      /** Format: float */
      rawTotal: number;
      taxRules?: GenericRecord$1;
      taxStatus: string;
      /** Format: float */
      totalPrice: number;
    };
    quoteNumber?: string;
    salesChannelId: string;
    /** Format: date-time */
    sentAt?: string;
    shippingCosts?: {
      calculatedTaxes?: GenericRecord$1;
      listPrice?: {
        /** Format: float */
        discount?: number;
        /** Format: float */
        percentage?: number;
        /** Format: float */
        price?: number;
      };
      /** Format: int64 */
      quantity: number;
      referencePrice?: GenericRecord$1;
      regulationPrice?: {
        /** Format: float */
        price?: number;
      };
      taxRules?: GenericRecord$1;
      /** Format: float */
      totalPrice: number;
      /** Format: float */
      unitPrice: number;
    };
    stateId: string;
    stateMachineState: components$1["schemas"]["StateMachineState"];
    /** Format: float */
    subtotalNet?: number;
    readonly taxStatus?: string;
    /** Format: float */
    totalDiscount?: number;
    transactions?: components$1["schemas"]["QuoteTransaction"][];
    /** Format: date-time */
    readonly updatedAt?: string;
    updatedById?: string;
    userId?: string;
    versionId?: string;
  };
  QuoteComment: {
    comment: string;
    /** Format: date-time */
    readonly createdAt?: string;
    createdById?: string;
    customer?: components$1["schemas"]["Customer"];
    customerId?: string;
    id: string;
    quoteId: string;
    quoteVersionId?: string;
    /** Format: date-time */
    seenAt?: string;
    stateId?: string;
    stateMachineState?: components$1["schemas"]["StateMachineState"];
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  QuoteDelivery: {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    id: string;
    positions?: components$1["schemas"]["QuoteDeliveryPosition"][];
    quoteId: string;
    quoteVersionId?: string;
    shippingCosts?: {
      calculatedTaxes?: GenericRecord$1;
      listPrice?: {
        /** Format: float */
        discount?: number;
        /** Format: float */
        percentage?: number;
        /** Format: float */
        price?: number;
      };
      /** Format: int64 */
      quantity: number;
      referencePrice?: GenericRecord$1;
      regulationPrice?: {
        /** Format: float */
        price?: number;
      };
      taxRules?: GenericRecord$1;
      /** Format: float */
      totalPrice: number;
      /** Format: float */
      unitPrice: number;
    };
    /** Format: date-time */
    shippingDateEarliest: string;
    /** Format: date-time */
    shippingDateLatest: string;
    shippingMethod?: components$1["schemas"]["ShippingMethod"];
    shippingMethodId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  QuoteDeliveryPosition: {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    id: string;
    price?: {
      calculatedTaxes?: GenericRecord$1;
      listPrice?: {
        /** Format: float */
        discount?: number;
        /** Format: float */
        percentage?: number;
        /** Format: float */
        price?: number;
      };
      /** Format: int64 */
      quantity: number;
      referencePrice?: GenericRecord$1;
      regulationPrice?: {
        /** Format: float */
        price?: number;
      };
      taxRules?: GenericRecord$1;
      /** Format: float */
      totalPrice: number;
      /** Format: float */
      unitPrice: number;
    };
    /** Format: int64 */
    quantity?: number;
    quoteDeliveryId: string;
    quoteDeliveryVersionId?: string;
    quoteLineItemId: string;
    quoteLineItemVersionId?: string;
    /** Format: float */
    totalPrice?: number;
    /** Format: float */
    unitPrice?: number;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  QuoteDocument: {
    active?: boolean;
    config: GenericRecord$1;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    deepLinkCode: string;
    documentMediaFile?: components$1["schemas"]["Media"];
    documentMediaFileId?: string;
    documentNumber?: string;
    documentType?: components$1["schemas"]["DocumentType"];
    documentTypeId: string;
    fileType: string;
    id: string;
    quote?: components$1["schemas"]["Quote"];
    quoteId: string;
    quoteVersionId?: string;
    sent?: boolean;
    static?: boolean;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  QuoteEmployee: {
    /** Format: date-time */
    readonly createdAt?: string;
    firstName: string;
    id?: string;
    lastName: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  QuoteJsonApi: components$1["schemas"]["resource"] & {
    /** Format: float */
    readonly amountNet?: number;
    /** Format: float */
    readonly amountTotal?: number;
    /** Format: date-time */
    readonly createdAt?: string;
    createdById?: string;
    currencyId: string;
    customerId: string;
    customFields?: GenericRecord$1;
    discount?: {
      type?: string;
      /** Format: float */
      value?: number;
    };
    /** Format: date-time */
    expirationDate?: string;
    id: string;
    languageId: string;
    orderId?: string;
    orderVersionId?: string;
    price?: {
      calculatedTaxes?: GenericRecord$1;
      /** Format: float */
      netPrice: number;
      /** Format: float */
      positionPrice: number;
      /** Format: float */
      rawTotal: number;
      taxRules?: GenericRecord$1;
      taxStatus: string;
      /** Format: float */
      totalPrice: number;
    };
    quoteNumber?: string;
    relationships?: {
      comments?: {
        data?: {
          /** @example a5d491060952aa8ad5fdee071be752de */
          id?: string;
          /** @example quote_comment */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /quote/c48e929b2b1eabba2ba036884433345e/comments
           */
          related?: string;
        };
      };
      currency?: {
        data?: {
          /** @example 1af0389838508d7016a9841eb6273962 */
          id?: string;
          /** @example currency */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /quote/c48e929b2b1eabba2ba036884433345e/currency
           */
          related?: string;
        };
      };
      deliveries?: {
        data?: {
          /** @example 6fc31b6b9cd717cc0dcb81152308f8af */
          id?: string;
          /** @example quote_delivery */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /quote/c48e929b2b1eabba2ba036884433345e/deliveries
           */
          related?: string;
        };
      };
      documents?: {
        data?: {
          /** @example 21f64da1e5792c8295b964d159a14491 */
          id?: string;
          /** @example quote_document */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /quote/c48e929b2b1eabba2ba036884433345e/documents
           */
          related?: string;
        };
      };
      language?: {
        data?: {
          /** @example 8512ae7d57b1396273f76fe6ed341a23 */
          id?: string;
          /** @example language */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /quote/c48e929b2b1eabba2ba036884433345e/language
           */
          related?: string;
        };
      };
      lineItems?: {
        data?: {
          /** @example a042af1aa9f3853fe3cd7dabc065568f */
          id?: string;
          /** @example quote_line_item */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /quote/c48e929b2b1eabba2ba036884433345e/lineItems
           */
          related?: string;
        };
      };
      stateMachineState?: {
        data?: {
          /** @example 1ab22d393154f21e3be76aca3ec3ee31 */
          id?: string;
          /** @example state_machine_state */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /quote/c48e929b2b1eabba2ba036884433345e/stateMachineState
           */
          related?: string;
        };
      };
      transactions?: {
        data?: {
          /** @example c15b977dd99332ca8623fbdfb86827e8 */
          id?: string;
          /** @example quote_transaction */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /quote/c48e929b2b1eabba2ba036884433345e/transactions
           */
          related?: string;
        };
      };
    };
    salesChannelId: string;
    /** Format: date-time */
    sentAt?: string;
    shippingCosts?: {
      calculatedTaxes?: GenericRecord$1;
      listPrice?: {
        /** Format: float */
        discount?: number;
        /** Format: float */
        percentage?: number;
        /** Format: float */
        price?: number;
      };
      /** Format: int64 */
      quantity: number;
      referencePrice?: GenericRecord$1;
      regulationPrice?: {
        /** Format: float */
        price?: number;
      };
      taxRules?: GenericRecord$1;
      /** Format: float */
      totalPrice: number;
      /** Format: float */
      unitPrice: number;
    };
    stateId: string;
    /** Format: float */
    subtotalNet?: number;
    readonly taxStatus?: string;
    /** Format: float */
    totalDiscount?: number;
    /** Format: date-time */
    readonly updatedAt?: string;
    updatedById?: string;
    userId?: string;
    versionId?: string;
  };
  QuoteLineItem: {
    children: components$1["schemas"]["QuoteLineItem"][];
    cover?: components$1["schemas"]["Media"];
    coverId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    deliveryPositions?: components$1["schemas"]["QuoteDeliveryPosition"][];
    description?: string;
    discount?: {
      type?: string;
      /** Format: int64 */
      value?: number;
    };
    good?: boolean;
    id: string;
    identifier: string;
    label: string;
    parent?: components$1["schemas"]["QuoteLineItem"];
    parentId?: string;
    parentVersionId?: string;
    payload?: GenericRecord$1;
    /** Format: int64 */
    position: number;
    priceDefinition?: GenericRecord$1;
    productId?: string;
    productPrice?: components$1["schemas"]["Price"][];
    productVersionId?: string;
    purchasePrice?: components$1["schemas"]["Price"][];
    /** Format: int64 */
    quantity: number;
    quoteId: string;
    quoteVersionId?: string;
    referencedId?: string;
    removable?: boolean;
    stackable?: boolean;
    states: string[];
    /** Format: float */
    totalPrice?: number;
    type?: string;
    /** Format: float */
    unitPrice?: number;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  QuoteTransaction: {
    amount: {
      calculatedTaxes?: GenericRecord$1;
      listPrice?: {
        /** Format: float */
        discount?: number;
        /** Format: float */
        percentage?: number;
        /** Format: float */
        price?: number;
      };
      /** Format: int64 */
      quantity: number;
      referencePrice?: GenericRecord$1;
      regulationPrice?: {
        /** Format: float */
        price?: number;
      };
      taxRules?: GenericRecord$1;
      /** Format: float */
      totalPrice: number;
      /** Format: float */
      unitPrice: number;
    };
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    id: string;
    paymentMethod?: components$1["schemas"]["PaymentMethod"];
    paymentMethodId: string;
    quoteId: string;
    quoteVersionId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  RangeFilter: {
    field: string;
    parameters: {
      gt?: number;
      gte?: number;
      lt?: number;
      lte?: number;
    };
    /** @enum {string} */
    type: "range";
  };
  ReferencePrice: {
    /** @enum {string} */
    apiAlias?: "cart_price_reference";
    hasRange: boolean;
    listPrice: components$1["schemas"]["ListPrice"] | null;
    price?: number;
    purchaseUnit?: number;
    referenceUnit?: number;
    regulationPrice: {
      /** @enum {string} */
      apiAlias?: "cart_regulation_price";
      price?: number;
    } | null;
    unitName: string;
    /** Format: ^[0-9a-f]{32}$ */
    variantId?: string | null;
  };
  Rule: {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    description?: string;
    extensions?: {
      swagCmsExtensionsBlockRules?: {
        data?: {
          /** @example ce0b9f43f8947576ee10c93d4d69a4c4 */
          id?: string;
          /** @example swag_cms_extensions_block_rule */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /rule/ab7a485ebe75b6dd7243ad719f23c7de/swagCmsExtensionsBlockRules
           */
          related?: string;
        };
      };
      warehouseGroup?: {
        data?: {
          /** @example 1768e3071b62161d415e0c24332055ed */
          id?: string;
          /** @example warehouse_group */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /rule/ab7a485ebe75b6dd7243ad719f23c7de/warehouseGroup
           */
          related?: string;
        };
      };
    };
    id?: string;
    name: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  RuleCondition: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SaasAppStorefrontConfig: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SaasSbpUserData: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SaasStorefrontDemoToken: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SaasUserLoginToken: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SalesChannel: {
    active?: boolean;
    configuration?: GenericRecord$1;
    country?: components$1["schemas"]["Country"];
    countryId: string;
    /** Format: date-time */
    readonly createdAt?: string;
    currency?: components$1["schemas"]["Currency"];
    currencyId: string;
    customerGroupId: string;
    customFields?: GenericRecord$1;
    domains?: components$1["schemas"]["SalesChannelDomain"][];
    footerCategory?: components$1["schemas"]["Category"];
    footerCategoryId?: string;
    footerCategoryVersionId?: string;
    hreflangActive?: boolean;
    hreflangDefaultDomain?: components$1["schemas"]["SalesChannelDomain"];
    hreflangDefaultDomainId?: string;
    id: string;
    language?: components$1["schemas"]["Language"];
    languageId: string;
    mailHeaderFooterId?: string;
    maintenance?: boolean;
    name: string;
    navigationCategory?: components$1["schemas"]["Category"];
    /** Format: int64 */
    navigationCategoryDepth?: number;
    navigationCategoryId: string;
    navigationCategoryVersionId?: string;
    paymentMethod?: components$1["schemas"]["PaymentMethod"];
    paymentMethodId: string;
    serviceCategory?: components$1["schemas"]["Category"];
    serviceCategoryId?: string;
    serviceCategoryVersionId?: string;
    shippingMethod?: components$1["schemas"]["ShippingMethod"];
    shippingMethodId: string;
    shortName?: string;
    taxCalculationType?: string;
    translated: {
      countryId: string;
      currencyId: string;
      customerGroupId: string;
      footerCategoryId: string;
      footerCategoryVersionId: string;
      hreflangDefaultDomainId: string;
      languageId: string;
      mailHeaderFooterId: string;
      name: string;
      navigationCategoryId: string;
      navigationCategoryVersionId: string;
      paymentMethodId: string;
      serviceCategoryId: string;
      serviceCategoryVersionId: string;
      shippingMethodId: string;
      shortName: string;
      taxCalculationType: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SalesChannelAnalytics: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SalesChannelContext: {
    /** @enum {string} */
    apiAlias: "sales_channel_context";
    /** Core context with general configuration values and state */
    context?: {
      currencyFactor?: number;
      currencyId?: string;
      /** Format: int32 */
      currencyPrecision?: number;
      languageIdChain?: string[];
      scope?: string;
      source?: string;
      taxState?: string;
      useCache?: boolean;
      versionId?: string;
    };
    currency?: components$1["schemas"]["Currency"];
    /** Customer group of the current user */
    currentCustomerGroup?: {
      displayGross?: boolean;
      name?: string;
    };
    customer?: components$1["schemas"]["Customer"];
    /** Fallback group if the default customer group is not applicable */
    fallbackCustomerGroup?: {
      displayGross?: boolean;
      name?: string;
    };
    languageInfo: {
      localeCode: string;
      name: string;
    };
    paymentMethod?: components$1["schemas"]["PaymentMethod"];
    salesChannel: components$1["schemas"]["SalesChannel"];
    shippingLocation?: {
      address?: components$1["schemas"]["CustomerAddress"];
      /** @enum {string} */
      apiAlias?: "cart_delivery_shipping_location";
      country?: components$1["schemas"]["Country"];
    };
    shippingMethod?: components$1["schemas"]["ShippingMethod"];
    /** Currently active tax rules and/or rates */
    taxRules?: {
      name?: string;
      /** Format: float */
      taxRate?: number;
    }[];
    /** Context the user session */
    token?: string;
  };
  SalesChannelDomain: {
    /** Format: date-time */
    readonly createdAt?: string;
    currency?: components$1["schemas"]["Currency"];
    currencyId: string;
    customFields?: GenericRecord$1;
    hreflangUseOnlyLocale?: boolean;
    id: string;
    language?: components$1["schemas"]["Language"];
    languageId: string;
    salesChannelDefaultHreflang?: components$1["schemas"]["SalesChannel"];
    salesChannelId: string;
    snippetSetId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    url: string;
  };
  SalesChannelType: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  Salutation: {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    displayName: string;
    id: string;
    letterName: string;
    salutationKey: string;
    translated: {
      displayName: string;
      letterName: string;
      salutationKey: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SalutationJsonApi: components$1["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    displayName: string;
    id: string;
    letterName: string;
    salutationKey: string;
    translated: {
      displayName: string;
      letterName: string;
      salutationKey: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  ScheduledTask: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  ScreenSharingToggledInteraction: components$1["schemas"]["BaseInteraction"] & {
    name: string;
    payload: components$1["schemas"]["ScreenSharingToggledPayload"];
  } & {
    /**
     * discriminator enum property added by openapi-typescript
     * @enum {string}
     */
    name: "screenSharing.toggled";
  };
  ScreenSharingToggledPayload: {
    /** Whether the screen sharing is active or not */
    active: boolean;
  };
  Script: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SearchByImageSearchTermResponse: {
    /** @enum {string} */
    apiAlias: "product_image_upload_search_term";
    extensions?: GenericRecord$1[];
    term: string;
  }[];
  SeoUrl: {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    /** Runtime field, cannot be used as part of the criteria. */
    error?: string;
    foreignKey: string;
    id: string;
    isCanonical?: boolean;
    isDeleted?: boolean;
    isModified?: boolean;
    languageId: string;
    pathInfo: string;
    /** @enum {string} */
    routeName:
      | "frontend.navigation.page"
      | "frontend.landing.page"
      | "frontend.detail.page";
    salesChannelId?: string;
    seoPathInfo: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    /** Runtime field, cannot be used as part of the criteria. */
    url?: string;
  };
  SeoUrlJsonApi: components$1["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    /** Runtime field, cannot be used as part of the criteria. */
    error?: string;
    foreignKey: string;
    id: string;
    isCanonical?: boolean;
    isDeleted?: boolean;
    isModified?: boolean;
    languageId: string;
    pathInfo: string;
    routeName: string;
    salesChannelId?: string;
    seoPathInfo: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    /** Runtime field, cannot be used as part of the criteria. */
    url?: string;
  };
  SeoUrlTemplate: {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    id?: string;
    isValid?: boolean;
    salesChannelId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  ShippingMethod: {
    active?: boolean;
    availabilityRule?: components$1["schemas"]["Rule"];
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    deliveryTime?: components$1["schemas"]["DeliveryTime"];
    deliveryTimeId: string;
    description?: string;
    id: string;
    media?: components$1["schemas"]["Media"];
    mediaId?: string;
    name: string;
    /** Format: int64 */
    position?: number;
    prices?: components$1["schemas"]["ShippingMethodPrice"][];
    tags?: components$1["schemas"]["Tag"][];
    tax?: components$1["schemas"]["Tax"];
    taxType?: string;
    technicalName?: string;
    trackingUrl?: string;
    translated: {
      deliveryTimeId: string;
      description: string;
      mediaId: string;
      name: string;
      taxType: string;
      technicalName: string;
      trackingUrl: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  ShippingMethodJsonApi: components$1["schemas"]["resource"] & {
    active?: boolean;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    deliveryTimeId: string;
    description?: string;
    id: string;
    mediaId?: string;
    name: string;
    /** Format: int64 */
    position?: number;
    relationships?: {
      availabilityRule?: {
        data?: {
          /** @example 9fbb7961d1cb158094924c679e1b302c */
          id?: string;
          /** @example rule */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /shipping-method/d72e7a227a27328b28342b32fc66b6bf/availabilityRule
           */
          related?: string;
        };
      };
      deliveryTime?: {
        data?: {
          /** @example 8c888ae25a7bd42057370e31f7e01044 */
          id?: string;
          /** @example delivery_time */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /shipping-method/d72e7a227a27328b28342b32fc66b6bf/deliveryTime
           */
          related?: string;
        };
      };
      media?: {
        data?: {
          /** @example 62933a2951ef01f4eafd9bdf4d3cd2f0 */
          id?: string;
          /** @example media */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /shipping-method/d72e7a227a27328b28342b32fc66b6bf/media
           */
          related?: string;
        };
      };
      prices?: {
        data?: {
          /** @example afae32efe0f84fece3f96b377b768b33 */
          id?: string;
          /** @example shipping_method_price */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /shipping-method/d72e7a227a27328b28342b32fc66b6bf/prices
           */
          related?: string;
        };
      };
      tags?: {
        data?: {
          /** @example d57ac45256849d9b13e2422d91580fb9 */
          id?: string;
          /** @example tag */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /shipping-method/d72e7a227a27328b28342b32fc66b6bf/tags
           */
          related?: string;
        };
      };
      tax?: {
        data?: {
          /** @example 06565e5611f23fdf8cc43e5077b92b54 */
          id?: string;
          /** @example tax */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /shipping-method/d72e7a227a27328b28342b32fc66b6bf/tax
           */
          related?: string;
        };
      };
    };
    taxType?: string;
    technicalName?: string;
    trackingUrl?: string;
    translated: {
      deliveryTimeId: string;
      description: string;
      mediaId: string;
      name: string;
      taxType: string;
      technicalName: string;
      trackingUrl: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  ShippingMethodPageRouteResponse: {
    active?: boolean;
    availabilityRule?: {
      description?: string;
      invalid?: boolean;
      name?: string;
      /** Format: int32 */
      priority?: number;
    };
    availabilityRuleId?: string;
    deliveryTime?: {
      /** Format: int32 */
      max?: number;
      /** Format: int32 */
      min?: number;
      name?: string;
      unit?: string;
    };
    deliveryTimeId?: string;
    description?: string;
    media?: {
      alt?: string;
      fileExtension?: string;
      fileName?: string;
      /** Format: int32 */
      fileSize?: number;
      mediaFolderId?: string;
      mediaTypeRaw?: string;
      metaDataRaw?: string;
      mimeType?: string;
      private?: boolean;
      thumbnailsRo?: string;
      title?: string;
      /** Format: date-time */
      uploadedAt?: string;
      url?: string;
      userId?: string;
    };
    mediaId?: string;
    name?: string;
    orderDeliveries?: {
      orderId?: string;
      /** Format: date-time */
      shippingDateEarliest?: string;
      /** Format: date-time */
      shippingDateLatest?: string;
      shippingMethodId?: string;
      shippingOrderAddressId?: string;
      stateId?: string;
    }[];
    prices?: {
      /** Format: int32 */
      calculation?: number;
      calculationRuleId?: string;
      currencyId?: string;
      /** Format: float */
      price?: number;
      /** Format: float */
      quantityEnd?: number;
      /** Format: float */
      quantityStart?: number;
      ruleId?: string;
      shippingMethodId?: string;
    }[];
    salesChannelDefaultAssignments?: {
      accessKey?: string;
      active?: boolean;
      countryId?: string;
      currencyId?: string;
      customerGroupId?: string;
      footerCategoryId?: string;
      hreflangActive?: boolean;
      hreflangDefaultDomainId?: string;
      languageId?: string;
      mailHeaderFooterId?: string;
      maintenance?: boolean;
      maintenanceIpWhitelist?: string;
      name?: string;
      /** Format: int32 */
      navigationCategoryDepth?: number;
      navigationCategoryId?: string;
      paymentMethodId?: string;
      serviceCategoryId?: string;
      shippingMethodId?: string;
      shortName?: string;
      typeId?: string;
    }[];
    salesChannels?: {
      accessKey?: string;
      active?: boolean;
      countryId?: string;
      currencyId?: string;
      customerGroupId?: string;
      footerCategoryId?: string;
      hreflangActive?: boolean;
      hreflangDefaultDomainId?: string;
      languageId?: string;
      mailHeaderFooterId?: string;
      maintenance?: boolean;
      maintenanceIpWhitelist?: string;
      name?: string;
      /** Format: int32 */
      navigationCategoryDepth?: number;
      navigationCategoryId?: string;
      paymentMethodId?: string;
      serviceCategoryId?: string;
      shippingMethodId?: string;
      shortName?: string;
      typeId?: string;
    }[];
    tags?: {
      name?: string;
    }[];
    translations?: {
      description?: string;
      name?: string;
      shippingMethodId?: string;
    }[];
  }[];
  ShippingMethodPrice: {
    /** Format: int64 */
    calculation?: number;
    calculationRuleId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    currencyPrice?: components$1["schemas"]["Price"][];
    customFields?: GenericRecord$1;
    id: string;
    /** Format: float */
    quantityEnd?: number;
    /** Format: float */
    quantityStart?: number;
    ruleId?: string;
    shippingMethodId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SimpleFilter: {
    field: string;
    /** @enum {string} */
    type: "contains" | "equalsAny" | "prefix" | "suffix";
    value: string;
  };
  Sitemap: {
    /** Format: date-time */
    created: string;
    filename: string;
  };
  Snippet: {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    id?: string;
    setId: string;
    translationKey: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    value: string;
  };
  SnippetSet: {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    id?: string;
    iso: string;
    name: string;
    snippets?: components$1["schemas"]["Snippet"][];
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  Sort: {
    field: string;
    naturalSorting?: boolean;
    /** @enum {string} */
    order: "ASC" | "DESC";
    type?: string;
  };
  SpatialRenderConfigSize: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SpatialScene: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SpatialSceneCamera: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SpatialSceneGroup: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SpatialSceneLight: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SpatialSceneMaterial: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SpatialSceneObject: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SpatialScenePrimitive: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SsoProvider: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    media?: components$1["schemas"]["Media"];
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SsoProviderCustomer: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  StateForAll: {
    accessibleFrom?: string | null;
    accessibleTo?: string | null;
    /** @default false */
    allowScreenSharing?: boolean;
    /** @default false */
    allowUserActionsForGuide?: boolean;
    /** @enum {string} */
    appointmentMode?: "guided" | "self";
    attendeeRestrictionType?: ("open" | "customer" | "rules") | null;
    /** @default false */
    broadcastMode?: boolean;
    currentDynamicPage?: components$1["schemas"]["DynamicPageOpenedPayload"];
    currentGuideProductId?: string | null;
    currentPageId?: string | null;
    currentSectionId?: string | null;
    /** @default 0 */
    currentSlideAlias?: number;
    currentSlideData?:
      | components$1["schemas"]["DynamicProductListingPageOpenedPayload"]
      | null;
    /** @default false */
    ended?: boolean;
    endedAt?: string | null;
    /** @default [] */
    extensions?: unknown[];
    lastActiveGuideSection?: string | null;
    productDetailDefaultPageId?: string | null;
    productListingDefaultPageId?: string | null;
    quickviewPageId?: string | null;
    /** @default false */
    running?: boolean;
    /** @default false */
    started?: boolean;
    startedAt?: string | null;
    /**
     * @default none
     * @enum {string}
     */
    videoAudioSettings?: "both" | "none" | "audio-only";
    /** @default  */
    videoRoomUrl?: string;
    /**
     * @default presentation
     * @enum {string}
     */
    viewMode?: "onlyYou" | "presentation" | "videoGrid";
  };
  StateForClients: {
    /** @default [] */
    extensions?: unknown[];
    hoveredElementId?: string | null;
    videoClientToken?: string | null;
  };
  StateMachine: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    states?: components$1["schemas"]["StateMachineState"][];
    transitions?: components$1["schemas"]["StateMachineTransition"][];
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  StateMachineHistory: {
    /** Format: date-time */
    readonly createdAt?: string;
    fromStateMachineState?: components$1["schemas"]["StateMachineState"];
    id?: string;
    toStateMachineState?: components$1["schemas"]["StateMachineState"];
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  StateMachineState: {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    id?: string;
    name: string;
    technicalName: string;
    translated: {
      name: string;
      technicalName: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  StateMachineTransition: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SubAggregations: {
    aggregation?:
      | components$1["schemas"]["AggregationMetrics"]
      | components$1["schemas"]["AggregationEntity"]
      | components$1["schemas"]["AggregationFilter"]
      | components$1["schemas"]["AggregationTerms"]
      | components$1["schemas"]["AggregationHistogram"]
      | components$1["schemas"]["AggregationRange"];
  };
  Subscription: {
    addresses?: components$1["schemas"]["SubscriptionAddress"][];
    billingAddress?: components$1["schemas"]["SubscriptionAddress"];
    billingAddressId: string;
    convertedOrder: GenericRecord$1;
    /** Format: date-time */
    readonly createdAt?: string;
    cronInterval: string;
    currency?: components$1["schemas"]["Currency"];
    currencyId: string;
    customFields?: GenericRecord$1;
    dateInterval: string;
    id: string;
    /** Format: int64 */
    initialExecutionCount?: number;
    language?: components$1["schemas"]["Language"];
    languageId: string;
    /** Format: date-time */
    nextSchedule: string;
    orders?: components$1["schemas"]["Order"][];
    paymentMethod?: components$1["schemas"]["PaymentMethod"];
    paymentMethodId: string;
    /** Format: int64 */
    remainingExecutionCount?: number;
    salesChannelId: string;
    shippingAddress?: components$1["schemas"]["SubscriptionAddress"];
    shippingAddressId: string;
    shippingMethod?: components$1["schemas"]["ShippingMethod"];
    shippingMethodId: string;
    stateMachineState?: components$1["schemas"]["StateMachineState"];
    subscriptionCustomer?: components$1["schemas"]["SubscriptionCustomer"];
    subscriptionInterval?: components$1["schemas"]["SubscriptionInterval"];
    subscriptionIntervalId?: string;
    subscriptionIntervalName: string;
    subscriptionNumber: string;
    subscriptionPlan?: components$1["schemas"]["SubscriptionPlan"];
    subscriptionPlanId?: string;
    subscriptionPlanName: string;
    tags?: components$1["schemas"]["Tag"][];
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SubscriptionAddress: {
    additionalAddressLine1?: string;
    additionalAddressLine2?: string;
    billingSubscription?: components$1["schemas"]["Subscription"];
    city: string;
    company?: string;
    country?: components$1["schemas"]["Country"];
    countryId: string;
    countryState?: components$1["schemas"]["CountryState"];
    countryStateId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    department?: string;
    firstName: string;
    id: string;
    lastName: string;
    phoneNumber?: string;
    salutation?: components$1["schemas"]["Salutation"];
    salutationId?: string;
    shippingSubscription?: components$1["schemas"]["Subscription"];
    street: string;
    subscription?: components$1["schemas"]["Subscription"];
    subscriptionId: string;
    title?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    vatId?: string;
    zipcode?: string;
  };
  SubscriptionCustomer: {
    company?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customerId?: string;
    customerNumber?: string;
    customFields?: GenericRecord$1;
    email: string;
    firstName: string;
    id: string;
    lastName: string;
    salutation?: components$1["schemas"]["Salutation"];
    salutationId: string;
    title?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    vatIds?: string[];
  };
  SubscriptionInterval: {
    active?: boolean;
    availabilityRuleId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    cronInterval?: string;
    dateInterval?: string;
    id: string;
    name: string;
    subscriptions?: components$1["schemas"]["Subscription"][];
    translated: {
      availabilityRuleId: string;
      cronInterval: string;
      dateInterval: string;
      name: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SubscriptionPlan: {
    active?: boolean;
    activeStorefrontLabel?: boolean;
    availabilityRuleId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    description?: string;
    /** Format: float */
    discountPercentage?: number;
    discountPrice?: components$1["schemas"]["Price"][];
    id: string;
    label?: string;
    /** Format: int64 */
    minimumExecutionCount?: number;
    name: string;
    subscriptions?: components$1["schemas"]["Subscription"][];
    translated: {
      availabilityRuleId: string;
      description: string;
      label: string;
      name: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SubscriptionPlanIntervalMapping: {
    id?: string;
    subscriptionInterval?: components$1["schemas"]["SubscriptionInterval"];
    subscriptionIntervalId: string;
    subscriptionPlan?: components$1["schemas"]["SubscriptionPlan"];
    subscriptionPlanId: string;
  };
  SubscriptionPlanJsonApi: components$1["schemas"]["resource"] & {
    active?: boolean;
    activeStorefrontLabel?: boolean;
    availabilityRuleId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    description?: string;
    /** Format: float */
    discountPercentage?: number;
    discountPrice?: components$1["schemas"]["Price"][];
    id: string;
    label?: string;
    /** Format: int64 */
    minimumExecutionCount?: number;
    name: string;
    relationships?: {
      subscriptions?: {
        data?: {
          /** @example 2d5d14f95af035cbd8437948de61f94c */
          id?: string;
          /** @example subscription */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /subscription-plan/5e63f9057837020694081b9412211bfb/subscriptions
           */
          related?: string;
        };
      };
    };
    translated: {
      availabilityRuleId: string;
      description: string;
      label: string;
      name: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SubscriptionPlanProductMapping: {
    id?: string;
    product?: components$1["schemas"]["Product"];
    productId: string;
    productVersionId?: string;
    subscriptionPlan?: components$1["schemas"]["SubscriptionPlan"];
    subscriptionPlanId: string;
  };
  SubscriptionTagMapping: {
    id?: string;
    subscription?: components$1["schemas"]["Subscription"];
    subscriptionId: string;
    tag?: components$1["schemas"]["Tag"];
    tagId: string;
  };
  SuccessResponse: {
    success?: boolean;
  };
  SwagCmsExtensionsBlockRule: {
    cmsBlock?: components$1["schemas"]["CmsBlock"];
    cmsBlockId: string;
    cmsBlockVersionId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    inverted?: boolean;
    /** Format: date-time */
    readonly updatedAt?: string;
    visibilityRule?: components$1["schemas"]["Rule"];
    visibilityRuleId?: string;
  };
  SwagCmsExtensionsForm: {
    cmsSlot?: components$1["schemas"]["CmsSlot"];
    cmsSlotId?: string;
    cmsSlotVersionId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    groups?: components$1["schemas"]["SwagCmsExtensionsFormGroup"][];
    id: string;
    isTemplate?: boolean;
    mailTemplate?: components$1["schemas"]["MailTemplate"];
    mailTemplateId: string;
    receivers?: GenericRecord$1;
    successMessage?: string;
    technicalName: string;
    title?: string;
    translated: {
      cmsSlotId: string;
      cmsSlotVersionId: string;
      mailTemplateId: string;
      successMessage: string;
      technicalName: string;
      title: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagCmsExtensionsFormGroup: {
    /** Format: date-time */
    readonly createdAt?: string;
    fields?: components$1["schemas"]["SwagCmsExtensionsFormGroupField"][];
    form?: components$1["schemas"]["SwagCmsExtensionsForm"];
    formId?: string;
    id: string;
    /** Format: int64 */
    position: number;
    technicalName: string;
    title?: string;
    translated: {
      formId: string;
      technicalName: string;
      title: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagCmsExtensionsFormGroupField: {
    config?: GenericRecord$1;
    /** Format: date-time */
    readonly createdAt?: string;
    errorMessage?: string;
    group?: components$1["schemas"]["SwagCmsExtensionsFormGroup"];
    groupId?: string;
    id: string;
    label: string;
    placeholder?: string;
    /** Format: int64 */
    position: number;
    required?: boolean;
    technicalName: string;
    translated: {
      errorMessage: string;
      groupId: string;
      label: string;
      placeholder: string;
      technicalName: string;
      type: string;
    };
    type: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    /** Format: int64 */
    width: number;
  };
  SwagCmsExtensionsQuickview: {
    active?: boolean;
    cmsBlock?: components$1["schemas"]["CmsBlock"];
    cmsBlockId?: string;
    cmsBlockVersionId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagCmsExtensionsScrollNavigation: {
    active?: boolean;
    cmsSection?: components$1["schemas"]["CmsSection"];
    cmsSectionId?: string;
    cmsSectionVersionId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    displayName?: string;
    id: string;
    translated: {
      cmsSectionId: string;
      cmsSectionVersionId: string;
      displayName: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagCmsExtensionsScrollNavigationPageSettings: {
    active?: boolean;
    bouncy?: boolean;
    cmsPage?: components$1["schemas"]["CmsPage"];
    cmsPageId?: string;
    cmsPageVersionId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    /** Format: int64 */
    duration?: number;
    easing?: string;
    /** Format: int64 */
    easingDegree?: number;
    id: string;
    nativeScrolling: boolean;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagCustomizedProductsTemplate: {
    active?: boolean;
    configurations?: components$1["schemas"]["SwagCustomizedProductsTemplateConfiguration"][];
    confirmInput?: boolean;
    /** Format: date-time */
    readonly createdAt?: string;
    readonly decisionTree?: GenericRecord$1;
    description?: string;
    displayName: string;
    exclusions?: components$1["schemas"]["SwagCustomizedProductsTemplateExclusion"][];
    id: string;
    internalName: string;
    media?: components$1["schemas"]["Media"];
    mediaId?: string;
    options?: components$1["schemas"]["SwagCustomizedProductsTemplateOption"][];
    optionsAutoCollapse?: boolean;
    parentVersionId?: string;
    products?: components$1["schemas"]["Product"][];
    stepByStep?: boolean;
    translated: {
      description: string;
      displayName: string;
      internalName: string;
      mediaId: string;
      parentVersionId: string;
      versionId: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  SwagCustomizedProductsTemplateConfiguration: {
    configuration: GenericRecord$1;
    /** Format: date-time */
    readonly createdAt?: string;
    hash: string;
    id: string;
    template?: components$1["schemas"]["SwagCustomizedProductsTemplate"];
    templateConfigurationShares?: components$1["schemas"]["SwagCustomizedProductsTemplateConfigurationShare"][];
    templateId: string;
    templateVersionId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  SwagCustomizedProductsTemplateConfigurationJsonApi: components$1["schemas"]["resource"] & {
    configuration: GenericRecord$1;
    /** Format: date-time */
    readonly createdAt?: string;
    hash: string;
    id: string;
    relationships?: {
      template?: {
        data?: {
          /** @example 66f6181bcb4cff4cd38fbc804a036db6 */
          id?: string;
          /** @example swag_customized_products_template */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-customized-products-template-configuration/ab78fa5f6df63876a7c6575bdf517fe2/template
           */
          related?: string;
        };
      };
      templateConfigurationShares?: {
        data?: {
          /** @example 81a31c81fde24f296e176502d32baa6d */
          id?: string;
          /** @example swag_customized_products_template_configuration_share */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-customized-products-template-configuration/ab78fa5f6df63876a7c6575bdf517fe2/templateConfigurationShares
           */
          related?: string;
        };
      };
    };
    templateId: string;
    templateVersionId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  SwagCustomizedProductsTemplateConfigurationShare: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagCustomizedProductsTemplateExclusion: {
    conditions?: components$1["schemas"]["SwagCustomizedProductsTemplateExclusionCondition"][];
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    name: string;
    template?: components$1["schemas"]["SwagCustomizedProductsTemplate"];
    templateId: string;
    templateVersionId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  SwagCustomizedProductsTemplateExclusionCondition: {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    templateExclusion?: components$1["schemas"]["SwagCustomizedProductsTemplateExclusion"];
    templateExclusionId: string;
    templateExclusionOperator?: components$1["schemas"]["SwagCustomizedProductsTemplateExclusionOperator"];
    templateExclusionOperatorId: string;
    templateExclusionVersionId?: string;
    templateOption?: components$1["schemas"]["SwagCustomizedProductsTemplateOption"];
    templateOptionId: string;
    templateOptionValues?: components$1["schemas"]["SwagCustomizedProductsTemplateOptionValue"][];
    templateOptionVersionId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  SwagCustomizedProductsTemplateExclusionOperator: {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    label: string;
    operator: string;
    templateExclusionConditions?: components$1["schemas"]["SwagCustomizedProductsTemplateExclusionCondition"][];
    templateOptionType: string;
    translated: {
      label: string;
      operator: string;
      templateOptionType: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagCustomizedProductsTemplateJsonApi: components$1["schemas"]["resource"] & {
    active?: boolean;
    confirmInput?: boolean;
    /** Format: date-time */
    readonly createdAt?: string;
    readonly decisionTree?: GenericRecord$1;
    description?: string;
    displayName: string;
    id: string;
    internalName: string;
    mediaId?: string;
    optionsAutoCollapse?: boolean;
    parentVersionId?: string;
    relationships?: {
      configurations?: {
        data?: {
          /** @example 86f23519571eb918e8812e1979d55409 */
          id?: string;
          /** @example swag_customized_products_template_configuration */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-customized-products-template/4751e4cb483e992aa073494b9cfa9be6/configurations
           */
          related?: string;
        };
      };
      exclusions?: {
        data?: {
          /** @example c6fc0a7508c1a1fe9e233e81d31133b8 */
          id?: string;
          /** @example swag_customized_products_template_exclusion */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-customized-products-template/4751e4cb483e992aa073494b9cfa9be6/exclusions
           */
          related?: string;
        };
      };
      media?: {
        data?: {
          /** @example 62933a2951ef01f4eafd9bdf4d3cd2f0 */
          id?: string;
          /** @example media */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-customized-products-template/4751e4cb483e992aa073494b9cfa9be6/media
           */
          related?: string;
        };
      };
      options?: {
        data?: {
          /** @example 93da65a9fd0004d9477aeac024e08e15 */
          id?: string;
          /** @example swag_customized_products_template_option */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-customized-products-template/4751e4cb483e992aa073494b9cfa9be6/options
           */
          related?: string;
        };
      };
      products?: {
        data?: {
          /** @example 86024cad1e83101d97359d7351051156 */
          id?: string;
          /** @example product */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-customized-products-template/4751e4cb483e992aa073494b9cfa9be6/products
           */
          related?: string;
        };
      };
    };
    stepByStep?: boolean;
    translated: {
      description: string;
      displayName: string;
      internalName: string;
      mediaId: string;
      parentVersionId: string;
      versionId: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  SwagCustomizedProductsTemplateOption: {
    advancedSurcharge?: boolean;
    calculatedPrice?: GenericRecord$1;
    /** Format: date-time */
    readonly createdAt?: string;
    description?: string;
    displayName: string;
    id: string;
    itemNumber?: string;
    oneTimeSurcharge?: boolean;
    /** Format: float */
    percentageSurcharge?: number;
    placeholder?: string;
    /** Format: int64 */
    position?: number;
    price?: components$1["schemas"]["Price"][];
    prices?: components$1["schemas"]["SwagCustomizedProductsTemplateOptionPrice"][];
    relativeSurcharge?: boolean;
    required?: boolean;
    tax?: components$1["schemas"]["Tax"];
    taxId?: string;
    template?: components$1["schemas"]["SwagCustomizedProductsTemplate"];
    templateExclusionConditions?: components$1["schemas"]["SwagCustomizedProductsTemplateExclusionCondition"][];
    templateId: string;
    templateVersionId?: string;
    translated: {
      description: string;
      displayName: string;
      itemNumber: string;
      placeholder: string;
      taxId: string;
      templateId: string;
      templateVersionId: string;
      type: string;
    };
    type: string;
    typeProperties?: GenericRecord$1;
    /** Format: date-time */
    readonly updatedAt?: string;
    values?: components$1["schemas"]["SwagCustomizedProductsTemplateOptionValue"][];
  };
  SwagCustomizedProductsTemplateOptionJsonApi: components$1["schemas"]["resource"] & {
    advancedSurcharge?: boolean;
    calculatedPrice?: GenericRecord$1;
    /** Format: date-time */
    readonly createdAt?: string;
    description?: string;
    displayName: string;
    id: string;
    itemNumber?: string;
    oneTimeSurcharge?: boolean;
    /** Format: float */
    percentageSurcharge?: number;
    placeholder?: string;
    /** Format: int64 */
    position?: number;
    price?: components$1["schemas"]["Price"][];
    relationships?: {
      prices?: {
        data?: {
          /** @example afae32efe0f84fece3f96b377b768b33 */
          id?: string;
          /** @example swag_customized_products_template_option_price */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-customized-products-template-option/6342f0c20b443cb5408ec0fc12430bcb/prices
           */
          related?: string;
        };
      };
      tax?: {
        data?: {
          /** @example 06565e5611f23fdf8cc43e5077b92b54 */
          id?: string;
          /** @example tax */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-customized-products-template-option/6342f0c20b443cb5408ec0fc12430bcb/tax
           */
          related?: string;
        };
      };
      template?: {
        data?: {
          /** @example 66f6181bcb4cff4cd38fbc804a036db6 */
          id?: string;
          /** @example swag_customized_products_template */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-customized-products-template-option/6342f0c20b443cb5408ec0fc12430bcb/template
           */
          related?: string;
        };
      };
      templateExclusionConditions?: {
        data?: {
          /** @example 57e853a74b92e339ec2e302b015e60f3 */
          id?: string;
          /** @example swag_customized_products_template_exclusion_condition */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-customized-products-template-option/6342f0c20b443cb5408ec0fc12430bcb/templateExclusionConditions
           */
          related?: string;
        };
      };
      values?: {
        data?: {
          /** @example f09cc7ee3a9a93273f4b80601cafb00c */
          id?: string;
          /** @example swag_customized_products_template_option_value */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-customized-products-template-option/6342f0c20b443cb5408ec0fc12430bcb/values
           */
          related?: string;
        };
      };
    };
    relativeSurcharge?: boolean;
    required?: boolean;
    taxId?: string;
    templateId: string;
    templateVersionId?: string;
    translated: {
      description: string;
      displayName: string;
      itemNumber: string;
      placeholder: string;
      taxId: string;
      templateId: string;
      templateVersionId: string;
      type: string;
    };
    type: string;
    typeProperties?: GenericRecord$1;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagCustomizedProductsTemplateOptionPrice: {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    /** Format: float */
    percentageSurcharge?: number;
    price?: components$1["schemas"]["Price"][];
    rule?: components$1["schemas"]["Rule"];
    ruleId?: string;
    templateOption?: components$1["schemas"]["SwagCustomizedProductsTemplateOption"];
    templateOptionId: string;
    templateOptionVersionId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  SwagCustomizedProductsTemplateOptionValue: {
    advancedSurcharge?: boolean;
    /** Format: date-time */
    readonly createdAt?: string;
    default?: boolean;
    displayName: string;
    id: string;
    itemNumber?: string;
    oneTimeSurcharge?: boolean;
    /** Format: float */
    percentageSurcharge?: number;
    /** Format: int64 */
    position: number;
    price?: components$1["schemas"]["Price"][];
    prices?: components$1["schemas"]["SwagCustomizedProductsTemplateOptionValuePrice"][];
    relativeSurcharge?: boolean;
    tax?: components$1["schemas"]["Tax"];
    taxId?: string;
    templateExclusionConditions?: components$1["schemas"]["SwagCustomizedProductsTemplateExclusionCondition"][];
    templateOption?: components$1["schemas"]["SwagCustomizedProductsTemplateOption"];
    templateOptionId: string;
    templateOptionVersionId?: string;
    translated: {
      displayName: string;
      itemNumber: string;
      taxId: string;
      templateOptionId: string;
      templateOptionVersionId: string;
      versionId: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    value?: GenericRecord$1;
    versionId?: string;
  };
  SwagCustomizedProductsTemplateOptionValueJsonApi: components$1["schemas"]["resource"] & {
    advancedSurcharge?: boolean;
    /** Format: date-time */
    readonly createdAt?: string;
    default?: boolean;
    displayName: string;
    id: string;
    itemNumber?: string;
    oneTimeSurcharge?: boolean;
    /** Format: float */
    percentageSurcharge?: number;
    /** Format: int64 */
    position: number;
    price?: components$1["schemas"]["Price"][];
    relationships?: {
      prices?: {
        data?: {
          /** @example afae32efe0f84fece3f96b377b768b33 */
          id?: string;
          /** @example swag_customized_products_template_option_value_price */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-customized-products-template-option-value/b57f26a8362182be3e67a815927b7f37/prices
           */
          related?: string;
        };
      };
      tax?: {
        data?: {
          /** @example 06565e5611f23fdf8cc43e5077b92b54 */
          id?: string;
          /** @example tax */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-customized-products-template-option-value/b57f26a8362182be3e67a815927b7f37/tax
           */
          related?: string;
        };
      };
      templateExclusionConditions?: {
        data?: {
          /** @example 57e853a74b92e339ec2e302b015e60f3 */
          id?: string;
          /** @example swag_customized_products_template_exclusion_condition */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-customized-products-template-option-value/b57f26a8362182be3e67a815927b7f37/templateExclusionConditions
           */
          related?: string;
        };
      };
      templateOption?: {
        data?: {
          /** @example 6891a002a90a39e71e67c4fc148db8df */
          id?: string;
          /** @example swag_customized_products_template_option */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-customized-products-template-option-value/b57f26a8362182be3e67a815927b7f37/templateOption
           */
          related?: string;
        };
      };
    };
    relativeSurcharge?: boolean;
    taxId?: string;
    templateOptionId: string;
    templateOptionVersionId?: string;
    translated: {
      displayName: string;
      itemNumber: string;
      taxId: string;
      templateOptionId: string;
      templateOptionVersionId: string;
      versionId: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    value?: GenericRecord$1;
    versionId?: string;
  };
  SwagCustomizedProductsTemplateOptionValuePrice: {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    /** Format: float */
    percentageSurcharge?: number;
    price?: components$1["schemas"]["Price"][];
    rule?: components$1["schemas"]["Rule"];
    ruleId?: string;
    templateOptionValue?: components$1["schemas"]["SwagCustomizedProductsTemplateOptionValue"];
    templateOptionValueId: string;
    templateOptionValueVersionId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  SwagDelayAction: {
    /** Format: date-time */
    readonly createdAt?: string;
    customerId?: string;
    id: string;
    orderId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagDynamicAccessLandingPageRule: {
    id?: string;
    landingPage?: components$1["schemas"]["LandingPage"];
    landingPageId: string;
    landingPageVersionId?: string;
    rule?: components$1["schemas"]["Rule"];
    ruleId: string;
  };
  SwagDynamicAccessProductRule: {
    id?: string;
    product?: components$1["schemas"]["Product"];
    productId: string;
    productVersionId?: string;
    rule?: components$1["schemas"]["Rule"];
    ruleId: string;
  };
  SwagLanguagePackLanguage: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagMigrationConnection: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagMigrationData: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagMigrationGeneralSetting: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagMigrationLogging: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagMigrationMapping: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagMigrationMediaFile: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagMigrationRun: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagPaypalPosSalesChannel: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagPaypalPosSalesChannelRun: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagPaypalPosSalesChannelRunLog: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagPaypalTransactionReport: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagPaypalVaultToken: {
    id?: string;
    identifier?: string;
  };
  SwagPaypalVaultTokenMapping: {
    /** Format: date-time */
    readonly createdAt?: string;
    customer?: components$1["schemas"]["Customer"];
    customerId: string;
    id?: string;
    paymentMethod?: components$1["schemas"]["PaymentMethod"];
    paymentMethodId: string;
    token?: components$1["schemas"]["SwagPaypalVaultToken"];
    tokenId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagSocialShoppingCustomer: {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagSocialShoppingOrder: {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagSocialShoppingProductError: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagSocialShoppingSalesChannel: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SystemConfig: {
    configurationKey: string;
    configurationValue: {
      _value?: GenericRecord$1;
    };
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    salesChannel?: components$1["schemas"]["SalesChannel"];
    salesChannelId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  Tag: {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    name: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  Tax: {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    id: string;
    name: string;
    /**
     * Format: int64
     * Added since version: 6.4.0.0.
     */
    position?: number;
    /** Format: float */
    taxRate: number;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  TaxProvider: {
    active?: boolean;
    appId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    id: string;
    name: string;
    /** Format: int64 */
    priority: number;
    processUrl?: string;
    translated: {
      appId: string;
      name: string;
      processUrl: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  TaxRule: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  TaxRuleType: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  Theme: {
    active: boolean;
    author: string;
    baseConfig?: GenericRecord$1;
    configValues?: GenericRecord$1;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    description?: string;
    helpTexts?: GenericRecord$1;
    id: string;
    labels?: GenericRecord$1;
    media?: components$1["schemas"]["Media"][];
    name: string;
    parentThemeId?: string;
    previewMediaId?: string;
    technicalName?: string;
    translated: {
      author: string;
      description: string;
      name: string;
      parentThemeId: string;
      previewMediaId: string;
      technicalName: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  ToggleBroadcastModeInteraction: components$1["schemas"]["BaseInteraction"] & {
    name: string;
    payload: components$1["schemas"]["ToggleBroadcastModePayload"];
  } & {
    /**
     * discriminator enum property added by openapi-typescript
     * @enum {string}
     */
    name: "broadcastMode.toggled";
  };
  ToggleBroadcastModePayload: {
    /** Status if the mode is toggled to active or inactive */
    active: boolean;
  };
  TotalCountMode: "none" | "exact" | "next-pages";
  Unit: {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord$1;
    id: string;
    name: string;
    shortCode: string;
    translated: {
      name: string;
      shortCode: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  UpdateAttendeeRequestBody: {
    /** Name of the attendee */
    attendeeName?: string;
    /** The permission for guide cart actions */
    guideCartPermissionsGranted?: boolean;
    /** Id of the attendee in the video chat tool */
    videoUserId?: string;
  };
  User: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  UserAccessKey: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  UserConfig: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  UserRecovery: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  ViewModeChangedInteraction: components$1["schemas"]["BaseInteraction"] & {
    name: string;
    payload: components$1["schemas"]["ViewModeChangedPayload"];
  } & {
    /**
     * discriminator enum property added by openapi-typescript
     * @enum {string}
     */
    name: "viewMode.changed";
  };
  ViewModeChangedPayload: {
    /**
     * The view mode of presentation
     * @default presentation
     * @enum {string}
     */
    mode?: "onlyYou" | "presentation" | "videoGrid";
  };
  Warehouse: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  WarehouseGroup: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  Webhook: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  WebhookEventLog: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  WishlistLoadRouteResponse: {
    products: components$1["schemas"]["ProductListingResult"];
    wishlist?: {
      customerId?: string;
      salesChannelId?: string;
    };
  };
  attributes: {
    [key: string]: unknown;
  };
  data: components$1["schemas"]["resource"] | components$1["schemas"]["resource"][];
  error: {
    /** An application-specific error code, expressed as a string value. */
    code?: string;
    /** A human-readable description of the problem. */
    description?: string;
    /** A human-readable explanation specific to this occurrence of the problem. */
    detail?: string;
    /** A unique identifier for this particular occurrence of the problem. */
    id?: string;
    links?: components$1["schemas"]["links"];
    meta?: components$1["schemas"]["meta"];
    source?: {
      /** A string indicating which query parameter caused the error. */
      parameter?: string;
      /** A JSON Pointer [RFC6901] to the associated entity in the request document [e.g. "/data" for a primary data object, or "/data/attributes/title" for a specific attribute]. */
      pointer?: string;
    };
    /** The HTTP status code applicable to this problem, expressed as a string value. */
    status?: string;
    /** A short, human-readable summary of the problem. It **SHOULD NOT** change from occurrence to occurrence of the problem, except for purposes of localization. */
    title?: string;
  };
  failure: {
    errors: components$1["schemas"]["error"][];
    links?: components$1["schemas"]["links"];
    meta?: components$1["schemas"]["meta"];
  };
  info: {
    jsonapi?: components$1["schemas"]["jsonapi"];
    links?: components$1["schemas"]["links"];
    meta: components$1["schemas"]["meta"];
  };
  jsonapi: {
    meta?: components$1["schemas"]["meta"];
    version?: string;
  };
  link:
    | string
    | {
        /**
         * Format: uri-reference
         * A string containing the link's URL.
         */
        href: string;
        meta?: components$1["schemas"]["meta"];
      };
  linkage: {
    id: string;
    meta?: components$1["schemas"]["meta"];
    type: string;
  };
  links: {
    [key: string]: components$1["schemas"]["link"];
  };
  meta: {
    [key: string]: unknown;
  };
  pagination: {
    /**
     * Format: uri-reference
     * The first page of data
     */
    first?: string;
    /**
     * Format: uri-reference
     * The last page of data
     */
    last?: string;
    /**
     * Format: uri-reference
     * The next page of data
     */
    next?: string;
    /**
     * Format: uri-reference
     * The previous page of data
     */
    prev?: string;
  };
  relationshipLinks: {
    related?: components$1["schemas"]["link"];
    self?: GenericRecord$1[] & components$1["schemas"]["link"];
  } & {
    [key: string]: unknown;
  };
  relationshipToMany: components$1["schemas"]["linkage"][];
  relationshipToOne: unknown & components$1["schemas"]["linkage"];
  relationships:
    | unknown
    | unknown
    | unknown
    | {
        /** Member, whose value represents "resource linkage". */
        data?:
          | components$1["schemas"]["relationshipToOne"]
          | components$1["schemas"]["relationshipToMany"];
        links?: components$1["schemas"]["relationshipLinks"];
      };
  resource: {
    attributes?: components$1["schemas"]["attributes"];
    id: string;
    links?: components$1["schemas"]["links"];
    meta?: components$1["schemas"]["meta"];
    relationships?: components$1["schemas"]["relationships"];
    type: string;
  };
  success: {
    data: components$1["schemas"]["data"];
    /** To reduce the number of HTTP requests, servers **MAY** allow responses that include related resources along with the requested primary resources. Such responses are called "compound documents". */
    included?: components$1["schemas"]["resource"][];
    /** Link members related to the primary data. */
    links?: components$1["schemas"]["links"] &
      components$1["schemas"]["pagination"];
    meta?: components$1["schemas"]["meta"];
  };
  swag_paypal_v1_capture: {
    amount: components$1["schemas"]["swag_paypal_v1_common_amount"];
    create_time: string;
    id: string;
    is_final_capture: boolean;
    links: components$1["schemas"]["swag_paypal_v1_common_link"][];
    parent_payment: string;
    reason_code: string;
    state: string;
    transaction_fee: components$1["schemas"]["swag_paypal_v1_capture_transaction_fee"];
    update_time: string;
  };
  swag_paypal_v1_capture_transaction_fee: components$1["schemas"]["swag_paypal_v1_common_value"];
  swag_paypal_v1_client_token: {
    client_token: string;
    /**
     * Format: date-time
     * Calculated expiration date
     */
    expire_date_time: string;
    /** The lifetime of the access token, in seconds. */
    expires_in: number;
  };
  swag_paypal_v1_common_address: {
    city: string;
    country_code: string;
    line1: string;
    line2: string | null;
    phone: string | null;
    postal_code: string;
    state: string | null;
  };
  swag_paypal_v1_common_amount: {
    currency: string;
    details: components$1["schemas"]["swag_paypal_v1_common_details"];
    total: string;
  };
  swag_paypal_v1_common_details: {
    discount: string;
    handling_fee: string;
    insurance: string;
    shipping: string;
    shipping_discount: string;
    subtotal: string;
    tax: string;
  };
  swag_paypal_v1_common_link: {
    enc_type: string | null;
    href: string;
    method: string;
    rel: string;
  };
  swag_paypal_v1_common_money: {
    currency_code: string;
    value: string;
  };
  swag_paypal_v1_common_value: {
    currency: string;
    value: string;
  };
  swag_paypal_v1_create_webhooks: {
    event_types: components$1["schemas"]["swag_paypal_v1_create_webhooks_event_type"][];
    url: string;
  };
  swag_paypal_v1_create_webhooks_event_type: {
    name: string;
  };
  swag_paypal_v1_disputes: {
    items: components$1["schemas"]["swag_paypal_v1_disputes_item"][] | null;
    links: components$1["schemas"]["swag_paypal_v1_common_link"][];
  };
  swag_paypal_v1_disputes_common_buyer: {
    name: string;
  };
  swag_paypal_v1_disputes_common_item: {
    dispute_amount: components$1["schemas"]["swag_paypal_v1_common_money"];
    item_description: string;
    item_id: string;
    item_quantity: string;
    notes: string;
    partner_transaction_id: string;
    reason: string;
  };
  swag_paypal_v1_disputes_common_product_details: {
    product_received: string;
    product_received_time: string;
    purchase_url: string;
    return_details: components$1["schemas"]["swag_paypal_v1_disputes_common_return_details"];
    sub_reasons: components$1["schemas"]["swag_paypal_v1_disputes_common_sub_reason"][];
  };
  swag_paypal_v1_disputes_common_return_details: {
    mode: string;
    receipt: boolean;
    return_confirmation_number: string;
    return_time: string;
    returned: boolean;
  };
  swag_paypal_v1_disputes_common_seller: {
    email: string;
    merchant_id: string;
    name: string;
  };
  swag_paypal_v1_disputes_common_service_details: {
    description: string;
    note: string;
    purchase_url: string;
    service_started: string;
    sub_reasons: components$1["schemas"]["swag_paypal_v1_disputes_common_sub_reason"][];
  };
  swag_paypal_v1_disputes_common_sub_reason: {
    sub_reason: string;
  };
  swag_paypal_v1_disputes_common_transaction: {
    buyer: components$1["schemas"]["swag_paypal_v1_disputes_common_buyer"];
    buyer_transaction_id: string;
    create_time: string;
    custom: string;
    gross_amount: components$1["schemas"]["swag_paypal_v1_common_money"];
    invoice_number: string;
    items: components$1["schemas"]["swag_paypal_v1_disputes_common_item"][];
    reference_id: string;
    seller: components$1["schemas"]["swag_paypal_v1_disputes_common_seller"];
    seller_transaction_id: string;
    transaction_status: string;
  };
  swag_paypal_v1_disputes_item: {
    adjudications: components$1["schemas"]["swag_paypal_v1_disputes_item_adjudication"][];
    buyer_response_due_date: string | null;
    communication_details:
      | components$1["schemas"]["swag_paypal_v1_disputes_item_communication_details"]
      | null;
    create_time: string;
    dispute_amount: components$1["schemas"]["swag_paypal_v1_disputes_item_dispute_amount"];
    dispute_channel: string | null;
    dispute_id: string;
    dispute_life_cycle_stage: string;
    dispute_outcome:
      | components$1["schemas"]["swag_paypal_v1_disputes_item_dispute_outcome"]
      | null;
    /** @enum {string|null} */
    dispute_state:
      | "REQUIRED_ACTION"
      | "REQUIRED_OTHER_PARTY_ACTION"
      | "UNDER_PAYPAL_REVIEW"
      | "RESOLVED"
      | "OPEN_INQUIRIES"
      | "APPEALABLE"
      | null;
    disputed_transactions:
      | components$1["schemas"]["swag_paypal_v1_disputes_item_disputed_transaction"][]
      | null;
    evidences:
      | components$1["schemas"]["swag_paypal_v1_disputes_item_evidence"][]
      | null;
    extensions: components$1["schemas"]["swag_paypal_v1_disputes_item_extensions"];
    external_reason_code: string | null;
    links: components$1["schemas"]["swag_paypal_v1_common_link"][];
    messages:
      | components$1["schemas"]["swag_paypal_v1_disputes_item_message"][]
      | null;
    money_movements: components$1["schemas"]["swag_paypal_v1_disputes_item_money_movement"][];
    offer: components$1["schemas"]["swag_paypal_v1_disputes_item_offer"] | null;
    partner_actions:
      | components$1["schemas"]["swag_paypal_v1_disputes_item_partner_action"][]
      | null;
    reason: string;
    refund_details:
      | components$1["schemas"]["swag_paypal_v1_disputes_item_refund_details"]
      | null;
    seller_response_due_date: string | null;
    status: string;
    supporting_info:
      | components$1["schemas"]["swag_paypal_v1_disputes_item_supporting_info"][]
      | null;
    update_time: string;
  };
  swag_paypal_v1_disputes_item_adjudication: {
    adjudication_time: string;
    dispute_life_cycle_stage: string;
    reason: string;
    type: string;
  };
  swag_paypal_v1_disputes_item_communication_details: {
    email: string;
    note: string;
    time_posted: string;
  };
  swag_paypal_v1_disputes_item_dispute_amount: components$1["schemas"]["swag_paypal_v1_common_money"];
  swag_paypal_v1_disputes_item_dispute_outcome: {
    amount_refunded: components$1["schemas"]["swag_paypal_v1_common_money"];
    outcome_code: string;
  };
  swag_paypal_v1_disputes_item_disputed_transaction: components$1["schemas"]["swag_paypal_v1_disputes_common_transaction"] & {
    seller_protection_eligible: boolean;
  };
  swag_paypal_v1_disputes_item_evidence: {
    documents: components$1["schemas"]["swag_paypal_v1_disputes_item_evidence_document"][];
    evidence_info: components$1["schemas"]["swag_paypal_v1_disputes_item_evidence_evidence_info"];
    evidence_type: string;
    item_id: string;
    notes: string;
  };
  swag_paypal_v1_disputes_item_evidence_document: {
    name: string;
  };
  swag_paypal_v1_disputes_item_evidence_evidence_info: {
    refund_ids: components$1["schemas"]["swag_paypal_v1_disputes_item_evidence_evidence_info_refund_id"][];
    tracking_info: components$1["schemas"]["swag_paypal_v1_disputes_item_evidence_evidence_info_tracking_info"][];
  };
  swag_paypal_v1_disputes_item_evidence_evidence_info_refund_id: {
    refund_id: string;
  };
  swag_paypal_v1_disputes_item_evidence_evidence_info_tracking_info: {
    carrier_name: string;
    carrier_name_other: string;
    tracking_number: string;
    tracking_url: string;
  };
  swag_paypal_v1_disputes_item_extensions: {
    billing_dispute_properties: components$1["schemas"]["swag_paypal_v1_disputes_item_extensions_billing_dispute_properties"];
    buyer_contacted_channel: string;
    buyer_contacted_time: string;
    merchandize_dispute_properties: components$1["schemas"]["swag_paypal_v1_disputes_item_extensions_merchandize_dispute_properties"];
    merchant_contacted: boolean;
    merchant_contacted_mode: string;
    merchant_contacted_outcome: string;
    merchant_contacted_time: string;
  };
  swag_paypal_v1_disputes_item_extensions_billing_dispute_properties: {
    canceled_recurring_billing: components$1["schemas"]["swag_paypal_v1_disputes_item_extensions_billing_dispute_properties_canceled_recurring_billing"];
    credit_not_processed: components$1["schemas"]["swag_paypal_v1_disputes_item_extensions_billing_dispute_properties_credit_not_processed"];
    duplicate_transaction: components$1["schemas"]["swag_paypal_v1_disputes_item_extensions_billing_dispute_properties_duplicate_transaction"];
    incorrect_transaction_amount: components$1["schemas"]["swag_paypal_v1_disputes_item_extensions_billing_dispute_properties_incorrect_transaction_amount"];
    payment_by_other_means: components$1["schemas"]["swag_paypal_v1_disputes_item_extensions_billing_dispute_properties_payment_by_other_means"];
  };
  swag_paypal_v1_disputes_item_extensions_billing_dispute_properties_canceled_recurring_billing: {
    cancellation_details: components$1["schemas"]["swag_paypal_v1_disputes_item_extensions_billing_dispute_properties_common_cancellation_details"];
    expected_refund: components$1["schemas"]["swag_paypal_v1_common_money"];
  };
  swag_paypal_v1_disputes_item_extensions_billing_dispute_properties_common_agreed_refund_details: {
    merchant_agreed_refund: boolean;
    merchant_agreed_refund_time: string;
  };
  swag_paypal_v1_disputes_item_extensions_billing_dispute_properties_common_cancellation_details: {
    cancellation_date: string;
    cancellation_mode: string;
    cancellation_number: string;
    cancelled: boolean;
  };
  swag_paypal_v1_disputes_item_extensions_billing_dispute_properties_credit_not_processed: {
    agreed_refund_details: components$1["schemas"]["swag_paypal_v1_disputes_item_extensions_billing_dispute_properties_common_agreed_refund_details"];
    cancellation_details: components$1["schemas"]["swag_paypal_v1_disputes_item_extensions_billing_dispute_properties_common_cancellation_details"];
    expected_refund: components$1["schemas"]["swag_paypal_v1_common_money"];
    issue_type: string;
    product_details: components$1["schemas"]["swag_paypal_v1_disputes_common_product_details"];
    service_details: components$1["schemas"]["swag_paypal_v1_disputes_common_service_details"];
  };
  swag_paypal_v1_disputes_item_extensions_billing_dispute_properties_duplicate_transaction: {
    original_transaction: components$1["schemas"]["swag_paypal_v1_disputes_common_transaction"];
    received_duplicate: boolean;
  };
  swag_paypal_v1_disputes_item_extensions_billing_dispute_properties_incorrect_transaction_amount: {
    correct_transaction_amount: components$1["schemas"]["swag_paypal_v1_common_money"];
    correct_transaction_time: string;
  };
  swag_paypal_v1_disputes_item_extensions_billing_dispute_properties_payment_by_other_means: {
    charge_different_from_original: boolean;
    payment_instrument_suffix: string;
    payment_method: string;
    received_duplicate: boolean;
  };
  swag_paypal_v1_disputes_item_extensions_merchandize_dispute_properties: {
    issue_type: string;
    product_details: components$1["schemas"]["swag_paypal_v1_disputes_common_product_details"];
    service_details: components$1["schemas"]["swag_paypal_v1_disputes_common_service_details"];
  };
  swag_paypal_v1_disputes_item_message: {
    content: string;
    posted_by: string;
    time_posted: string;
  };
  swag_paypal_v1_disputes_item_money_movement: {
    affected_party: string;
    amount: components$1["schemas"]["swag_paypal_v1_common_amount"];
    initiated_time: string;
    reason: string;
    type: string;
  };
  swag_paypal_v1_disputes_item_offer: {
    buyer_requested_amount: components$1["schemas"]["swag_paypal_v1_common_money"];
    history:
      | components$1["schemas"]["swag_paypal_v1_disputes_item_offer_history"][]
      | null;
    offer_type: string;
    seller_offered_amount: components$1["schemas"]["swag_paypal_v1_common_money"];
  };
  swag_paypal_v1_disputes_item_offer_history: {
    actor: string;
    event_type: string;
    offer_time: string;
    offer_type: string;
  };
  swag_paypal_v1_disputes_item_partner_action: {
    amount: components$1["schemas"]["swag_paypal_v1_common_money"];
    create_time: string;
    due_time: string;
    id: string;
    name: string;
    status: string;
    update_time: string;
  };
  swag_paypal_v1_disputes_item_refund_details: {
    allowed_refund_amount: components$1["schemas"]["swag_paypal_v1_common_money"];
  };
  swag_paypal_v1_disputes_item_supporting_info: {
    notes: string;
    provided_time: string;
    source: string;
  };
  swag_paypal_v1_do_void: {
    amount: components$1["schemas"]["swag_paypal_v1_common_amount"];
    create_time: string;
    id: string;
    links: components$1["schemas"]["swag_paypal_v1_common_link"][];
    parent_payment: string;
    state: string;
    update_time: string;
  };
  swag_paypal_v1_merchant_integrations: {
    capabilities:
      | components$1["schemas"]["swag_paypal_v1_merchant_integrations_capability"][]
      | null;
    granted_permissions: string[];
    legal_name: string;
    merchant_id: string;
    oauth_integrations: components$1["schemas"]["swag_paypal_v1_merchant_integrations_oauth_integration"][];
    payments_receivable: boolean;
    primary_email: string;
    primary_email_confirmed: boolean;
    products: components$1["schemas"]["swag_paypal_v1_merchant_integrations_product"][];
    tracking_id: string;
  };
  swag_paypal_v1_merchant_integrations_capability: {
    name: string;
    status: string;
  };
  swag_paypal_v1_merchant_integrations_oauth_integration: {
    integration_method?: string;
    integration_type?: string;
    oauth_third_party?: components$1["schemas"]["swag_paypal_v1_merchant_integrations_oauth_integration_oauth_third_party"][];
    status?: string;
  };
  swag_paypal_v1_merchant_integrations_oauth_integration_oauth_third_party: {
    access_token?: string;
    merchant_client_id?: string;
    partner_client_id?: string;
    refresh_token?: string;
    scopes: string[];
  };
  swag_paypal_v1_merchant_integrations_product: {
    capabilities?: string[];
    name: string;
    vetting_status?: string;
  };
  swag_paypal_v1_oauth_credentials: {
    restId: string;
    restSecret: string;
    url: string;
  };
  swag_paypal_v1_patch: {
    /** @enum {string} */
    op: "add" | "replace";
    path: string;
    value: string | Record<string, never>[];
  };
  swag_paypal_v1_payment: {
    application_context: components$1["schemas"]["swag_paypal_v1_payment_application_context"];
    cart: string;
    create_time: string;
    id: string;
    /**
     * @default sale
     * @enum {string}
     */
    intent?: "sale" | "authorize" | "order";
    links: components$1["schemas"]["swag_paypal_v1_common_link"][];
    payer: components$1["schemas"]["swag_paypal_v1_payment_payer"];
    payment_instruction:
      | components$1["schemas"]["swag_paypal_v1_payment_payment_instruction"]
      | null;
    redirect_urls: components$1["schemas"]["swag_paypal_v1_payment_redirect_urls"];
    state: string;
    transactions: components$1["schemas"]["swag_paypal_v1_payment_transaction"][];
    update_time: string;
  };
  swag_paypal_v1_payment_application_context: {
    brand_name: string;
    /** @enum {string} */
    landing_page: "Login" | "Billing";
    locale: string;
    /** @default SET_PROVIDED_ADDRESS */
    shipping_preference?: string;
    /** @default commit */
    user_action?: string;
  };
  swag_paypal_v1_payment_payer: {
    external_selected_funding_instrument_type: string;
    payer_info: components$1["schemas"]["swag_paypal_v1_payment_payer_payer_info"];
    payment_method: string;
    status: string;
  };
  swag_paypal_v1_payment_payer_execute_payer_info: {
    payer_id: string;
  };
  swag_paypal_v1_payment_payer_payer_info: components$1["schemas"]["swag_paypal_v1_payment_payer_execute_payer_info"] & {
    billing_address:
      | components$1["schemas"]["swag_paypal_v1_common_address"]
      | null;
    country_code: string;
    email: string;
    first_name: string;
    last_name: string;
    phone: string;
    shipping_address: components$1["schemas"]["swag_paypal_v1_payment_transaction_item_list_shipping_address"];
  };
  swag_paypal_v1_payment_payment_instruction: {
    amount: components$1["schemas"]["swag_paypal_v1_common_value"];
    instruction_type: string;
    links: components$1["schemas"]["swag_paypal_v1_common_link"][];
    payment_due_date: string;
    recipient_banking_instruction: components$1["schemas"]["swag_paypal_v1_payment_payment_instruction_recipient_banking_instruction"];
    reference_number: string;
  };
  swag_paypal_v1_payment_payment_instruction_recipient_banking_instruction: {
    account_holder_name: string;
    bank_identifier_code: string;
    bank_name: string;
    international_bank_account_number: string;
  };
  swag_paypal_v1_payment_redirect_urls: {
    cancel_url: string;
    return_url: string;
  };
  swag_paypal_v1_payment_transaction: {
    amount: components$1["schemas"]["swag_paypal_v1_common_amount"];
    custom: string;
    description: string;
    invoice_number: string | null;
    item_list:
      | components$1["schemas"]["swag_paypal_v1_payment_transaction_item_list"]
      | null;
    payee: components$1["schemas"]["swag_paypal_v1_payment_transaction_payee"];
    related_resources: components$1["schemas"]["swag_paypal_v1_payment_transaction_related_resource"][];
    soft_descriptor: string;
  };
  swag_paypal_v1_payment_transaction_item_list: {
    items: components$1["schemas"]["swag_paypal_v1_payment_transaction_item_list_item"][];
    shipping_address: components$1["schemas"]["swag_paypal_v1_payment_transaction_item_list_shipping_address"];
    shipping_options: components$1["schemas"]["swag_paypal_v1_payment_transaction_item_list_shipping_option"][];
    shipping_phone_number: string;
  };
  swag_paypal_v1_payment_transaction_item_list_item: {
    currency: string;
    name: string;
    price: string;
    quantity: number;
    sku: string | null;
    tax: string;
  };
  swag_paypal_v1_payment_transaction_item_list_shipping_address: components$1["schemas"]["swag_paypal_v1_common_address"] & {
    recipient_name: string;
  };
  swag_paypal_v1_payment_transaction_item_list_shipping_option: unknown;
  swag_paypal_v1_payment_transaction_payee: {
    email: string;
    merchant_id: string;
  };
  swag_paypal_v1_payment_transaction_related_resource: {
    authorization:
      | components$1["schemas"]["swag_paypal_v1_payment_transaction_related_resource_authorization"]
      | null;
    capture:
      | components$1["schemas"]["swag_paypal_v1_payment_transaction_related_resource_capture"]
      | null;
    order:
      | components$1["schemas"]["swag_paypal_v1_payment_transaction_related_resource_order"]
      | null;
    refund:
      | components$1["schemas"]["swag_paypal_v1_payment_transaction_related_resource_refund"]
      | null;
    sale:
      | components$1["schemas"]["swag_paypal_v1_payment_transaction_related_resource_sale"]
      | null;
  };
  swag_paypal_v1_payment_transaction_related_resource_authorization: {
    amount: components$1["schemas"]["swag_paypal_v1_common_amount"];
    create_time: string;
    id: string;
    links: components$1["schemas"]["swag_paypal_v1_common_link"][];
    parent_payment: string;
    payment_mode: string;
    protection_eligibility: string;
    protection_eligibility_type: string;
    reason_code: string;
    receipt_id: string;
    state: string;
    update_time: string;
    valid_until: string;
  };
  swag_paypal_v1_payment_transaction_related_resource_capture: {
    amount: components$1["schemas"]["swag_paypal_v1_common_amount"];
    create_time: string;
    custom: string;
    id: string;
    invoice_number: string;
    links: components$1["schemas"]["swag_paypal_v1_common_link"][];
    parent_payment: string;
    payment_mode: string;
    protection_eligibility: string;
    protection_eligibility_type: string;
    receipt_id: string;
    state: string;
    transaction_fee: components$1["schemas"]["swag_paypal_v1_common_value"];
    update_time: string;
  };
  swag_paypal_v1_payment_transaction_related_resource_order: {
    amount: components$1["schemas"]["swag_paypal_v1_common_amount"];
    create_time: string;
    id: string;
    links: components$1["schemas"]["swag_paypal_v1_common_link"][];
    parent_payment: string;
    payment_mode: string;
    protection_eligibility: string;
    protection_eligibility_type: string;
    reason_code: string;
    receipt_id: string;
    state: string;
    update_time: string;
  };
  swag_paypal_v1_payment_transaction_related_resource_refund: {
    amount: components$1["schemas"]["swag_paypal_v1_common_amount"];
    capture_id: string;
    create_time: string;
    id: string;
    links: components$1["schemas"]["swag_paypal_v1_common_link"][];
    parent_payment: string;
    payment_mode: string;
    protection_eligibility: string;
    protection_eligibility_type: string;
    receipt_id: string;
    sale_id: string;
    state: string;
    update_time: string;
  };
  swag_paypal_v1_payment_transaction_related_resource_sale: {
    amount: components$1["schemas"]["swag_paypal_v1_common_amount"];
    create_time: string;
    id: string;
    links: components$1["schemas"]["swag_paypal_v1_common_link"][];
    parent_payment: string;
    payment_mode: string;
    protection_eligibility: string;
    protection_eligibility_type: string;
    receipt_id: string;
    state: string;
    transaction_fee: components$1["schemas"]["swag_paypal_v1_common_value"];
    update_time: string;
  };
  swag_paypal_v1_plan: {
    billing_cycles: components$1["schemas"]["swag_paypal_v1_plan_billing_cycle"][];
    description: string | null;
    name: string;
    payment_preferences: components$1["schemas"]["swag_paypal_v1_plan_payment_preferences"];
    product_id: string;
    status: string;
    taxes: components$1["schemas"]["swag_paypal_v1_plan_taxes"];
  };
  swag_paypal_v1_plan_billing_cycle: {
    frequency: components$1["schemas"]["swag_paypal_v1_plan_billing_cycle_frequency"];
    pricing_scheme: components$1["schemas"]["swag_paypal_v1_plan_billing_cycle_pricing_scheme"];
    sequence: number;
    tenure_type: string;
    total_cycles: number;
  };
  swag_paypal_v1_plan_billing_cycle_frequency: {
    interval_count: number;
    interval_unit: string;
  };
  swag_paypal_v1_plan_billing_cycle_pricing_scheme: {
    fixed_price: components$1["schemas"]["swag_paypal_v1_common_money"];
  };
  swag_paypal_v1_plan_payment_preferences: {
    auto_bill_outstanding: boolean;
    payment_failure_threshold: number;
  };
  swag_paypal_v1_plan_taxes: {
    inclusive: boolean;
    percentage: string;
  };
  swag_paypal_v1_product: {
    description: string;
    name: string;
    type: string;
  };
  swag_paypal_v1_refund: {
    amount: components$1["schemas"]["swag_paypal_v1_common_amount"];
    capture_id: string;
    create_time: string;
    description: string;
    id: string;
    invoice_number: string;
    links: components$1["schemas"]["swag_paypal_v1_common_link"][];
    parent_payment: string;
    reason: string;
    refund_from_received_amount: components$1["schemas"]["swag_paypal_v1_common_value"];
    refund_from_transaction_fee: components$1["schemas"]["swag_paypal_v1_common_value"];
    sale_id: string;
    state: string;
    total_refunded_amount: components$1["schemas"]["swag_paypal_v1_common_value"];
    update_time: string;
  };
  swag_paypal_v1_shipping: {
    trackers: components$1["schemas"]["swag_paypal_v1_shipping_tracker"][];
  };
  swag_paypal_v1_shipping_tracker: {
    carrier: string;
    notify_buyer: boolean;
    /** Pattern: '2022-08-15' */
    shipment_date: string;
    status: string;
    tracking_number: string;
    transaction_id: string;
  };
  swag_paypal_v1_subscription: {
    application_context: components$1["schemas"]["swag_paypal_v1_subscription_application_context"];
    billing_info:
      | components$1["schemas"]["swag_paypal_v1_subscription_billing_info"]
      | null;
    create_time: string;
    id: string;
    links: components$1["schemas"]["swag_paypal_v1_common_link"][];
    plan_id: string;
    quantity: string;
    shipping_amount: components$1["schemas"]["swag_paypal_v1_common_money"];
    start_time: string;
    status: string;
    status_update_time: string;
    subscriber: components$1["schemas"]["swag_paypal_v1_subscription_subscriber"];
    update_time: string;
  };
  swag_paypal_v1_subscription_application_context: {
    brand_name: string;
    cancel_url: string;
    locale: string;
    return_url: string;
    /** @default SET_PROVIDED_ADDRESS */
    shipping_preference?: string;
    /** @default SUBSCRIBE_NOW */
    user_action?: string;
  };
  swag_paypal_v1_subscription_billing_info: {
    cycle_executions: components$1["schemas"]["swag_paypal_v1_subscription_billing_info_cycle_execution"][];
    failed_payments_count: number;
    last_payment: components$1["schemas"]["swag_paypal_v1_subscription_billing_info_last_payment"];
    next_billing_time: string | null;
    outstanding_balance: components$1["schemas"]["swag_paypal_v1_subscription_billing_info_outstanding_balance"];
  };
  swag_paypal_v1_subscription_billing_info_cycle_execution: {
    cycles_completed: number;
    cycles_remaining: number;
    sequence: number;
    tenure_type: string;
    total_cycles: number;
  };
  swag_paypal_v1_subscription_billing_info_last_payment: {
    amount: components$1["schemas"]["swag_paypal_v1_common_money"];
    time: string;
  };
  swag_paypal_v1_subscription_billing_info_outstanding_balance: components$1["schemas"]["swag_paypal_v1_common_money"];
  swag_paypal_v1_subscription_subscriber: {
    email_address: string;
    name: components$1["schemas"]["swag_paypal_v1_subscription_subscriber_name"];
    payer_id: string;
    shipping_address:
      | components$1["schemas"]["swag_paypal_v1_subscription_subscriber_shipping_address"]
      | null;
  };
  swag_paypal_v1_subscription_subscriber_name: {
    given_name: string;
    surname: string;
  };
  swag_paypal_v1_subscription_subscriber_shipping_address: {
    address:
      | components$1["schemas"]["swag_paypal_v1_subscription_subscriber_shipping_address_address"]
      | null;
    name:
      | components$1["schemas"]["swag_paypal_v1_subscription_subscriber_shipping_address_name"]
      | null;
  };
  swag_paypal_v1_subscription_subscriber_shipping_address_address: {
    address_line_1: string | null;
    address_line_2: string | null;
    admin_area_1: string | null;
    admin_area_2: string | null;
    country_code: string;
    postal_code: string | null;
  };
  swag_paypal_v1_subscription_subscriber_shipping_address_name: {
    full_name: string;
  };
  swag_paypal_v1_token: {
    /** The access token issued by PayPal. After the access token
     *     expires (see $expiresIn), you must request a new access token. */
    access_token: string;
    app_id: string;
    /**
     * Format: date-time
     * Calculated expiration date
     */
    expire_date_time: string;
    /** The lifetime of the access token, in seconds. */
    expires_in: number;
    id_token: string | null;
    nonce: string;
    /** Scopes expressed in the form of resource URL endpoints. The value of the scope parameter
     *     is expressed as a list of space-delimited, case-sensitive strings. */
    scope: string;
    /** The type of the token issued as described in OAuth2.0 RFC6749,
     *     Section 7.1. Value is case insensitive. */
    token_type: string;
  };
  swag_paypal_v1_webhook: {
    create_time: string;
    event_type: string;
    event_version: string;
    id: string;
    links: components$1["schemas"]["swag_paypal_v1_common_link"][];
    resource:
      | (
          | components$1["schemas"]["swag_paypal_v3_payment_token"]
          | components$1["schemas"]["swag_paypal_v2_order_purchase_unit_payments_authorization"]
          | components$1["schemas"]["swag_paypal_v2_order_purchase_unit_payments_capture"]
          | components$1["schemas"]["swag_paypal_v2_order_purchase_unit_payments_refund"]
          | components$1["schemas"]["swag_paypal_v1_webhook_resource"]
          | components$1["schemas"]["swag_paypal_v1_subscription"]
        )
      | null;
    resource_type: string;
    resource_version: string;
    summary: string;
  };
  swag_paypal_v1_webhook_resource: {
    amount: components$1["schemas"]["swag_paypal_v1_common_amount"];
    billing_agreement_id: string | null;
    clearing_time: string;
    create_time: string;
    id: string;
    invoice_number: string;
    links: components$1["schemas"]["swag_paypal_v1_common_link"][];
    merchant_id: string | null;
    parent_payment: string | null;
    payment_mode: string;
    protection_eligibility: string;
    protection_eligibility_type: string;
    refund_reason_code: string | null;
    sale_id: string | null;
    state: string;
    transaction_fee: components$1["schemas"]["swag_paypal_v1_common_value"];
    update_time: string;
  };
  swag_paypal_v2_common_address: {
    /** The first line of the address. For example, number or street. For example, 173 Drury Lane.
     *     Required for data entry and compliance and risk checks. Must contain the full address. */
    address_line_1: string | null;
    /** The second line of the address. For example, suite or apartment number. */
    address_line_2: string | null;
    /** The highest level sub-division in a country, which is usually a province, state, or ISO-3166-2 subdivision.
     *     Format for postal delivery. For example, CA and not California. */
    admin_area_1: string | null;
    /** A city, town, or village. Smaller than $adminArea1 */
    admin_area_2: string | null;
    country_code: string;
    postal_code: string | null;
  };
  swag_paypal_v2_common_link: {
    enc_type: string | null;
    href: string;
    method: string;
    rel: string;
  };
  swag_paypal_v2_common_money: {
    currency_code: string;
    value: string;
  };
  swag_paypal_v2_common_name: {
    given_name: string;
    surname: string;
  };
  swag_paypal_v2_common_phone_number: {
    country_code: string;
    national_number: string;
  };
  swag_paypal_v2_order: {
    application_context: components$1["schemas"]["swag_paypal_v2_order_application_context"];
    create_time: string;
    id: string;
    intent: string;
    links: components$1["schemas"]["swag_paypal_v2_common_link"][];
    payer: components$1["schemas"]["swag_paypal_v2_order_payer"];
    payment_source:
      | components$1["schemas"]["swag_paypal_v2_order_payment_source"]
      | null;
    processing_instruction: string;
    purchase_units:
      | components$1["schemas"]["swag_paypal_v2_order_purchase_unit"][]
      | null;
    status: string;
    update_time: string;
  };
  swag_paypal_v2_order_application_context: {
    brand_name: string;
    cancel_url: string;
    /**
     * @default NO_PREFERENCE
     * @enum {string}
     */
    landing_page?: "LOGIN" | "BILLING" | "NO_PREFERENCE";
    return_url: string;
    /**
     * @default SET_PROVIDED_ADDRESS
     * @enum {string}
     */
    shipping_preference?:
      | "SET_PROVIDED_ADDRESS"
      | "NO_SHIPPING"
      | "GET_FROM_FILE";
    /**
     * @default PAY_NOW
     * @enum {string}
     */
    user_action?: "CONTINUE" | "PAY_NOW";
  };
  swag_paypal_v2_order_payer: {
    address: components$1["schemas"]["swag_paypal_v2_common_address"];
    email_address: string;
    name: components$1["schemas"]["swag_paypal_v2_common_name"];
    payer_id: string;
    phone:
      | components$1["schemas"]["swag_paypal_v2_order_payment_source_common_phone"]
      | null;
  };
  swag_paypal_v2_order_payment_source: {
    apple_pay: components$1["schemas"]["swag_paypal_v2_order_payment_source_apple_pay"];
    bancontact:
      | components$1["schemas"]["swag_paypal_v2_order_payment_source_bancontact"]
      | null;
    blik:
      | components$1["schemas"]["swag_paypal_v2_order_payment_source_blik"]
      | null;
    boletobancario:
      | components$1["schemas"]["swag_paypal_v2_order_payment_source_boletobancario"]
      | null;
    card:
      | components$1["schemas"]["swag_paypal_v2_order_payment_source_card"]
      | null;
    eps:
      | components$1["schemas"]["swag_paypal_v2_order_payment_source_eps"]
      | null;
    giropay:
      | components$1["schemas"]["swag_paypal_v2_order_payment_source_giropay"]
      | null;
    google_pay:
      | components$1["schemas"]["swag_paypal_v2_order_payment_source_google_pay"]
      | null;
    ideal:
      | components$1["schemas"]["swag_paypal_v2_order_payment_source_ideal"]
      | null;
    multibanco:
      | components$1["schemas"]["swag_paypal_v2_order_payment_source_multibanco"]
      | null;
    my_bank:
      | components$1["schemas"]["swag_paypal_v2_order_payment_source_my_bank"]
      | null;
    oxxo:
      | components$1["schemas"]["swag_paypal_v2_order_payment_source_oxxo"]
      | null;
    p24:
      | components$1["schemas"]["swag_paypal_v2_order_payment_source_p24"]
      | null;
    pay_upon_invoice:
      | components$1["schemas"]["swag_paypal_v2_order_payment_source_pay_upon_invoice"]
      | null;
    paypal:
      | components$1["schemas"]["swag_paypal_v2_order_payment_source_paypal"]
      | null;
    sofort:
      | components$1["schemas"]["swag_paypal_v2_order_payment_source_sofort"]
      | null;
    token:
      | components$1["schemas"]["swag_paypal_v2_order_payment_source_token"]
      | null;
    trustly:
      | components$1["schemas"]["swag_paypal_v2_order_payment_source_trustly"]
      | null;
    venmo:
      | components$1["schemas"]["swag_paypal_v2_order_payment_source_venmo"]
      | null;
  };
  swag_paypal_v2_order_payment_source_apple_pay: {
    attributes:
      | components$1["schemas"]["swag_paypal_v2_order_payment_source_common_attributes"]
      | null;
    card:
      | components$1["schemas"]["swag_paypal_v2_order_payment_source_card"]
      | null;
    country_code: string;
    experience_context: components$1["schemas"]["swag_paypal_v2_order_payment_source_common_experience_context"];
    name: string;
  };
  swag_paypal_v2_order_payment_source_bancontact: {
    country_code: string;
    experience_context: components$1["schemas"]["swag_paypal_v2_order_payment_source_common_experience_context"];
    name: string;
  };
  swag_paypal_v2_order_payment_source_blik: {
    country_code: string;
    email: string;
    experience_context: components$1["schemas"]["swag_paypal_v2_order_payment_source_common_experience_context"];
    name: string;
  };
  swag_paypal_v2_order_payment_source_boletobancario: {
    billing_address: components$1["schemas"]["swag_paypal_v2_common_address"];
    country_code: string;
    email: string;
    experience_context: components$1["schemas"]["swag_paypal_v2_order_payment_source_common_experience_context"];
    expiry_date: string;
    name: string;
    tax_info: components$1["schemas"]["swag_paypal_v2_order_payment_source_boletobancario_tax_info"];
  };
  swag_paypal_v2_order_payment_source_boletobancario_tax_info: {
    tax_id: string;
    tax_id_type: string;
  };
  swag_paypal_v2_order_payment_source_card: {
    attributes:
      | components$1["schemas"]["swag_paypal_v2_order_payment_source_common_attributes"]
      | null;
    authentication_result:
      | components$1["schemas"]["swag_paypal_v2_order_payment_source_card_authentication_result"]
      | null;
    billing_address:
      | components$1["schemas"]["swag_paypal_v2_common_address"]
      | null;
    brand: string;
    country_code: string;
    experience_context: components$1["schemas"]["swag_paypal_v2_order_payment_source_common_experience_context"];
    last_digits: string;
    name: string;
    stored_credential:
      | components$1["schemas"]["swag_paypal_v2_order_payment_source_card_stored_credential"]
      | null;
    type: string;
    vault_id: string;
  };
  swag_paypal_v2_order_payment_source_card_authentication_result: {
    liability_shift: string;
    three_d_secure:
      | components$1["schemas"]["swag_paypal_v2_order_payment_source_card_authentication_result_3d_secure"]
      | null;
  };
  swag_paypal_v2_order_payment_source_card_authentication_result_3d_secure: {
    authentication_status: string;
    enrollment_status: string;
  };
  swag_paypal_v2_order_payment_source_card_stored_credential: {
    /** @enum {string} */
    payment_initiator: "MERCHANT" | "CUSTOMER";
    /** @enum {string} */
    payment_type: "RECURRING" | "ONE_TIME" | "UNSCHEDULED";
    previous_network_transaction_reference: string;
    /** @enum {string} */
    usage: "DERIVED" | "FIRST" | "SUBSEQUENT";
  };
  swag_paypal_v2_order_payment_source_common_attributes: {
    customer: components$1["schemas"]["swag_paypal_v2_order_payment_source_common_attributes_customer"];
    vault: components$1["schemas"]["swag_paypal_v2_order_payment_source_common_attributes_vault"];
    verification: components$1["schemas"]["swag_paypal_v2_order_payment_source_common_attributes_verification"];
  };
  swag_paypal_v2_order_payment_source_common_attributes_customer: {
    id: string;
  };
  swag_paypal_v2_order_payment_source_common_attributes_vault: {
    confirm_payment_token: string;
    customer:
      | components$1["schemas"]["swag_paypal_v2_order_payment_source_common_attributes_customer"]
      | null;
    id: string | null;
    links: components$1["schemas"]["swag_paypal_v2_common_link"][];
    permit_multiple_payment_tokens: boolean;
    status: string;
    store_in_vault: string;
    usage_type: string;
  };
  swag_paypal_v2_order_payment_source_common_attributes_verification: {
    method: string;
  };
  swag_paypal_v2_order_payment_source_common_experience_context: {
    brand_name: string;
    cancel_url: string;
    /** Only: PUI */
    customer_service_instructions: string[];
    /**
     * @default NO_PREFERENCE
     * @enum {string}
     */
    landing_page?: "LOGIN" | "GUEST_CHECKOUT" | "NO_PREFERENCE";
    locale: string;
    logo_url: string;
    /**
     * Only: PayPal Wallet
     * @enum {string}
     */
    payment_method_preference: "UNRESTRICTED" | "IMMEDIATE_PAYMENT_REQUIRED";
    return_url: string;
    /**
     * @default SET_PROVIDED_ADDRESS
     * @enum {string}
     */
    shipping_preference?:
      | "SET_PROVIDED_ADDRESS"
      | "NO_SHIPPING"
      | "GET_FROM_FILE";
    /**
     * @default PAY_NOW
     * @enum {string}
     */
    user_action?: "CONTINUE" | "PAY_NOW";
  };
  swag_paypal_v2_order_payment_source_common_phone: {
    phone_number: components$1["schemas"]["swag_paypal_v2_common_phone_number"];
    phone_type: string;
  };
  swag_paypal_v2_order_payment_source_eps: {
    country_code: string;
    experience_context: components$1["schemas"]["swag_paypal_v2_order_payment_source_common_experience_context"];
    name: string;
  };
  swag_paypal_v2_order_payment_source_giropay: {
    country_code: string;
    experience_context: components$1["schemas"]["swag_paypal_v2_order_payment_source_common_experience_context"];
    name: string;
  };
  swag_paypal_v2_order_payment_source_google_pay: {
    attributes:
      | components$1["schemas"]["swag_paypal_v2_order_payment_source_common_attributes"]
      | null;
    card:
      | components$1["schemas"]["swag_paypal_v2_order_payment_source_card"]
      | null;
    experience_context: components$1["schemas"]["swag_paypal_v2_order_payment_source_common_experience_context"];
  };
  swag_paypal_v2_order_payment_source_ideal: {
    country_code: string;
    experience_context: components$1["schemas"]["swag_paypal_v2_order_payment_source_common_experience_context"];
    name: string;
  };
  swag_paypal_v2_order_payment_source_multibanco: {
    country_code: string;
    experience_context: components$1["schemas"]["swag_paypal_v2_order_payment_source_common_experience_context"];
    name: string;
  };
  swag_paypal_v2_order_payment_source_my_bank: {
    country_code: string;
    experience_context: components$1["schemas"]["swag_paypal_v2_order_payment_source_common_experience_context"];
    name: string;
  };
  swag_paypal_v2_order_payment_source_oxxo: {
    country_code: string;
    email: string;
    experience_context: components$1["schemas"]["swag_paypal_v2_order_payment_source_common_experience_context"];
    name: string;
  };
  swag_paypal_v2_order_payment_source_p24: {
    country_code: string;
    email: string;
    experience_context: components$1["schemas"]["swag_paypal_v2_order_payment_source_common_experience_context"];
    name: string;
  };
  swag_paypal_v2_order_payment_source_pay_upon_invoice: {
    billing_address: components$1["schemas"]["swag_paypal_v2_common_address"];
    birth_date: string;
    deposit_bank_details: components$1["schemas"]["swag_paypal_v2_order_payment_source_pay_upon_invoice_deposit_bank_details"];
    email: string;
    experience_context: components$1["schemas"]["swag_paypal_v2_order_payment_source_common_experience_context"];
    name: components$1["schemas"]["swag_paypal_v2_common_name"];
    payment_reference: string;
    phone: components$1["schemas"]["swag_paypal_v2_common_phone_number"];
  };
  swag_paypal_v2_order_payment_source_pay_upon_invoice_deposit_bank_details: {
    account_holder_name: string;
    bank_name: string;
    bic: string;
    iban: string;
  };
  swag_paypal_v2_order_payment_source_paypal: {
    account_id: string;
    address: components$1["schemas"]["swag_paypal_v2_common_address"];
    attributes:
      | components$1["schemas"]["swag_paypal_v2_order_payment_source_common_attributes"]
      | null;
    billing_agreement_id: string;
    birth_date: string;
    email_address: string;
    experience_context: components$1["schemas"]["swag_paypal_v2_order_payment_source_common_experience_context"];
    name: components$1["schemas"]["swag_paypal_v2_common_name"];
    phone_number:
      | components$1["schemas"]["swag_paypal_v2_common_phone_number"]
      | null;
    phone_type: string;
    vault_id: string;
  };
  swag_paypal_v2_order_payment_source_sofort: {
    country_code: string;
    experience_context: components$1["schemas"]["swag_paypal_v2_order_payment_source_common_experience_context"];
    name: string;
  };
  swag_paypal_v2_order_payment_source_token: {
    experience_context: components$1["schemas"]["swag_paypal_v2_order_payment_source_common_experience_context"];
    id: string;
    stored_payment_source: components$1["schemas"]["swag_paypal_v2_order_payment_source_token_stored_payment_source"];
    type: string;
  };
  swag_paypal_v2_order_payment_source_token_stored_payment_source: {
    payment_initiator: string;
    payment_type: string;
    usage: string;
  };
  swag_paypal_v2_order_payment_source_trustly: {
    country_code: string;
    experience_context: components$1["schemas"]["swag_paypal_v2_order_payment_source_common_experience_context"];
    name: string;
  };
  swag_paypal_v2_order_payment_source_venmo: {
    account_id: string;
    address: components$1["schemas"]["swag_paypal_v2_common_address"];
    attributes:
      | components$1["schemas"]["swag_paypal_v2_order_payment_source_common_attributes"]
      | null;
    email_address: string;
    experience_context: components$1["schemas"]["swag_paypal_v2_order_payment_source_common_experience_context"];
    name: components$1["schemas"]["swag_paypal_v2_common_name"];
    phone_number:
      | components$1["schemas"]["swag_paypal_v2_common_phone_number"]
      | null;
    user_name: string;
    vault_id: string;
  };
  swag_paypal_v2_order_purchase_unit: {
    amount: components$1["schemas"]["swag_paypal_v2_order_purchase_unit_amount"];
    custom_id: string | null;
    description: string;
    invoice_id: string | null;
    items:
      | components$1["schemas"]["swag_paypal_v2_order_purchase_unit_item"][]
      | null;
    payee: components$1["schemas"]["swag_paypal_v2_order_purchase_unit_payee"];
    payments:
      | components$1["schemas"]["swag_paypal_v2_order_purchase_unit_payments"]
      | null;
    reference_id: string;
    shipping: components$1["schemas"]["swag_paypal_v2_order_purchase_unit_shipping"];
  };
  swag_paypal_v2_order_purchase_unit_amount: components$1["schemas"]["swag_paypal_v2_common_money"] & {
    breakdown:
      | components$1["schemas"]["swag_paypal_v2_order_purchase_unit_amount_breakdown"]
      | null;
  };
  swag_paypal_v2_order_purchase_unit_amount_breakdown: {
    discount: components$1["schemas"]["swag_paypal_v2_common_money"];
    handling: components$1["schemas"]["swag_paypal_v2_common_money"];
    insurance: components$1["schemas"]["swag_paypal_v2_common_money"];
    item_total: components$1["schemas"]["swag_paypal_v2_common_money"];
    shipping: components$1["schemas"]["swag_paypal_v2_common_money"];
    shipping_discount: components$1["schemas"]["swag_paypal_v2_common_money"];
    tax_total: components$1["schemas"]["swag_paypal_v2_common_money"] | null;
  };
  swag_paypal_v2_order_purchase_unit_item: {
    /** @enum {string} */
    category: "PHYSICAL_GOODS" | "DIGITAL_GOODS" | "DONATION";
    name: string;
    quantity: number;
    sku: string | null;
    tax: components$1["schemas"]["swag_paypal_v2_common_money"];
    tax_rate: string | number | Record<string, never>;
    unit_amount: components$1["schemas"]["swag_paypal_v2_common_money"];
  };
  swag_paypal_v2_order_purchase_unit_payee: {
    display_data: components$1["schemas"]["swag_paypal_v2_order_purchase_unit_payee_display_data"];
    email_address: string;
    merchant_id: string;
  };
  swag_paypal_v2_order_purchase_unit_payee_display_data: {
    brand_name: string;
  };
  swag_paypal_v2_order_purchase_unit_payments: {
    authorizations:
      | components$1["schemas"]["swag_paypal_v2_order_purchase_unit_payments_authorization"][]
      | null;
    captures:
      | components$1["schemas"]["swag_paypal_v2_order_purchase_unit_payments_capture"][]
      | null;
    refunds:
      | components$1["schemas"]["swag_paypal_v2_order_purchase_unit_payments_refund"][]
      | null;
  };
  swag_paypal_v2_order_purchase_unit_payments_authorization: {
    amount: components$1["schemas"]["swag_paypal_v2_common_money"] | null;
    create_time: string;
    custom_id: string | null;
    expiration_time: string;
    id: string;
    links: components$1["schemas"]["swag_paypal_v2_common_link"][];
    seller_protection: components$1["schemas"]["swag_paypal_v2_order_purchase_unit_payments_common_seller_protection"];
    status: string;
    update_time: string;
  };
  swag_paypal_v2_order_purchase_unit_payments_authorization_seller_protection: {
    dispute_categories: string[];
    status: string;
  };
  swag_paypal_v2_order_purchase_unit_payments_capture: {
    amount: components$1["schemas"]["swag_paypal_v2_common_money"] | null;
    create_time: string;
    custom_id: string | null;
    disbursement_mode: string;
    final_capture: boolean;
    id: string;
    invoice_id: string | null;
    links: components$1["schemas"]["swag_paypal_v2_common_link"][];
    note_to_payer: string | null;
    processor_response: components$1["schemas"]["swag_paypal_v2_order_purchase_unit_payments_capture_processor_response"];
    seller_protection: components$1["schemas"]["swag_paypal_v2_order_purchase_unit_payments_common_seller_protection"];
    seller_receivable_breakdown: components$1["schemas"]["swag_paypal_v2_order_purchase_unit_payments_capture_seller_receivable_breakdown"];
    status: string;
    update_time: string;
  };
  swag_paypal_v2_order_purchase_unit_payments_capture_processor_response: {
    avs_code: string | null;
    cvv_code: string | null;
    response_code: string | null;
  };
  swag_paypal_v2_order_purchase_unit_payments_capture_seller_receivable_breakdown: {
    gross_amount: components$1["schemas"]["swag_paypal_v2_common_money"];
    net_amount: components$1["schemas"]["swag_paypal_v2_common_money"];
    paypal_fee: components$1["schemas"]["swag_paypal_v2_common_money"];
  };
  swag_paypal_v2_order_purchase_unit_payments_common_seller_protection: {
    dispute_categories: string[];
    status: string;
  };
  swag_paypal_v2_order_purchase_unit_payments_refund: {
    amount: components$1["schemas"]["swag_paypal_v2_common_money"] | null;
    create_time: string;
    custom_id: string | null;
    id: string;
    invoice_id: string | null;
    links: components$1["schemas"]["swag_paypal_v2_common_link"][];
    note_to_payer: string | null;
    seller_payable_breakdown: components$1["schemas"]["swag_paypal_v2_order_purchase_unit_payments_refund_seller_payable_breakdown"];
    status: string;
    update_time: string;
  };
  swag_paypal_v2_order_purchase_unit_payments_refund_seller_payable_breakdown: {
    gross_amount: components$1["schemas"]["swag_paypal_v2_common_money"];
    net_amount: components$1["schemas"]["swag_paypal_v2_common_money"];
    paypal_fee: components$1["schemas"]["swag_paypal_v2_common_money"];
    total_refunded_amount: components$1["schemas"]["swag_paypal_v2_common_money"];
  };
  swag_paypal_v2_order_purchase_unit_shipping: {
    address: components$1["schemas"]["swag_paypal_v2_common_address"];
    name: components$1["schemas"]["swag_paypal_v2_order_purchase_unit_shipping_name"];
    trackers:
      | components$1["schemas"]["swag_paypal_v2_order_purchase_unit_shipping_tracker"][]
      | null;
  };
  swag_paypal_v2_order_purchase_unit_shipping_name: {
    full_name: string;
  };
  swag_paypal_v2_order_purchase_unit_shipping_tracker: {
    id: string;
    items: components$1["schemas"]["swag_paypal_v2_order_purchase_unit_item"][];
    links: components$1["schemas"]["swag_paypal_v2_common_link"][];
    notify_payer: boolean;
    status: string;
  };
  swag_paypal_v2_order_purchase_unit_shipping_tracker_item: {
    image_url: string | null;
    name: string;
    quantity: number;
    sku: string | null;
    url: string | null;
  };
  swag_paypal_v2_order_tracker: {
    capture_id: string;
    carrier: string;
    carrier_name_other: string | null;
    items: components$1["schemas"]["swag_paypal_v2_order_purchase_unit_shipping_tracker_item"][];
    /** @default false */
    notify_payer?: boolean;
    tracking_number: string;
  };
  swag_paypal_v2_patch: {
    from: string;
    op: string;
    path: string;
    value:
      | (
          | number
          | Record<string, never>
          | string
          | boolean
          | Record<string, never>[]
        )
      | null;
  };
  swag_paypal_v2_referral: {
    business_entity: components$1["schemas"]["swag_paypal_v2_referral_business_entity"];
    capabilities: string[];
    legal_consents: components$1["schemas"]["swag_paypal_v2_referral_legal_consent"][];
    links: components$1["schemas"]["swag_paypal_v2_common_link"][];
    operations: components$1["schemas"]["swag_paypal_v2_referral_operation"][];
    partner_config_override: components$1["schemas"]["swag_paypal_v2_referral_partner_config_override"];
    preferred_language_code: string;
    products: string[];
    tracking_id: string;
  };
  swag_paypal_v2_referral_business_entity: {
    addresses: components$1["schemas"]["swag_paypal_v2_referral_business_entity_address"][];
  };
  swag_paypal_v2_referral_business_entity_address: {
    country_code: string;
    /** @default WORK */
    type?: string;
  };
  swag_paypal_v2_referral_legal_consent: {
    granted: boolean;
    /** @default SHARE_DATA_CONSENT */
    type?: string;
  };
  swag_paypal_v2_referral_operation: {
    api_integration_preference: components$1["schemas"]["swag_paypal_v2_referral_operation_integration_preference"];
    /** @default API_INTEGRATION */
    operation?: string;
  };
  swag_paypal_v2_referral_operation_integration_preference: {
    rest_api_integration: components$1["schemas"]["swag_paypal_v2_referral_operation_integration_preference_integration"];
  };
  swag_paypal_v2_referral_operation_integration_preference_integration: {
    /** @default PAYPAL */
    integration_method?: string;
    /** @default THIRD_PARTY */
    integration_type?: string;
    third_party_details: components$1["schemas"]["swag_paypal_v2_referral_operation_integration_preference_integration_third_party_details"];
  };
  swag_paypal_v2_referral_operation_integration_preference_integration_third_party_details: {
    features: string[];
  };
  swag_paypal_v2_referral_partner_config_override: {
    partner_logo_url: string;
    return_url: string;
  };
  swag_paypal_v3_payment_token: {
    customer: components$1["schemas"]["swag_paypal_v2_order_payment_source_common_attributes_customer"];
    id: string;
    links: components$1["schemas"]["swag_paypal_v2_common_link"][];
    metadata:
      | components$1["schemas"]["swag_paypal_v3_payment_token_metadata"]
      | null;
    payment_source: components$1["schemas"]["swag_paypal_v2_order_payment_source"];
    status: string;
  };
  swag_paypal_v3_payment_token_metadata: {
    order_id: string;
  };
};
type operations$1 = {
  "api-info get /_info/openapi3.json": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Type of the api */
      type?: "jsonapi" | "json";
    };
    response: {
      components?: {
        callbacks?: GenericRecord$1;
        examples?: GenericRecord$1;
        headers?: GenericRecord$1;
        links?: GenericRecord$1;
        parameters?: GenericRecord$1;
        pathItems?: GenericRecord$1;
        requestBodies?: GenericRecord$1;
        responses?: GenericRecord$1;
        schemas?: GenericRecord$1;
        securitySchemes?: GenericRecord$1;
      };
      externalDocs?: {
        description?: string;
        /** Format: uri */
        url: string;
      };
      info: {
        contact?: {
          /** Format: email */
          email?: string;
          name?: string;
          /** Format: uri */
          url?: string;
        };
        description?: string;
        license?: {
          identifier?: string;
          name: string;
          /** Format: uri */
          url?: string;
        };
        summary?: string;
        /** Format: uri */
        termsOfService?: string;
        title: string;
        version: string;
      };
      jsonSchemaDialect?: string;
      openapi: string;
      paths?: GenericRecord$1;
      security?: GenericRecord$1[];
      servers?: {
        url: string;
      }[];
      tags?: {
        description?: string;
        externalDocs?: {
          description?: string;
          /** Format: uri */
          url: string;
        };
        name: string;
      }[];
      webhooks?: GenericRecord$1;
    };
    responseCode: 200;
  };
  "getRoutes get /_info/routes": {
    contentType?: "application/json";
    accept?: "application/json";
    response: {
      endpoints: {
        methods: string[];
        path: string;
      }[];
    };
    responseCode: 200;
  };
  "createCustomerAddress post /account/address": {
    contentType?: "application/json";
    accept?: "application/json";
    body: components$1["schemas"]["CustomerAddressBody"];
    response: components$1["schemas"]["CustomerAddress"] &
      components$1["schemas"]["CustomerAddressRead"];
    responseCode: 200;
  };
  "deleteCustomerAddress delete /account/address/{addressId}": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** ID of the address to be deleted. */
      addressId: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateCustomerAddress patch /account/address/{addressId}": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Address ID */
      addressId: string;
    };
    body: components$1["schemas"]["CustomerAddressBody"];
    response: components$1["schemas"]["CustomerAddress"] &
      components$1["schemas"]["CustomerAddressRead"];
    responseCode: 200;
  };
  "defaultBillingAddress patch /account/address/default-billing/{addressId}": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Address ID */
      addressId: string;
    };
    response: never;
    responseCode: 200;
  };
  "defaultShippingAddress patch /account/address/default-shipping/{addressId}": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Address ID */
      addressId: string;
    };
    response: never;
    responseCode: 200;
  };
  "changeEmail post /account/change-email": {
    contentType?: "application/json";
    accept?: "application/json";
    body: {
      /** New email address. Has to be unique amongst all customers */
      email: string;
      /** Confirmation of the new email address. */
      emailConfirmation: string;
      /** Customer's current password */
      password: string;
    };
    response: components$1["schemas"]["SuccessResponse"];
    responseCode: 200;
  };
  "changeLanguage post /account/change-language": {
    contentType?: "application/json";
    accept?: "application/json";
    body: {
      /** New languageId */
      language?: string;
    };
    response: components$1["schemas"]["SuccessResponse"];
    responseCode: 200;
  };
  "changePassword post /account/change-password": {
    contentType?: "application/json";
    accept?: "application/json";
    body: {
      /** New Password for the customer */
      newPassword: string;
      /** Confirmation of the new password */
      newPasswordConfirm: string;
      /** Current password of the customer */
      password: string;
    };
    response: components$1["schemas"]["SuccessResponse"];
    responseCode: 200;
  };
  "changePaymentMethod post /account/change-payment-method/{paymentMethodId}": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Identifier of the desired default payment method */
      paymentMethodId: string;
    };
    response: components$1["schemas"]["SuccessResponse"];
    responseCode: 200;
  };
  "changeProfile post /account/change-profile": {
    contentType?: "application/json";
    accept?: "application/json";
    body: {
      /** Birthday day */
      birthdayDay?: number;
      /** Birthday month */
      birthdayMonth?: number;
      /** Birthday year */
      birthdayYear?: number;
      /** Customer first name. Value will be reused for shipping and billing address if not provided explicitly. */
      firstName: string;
      /** Customer last name. Value will be reused for shipping and billing address if not provided explicitly. */
      lastName: string;
      /** Id of the salutation for the customer account. Fetch options using `salutation` endpoint. */
      salutationId?: string;
      /** (Academic) title of the customer */
      title?: string;
    } & (
      | {
          /**
           * Type of the customer account. Default value is 'private'.
           * @default private
           * @enum {string}
           */
          accountType?: "private";
          company?: null;
          vatIds?: null;
        }
      | {
          /**
           * Type of the customer account. Can be `private` or `business`.
           * @enum {string}
           */
          accountType: "business";
          /** Company of the customer. Only required when `accountType` is `business`. */
          company: string;
          /** VAT IDs of the customer's company. Only valid when `accountType` is `business`. */
          vatIds: [string, ...string[]];
        }
      | {
          /**
           * Type of the customer account. Default value is 'private'.
           * @default private
           * @enum {string}
           */
          accountType?: "private";
          company?: null;
          vatIds?: null;
        }
      | {
          /**
           * Type of the customer account. Can be `private` or `business`.
           * @enum {string}
           */
          accountType: "business";
          /** Company of the customer. Only required when `accountType` is `business`. */
          company: string;
          /** VAT IDs of the customer's company. Only valid when `accountType` is `business`. */
          vatIds: [string, ...string[]];
        }
    );
    response: components$1["schemas"]["SuccessResponse"];
    responseCode: 200;
  };
  "readCustomer post /account/customer": {
    contentType?: "application/json";
    accept?: "application/json";
    body?: components$1["schemas"]["Criteria"];
    response: components$1["schemas"]["Customer"];
    responseCode: 200;
  };
  "deleteCustomer delete /account/customer": {
    contentType?: "application/json";
    accept?: "application/json";
    response: never;
    responseCode: 204;
  };
  "getCustomerRecoveryIsExpired post /account/customer-recovery-is-expired": {
    contentType?: "application/json";
    accept?: "application/json";
    body: {
      /** Parameter from the link in the confirmation mail sent in Step 1 */
      hash: string;
    };
    response: {
      /** @enum {string} */
      apiAlias?: "array_struct";
      data?: {
        isExpired: boolean;
      }[];
    };
    responseCode: 200;
  };
  "listAddress post /account/list-address": {
    contentType?: "application/json";
    accept?: "application/json";
    body?: components$1["schemas"]["Criteria"];
    response: {
      elements: components$1["schemas"]["CustomerAddress"][];
    } & components$1["schemas"]["EntitySearchResult"];
    responseCode: 200;
  };
  "loginCustomer post /account/login": {
    contentType?: "application/json";
    accept?: "application/json";
    body: {
      /** Password */
      password: string;
      /** Email */
      username: string;
    };
    response: {
      /** Define the URL which browser will be redirected to */
      redirectUrl?: string;
    };
    responseCode: 200;
  };
  "imitateCustomerLogin post /account/login/imitate-customer": {
    contentType?: "application/json";
    accept?: "application/json";
    body: {
      /** ID of the customer */
      customerId: string;
      /** Generated customer impersonation token */
      token: string;
      /** ID of the user who generated the token */
      userId: string;
    };
    response: {
      /** Define the URL which browser will be redirected to */
      redirectUrl?: string;
    };
    responseCode: 200;
  };
  "logoutCustomer post /account/logout": {
    contentType?: "application/json";
    accept?: "application/json";
    response: {
      /** Define the URL which browser will be redirected to */
      redirectUrl?: string;
    };
    responseCode: 200;
  };
  "readNewsletterRecipient post /account/newsletter-recipient": {
    contentType?: "application/json";
    accept?: "application/json";
    body?: components$1["schemas"]["Criteria"];
    response: components$1["schemas"]["AccountNewsletterRecipient"];
    responseCode: 200;
  };
  "sendRecoveryMail post /account/recovery-password": {
    contentType?: "application/json";
    accept?: "application/json";
    body: {
      /** E-Mail address to identify the customer */
      email: string;
      /** URL of the storefront to use for the generated reset link. It has to be a domain that is configured in the sales channel domain settings. */
      storefrontUrl: string;
    };
    response: components$1["schemas"]["SuccessResponse"];
    responseCode: 200;
  };
  "recoveryPassword post /account/recovery-password-confirm": {
    contentType?: "application/json";
    accept?: "application/json";
    body: {
      /** Parameter from the link in the confirmation mail sent in Step 1 */
      hash: string;
      /** New password for the customer */
      newPassword: string;
      /** Confirmation of the new password */
      newPasswordConfirm: string;
    };
    response: components$1["schemas"]["SuccessResponse"];
    responseCode: 200;
  };
  "register post /account/register": {
    contentType?: "application/json";
    accept?: "application/json";
    body: {
      /** Flag indicating accepted data protection */
      acceptedDataProtection: boolean;
      /** Field can be used to store an affiliate tracking code */
      affiliateCode?: string;
      billingAddress: components$1["schemas"]["CustomerAddress"];
      /** Birthday day */
      birthdayDay?: number;
      /** Birthday month */
      birthdayMonth?: number;
      /** Birthday year */
      birthdayYear?: number;
      /** Field can be used to store a campaign tracking code */
      campaignCode?: string;
      /** Email of the customer. Has to be unique, unless `guest` is `true` */
      email: string;
      /** Customer first name. Value will be reused for shipping and billing address if not provided explicitly. */
      firstName: string;
      /**
       * If set, will create a guest customer. Guest customers can re-use an email address and don't need a password.
       * @default false
       */
      guest?: boolean;
      /** Customer last name. Value will be reused for shipping and billing address if not provided explicitly. */
      lastName: string;
      /** Password for the customer. Required, unless `guest` is `true` */
      password: string;
      /** Id of the salutation for the customer account. Fetch options using `salutation` endpoint. */
      salutationId?: string;
      shippingAddress?: components$1["schemas"]["CustomerAddress"];
      /** URL of the storefront for that registration. Used in confirmation emails. Has to be one of the configured domains of the sales channel. */
      storefrontUrl: string;
      /** (Academic) title of the customer */
      title?: string;
    } & (
      | {
          /**
           * Type of the customer account. Default value is 'private'.
           * @default private
           * @enum {string}
           */
          accountType?: "private";
          company?: null;
          vatIds?: null;
        }
      | {
          /**
           * Type of the customer account. Can be `private` or `business`.
           * @enum {string}
           */
          accountType: "business";
          /** Company of the customer. Only required when `accountType` is `business`. */
          company: string;
          /** VAT IDs of the customer's company. Only valid when `accountType` is `business`. */
          vatIds: [string, ...string[]];
        }
      | {
          /**
           * Type of the customer account. Default value is 'private'.
           * @default private
           * @enum {string}
           */
          accountType?: "private";
          company?: null;
          vatIds?: null;
        }
      | {
          /**
           * Type of the customer account. Can be `private` or `business`.
           * @enum {string}
           */
          accountType: "business";
          /** Company of the customer. Only required when `accountType` is `business`. */
          company: string;
          /** VAT IDs of the customer's company. Only valid when `accountType` is `business`. */
          vatIds: [string, ...string[]];
        }
    );
    response: components$1["schemas"]["Customer"];
    responseCode: 200;
  };
  "registerConfirm post /account/register-confirm": {
    contentType?: "application/json";
    accept?: "application/json";
    body: {
      /** Email hash from the email received */
      em: string;
      /** Hash from the email received */
      hash: string;
    };
    response: never;
    responseCode: 200;
  };
  "generateJWTAppSystemAppServer post /app-system/{name}/generate-token": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Name of the app */
      name: string;
    };
    body?: GenericRecord$1;
    response: {
      /** Format: date-time */
      expires?: string;
      shopId?: string;
      token?: string;
    };
    responseCode: 200;
  };
  "readApprovalRules get /approval-rule": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Number of items per page */
      limit?: number;
      /** Page number */
      p?: number;
    };
    response: {
      elements?: components$1["schemas"]["ApprovalRule"][];
    } & components$1["schemas"]["EntitySearchResult"];
    responseCode: 200;
  };
  "listApprovalRules post /approval-rule": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Number of items per page */
      limit?: number;
      /** Page number */
      p?: number;
    };
    body?: components$1["schemas"]["Criteria"];
    response: {
      elements?: components$1["schemas"]["ApprovalRule"][];
    } & components$1["schemas"]["EntitySearchResult"];
    responseCode: 200;
  };
  "readApprovalRule get /approval-rule/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Identifier of the approval rule to be fetched */
      id: string;
    };
    response: components$1["schemas"]["ApprovalRule"];
    responseCode: 200;
  };
  "updateApprovalRule patch /approval-rule/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Identifier of the approval rule to be updated */
      id: string;
    };
    body: {
      /** Active status of the approval rule */
      active?: boolean;
      /** ID of the role that can approve the rule */
      approvalRuleApprove?: string;
      /** List of rules */
      approvalRuleCondition?: {
        /** Type of the rule */
        type?: string;
        /** Value */
        value?: string;
      };
      /** Name of the approval rule */
      approvalRuleName?: string;
      /** ID of the role that is affected by the rule */
      approvalRuleRole?: string;
      /** Description of the approval rule */
      description?: string;
      /** Priority of the approval rule */
      priority?: number;
    };
    response: components$1["schemas"]["ApprovalRule"];
    responseCode: 200;
  };
  "createApprovalRule post /approval-rule/create": {
    contentType?: "application/json";
    accept?: "application/json";
    body: {
      /** Active status of the approval rule */
      active?: boolean;
      /** ID of the role that can approve the rule */
      approvalRuleApprove?: string;
      /** List of rules */
      approvalRuleCondition?: {
        /** Type of the rule */
        type?: string;
        /** Value */
        value?: string;
      };
      /** Name of the approval rule */
      approvalRuleName?: string;
      /** ID of the role that is affected by the rule */
      approvalRuleRole?: string;
      /** Description of the approval rule */
      description?: string;
      /** Priority of the approval rule */
      priority?: number;
    };
    response: components$1["schemas"]["ApprovalRule"];
    responseCode: 200;
  };
  "readBreadcrumb get /breadcrumb/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** UUID for referrer category only used for product breadcrumb */
      referrerCategoryId?: string;
      /** Type: category or product (optional - default: product) */
      type?: "product" | "category";
    };
    pathParams: {
      /** UUID for product or category */
      id: string;
    };
    response: components$1["schemas"]["BreadcrumbCollection"];
    responseCode: 200;
  };
  "readCategoryList post /category": {
    contentType?: "application/json";
    accept?: "application/json";
    headers?: {
      /** Instructs Shopware to return the response in the given language. */
      "sw-language-id"?: string;
    };
    body?: components$1["schemas"]["Criteria"];
    response: {
      elements?: components$1["schemas"]["Category"][];
    } & components$1["schemas"]["EntitySearchResult"];
    responseCode: 200;
  };
  "readCategory post /category/{navigationId}": {
    contentType?: "application/json";
    accept?: "application/json";
    headers?: {
      /** Instructs Shopware to try and resolve SEO URLs for the given navigation item */
      "sw-include-seo-urls"?: boolean;
      /** Instructs Shopware to return the response in the given language. */
      "sw-language-id"?: string;
    };
    query?: {
      /** Resolves only the given slot identifiers. The identifiers have to be seperated by a '|' character */
      slots?: string;
    };
    pathParams: {
      /** Identifier of the category to be fetched */
      navigationId: string;
    };
    body: components$1["schemas"]["Criteria"] &
      components$1["schemas"]["ProductListingCriteria"];
    response: components$1["schemas"]["Category"];
    responseCode: 200;
  };
  "readCart get /checkout/cart": {
    contentType?: "application/json";
    accept?: "application/json";
    headers?: {
      /** Instructs Shopware to return the response in the given language. */
      "sw-language-id"?: string;
    };
    response: components$1["schemas"]["Cart"];
    responseCode: 200;
  };
  "deleteCart delete /checkout/cart": {
    contentType?: "application/json";
    accept?: "application/json";
    response: components$1["schemas"]["SuccessResponse"];
    responseCode: 204;
  };
  "addLineItem post /checkout/cart/line-item": {
    contentType?: "application/json";
    accept?: "application/json";
    headers?: {
      /** Instructs Shopware to return the response in the given language. */
      "sw-language-id"?: string;
    };
    body: {
      items: (
        | {
            id: string;
            quantity: number;
            referencedId?: string;
            /** @enum {string} */
            type: "product" | "custom" | "credit" | "discount" | "container";
          }
        | {
            id?: string;
            quantity?: number;
            referencedId: string;
            /** @enum {string} */
            type: "promotion";
          }
      )[];
    };
    response: components$1["schemas"]["Cart"];
    responseCode: 200;
  };
  "removeLineItemDeprecated delete /checkout/cart/line-item": {
    contentType?: "application/json";
    accept?: "application/json";
    headers?: {
      /** Instructs Shopware to return the response in the given language. */
      "sw-language-id"?: string;
    };
    query: {
      /** A list of product identifiers. */
      ids: string[];
    };
    response: components$1["schemas"]["Cart"];
    responseCode: 200;
  };
  "updateLineItem patch /checkout/cart/line-item": {
    contentType?: "application/json";
    accept?: "application/json";
    headers?: {
      /** Instructs Shopware to return the response in the given language. */
      "sw-language-id"?: string;
    };
    body: {
      items: [
        {
          id: string;
          quantity: number;
        },
        ...{
          id: string;
          quantity: number;
        }[],
      ];
    };
    response: components$1["schemas"]["Cart"];
    responseCode: 200;
  };
  "removeLineItem post /checkout/cart/line-item/delete": {
    contentType?: "application/json";
    accept?: "application/json";
    headers?: {
      /** Instructs Shopware to return the response in the given language. */
      "sw-language-id"?: string;
    };
    body: {
      /** A list of product identifiers. */
      ids: [string, ...string[]];
    };
    response: components$1["schemas"]["Cart"];
    responseCode: 200;
  };
  "checkoutGateway get /checkout/gateway": {
    contentType?: "application/json";
    accept?: "application/json";
    response: {
      errors?: {
        /** If the error is blocking */
        blocking?: boolean;
        /** Error code */
        code?: string;
        /** Error detail */
        detail?: string;
      }[];
      paymentMethods?: {
        /** aggregation result */
        aggregations?: GenericRecord$1;
        elements?: components$1["schemas"]["PaymentMethod"][];
        /** Total amount */
        total?: number;
      };
      shippingMethods?: {
        /** aggregation result */
        aggregations?: GenericRecord$1;
        elements?: components$1["schemas"]["ShippingMethod"][];
        /** Total amount */
        total?: number;
      };
    };
    responseCode: 200;
  };
  "createOrder post /checkout/order": {
    contentType?: "application/json";
    accept?: "application/json";
    headers?: {
      /** Instructs Shopware to return the response in the given language. */
      "sw-language-id"?: string;
    };
    body: {
      /** The affiliate code can be used to track which referrer the customer came through. An example could be `Price-comparison-company-XY`. */
      affiliateCode?: string;
      /** The campaign code is used to track which action the customer came from. An example could be `Summer-Deals` */
      campaignCode?: string;
      /** Adds a comment from the customer to the order. */
      customerComment?: string;
    };
    response: components$1["schemas"]["Order"];
    responseCode: 200;
  };
  "readCms post /cms/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    headers?: {
      /** Instructs Shopware to return the response in the given language. */
      "sw-language-id"?: string;
    };
    pathParams: {
      /** Identifier of the CMS page to be resolved */
      id: string;
    };
    body: {
      /** Resolves only the given slot identifiers. The identifiers have to be seperated by a `|` character. */
      slots?: string;
    } & components$1["schemas"]["ProductListingCriteria"];
    response: components$1["schemas"]["CmsPage"];
    responseCode: 200;
  };
  "sendContactMail post /contact-form": {
    contentType?: "application/json";
    accept?: "application/json";
    headers?: {
      /** Instructs Shopware to return the response in the given language. */
      "sw-language-id"?: string;
    };
    body: {
      /** Type of the content management page */
      cmsPageType?: string;
      /** The message of the contact form */
      comment: string;
      /** Email address */
      email: string;
      /** Entity name for slot config */
      entityName?: string;
      /** Firstname. This field may be required depending on the system settings. */
      firstName?: string;
      /** Lastname. This field may be required depending on the system settings. */
      lastName?: string;
      /** Identifier of the navigation page. Can be used to override the configuration.
       *     Take a look at the settings of a category containing a concat form in the administration. */
      navigationId?: string;
      /** Phone. This field may be required depending on the system settings. */
      phone?: string;
      /** Identifier of the salutation. Use `/api/salutation` endpoint to fetch possible values. */
      salutationId?: string;
      /** Identifier of the cms element */
      slotId?: string;
      /** The subject of the contact form. */
      subject: string;
    };
    response: never;
    responseCode: 200;
  };
  "readContext get /context": {
    contentType?: "application/json";
    accept?: "application/json";
    response: components$1["schemas"]["SalesChannelContext"];
    responseCode: 200;
  };
  "updateContext patch /context": {
    contentType?: "application/json";
    accept?: "application/json";
    body: {
      /** Billing Address */
      billingAddressId?: string;
      /** Country */
      countryId?: string;
      /** Country State */
      countryStateId?: string;
      /** Currency */
      currencyId?: string;
      /** Language */
      languageId?: string;
      /** Payment Method */
      paymentMethodId?: string;
      /** Shipping Address */
      shippingAddressId?: string;
      /** Shipping Method */
      shippingMethodId?: string;
    };
    response: {
      /** Define the URL which browser will be redirected to */
      redirectUrl?: string;
    };
    responseCode: 200;
  };
  "readCountry post /country": {
    contentType?: "application/json";
    accept?: "application/json";
    headers?: {
      /** Instructs Shopware to return the response in the given language. */
      "sw-language-id"?: string;
    };
    body?: components$1["schemas"]["Criteria"];
    response: {
      elements?: components$1["schemas"]["Country"][];
    } & components$1["schemas"]["EntitySearchResult"];
    responseCode: 200;
  };
  "readCountryState post /country-state/{countryId}": {
    contentType?: "application/json";
    accept?: "application/json";
    headers?: {
      /** Instructs Shopware to return the response in the given language. */
      "sw-language-id"?: string;
    };
    pathParams: {
      countryId: string;
    };
    body?: components$1["schemas"]["Criteria"];
    response: {
      elements?: components$1["schemas"]["CountryState"][];
    } & components$1["schemas"]["EntitySearchResult"];
    responseCode: 200;
  };
  "readCurrency post /currency": {
    contentType?: "application/json";
    accept?: "application/json";
    headers?: {
      /** Instructs Shopware to return the response in the given language. */
      "sw-language-id"?: string;
    };
    body?: components$1["schemas"]["Criteria"];
    response: components$1["schemas"]["Currency"][];
    responseCode: 200;
  };
  "getCustomerGroupRegistrationInfo get /customer-group-registration/config/{customerGroupId}": {
    contentType?: "application/json";
    accept?: "application/json";
    headers?: {
      /** Instructs Shopware to return the response in the given language. */
      "sw-language-id"?: string;
    };
    pathParams: {
      /** Customer group id */
      customerGroupId: string;
    };
    response: components$1["schemas"]["CustomerGroup"];
    responseCode: 200;
  };
  "readCustomerWishlist post /customer/wishlist": {
    contentType?: "application/json";
    accept?: "application/json";
    headers?: {
      /** Instructs Shopware to return the response in the given language. */
      "sw-language-id"?: string;
    };
    body?: components$1["schemas"]["Criteria"];
    response: components$1["schemas"]["WishlistLoadRouteResponse"];
    responseCode: 200;
  };
  "addProductOnWishlist post /customer/wishlist/add/{productId}": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Identifier of the product to be added. */
      productId: string;
    };
    response: components$1["schemas"]["SuccessResponse"];
    responseCode: 200;
  };
  "deleteProductOnWishlist delete /customer/wishlist/delete/{productId}": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** The identifier of the product to be removed from the wishlist. */
      productId: string;
    };
    response: components$1["schemas"]["SuccessResponse"];
    responseCode: 200;
  };
  "mergeProductOnWishlist post /customer/wishlist/merge": {
    contentType?: "application/json";
    accept?: "application/json";
    body: {
      /** List product id */
      productIds?: string[];
    };
    response: components$1["schemas"]["SuccessResponse"];
    responseCode: 200;
  };
  "download post /document/download/{documentId}/{deepLinkCode}": {
    contentType?: "application/json";
    accept?: "application/json";
    headers?: {
      /** Instructs Shopware to return the response in the given language. */
      "sw-language-id"?: string;
    };
    pathParams: {
      deepLinkCode: string;
      documentId: string;
    };
    body?: components$1["schemas"]["Criteria"];
    response: components$1["schemas"]["Document"];
    responseCode: 200;
  };
  "attendeeRespondInvitation patch /dsr/appointment/{appointmentId}/attendee/respond-invitation": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** The appointment id you respond to */
      appointmentId: string;
    };
    body: {
      /**
       * The status you respond to
       * @enum {string}
       */
      answer?: "accepted" | "maybe" | "declined";
      /** The token will be attached to the invitation response link in the invitation mail */
      token: string;
    };
    response: components$1["schemas"]["AttendeeRespondInvitationResponse"];
    responseCode: 200;
  };
  "getCalendarFile post /dsr/appointment/{appointmentId}/download-ics": {
    contentType?: "application/json";
    accept: "text/calendar";
    pathParams: {
      /** The appointment id you want to get the calendar file */
      appointmentId: string;
    };
    body: {
      /** The token will be attached to the invitation response link in the invitation mail */
      token: string;
    };
    response: unknown;
    responseCode: 200;
  };
  "dsrReadAppointmentSettings get /dsr/appointment/{presentationPath}/basic-setting": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Presentation path */
      presentationPath: string;
    };
    response: components$1["schemas"]["AppointmentBasicSettingResponse"];
    responseCode: 200;
  };
  "joinAppointmentAsClient post /dsr/appointment/{presentationPath}/join-as-client": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Presentation path */
      presentationPath: string;
    };
    body?: {
      /** The name of the attendee */
      attendeeName?: string | null;
    };
    response: components$1["schemas"]["JoinAppointmentResponse"];
    responseCode: 200;
  };
  "updateAttendee patch /dsr/appointment/attendee": {
    contentType?: "application/json";
    accept?: "application/json";
    body: components$1["schemas"]["UpdateAttendeeRequestBody"];
    response: {
      /**
       * The api alias of the API
       * @default dsr.appointment.update-attendee
       */
      apiAlias?: string;
      /** The data is used to update the attendee information */
      data?: unknown;
    };
    responseCode: 200;
  };
  "getAttendeeProductCollection get /dsr/appointment/collection/{alias}": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** The alias of collection you want to get */
      alias: "liked" | "disliked";
    };
    response: components$1["schemas"]["AttendeeProductCollectionResponse"];
    responseCode: 200;
  };
  "attendeeProductCollectionAddProduct post /dsr/appointment/collection/{alias}/{productId}": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** The alias of collection you want to add */
      alias: "liked" | "disliked";
      /** The product id you want to add */
      productId: string;
    };
    response: never;
    responseCode: 204;
  };
  "attendeeProductCollectionRemoveProduct delete /dsr/appointment/collection/{alias}/{productId}": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** The alias of collection you want to remove */
      alias: "liked" | "disliked";
      /** The product id you want to remove */
      productId: string;
    };
    response: never;
    responseCode: 204;
  };
  "getLastSeenProducts get /dsr/appointment/collection/last-seen": {
    contentType?: "application/json";
    accept?: "application/json";
    response: components$1["schemas"]["AttendeeProductCollectionLastSeenResponse"];
    responseCode: 200;
  };
  "getPresentationStructure get /dsr/appointment/presentation": {
    contentType?: "application/json";
    accept?: "application/json";
    response: components$1["schemas"]["PresentationStructure"];
    responseCode: 200;
  };
  "getSlideData get /dsr/appointment/presentation/{presentationCmsPageId}/slide/{sectionId}": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Presentation CMS page id for which the data is requested */
      presentationCmsPageId: string;
      /** CMS section id for which the data is requested */
      sectionId: string;
    };
    response: components$1["schemas"]["PresentationSlideData"];
    responseCode: 200;
  };
  "getSlideProducts post /dsr/appointment/presentation/{presentationCmsPageId}/slide/{sectionId}/products": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Presentation CMS page id for which the data is requested */
      presentationCmsPageId: string;
      /** CMS section id for which the data is requested */
      sectionId: string;
    };
    body: components$1["schemas"]["Criteria"];
    response: components$1["schemas"]["ProductListingResult"];
    responseCode: 200;
  };
  "getClientPresentationState get /dsr/appointment/presentation/state": {
    contentType?: "application/json";
    accept?: "application/json";
    response: components$1["schemas"]["ClientPresentationStateResponse"];
    responseCode: 200;
  };
  "createAppointmentRequest post /dsr/appointment/request": {
    contentType?: "application/json";
    accept?: "application/json";
    body: components$1["schemas"]["CreateAppointmentRequestBody"];
    response: {
      /**
       * The api alias of the API
       * @default dsr.appointment.create-appointment-request
       */
      apiAlias?: string;
      /** The data is used to create the appointment request */
      data?: string[];
    };
    responseCode: 200;
  };
  "addInteraction post /dsr/interaction": {
    contentType?: "application/json";
    accept?: "application/json";
    body: components$1["schemas"]["CreateInteractionRequestBody"];
    response: never;
    responseCode: 200;
  };
  "dsrProductListing post /dsr/product-listing": {
    contentType?: "application/json";
    accept?: "application/json";
    body?:
      | components$1["schemas"]["Criteria"]
      | {
          /**
           * Load interaction (like & dislike) to product of attendee. It will be added into product extensions named interaction
           * @default false
           */
          interaction?: boolean;
          /**
           * Load all product ids, you can access it from `extensions.allIds` of the response
           * @default false
           */
          loadAllIds?: boolean;
          /**
           * load all variants following the main products
           * @default false
           */
          loadVariants?: boolean;
          /**
           * Use id sorting instead of other sorting fields
           * @default false
           */
          useIdSorting?: boolean;
        };
    response: {
      elements?: components$1["schemas"]["Product"][];
    } & components$1["schemas"]["EntitySearchResult"];
    responseCode: 200;
  };
  "dsrReadProductDetailPage get /dsr/product/{productId}": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      productId: string;
    };
    response: components$1["schemas"]["ProductPageResult"];
    responseCode: 200;
  };
  "resolveQuickviewPage get /dsr/quickview/{productId}/{cmsPageLayoutId}": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** The cms page id using as product quick view */
      cmsPageLayoutId: string;
      /** The product id */
      productId: string;
    };
    response: {
      cmsPage?: components$1["schemas"]["CmsPage"];
      configurator?: components$1["schemas"]["PropertyGroup"][];
      product?: components$1["schemas"]["Product"];
    };
    responseCode: 200;
  };
  "dsrReadShopPage get /dsr/shop-pages/{layoutName}": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      layoutName: string;
    };
    response: components$1["schemas"]["CmsPage"];
    responseCode: 200;
  };
  "readEmployees get /employee": {
    contentType?: "application/json";
    accept?: "application/json";
    body?: components$1["schemas"]["Criteria"];
    response: {
      elements?: components$1["schemas"]["B2bEmployee"][];
    } & components$1["schemas"]["EntitySearchResult"];
    responseCode: 200;
  };
  "readEmployeesPOST post /employee": {
    contentType?: "application/json";
    accept?: "application/json";
    body?: components$1["schemas"]["Criteria"];
    response: {
      elements?: components$1["schemas"]["B2bEmployee"][];
    } & components$1["schemas"]["EntitySearchResult"];
    responseCode: 200;
  };
  "readEmployee get /employee/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Identifier of the employee to be fetched */
      id: string;
    };
    response: components$1["schemas"]["B2bEmployee"];
    responseCode: 200;
  };
  "deleteEmployee delete /employee/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Identifier of the employee to be deleted */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateEmployee patch /employee/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Identifier of the employee to be updated */
      id: string;
    };
    body: {
      /** New email of the employee */
      email?: string;
      /** New first name of the employee */
      firstName?: string;
      /** New last name of the employee */
      lastName?: string;
      /** New id of the role of the employee */
      roleId?: string;
    };
    response: components$1["schemas"]["B2bEmployee"];
    responseCode: 200;
  };
  "createEmployee post /employee/create": {
    contentType?: "application/json";
    accept?: "application/json";
    body: {
      /** Email of the new employee */
      email: string;
      /** First name of the new employee */
      firstName: string;
      /** Identifier of the [language](#/System%20%26%20Context/readLanguages) to be set for the new employee. */
      languageId: string;
      /** Last name of the new employee */
      lastName: string;
      /** Id of the role of the new employee */
      roleId?: string;
    };
    response: components$1["schemas"]["B2bEmployee"];
    responseCode: 200;
  };
  "reinviteEmployee post /employee/reinvite/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Identifier of the employee to be reinvited */
      id: string;
    };
    body: {
      /** URL of the storefront domain */
      storefrontUrl?: string;
    };
    response: components$1["schemas"]["B2bEmployee"];
    responseCode: 200;
  };
  "handlePaymentMethod post /handle-payment": {
    contentType?: "application/json";
    accept?: "application/json";
    body: {
      /** URL to which the client should be redirected after erroneous payment */
      errorUrl?: string;
      /** URL to which the client should be redirected after successful payment */
      finishUrl?: string;
      /** Identifier of an order */
      orderId: string;
    };
    response: {
      redirectUrl: string;
    };
    responseCode: 200;
  };
  "readLandingPage post /landing-page/{landingPageId}": {
    contentType?: "application/json";
    accept?: "application/json";
    headers?: {
      /** Instructs Shopware to return the response in the given language. */
      "sw-language-id"?: string;
    };
    pathParams: {
      /** Identifier of the landing page. */
      landingPageId: string;
    };
    body: components$1["schemas"]["Criteria"] &
      ({
        /** Resolves only the given slot identifiers. The identifiers have to be seperated by a `|` character. */
        slots?: string;
      } & components$1["schemas"]["ProductListingCriteria"]);
    response: components$1["schemas"]["LandingPage"];
    responseCode: 200;
  };
  "readLanguages post /language": {
    contentType?: "application/json";
    accept?: "application/json";
    headers?: {
      /** Instructs Shopware to return the response in the given language. */
      "sw-language-id"?: string;
    };
    body?: components$1["schemas"]["Criteria"];
    response: {
      elements: components$1["schemas"]["Language"][];
    } & components$1["schemas"]["EntitySearchResult"];
    responseCode: 200;
  };
  "readMedia post /media": {
    contentType?: "application/json";
    accept?: "application/json";
    body: {
      /** Identifier (UUID) of the media entity to be fetched. */
      ids: string[];
    };
    response: components$1["schemas"]["Media"][];
    responseCode: 200;
  };
  "readNavigation post /navigation/{activeId}/{rootId}": {
    contentType?: "application/json";
    accept?: "application/json";
    headers?: {
      /** Instructs Shopware to try and resolve SEO URLs for the given navigation item */
      "sw-include-seo-urls"?: boolean;
      /** Instructs Shopware to return the response in the given language. */
      "sw-language-id"?: string;
    };
    pathParams: {
      /** Identifier of the active category in the navigation tree (if not used, just set to the same as rootId). */
      activeId: string | components$1["schemas"]["NavigationType"];
      /** Identifier of the root category for your desired navigation tree. You can use it to fetch sub-trees of your navigation tree. */
      rootId: string | components$1["schemas"]["NavigationType"];
    };
    body: components$1["schemas"]["Criteria"] & {
      /** Return the categories as a tree or as a flat list. */
      buildTree?: GenericRecord$1[];
      /**
       * Format: int32
       * Determines the depth of fetched navigation levels.
       */
      depth?: number;
    };
    response: components$1["schemas"]["NavigationRouteResponse"];
    responseCode: 200;
  };
  "confirmNewsletter post /newsletter/confirm": {
    contentType?: "application/json";
    accept?: "application/json";
    body: {
      /** Email hash parameter from the link in the confirmation mail */
      em: string;
      /** Hash parameter from link the in the confirmation mail */
      hash: string;
    };
    response: never;
    responseCode: 200;
  };
  "subscribeToNewsletter post /newsletter/subscribe": {
    contentType?: "application/json";
    accept?: "application/json";
    body: {
      /** City */
      city?: string;
      /** Custom field data that should be added to the subscription. */
      customFields?: string;
      /** Email address that will receive the confirmation and the newsletter. */
      email: string;
      /** First name */
      firstName?: string;
      /** Identifier of the language. */
      languageId?: string;
      /** Last name */
      lastName?: string;
      /** Defines what should be done. */
      option: string;
      /** Identifier of the salutation. */
      salutationId?: string;
      /** Url of the storefront of the shop. This will be used for generating the link to the /newsletter/confirm inside the confirm email. */
      storefrontUrl: string;
      /** Street */
      street?: string;
      /** Zip code */
      tags?: string;
      /** Zip code */
      zipCode?: string;
    };
    response: never;
    responseCode: 200;
  };
  "unsubscribeToNewsletter post /newsletter/unsubscribe": {
    contentType?: "application/json";
    accept?: "application/json";
    body: {
      /** Email address that should be removed from the mailing lists. */
      email: string;
    };
    response: never;
    responseCode: 200;
  };
  "readOrder post /order": {
    contentType?: "application/json";
    accept?: "application/json";
    headers?: {
      /** Instructs Shopware to return the response in the given language. */
      "sw-language-id"?: string;
    };
    body: components$1["schemas"]["Criteria"] & {
      /** Check if the payment method of the order is still changeable. */
      checkPromotion?: boolean;
    };
    response: components$1["schemas"]["OrderRouteResponse"];
    responseCode: 200;
  };
  "orderDownloadFile get /order/download/{orderId}/{downloadId}": {
    contentType?: "application/json";
    accept: "application/octet-stream";
    headers?: {
      /** Instructs Shopware to return the response in the given language. */
      "sw-language-id"?: string;
    };
    pathParams: {
      downloadId: string;
      orderId: string;
    };
    response: Blob;
    responseCode: 200;
  };
  "orderSetPayment post /order/payment": {
    contentType?: "application/json";
    accept?: "application/json";
    headers?: {
      /** Instructs Shopware to return the response in the given language. */
      "sw-language-id"?: string;
    };
    body: {
      /** The identifier of the order. */
      orderId: string;
      /** The identifier of the paymentMethod to be set */
      paymentMethodId: string;
    };
    response: components$1["schemas"]["SuccessResponse"];
    responseCode: 200;
  };
  "cancelOrder post /order/state/cancel": {
    contentType?: "application/json";
    accept?: "application/json";
    headers?: {
      /** Instructs Shopware to return the response in the given language. */
      "sw-language-id"?: string;
    };
    body: {
      /** The identifier of the order to be canceled. */
      orderId: string;
    };
    response: components$1["schemas"]["StateMachineState"];
    responseCode: 200;
  };
  "readPaymentMethod post /payment-method": {
    contentType?: "application/json";
    accept?: "application/json";
    headers?: {
      /** Instructs Shopware to return the response in the given language. */
      "sw-language-id"?: string;
    };
    body: components$1["schemas"]["Criteria"] & {
      /** List only available */
      onlyAvailable?: boolean;
    };
    response: {
      /** aggregation result */
      aggregations?: GenericRecord$1;
      elements?: components$1["schemas"]["PaymentMethod"][];
      /** Total amount */
      total?: number;
    };
    responseCode: 200;
  };
  "createPayPalOrder post /paypal/create-order": {
    contentType?: "application/json";
    accept?: "application/json";
    body: {
      /** Use an existing order id to create PayPal order */
      orderId?: string;
      /**
       * Use an existing order id to create PayPal order
       * @default ppcp
       */
      product?: string;
    };
    response: {
      token?: string;
    };
    responseCode: 200;
  };
  "createPayPalExpressOrder post /paypal/express/create-order": {
    contentType?: "application/json";
    accept?: "application/json";
    response: never;
    responseCode: 200;
  };
  "preparePayPalExpressCheckout post /paypal/express/prepare-checkout": {
    contentType?: "application/json";
    accept?: "application/json";
    body: {
      /** ID of the paypal order */
      token?: string;
    };
    response: {
      redirectUrl?: string;
    };
    responseCode: 200;
  };
  "setPaymentMethodEligibility post /paypal/payment-method-eligibility": {
    contentType?: "application/json";
    accept?: "application/json";
    body: {
      /** List of PayPal payment method identifiers according to constant REMOVABLE_PAYMENT_HANDLERS */
      paymentMethods?: string[];
    };
    response: never;
    responseCode: 204;
  };
  "getPUIPaymentInstructions get /paypal/pui/payment-instructions/{transactionId}": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Identifier of the order transaction to be fetched */
      transactionId: string;
    };
    response: never;
    responseCode: 200;
  };
  "getPayPalCustomerVaultToken get /paypal/vault-token": {
    contentType?: "application/json";
    accept?: "application/json";
    response: {
      token?: string;
    };
    responseCode: 200;
  };
  "paypalVaultClear post /paypal/vault/clear": {
    contentType?: "application/json";
    accept?: "application/json";
    body: {
      /** @enum {string} */
      type?: "cancel" | "browser" | "error";
    };
    response: never;
    responseCode: 204;
  };
  "fetchPendingOrder post /pending-order/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Identifier of the pending order to be fetched */
      id: string;
    };
    response: components$1["schemas"]["PendingOrder"];
    responseCode: 200;
  };
  "approvePendingOrder post /pending-order/{id}/approve": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Identifier of the pending order to be approved */
      id: string;
    };
    body?: {
      /** Message content */
      comment?: string;
    };
    response: never;
    responseCode: 204;
  };
  "createOrderFromPendingOrder post /pending-order/{id}/checkout/order": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Identifier of the pending order to be used to create a order */
      id: string;
    };
    body?: {
      /** Message content */
      customerComment?: string;
    };
    response: components$1["schemas"]["Order"];
    responseCode: 200;
  };
  "declinePendingOrder post /pending-order/{id}/decline": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Identifier of the pending order to be declined */
      id: string;
    };
    body?: {
      /** Message content */
      comment?: string;
    };
    response: never;
    responseCode: 204;
  };
  "requestOrderApproval post /pending-order/request": {
    contentType?: "application/json";
    accept?: "application/json";
    body?: {
      /** Message content */
      comment?: string;
    };
    response: components$1["schemas"]["PendingOrder"];
    responseCode: 200;
  };
  "readPermissions get /permission": {
    contentType?: "application/json";
    accept?: "application/json";
    response: {
      elements?: {
        permissionDependencies?: string[];
        permissionGroupName?: string;
        permissionName?: string;
      }[];
    } & components$1["schemas"]["EntitySearchResult"];
    responseCode: 200;
  };
  "addPermission post /permission": {
    contentType?: "application/json";
    accept?: "application/json";
    body: {
      /** Optional dependencies for the new permission */
      dependencies?: string[];
      /** Group of the new permission */
      group?: string;
      /** Name of the new permission */
      name?: string;
    };
    response: {
      elements?: {
        permissionDependencies?: string[];
        permissionGroupName?: string;
        permissionName?: string;
      }[];
    } & components$1["schemas"]["EntitySearchResult"];
    responseCode: 200;
  };
  "readProduct post /product": {
    contentType?: "application/json";
    accept?: "application/json";
    headers?: {
      /** Instructs Shopware to return the response in the given language. */
      "sw-language-id"?: string;
    };
    body?: components$1["schemas"]["Criteria"];
    response: {
      elements: components$1["schemas"]["Product"][];
    } & components$1["schemas"]["EntitySearchResult"];
    responseCode: 200;
  };
  "readProductExport get /product-export/{accessKey}/{fileName}": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Access Key */
      accessKey: string;
      /** File Name */
      fileName: string;
    };
    response: never;
    responseCode: 200;
  };
  "readProductListing post /product-listing/{categoryId}": {
    contentType?: "application/json";
    accept?: "application/json";
    headers?: {
      /** Determines if the response must contain a SeoUrl entity for a product entity */
      "sw-include-seo-urls"?: boolean;
      /** Instructs Shopware to return the response in the given language. */
      "sw-language-id"?: string;
    };
    pathParams: {
      /** Identifier of a category. */
      categoryId: string;
    };
    body: components$1["schemas"]["ProductListingCriteria"] &
      components$1["schemas"]["ProductListingFlags"];
    response: components$1["schemas"]["ProductListingResult"];
    responseCode: 200;
  };
  "readProductDetail post /product/{productId}": {
    contentType?: "application/json";
    accept?: "application/json";
    headers?: {
      /** Instructs Shopware to try and resolve SEO URLs for the given navigation item */
      "sw-include-seo-urls"?: boolean;
      /** Instructs Shopware to return the response in the given language. */
      "sw-language-id"?: string;
    };
    pathParams: {
      /** Product ID */
      productId: string;
    };
    body?: components$1["schemas"]["Criteria"];
    response: components$1["schemas"]["ProductDetailResponse"];
    responseCode: 200;
  };
  "readProductCrossSellings post /product/{productId}/cross-selling": {
    contentType?: "application/json";
    accept?: "application/json";
    headers?: {
      /** Instructs Shopware to try and resolve SEO URLs for the given navigation item */
      "sw-include-seo-urls"?: boolean;
      /** Instructs Shopware to return the response in the given language. */
      "sw-language-id"?: string;
    };
    pathParams: {
      /** Product ID */
      productId: string;
    };
    response: components$1["schemas"]["CrossSellingElementCollection"];
    responseCode: 200;
  };
  "searchProductVariantIds post /product/{productId}/find-variant": {
    contentType?: "application/json";
    accept?: "application/json";
    headers?: {
      /** Instructs Shopware to return the response in the given language. */
      "sw-language-id"?: string;
    };
    pathParams: {
      /** Product ID */
      productId: string;
    };
    body: {
      /** The options parameter for the variant to find. */
      options: string[];
      /** The id of the option group that has been switched. */
      switchedGroup?: string;
    };
    response: components$1["schemas"]["FindProductVariantRouteResponse"];
    responseCode: 200;
  };
  "saveProductReview post /product/{productId}/review": {
    contentType?: "application/json";
    accept?: "application/json";
    headers?: {
      /** Instructs Shopware to return the response in the given language. */
      "sw-language-id"?: string;
    };
    pathParams: {
      /** Identifier of the product which is reviewed. */
      productId: string;
    };
    body: {
      /** The content of review. */
      content: string;
      /** The email address of the review author. If not set, the email of the customer is chosen. */
      email?: string;
      /** The name of the review author. If not set, the first name of the customer is chosen. */
      name?: string;
      /**
       * Format: double
       * The review rating for the product.
       */
      points: number;
      /** The title of the review. */
      title: string;
    };
    response: never;
    responseCode: 200;
  };
  "readProductReviews post /product/{productId}/reviews": {
    contentType?: "application/json";
    accept?: "application/json";
    headers?: {
      /** Instructs Shopware to return the response in the given language. */
      "sw-language-id"?: string;
    };
    pathParams: {
      /** Identifier of the product. */
      productId: string;
    };
    body?: components$1["schemas"]["Criteria"];
    response: {
      elements?: components$1["schemas"]["ProductReview"][];
    } & components$1["schemas"]["EntitySearchResult"];
    responseCode: 200;
  };
  "searchByImageSearchTerm post /product/image-upload-search/search-term": {
    contentType?: "application/json";
    accept?: "application/json";
    body: {
      /**
       * Format: binary
       * Base-64 encoded image
       */
      file?: Blob;
    };
    response: components$1["schemas"]["SearchByImageSearchTermResponse"];
    responseCode: 200;
  };
  "naturalLanguageSearchTerm post /product/natural-language/search-term": {
    contentType?: "application/json";
    accept?: "application/json";
    body: {
      /**
       * Natural language query
       * @example I'm looking for a present for my wife
       */
      query?: string;
    };
    response: components$1["schemas"]["NaturalLanguageSearchTermResponse"];
    responseCode: 200;
  };
  "switchPaymentOrShippingMethod post /quote/{id}/configure": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Identifier of the quote to be reinvited */
      id: string;
    };
    body: {
      /** Id of the payment method */
      paymentMethodId?: string;
      /** Id of the shipping method */
      shippingMethodId?: string;
    };
    response: never;
    responseCode: 204;
  };
  "declineQuote post /quote/{id}/decline": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Identifier of the quote to be reinvited */
      id: string;
    };
    body?: {
      /** Message content */
      comment?: string;
    };
    response: never;
    responseCode: 204;
  };
  "requestChangeQuote post /quote/{id}/request-change": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Identifier of the quote to be reinvited */
      id: string;
    };
    body?: {
      /** Message content */
      comment?: string;
    };
    response: never;
    responseCode: 204;
  };
  "sendMessageInQuote post /quote/{id}/send-message": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Identifier of the quote to be reinvited */
      id: string;
    };
    body?: {
      /** Message content */
      comment?: string;
    };
    response: never;
    responseCode: 204;
  };
  "readQuote post /quote/detail/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Identifier of the quote to be fetched */
      id: string;
    };
    body?: components$1["schemas"]["Criteria"];
    response: components$1["schemas"]["Quote"];
    responseCode: 200;
  };
  "downloadQuoteDocument post /quote/document/download/{documentId}/{deepLinkCode}": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Deep link code of the quote document */
      deepLinkCode: string;
      /** Identifier of the quote document to be reinvited */
      documentId: string;
    };
    response: never;
    responseCode: 200;
  };
  "createOrderFromQuote post /quote/order/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Identifier of the quote to be reinvited */
      id: string;
    };
    body?: {
      /** Message content */
      customerComment?: string;
    };
    response: components$1["schemas"]["Order"];
    responseCode: 200;
  };
  "requestQuote post /quote/request": {
    contentType?: "application/json";
    accept?: "application/json";
    body?: {
      /** Message content */
      comment?: string;
    };
    response: components$1["schemas"]["Quote"];
    responseCode: 200;
  };
  "readQuotes post /quotes": {
    contentType?: "application/json";
    accept?: "application/json";
    body?: components$1["schemas"]["Criteria"];
    response: {
      elements?: components$1["schemas"]["Quote"][];
    } & components$1["schemas"]["EntitySearchResult"];
    responseCode: 200;
  };
  "readRoles get /role": {
    contentType?: "application/json";
    accept?: "application/json";
    response: {
      elements?: components$1["schemas"]["B2bComponentsRole"][];
    } & components$1["schemas"]["EntitySearchResult"];
    responseCode: 200;
  };
  "readRolesPOST post /role": {
    contentType?: "application/json";
    accept?: "application/json";
    body?: components$1["schemas"]["Criteria"];
    response: {
      elements?: components$1["schemas"]["B2bComponentsRole"][];
    } & components$1["schemas"]["EntitySearchResult"];
    responseCode: 200;
  };
  "readRole get /role/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Identifier of the role to be fetched */
      id: string;
    };
    response: components$1["schemas"]["B2bComponentsRole"];
    responseCode: 200;
  };
  "deleteRole delete /role/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Identifier of the role to be fetched */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateRole patch /role/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Identifier of the role to be updated */
      id: string;
    };
    body: {
      /** Ability to set the role as default */
      isDefaultRole?: boolean;
      /** New name of the role */
      name?: string;
      /** New permissions of the role */
      permissions?: string[];
    };
    response: components$1["schemas"]["B2bComponentsRole"];
    responseCode: 200;
  };
  "createRole post /role/create": {
    contentType?: "application/json";
    accept?: "application/json";
    body: {
      /** Ability to set the new role as default */
      isDefaultRole?: boolean;
      /** Name of the new role */
      name?: string;
      /** Permissions of the new role */
      permissions?: string[];
    };
    response: components$1["schemas"]["B2bComponentsRole"];
    responseCode: 200;
  };
  "updateDefaultRoleId post /role/default": {
    contentType?: "application/json";
    accept?: "application/json";
    body: {
      /** Id of the roleId to be set as default */
      id?: string;
    };
    response: never;
    responseCode: 204;
  };
  "readSalutation post /salutation": {
    contentType?: "application/json";
    accept?: "application/json";
    headers?: {
      /** Instructs Shopware to return the response in the given language. */
      "sw-language-id"?: string;
    };
    body?: components$1["schemas"]["Criteria"];
    response: {
      elements?: components$1["schemas"]["Salutation"][];
    } & components$1["schemas"]["EntitySearchResult"];
    responseCode: 200;
  };
  "getScriptStoreApiRoute get /script/{hook}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Dynamic hook which used to build the hook name */
          hook: string;
        };
        response: {
          [key: string]: unknown;
        } | null;
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Dynamic hook which used to build the hook name */
          hook: string;
        };
        response: {
          [key: string]: unknown;
        } | null;
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Dynamic hook which used to build the hook name */
          hook: string;
        };
        response: never;
        responseCode: 204;
      };
  "postScriptStoreApiRoute post /script/{hook}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Dynamic hook which used to build the hook name */
          hook: string;
        };
        response: {
          [key: string]: unknown;
        } | null;
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Dynamic hook which used to build the hook name */
          hook: string;
        };
        response: {
          [key: string]: unknown;
        } | null;
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Dynamic hook which used to build the hook name */
          hook: string;
        };
        response: never;
        responseCode: 204;
      };
  "searchPage post /search": {
    contentType?: "application/json";
    accept?: "application/json";
    headers?: {
      /** Instructs Shopware to try and resolve SEO URLs for the given navigation item */
      "sw-include-seo-urls"?: boolean;
      /** Instructs Shopware to return the response in the given language. */
      "sw-language-id"?: string;
    };
    body: {
      /** Using the search parameter, the server performs a text search on all records based on their data model and weighting as defined in the entity definition using the SearchRanking flag. */
      search: string;
    } & components$1["schemas"]["ProductListingCriteria"] &
      components$1["schemas"]["ProductListingFlags"];
    response: components$1["schemas"]["ProductListingResult"];
    responseCode: 200;
  };
  "searchSuggest post /search-suggest": {
    contentType?: "application/json";
    accept?: "application/json";
    headers?: {
      /** Instructs Shopware to return the response in the given language. */
      "sw-language-id"?: string;
    };
    body: {
      /** Using the search parameter, the server performs a text search on all records based on their data model and weighting as defined in the entity definition using the SearchRanking flag. */
      search: string;
    } & components$1["schemas"]["ProductListingFlags"];
    response: components$1["schemas"]["ProductListingResult"];
    responseCode: 200;
  };
  "readSeoUrl post /seo-url": {
    contentType?: "application/json";
    accept?: "application/json";
    headers?: {
      /** Instructs Shopware to return the response in the given language. */
      "sw-language-id"?: string;
    };
    body?: components$1["schemas"]["Criteria"];
    response: {
      elements: components$1["schemas"]["SeoUrl"][];
    } & components$1["schemas"]["EntitySearchResult"];
    responseCode: 200;
  };
  "readShippingMethod post /shipping-method": {
    contentType?: "application/json";
    accept?: "application/json";
    headers?: {
      /** Instructs Shopware to return the response in the given language. */
      "sw-language-id"?: string;
    };
    query?: {
      /** List only available shipping methods. This filters shipping methods methods which can not be used in the actual context because of their availability rule. */
      onlyAvailable?: boolean;
    };
    body?: components$1["schemas"]["Criteria"];
    response: {
      /** aggregation result */
      aggregations?: GenericRecord$1;
      elements: components$1["schemas"]["ShippingMethod"][];
      /** Total amount */
      total?: number;
    } & components$1["schemas"]["EntitySearchResult"];
    responseCode: 200;
  };
  "createShoppingList post /shopping-list": {
    contentType?: "application/json";
    accept?: "application/json";
    body: {
      lineItems?: {
        [key: string]: {
          /** Product id */
          id: string;
          /** Quantity of the product */
          quantity: number;
        };
      };
      /** Shopping list name */
      name: string;
    };
    response: never;
    responseCode: 204;
  };
  "removeShoppingLists delete /shopping-list": {
    contentType?: "application/json";
    accept?: "application/json";
    body: {
      /** Shopping list ids */
      ids: string[];
    };
    response: never;
    responseCode: 204;
  };
  "readShoppingList post /shopping-list/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Identifier of the shopping list to be fetched */
      id: string;
    };
    body?: components$1["schemas"]["Criteria"];
    response: components$1["schemas"]["B2bComponentsShoppingList"];
    responseCode: 200;
  };
  "addLineItems post /shopping-list/{id}/add": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Identifier of the shopping list to be fetched */
      id: string;
    };
    body?: {
      lineItems: {
        [key: string]: {
          /** Product id */
          id: string;
          /** Quantity of the product */
          quantity: number;
        };
      };
    };
    response: never;
    responseCode: 204;
  };
  "updateShoppingList patch /shopping-list/{id}/change-name": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Identifier of the shopping list to be fetched */
      id: string;
    };
    body: {
      /** Shopping list name */
      name: string;
    };
    response: never;
    responseCode: 204;
  };
  "duplicateShoppingList post /shopping-list/{id}/duplicate": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Identifier of the shopping list to be fetched */
      id: string;
    };
    body: {
      /** Shopping list name */
      name: string;
    };
    response: {
      /** The generated id of the duplicated shopping list */
      id?: string;
    };
    responseCode: 200;
  };
  "summaryShoppingList get /shopping-list/{id}/summary": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Identifier of the shopping list to be fetched */
      id: string;
    };
    response: {
      price?: {
        /**
         * Format: float
         * Net price of the cart
         */
        netPrice?: number;
        /**
         * Format: float
         * Price for all line items in the cart
         */
        positionPrice?: number;
        /** Tax calculation for the cart. One of `gross`, `net` or `tax-free` */
        taxStatus?: string;
        /**
         * Format: float
         * Total price of the cart, including shipping costs, discounts and taxes
         */
        totalPrice?: number;
      };
    };
    responseCode: 200;
  };
  "updateLineItems post /shopping-list/line-item/{id}/change-quantity": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Identifier of the shopping list line item to be fetched */
      id: string;
    };
    body: {
      /** new line item quantity */
      quantity: number;
    };
    response: never;
    responseCode: 204;
  };
  "removeLineItems post /shopping-list/line-item/remove": {
    contentType?: "application/json";
    accept?: "application/json";
    body: {
      /** Line items ids */
      ids?: string[];
      /** List id */
      listId?: string;
      /** Product ids */
      productIds?: string[];
    };
    response: never;
    responseCode: 204;
  };
  "readShoppingLists post /shopping-lists": {
    contentType?: "application/json";
    accept?: "application/json";
    body?: components$1["schemas"]["Criteria"];
    response: {
      elements?: components$1["schemas"]["B2bComponentsShoppingList"][];
    } & components$1["schemas"]["EntitySearchResult"];
    responseCode: 200;
  };
  "addShoppingListsToCart post /shopping-lists/add-to-cart": {
    contentType?: "application/json";
    accept?: "application/json";
    body: {
      /** Shopping list ids */
      ids: string[];
    };
    response: never;
    responseCode: 204;
  };
  "readSitemap get /sitemap": {
    contentType?: "application/json";
    accept?: "application/json";
    headers?: {
      /** Instructs Shopware to return the response in the given language. */
      "sw-language-id"?: string;
    };
    response: components$1["schemas"]["Sitemap"][];
    responseCode: 200;
  };
  "getSitemapFile get /sitemap/{filePath}":
    | {
        contentType?: "application/json";
        accept: "application/gzip";
        headers?: {
          /** Instructs Shopware to return the response in the given language. */
          "sw-language-id"?: string;
        };
        pathParams: {
          /** The path to the sitemap file */
          filePath: string;
        };
        response: Blob;
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/xml";
        headers?: {
          /** Instructs Shopware to return the response in the given language. */
          "sw-language-id"?: string;
        };
        pathParams: {
          /** The path to the sitemap file */
          filePath: string;
        };
        response: Blob;
        responseCode: 200;
      };
  "auth post /sso/auth/{providerId}": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Identifier of the SSO provider used to authenticate */
      providerId: string;
    };
    response: components$1["schemas"]["SuccessResponse"];
    responseCode: 204;
  };
  "redirect post /sso/redirect/{providerId}": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Identifier of the SSO provider used to authenticate */
      providerId: string;
    };
    response: components$1["schemas"]["SuccessResponse"];
    responseCode: 204;
  };
};

type SimpleUnionOmit$1<T, K extends string | number | symbol> = T extends unknown ? Omit<T, K> : never;
type SimpleUnionPick$1<T, K extends keyof T> = T extends unknown ? Pick<T, K> : never;
type RenameByT$1<T, U> = {
    [K in keyof U as K extends keyof T ? T[K] extends string ? T[K] : never : K]: K extends keyof U ? U[K] : never;
};
type RequestReturnType$1<CURRENT_OPERATION extends {
    response: unknown;
    responseCode: number;
}> = RenameByT$1<{
    response: "data";
    responseCode: "status";
}, SimpleUnionPick$1<CURRENT_OPERATION, "response" | "responseCode">>;
type RequestParameters<CURRENT_OPERATION> = SimpleUnionOmit$1<CURRENT_OPERATION, "response" | "responseCode">;
type InvokeParameters<CURRENT_OPERATION> = RequestParameters<CURRENT_OPERATION> & {
    fetchOptions?: Pick<FetchOptions<"json">, "cache" | "duplex" | "keepalive" | "priority" | "redirect" | "retry" | "retryDelay" | "retryStatusCodes" | "signal" | "timeout">;
};
type GlobalFetchOptions = Pick<FetchOptions<ResponseType>, "retry" | "retryDelay" | "retryStatusCodes" | "timeout">;
type ApiClientHooks = {
    onContextChanged: (newContextToken: string) => void;
    onResponseError: (response: FetchResponse<ResponseType>) => void;
    onSuccessResponse: <T>(response: FetchResponse<T>) => void;
    onDefaultHeaderChanged: <T>(headerName: string, value?: T) => void;
    onRequest: (context: FetchContext) => void;
};
declare function createAPIClient<OPERATIONS extends Record<string, any> = operations$1, PATHS extends string | number | symbol = keyof OPERATIONS>(params: {
    baseURL?: string;
    accessToken?: string;
    contextToken?: string;
    defaultHeaders?: ClientHeaders;
    fetchOptions?: GlobalFetchOptions;
}): {
    invoke: <INVOKE_PATH extends PATHS, OPERATION_NAME extends string = INVOKE_PATH extends `${infer R}` ? R extends string ? R : never : never, CURRENT_OPERATION extends OPERATIONS[OPERATION_NAME] = OPERATION_NAME extends keyof OPERATIONS ? OPERATIONS[OPERATION_NAME] : never>(pathParam: OPERATION_NAME extends keyof OPERATIONS ? OPERATION_NAME : never, ...params: SimpleUnionOmit$1<CURRENT_OPERATION, "response" | "responseCode"> extends {
        body: unknown;
    } | {
        query: unknown;
    } | {
        header: unknown;
    } | {
        pathParams: unknown;
    } ? [InvokeParameters<CURRENT_OPERATION>] : [InvokeParameters<CURRENT_OPERATION>?]) => Promise<RequestReturnType$1<CURRENT_OPERATION>>;
    /**
     * Default headers used in every client request (if not overriden in specific request).
     */
    defaultHeaders: ClientHeadersProxy;
    hook: <NameT extends hookable.HookKeys<ApiClientHooks>>(name: NameT, function_: ApiClientHooks[NameT] extends hookable.HookCallback ? ApiClientHooks[NameT] : never, options?: {
        allowDeprecated?: boolean;
    }) => () => void;
    /**
     * Update the base configuration for API client
     */
    updateBaseConfig: (config: {
        baseURL?: string;
        accessToken?: string;
    }) => void;
    /**
     * Get the current base configuration
     */
    getBaseConfig: () => {
        baseURL: string | undefined;
        accessToken: string | undefined;
    };
};

/**
 * This file is auto-generated. Do not make direct changes to the file.
 * Instead override it in your shopware.d.ts file.
 *
 * Shopware API version: 6.6.6.0
 *
 */
type GenericRecord =
  | never
  | null
  | string
  | string[]
  | number
  | {
      [key: string]: GenericRecord;
    };
type components = {
  schemas: Schemas;
};
type Schemas = {
  AbstractDynamicPageOpenedPayload: {
    /** @default true */
    opened?: boolean;
    /** The type of the current dynamic page */
    type: string;
  };
  AclRole: {
    app?: components["schemas"]["App"];
    /** Format: date-time */
    readonly createdAt?: string;
    /** Format: date-time */
    deletedAt?: string;
    description?: string;
    id: string;
    integrations?: components["schemas"]["Integration"][];
    name: string;
    privileges?: GenericRecord[];
    /** Format: date-time */
    readonly updatedAt?: string;
    users?: components["schemas"]["User"][];
  };
  AclRoleJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    /** Format: date-time */
    deletedAt?: string;
    description?: string;
    id: string;
    name: string;
    privileges?: GenericRecord[];
    relationships?: {
      app?: {
        data?: {
          /** @example d2a57dc1d883fd21fb9951699df71cc7 */
          id?: string;
          /** @example app */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /acl-role/87857e66337bf79fa25f363fefba38a1/app
           */
          related?: string;
        };
      };
      integrations?: {
        data?: {
          /** @example 415320131958c70f4f250ca4d7e63bbd */
          id?: string;
          /** @example integration */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /acl-role/87857e66337bf79fa25f363fefba38a1/integrations
           */
          related?: string;
        };
      };
      users?: {
        data?: {
          /** @example 9bc65c2abec141778ffaa729489f3e87 */
          id?: string;
          /** @example user */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /acl-role/87857e66337bf79fa25f363fefba38a1/users
           */
          related?: string;
        };
      };
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  AclUserRole: {
    aclRole?: components["schemas"]["AclRole"];
    aclRoleId: string;
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    user?: components["schemas"]["User"];
    userId: string;
  };
  AdvancedSearchAction: {
    active?: boolean;
    config?: components["schemas"]["AdvancedSearchConfig"];
    configId: string;
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    name: string;
    searchTerms?: components["schemas"]["AdvancedSearchActionSearchTerm"][];
    type: string;
    typeConfig?: GenericRecord;
    /** Format: date-time */
    readonly updatedAt?: string;
    /** Format: date-time */
    validFrom?: string;
    /** Format: date-time */
    validTo?: string;
  };
  AdvancedSearchActionJsonApi: components["schemas"]["resource"] & {
    active?: boolean;
    configId: string;
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    name: string;
    relationships?: {
      config?: {
        data?: {
          /** @example 2245023265ae4cf87d02c8b6ba991139 */
          id?: string;
          /** @example advanced_search_config */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /advanced-search-action/2a6023897ca55437c49e4a41b8f76f77/config
           */
          related?: string;
        };
      };
      searchTerms?: {
        data?: {
          /** @example 952c07f523c564f09844ca7f880c2467 */
          id?: string;
          /** @example advanced_search_action_search_term */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /advanced-search-action/2a6023897ca55437c49e4a41b8f76f77/searchTerms
           */
          related?: string;
        };
      };
    };
    type: string;
    typeConfig?: GenericRecord;
    /** Format: date-time */
    readonly updatedAt?: string;
    /** Format: date-time */
    validFrom?: string;
    /** Format: date-time */
    validTo?: string;
  };
  AdvancedSearchActionSearchTerm: {
    action?: components["schemas"]["AdvancedSearchAction"];
    actionId: string;
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    salesChannel?: components["schemas"]["SalesChannel"];
    salesChannelId: string;
    term: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  AdvancedSearchActionSearchTermJsonApi: components["schemas"]["resource"] & {
    actionId: string;
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    relationships?: {
      action?: {
        data?: {
          /** @example 418c5509e2171d55b0aee5c2ea4442b5 */
          id?: string;
          /** @example advanced_search_action */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /advanced-search-action-search-term/a7e591b2d328bc4e62fbd4fd300da858/action
           */
          related?: string;
        };
      };
      salesChannel?: {
        data?: {
          /** @example ec3712a84143b57e0db620eaac6e55b8 */
          id?: string;
          /** @example sales_channel */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /advanced-search-action-search-term/a7e591b2d328bc4e62fbd4fd300da858/salesChannel
           */
          related?: string;
        };
      };
    };
    salesChannelId: string;
    term: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  AdvancedSearchBoosting: {
    active?: boolean;
    /** Format: float */
    boost: number;
    config?: components["schemas"]["AdvancedSearchConfig"];
    configId: string;
    /** Format: date-time */
    readonly createdAt?: string;
    entityStream?: components["schemas"]["AdvancedSearchEntityStream"];
    entityStreamId?: string;
    id: string;
    name: string;
    productStream?: components["schemas"]["ProductStream"];
    productStreamId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    /** Format: date-time */
    validFrom?: string;
    /** Format: date-time */
    validTo?: string;
  };
  AdvancedSearchBoostingJsonApi: components["schemas"]["resource"] & {
    active?: boolean;
    /** Format: float */
    boost: number;
    configId: string;
    /** Format: date-time */
    readonly createdAt?: string;
    entityStreamId?: string;
    id: string;
    name: string;
    productStreamId?: string;
    relationships?: {
      config?: {
        data?: {
          /** @example 2245023265ae4cf87d02c8b6ba991139 */
          id?: string;
          /** @example advanced_search_config */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /advanced-search-boosting/594f5cafa4dccca1634893a5a0a86ec9/config
           */
          related?: string;
        };
      };
      entityStream?: {
        data?: {
          /** @example 62acf68da615789a0175ef827f74acbb */
          id?: string;
          /** @example advanced_search_entity_stream */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /advanced-search-boosting/594f5cafa4dccca1634893a5a0a86ec9/entityStream
           */
          related?: string;
        };
      };
      productStream?: {
        data?: {
          /** @example 49561f6faa0badfce831a183d2ec7c2f */
          id?: string;
          /** @example product_stream */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /advanced-search-boosting/594f5cafa4dccca1634893a5a0a86ec9/productStream
           */
          related?: string;
        };
      };
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    /** Format: date-time */
    validFrom?: string;
    /** Format: date-time */
    validTo?: string;
  };
  AdvancedSearchConfig: {
    andLogic?: boolean;
    boostings?: components["schemas"]["AdvancedSearchBoosting"][];
    /** Format: date-time */
    readonly createdAt?: string;
    esEnabled?: boolean;
    fields?: components["schemas"]["AdvancedSearchConfigField"][];
    hitCount?: {
      category?: {
        /** Format: int64 */
        maxSearchCount?: number;
        /** Format: int64 */
        maxSuggestCount?: number;
      };
      product?: {
        /** Format: int64 */
        maxSearchCount?: number;
        /** Format: int64 */
        maxSuggestCount?: number;
      };
      product_manufacturer?: {
        /** Format: int64 */
        maxSearchCount?: number;
        /** Format: int64 */
        maxSuggestCount?: number;
      };
    };
    id: string;
    /** Format: int64 */
    minSearchLength?: number;
    salesChannel?: components["schemas"]["SalesChannel"];
    salesChannelId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  AdvancedSearchConfigField: {
    config?: components["schemas"]["AdvancedSearchConfig"];
    configId: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customField?: components["schemas"]["CustomField"];
    customFieldId?: string;
    entity: string;
    field: string;
    id: string;
    /** Format: int64 */
    ranking?: number;
    searchable?: boolean;
    tokenize?: boolean;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  AdvancedSearchConfigFieldJsonApi: components["schemas"]["resource"] & {
    configId: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFieldId?: string;
    entity: string;
    field: string;
    id: string;
    /** Format: int64 */
    ranking?: number;
    relationships?: {
      config?: {
        data?: {
          /** @example 2245023265ae4cf87d02c8b6ba991139 */
          id?: string;
          /** @example advanced_search_config */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /advanced-search-config-field/34ed84349128fa95e8aa7d3a69bd99c9/config
           */
          related?: string;
        };
      };
      customField?: {
        data?: {
          /** @example ed2028a1c479c7e0065da597452d9c11 */
          id?: string;
          /** @example custom_field */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /advanced-search-config-field/34ed84349128fa95e8aa7d3a69bd99c9/customField
           */
          related?: string;
        };
      };
    };
    searchable?: boolean;
    tokenize?: boolean;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  AdvancedSearchConfigJsonApi: components["schemas"]["resource"] & {
    andLogic?: boolean;
    /** Format: date-time */
    readonly createdAt?: string;
    esEnabled?: boolean;
    hitCount?: {
      category?: {
        /** Format: int64 */
        maxSearchCount?: number;
        /** Format: int64 */
        maxSuggestCount?: number;
      };
      product?: {
        /** Format: int64 */
        maxSearchCount?: number;
        /** Format: int64 */
        maxSuggestCount?: number;
      };
      product_manufacturer?: {
        /** Format: int64 */
        maxSearchCount?: number;
        /** Format: int64 */
        maxSuggestCount?: number;
      };
    };
    id: string;
    /** Format: int64 */
    minSearchLength?: number;
    relationships?: {
      boostings?: {
        data?: {
          /** @example 8e571802e4ea39b214104ca60e13b5a6 */
          id?: string;
          /** @example advanced_search_boosting */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /advanced-search-config/63246bc46dc5b3716c6f5f92044238e4/boostings
           */
          related?: string;
        };
      };
      fields?: {
        data?: {
          /** @example d05b6ed7d2345020440df396d6da7f73 */
          id?: string;
          /** @example advanced_search_config_field */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /advanced-search-config/63246bc46dc5b3716c6f5f92044238e4/fields
           */
          related?: string;
        };
      };
      salesChannel?: {
        data?: {
          /** @example ec3712a84143b57e0db620eaac6e55b8 */
          id?: string;
          /** @example sales_channel */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /advanced-search-config/63246bc46dc5b3716c6f5f92044238e4/salesChannel
           */
          related?: string;
        };
      };
    };
    salesChannelId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  AdvancedSearchEntityStream: {
    readonly apiFilter?: GenericRecord;
    boosting?: components["schemas"]["AdvancedSearchBoosting"];
    /** Format: date-time */
    readonly createdAt?: string;
    filters?: components["schemas"]["AdvancedSearchEntityStreamFilter"][];
    id: string;
    readonly invalid?: boolean;
    type: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  AdvancedSearchEntityStreamFilter: {
    /** Format: date-time */
    readonly createdAt?: string;
    entityStream?: components["schemas"]["AdvancedSearchEntityStream"];
    entityStreamId: string;
    field?: string;
    id: string;
    operator?: string;
    parameters?: GenericRecord;
    parent?: components["schemas"]["AdvancedSearchEntityStreamFilter"];
    parentId?: string;
    /** Format: int64 */
    position?: number;
    queries?: components["schemas"]["AdvancedSearchEntityStreamFilter"][];
    type: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    value?: string;
  };
  AdvancedSearchEntityStreamFilterJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    entityStreamId: string;
    field?: string;
    id: string;
    operator?: string;
    parameters?: GenericRecord;
    parentId?: string;
    /** Format: int64 */
    position?: number;
    relationships?: {
      entityStream?: {
        data?: {
          /** @example 62acf68da615789a0175ef827f74acbb */
          id?: string;
          /** @example advanced_search_entity_stream */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /advanced-search-entity-stream-filter/910af2160df3a00f3843e6e06940790f/entityStream
           */
          related?: string;
        };
      };
      parent?: {
        data?: {
          /** @example d0e45878043844ffc41aac437e86b602 */
          id?: string;
          /** @example advanced_search_entity_stream_filter */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /advanced-search-entity-stream-filter/910af2160df3a00f3843e6e06940790f/parent
           */
          related?: string;
        };
      };
      queries?: {
        data?: {
          /** @example 5da7eb4247add5dbd5776c9c0b38460a */
          id?: string;
          /** @example advanced_search_entity_stream_filter */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /advanced-search-entity-stream-filter/910af2160df3a00f3843e6e06940790f/queries
           */
          related?: string;
        };
      };
    };
    type: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    value?: string;
  };
  AdvancedSearchEntityStreamJsonApi: components["schemas"]["resource"] & {
    readonly apiFilter?: GenericRecord;
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    readonly invalid?: boolean;
    relationships?: {
      boosting?: {
        data?: {
          /** @example 6ab105abdd48ced24ce7b0e516ca0970 */
          id?: string;
          /** @example advanced_search_boosting */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /advanced-search-entity-stream/8bc027ef6b979dafaf6e1691bf314134/boosting
           */
          related?: string;
        };
      };
      filters?: {
        data?: {
          /** @example 2c9885d2b0c7e26971f60a90f33cf718 */
          id?: string;
          /** @example advanced_search_entity_stream_filter */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /advanced-search-entity-stream/8bc027ef6b979dafaf6e1691bf314134/filters
           */
          related?: string;
        };
      };
    };
    type: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  AdvancedSearchSynonym: {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    language?: components["schemas"]["Language"];
    languageId?: string;
    left: string[];
    right?: string[];
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  AdvancedSearchSynonymJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    languageId?: string;
    left: string[];
    relationships?: {
      language?: {
        data?: {
          /** @example 8512ae7d57b1396273f76fe6ed341a23 */
          id?: string;
          /** @example language */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /advanced-search-synonym/f8fe978e49caae961d38f793b4901801/language
           */
          related?: string;
        };
      };
    };
    right?: string[];
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  AggregationEntity: {
    /** The entity definition e.g "product_manufacturer". */
    definition: string;
    /** The field you want to aggregate over. */
    field: string;
    /** Give your aggregation an identifier, so you can find it easier */
    name: string;
    /**
     * The type of aggregation
     * @enum {string}
     */
    type: "entity";
  };
  AggregationFilter: {
    filter: components["schemas"]["Filters"][];
    /** Give your aggregation an identifier, so you can find it easier */
    name: string;
    /**
     * The type of aggregation
     * @enum {string}
     */
    type: "filter";
  };
  AggregationHistogram: {
    /** The field you want to aggregate over. */
    field: string;
    /** The format of the histogram */
    format?: string;
    /** The interval of the histogram */
    interval?: number;
    /** Give your aggregation an identifier, so you can find it easier */
    name: string;
    /** The timezone of the histogram */
    timeZone?: string;
    /**
     * The type of aggregation
     * @enum {string}
     */
    type: "histogram";
  };
  AggregationMetrics: {
    field: string;
    name: string;
    /** @enum {string} */
    type: "avg" | "count" | "max" | "min" | "stats" | "sum";
  };
  AggregationRange: {
    /** The field you want to aggregate over. */
    field: string;
    /** Give your aggregation an identifier, so you can find it easier */
    name: string;
    /** The ranges of the aggregation */
    ranges: (
      | {
          /** The lower bound of the range */
          from: number;
          /** The upper bound of the range */
          to: number;
        }
      | {
          /** The lower bound of the range */
          from: string;
        }
      | {
          /** The upper bound of the range */
          to: string;
        }
    )[];
    /**
     * The type of aggregation
     * @enum {string}
     */
    type: "range";
  };
  AggregationTerms: {
    /** The field you want to aggregate over. */
    field: string;
    /** The number of terms to return */
    limit?: number;
    /** Give your aggregation an identifier, so you can find it easier */
    name: string;
    /** Sorting the aggregation result. */
    sort?: components["schemas"]["Sort"][];
    /**
     * The type of aggregation
     * @enum {string}
     */
    type: "terms";
  };
  Aggregations: (
    | components["schemas"]["AggregationMetrics"]
    | (components["schemas"]["AggregationEntity"] &
        components["schemas"]["SubAggregations"])
    | (components["schemas"]["AggregationFilter"] &
        components["schemas"]["SubAggregations"])
    | (components["schemas"]["AggregationTerms"] &
        components["schemas"]["SubAggregations"])
    | (components["schemas"]["AggregationHistogram"] &
        components["schemas"]["SubAggregations"])
    | (components["schemas"]["AggregationRange"] &
        components["schemas"]["SubAggregations"])
  )[];
  App: {
    aclRole?: components["schemas"]["AclRole"];
    aclRoleId: string;
    actionButtons?: components["schemas"]["AppActionButton"][];
    active?: boolean;
    allowDisable?: boolean;
    allowedHosts?: string[];
    appShippingMethods?: components["schemas"]["AppShippingMethod"][];
    author?: string;
    baseAppUrl?: string;
    checkoutGatewayUrl?: string;
    cmsBlocks?: components["schemas"]["AppCmsBlock"][];
    configurable?: boolean;
    cookies?: GenericRecord[];
    copyright?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    customFieldSets?: components["schemas"]["CustomFieldSet"][];
    description?: string;
    extensions?: {
      storefrontConfig?: {
        data?: {
          /** @example bd1f4963443684177aac2b302cded7ac */
          id?: string;
          /** @example saas_app_storefront_config */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /app/ac863f346e618f9a959b5c95d5d28941/storefrontConfig
           */
          related?: string;
        };
      };
    };
    flowActions?: components["schemas"]["AppFlowAction"][];
    flowEvents?: components["schemas"]["AppFlowEvent"][];
    /** Runtime field, cannot be used as part of the criteria. */
    readonly icon?: string;
    id: string;
    integration?: components["schemas"]["Integration"];
    integrationId: string;
    label: string;
    license?: string;
    mainModule?: GenericRecord;
    modules?: GenericRecord[];
    name: string;
    path: string;
    paymentMethods?: components["schemas"]["AppPaymentMethod"][];
    privacy?: string;
    privacyPolicyExtensions?: string;
    selfManaged?: boolean;
    sourceConfig?: GenericRecord;
    sourceType?: string;
    taxProviders?: components["schemas"]["TaxProvider"][];
    /** Format: int64 */
    templateLoadPriority?: number;
    templates?: components["schemas"]["AppTemplate"][];
    translated: {
      aclRoleId: string;
      author: string;
      baseAppUrl: string;
      checkoutGatewayUrl: string;
      copyright: string;
      description: string;
      icon: string;
      integrationId: string;
      label: string;
      license: string;
      name: string;
      path: string;
      privacy: string;
      privacyPolicyExtensions: string;
      sourceType: string;
      version: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    version: string;
    webhooks?: components["schemas"]["Webhook"][];
  };
  AppActionButton: {
    action: string;
    app?: components["schemas"]["App"];
    appId: string;
    /** Format: date-time */
    readonly createdAt?: string;
    entity: string;
    id: string;
    label: string;
    translated: {
      action: string;
      appId: string;
      entity: string;
      label: string;
      url: string;
      view: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    url: string;
    view: string;
  };
  AppActionButtonJsonApi: components["schemas"]["resource"] & {
    action: string;
    appId: string;
    /** Format: date-time */
    readonly createdAt?: string;
    entity: string;
    id: string;
    label: string;
    relationships?: {
      app?: {
        data?: {
          /** @example d2a57dc1d883fd21fb9951699df71cc7 */
          id?: string;
          /** @example app */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /app-action-button/5c44158189757c2cf5f047ce1fe3e634/app
           */
          related?: string;
        };
      };
    };
    translated: {
      action: string;
      appId: string;
      entity: string;
      label: string;
      url: string;
      view: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    url: string;
    view: string;
  };
  AppAdministrationSnippet: {
    appId: string;
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    localeId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    value: string;
  };
  AppAdministrationSnippetJsonApi: components["schemas"]["resource"] & {
    appId: string;
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    localeId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    value: string;
  };
  AppCmsBlock: {
    app?: components["schemas"]["App"];
    appId: string;
    block: GenericRecord;
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    label: string;
    name: string;
    styles: string;
    template: string;
    translated: {
      appId: string;
      label: string;
      name: string;
      styles: string;
      template: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  AppCmsBlockJsonApi: components["schemas"]["resource"] & {
    appId: string;
    block: GenericRecord;
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    label: string;
    name: string;
    relationships?: {
      app?: {
        data?: {
          /** @example d2a57dc1d883fd21fb9951699df71cc7 */
          id?: string;
          /** @example app */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /app-cms-block/954814c609e0fd182bf61e99769a25f7/app
           */
          related?: string;
        };
      };
    };
    styles: string;
    template: string;
    translated: {
      appId: string;
      label: string;
      name: string;
      styles: string;
      template: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  AppFlowAction: {
    app?: components["schemas"]["App"];
    appId: string;
    badge?: string;
    config?: GenericRecord;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    delayable?: boolean;
    description?: string;
    flowSequences?: components["schemas"]["FlowSequence"][];
    headers?: GenericRecord;
    headline?: string;
    /** Runtime field, cannot be used as part of the criteria. */
    readonly icon?: string;
    iconRaw?: string;
    id: string;
    label: string;
    name: string;
    parameters?: GenericRecord;
    requirements?: string[];
    swIcon?: string;
    translated: {
      appId: string;
      badge: string;
      description: string;
      headline: string;
      icon: string;
      iconRaw: string;
      label: string;
      name: string;
      swIcon: string;
      url: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    url: string;
  };
  AppFlowActionJsonApi: components["schemas"]["resource"] & {
    appId: string;
    badge?: string;
    config?: GenericRecord;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    delayable?: boolean;
    description?: string;
    headers?: GenericRecord;
    headline?: string;
    /** Runtime field, cannot be used as part of the criteria. */
    readonly icon?: string;
    iconRaw?: string;
    id: string;
    label: string;
    name: string;
    parameters?: GenericRecord;
    relationships?: {
      app?: {
        data?: {
          /** @example d2a57dc1d883fd21fb9951699df71cc7 */
          id?: string;
          /** @example app */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /app-flow-action/d976e1ecc9f1084ec17f507c84f92278/app
           */
          related?: string;
        };
      };
      flowSequences?: {
        data?: {
          /** @example 3a0d70b6dd3624074e5e15cd07e7fa90 */
          id?: string;
          /** @example flow_sequence */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /app-flow-action/d976e1ecc9f1084ec17f507c84f92278/flowSequences
           */
          related?: string;
        };
      };
    };
    requirements?: string[];
    swIcon?: string;
    translated: {
      appId: string;
      badge: string;
      description: string;
      headline: string;
      icon: string;
      iconRaw: string;
      label: string;
      name: string;
      swIcon: string;
      url: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    url: string;
  };
  AppFlowEvent: {
    app?: components["schemas"]["App"];
    appId: string;
    aware: string[];
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    flows?: components["schemas"]["Flow"][];
    id: string;
    name: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  AppFlowEventJsonApi: components["schemas"]["resource"] & {
    appId: string;
    aware: string[];
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    id: string;
    name: string;
    relationships?: {
      app?: {
        data?: {
          /** @example d2a57dc1d883fd21fb9951699df71cc7 */
          id?: string;
          /** @example app */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /app-flow-event/ee419db2bca734414b0df87b3a919831/app
           */
          related?: string;
        };
      };
      flows?: {
        data?: {
          /** @example 0db2dd944f9ee9a131f44b79d331d371 */
          id?: string;
          /** @example flow */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /app-flow-event/ee419db2bca734414b0df87b3a919831/flows
           */
          related?: string;
        };
      };
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  AppJsonApi: components["schemas"]["resource"] & {
    aclRoleId: string;
    active?: boolean;
    allowDisable?: boolean;
    allowedHosts?: string[];
    author?: string;
    baseAppUrl?: string;
    checkoutGatewayUrl?: string;
    configurable?: boolean;
    cookies?: GenericRecord[];
    copyright?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    description?: string;
    extensions?: {
      storefrontConfig?: {
        data?: {
          /** @example bd1f4963443684177aac2b302cded7ac */
          id?: string;
          /** @example saas_app_storefront_config */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /app/ac863f346e618f9a959b5c95d5d28941/storefrontConfig
           */
          related?: string;
        };
      };
    };
    /** Runtime field, cannot be used as part of the criteria. */
    readonly icon?: string;
    id: string;
    integrationId: string;
    label: string;
    license?: string;
    mainModule?: GenericRecord;
    modules?: GenericRecord[];
    name: string;
    path: string;
    privacy?: string;
    privacyPolicyExtensions?: string;
    relationships?: {
      aclRole?: {
        data?: {
          /** @example 250aa1c64b973365fd6fd489eefbdefc */
          id?: string;
          /** @example acl_role */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /app/ac863f346e618f9a959b5c95d5d28941/aclRole
           */
          related?: string;
        };
      };
      actionButtons?: {
        data?: {
          /** @example 2c7967427ed432e546ef1c0cb8d5da9e */
          id?: string;
          /** @example app_action_button */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /app/ac863f346e618f9a959b5c95d5d28941/actionButtons
           */
          related?: string;
        };
      };
      appShippingMethods?: {
        data?: {
          /** @example 1ad05ee47064647ee5b2dc8c12b1041c */
          id?: string;
          /** @example app_shipping_method */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /app/ac863f346e618f9a959b5c95d5d28941/appShippingMethods
           */
          related?: string;
        };
      };
      cmsBlocks?: {
        data?: {
          /** @example 3636c4901eab836dfb837e1a9a37d3c0 */
          id?: string;
          /** @example app_cms_block */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /app/ac863f346e618f9a959b5c95d5d28941/cmsBlocks
           */
          related?: string;
        };
      };
      customFieldSets?: {
        data?: {
          /** @example 9b29ba872ce510f033b31364c8602760 */
          id?: string;
          /** @example custom_field_set */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /app/ac863f346e618f9a959b5c95d5d28941/customFieldSets
           */
          related?: string;
        };
      };
      flowActions?: {
        data?: {
          /** @example 8d83a8af9d1b8b85dae9bdb76b7dbe7f */
          id?: string;
          /** @example app_flow_action */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /app/ac863f346e618f9a959b5c95d5d28941/flowActions
           */
          related?: string;
        };
      };
      flowEvents?: {
        data?: {
          /** @example 045e9ec14eafd26d17854fb4fe7c9cae */
          id?: string;
          /** @example app_flow_event */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /app/ac863f346e618f9a959b5c95d5d28941/flowEvents
           */
          related?: string;
        };
      };
      integration?: {
        data?: {
          /** @example 776ea3bf11df5829827f7afb43c37174 */
          id?: string;
          /** @example integration */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /app/ac863f346e618f9a959b5c95d5d28941/integration
           */
          related?: string;
        };
      };
      paymentMethods?: {
        data?: {
          /** @example b631b1ab565525e892f9cdc1242cca14 */
          id?: string;
          /** @example app_payment_method */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /app/ac863f346e618f9a959b5c95d5d28941/paymentMethods
           */
          related?: string;
        };
      };
      taxProviders?: {
        data?: {
          /** @example 01a1a9d428b6402dc8255d99c787a00e */
          id?: string;
          /** @example tax_provider */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /app/ac863f346e618f9a959b5c95d5d28941/taxProviders
           */
          related?: string;
        };
      };
      templates?: {
        data?: {
          /** @example fed36e93a0509e20f2dc96cbbd85b678 */
          id?: string;
          /** @example app_template */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /app/ac863f346e618f9a959b5c95d5d28941/templates
           */
          related?: string;
        };
      };
      webhooks?: {
        data?: {
          /** @example c10f40999b74c408263f790b30e70efe */
          id?: string;
          /** @example webhook */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /app/ac863f346e618f9a959b5c95d5d28941/webhooks
           */
          related?: string;
        };
      };
    };
    selfManaged?: boolean;
    sourceConfig?: GenericRecord;
    sourceType?: string;
    /** Format: int64 */
    templateLoadPriority?: number;
    translated: {
      aclRoleId: string;
      author: string;
      baseAppUrl: string;
      checkoutGatewayUrl: string;
      copyright: string;
      description: string;
      icon: string;
      integrationId: string;
      label: string;
      license: string;
      name: string;
      path: string;
      privacy: string;
      privacyPolicyExtensions: string;
      sourceType: string;
      version: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    version: string;
  };
  AppPaymentMethod: {
    app?: components["schemas"]["App"];
    appId?: string;
    appName: string;
    captureUrl?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    finalizeUrl?: string;
    id: string;
    identifier: string;
    originalMedia?: components["schemas"]["Media"];
    originalMediaId?: string;
    paymentMethod?: components["schemas"]["PaymentMethod"];
    paymentMethodId: string;
    payUrl?: string;
    recurringUrl?: string;
    refundUrl?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    validateUrl?: string;
  };
  AppPaymentMethodJsonApi: components["schemas"]["resource"] & {
    appId?: string;
    appName: string;
    captureUrl?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    finalizeUrl?: string;
    id: string;
    identifier: string;
    originalMediaId?: string;
    paymentMethodId: string;
    payUrl?: string;
    recurringUrl?: string;
    refundUrl?: string;
    relationships?: {
      app?: {
        data?: {
          /** @example d2a57dc1d883fd21fb9951699df71cc7 */
          id?: string;
          /** @example app */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /app-payment-method/84f7c932de07ae9a57398d64828a7eae/app
           */
          related?: string;
        };
      };
      originalMedia?: {
        data?: {
          /** @example 56386c66f82d9cd5639a5a7447971ead */
          id?: string;
          /** @example media */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /app-payment-method/84f7c932de07ae9a57398d64828a7eae/originalMedia
           */
          related?: string;
        };
      };
      paymentMethod?: {
        data?: {
          /** @example 68ec1eeea9f1b7744e231b5bd0d97df0 */
          id?: string;
          /** @example payment_method */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /app-payment-method/84f7c932de07ae9a57398d64828a7eae/paymentMethod
           */
          related?: string;
        };
      };
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    validateUrl?: string;
  };
  AppScriptCondition: {
    active: boolean;
    app?: components["schemas"]["App"];
    appId: string;
    config?: GenericRecord;
    /** Format: date-time */
    readonly createdAt?: string;
    group?: string;
    id: string;
    identifier: string;
    name: string;
    ruleConditions?: components["schemas"]["RuleCondition"][];
    script?: string;
    translated: {
      appId: string;
      group: string;
      identifier: string;
      name: string;
      script: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  AppScriptConditionJsonApi: components["schemas"]["resource"] & {
    active: boolean;
    appId: string;
    config?: GenericRecord;
    /** Format: date-time */
    readonly createdAt?: string;
    group?: string;
    id: string;
    identifier: string;
    name: string;
    relationships?: {
      app?: {
        data?: {
          /** @example d2a57dc1d883fd21fb9951699df71cc7 */
          id?: string;
          /** @example app */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /app-script-condition/145c18275de1a9701ba31357e0bce9b5/app
           */
          related?: string;
        };
      };
      ruleConditions?: {
        data?: {
          /** @example 24bfabce4195894c9aed9b8bcfb0b748 */
          id?: string;
          /** @example rule_condition */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /app-script-condition/145c18275de1a9701ba31357e0bce9b5/ruleConditions
           */
          related?: string;
        };
      };
    };
    script?: string;
    translated: {
      appId: string;
      group: string;
      identifier: string;
      name: string;
      script: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  AppShippingMethod: {
    app?: components["schemas"]["App"];
    appId?: string;
    appName: string;
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    identifier: string;
    originalMedia?: components["schemas"]["Media"];
    originalMediaId?: string;
    shippingMethod?: components["schemas"]["ShippingMethod"];
    shippingMethodId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  AppShippingMethodJsonApi: components["schemas"]["resource"] & {
    appId?: string;
    appName: string;
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    identifier: string;
    originalMediaId?: string;
    relationships?: {
      app?: {
        data?: {
          /** @example d2a57dc1d883fd21fb9951699df71cc7 */
          id?: string;
          /** @example app */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /app-shipping-method/de94cc387f2598e321fc402da2abda66/app
           */
          related?: string;
        };
      };
      originalMedia?: {
        data?: {
          /** @example 56386c66f82d9cd5639a5a7447971ead */
          id?: string;
          /** @example media */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /app-shipping-method/de94cc387f2598e321fc402da2abda66/originalMedia
           */
          related?: string;
        };
      };
      shippingMethod?: {
        data?: {
          /** @example e97bfcdc0cae44bc9e4ab35762eaf0e1 */
          id?: string;
          /** @example shipping_method */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /app-shipping-method/de94cc387f2598e321fc402da2abda66/shippingMethod
           */
          related?: string;
        };
      };
    };
    shippingMethodId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  AppTemplate: {
    active: boolean;
    app?: components["schemas"]["App"];
    appId: string;
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    path: string;
    template: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  AppTemplateJsonApi: components["schemas"]["resource"] & {
    active: boolean;
    appId: string;
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    path: string;
    relationships?: {
      app?: {
        data?: {
          /** @example d2a57dc1d883fd21fb9951699df71cc7 */
          id?: string;
          /** @example app */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /app-template/ca9106b8b82ff55b6fdce530ccb952a7/app
           */
          related?: string;
        };
      };
    };
    template: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  Association: {
    [key: string]: components["schemas"]["Criteria"];
  };
  AttendeeInsights: {
    /** Sum of the cart net in base currency */
    cartSum?: number;
    /** Id of the attendee */
    id?: string;
    /** Sum of all quantities in the cart which were added during the appointment */
    productCount?: number;
  };
  B2bBusinessPartner: {
    /** Format: date-time */
    readonly createdAt?: string;
    customer?: components["schemas"]["Customer"];
    customerId?: string;
    customFields?: GenericRecord;
    defaultRole?: components["schemas"]["B2bComponentsRole"];
    defaultRoleId?: string;
    id: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  B2bBusinessPartnerJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    customerId?: string;
    customFields?: GenericRecord;
    defaultRoleId?: string;
    id: string;
    relationships?: {
      customer?: {
        data?: {
          /** @example 91ec1f9324753048c0096d036a694f86 */
          id?: string;
          /** @example customer */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /b2b-business-partner/7ba58cf5989d881e8226f193613ed414/customer
           */
          related?: string;
        };
      };
      defaultRole?: {
        data?: {
          /** @example 2944ea414640901d532eba5106eb706b */
          id?: string;
          /** @example b2b_components_role */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /b2b-business-partner/7ba58cf5989d881e8226f193613ed414/defaultRole
           */
          related?: string;
        };
      };
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  B2bComponentsApprovalRule: {
    active: boolean;
    affectedRole?: components["schemas"]["B2bComponentsRole"];
    affectedRoleId?: string;
    businessPartnerCustomer?: components["schemas"]["Customer"];
    businessPartnerCustomerId?: string;
    conditions: GenericRecord;
    /** Format: date-time */
    readonly createdAt?: string;
    description?: string;
    id: string;
    name: string;
    /** Format: int64 */
    priority: number;
    reviewerRole?: components["schemas"]["B2bComponentsRole"];
    reviewerRoleId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  B2bComponentsApprovalRuleAppScriptCondition: {
    active: boolean;
    app?: components["schemas"]["App"];
    appId: string;
    config?: GenericRecord;
    /** Format: date-time */
    readonly createdAt?: string;
    group?: string;
    id: string;
    identifier: string;
    name: string;
    script?: string;
    translated: {
      appId: string;
      group: string;
      identifier: string;
      name: string;
      script: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  B2bComponentsApprovalRuleAppScriptConditionJsonApi: components["schemas"]["resource"] & {
    active: boolean;
    appId: string;
    config?: GenericRecord;
    /** Format: date-time */
    readonly createdAt?: string;
    group?: string;
    id: string;
    identifier: string;
    name: string;
    relationships?: {
      app?: {
        data?: {
          /** @example d2a57dc1d883fd21fb9951699df71cc7 */
          id?: string;
          /** @example app */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /b2b-components-approval-rule-app-script-condition/031e11005a97d52a5c7950ff98b5f2bb/app
           */
          related?: string;
        };
      };
    };
    script?: string;
    translated: {
      appId: string;
      group: string;
      identifier: string;
      name: string;
      script: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  B2bComponentsApprovalRuleJsonApi: components["schemas"]["resource"] & {
    active: boolean;
    affectedRoleId?: string;
    businessPartnerCustomerId?: string;
    conditions: GenericRecord;
    /** Format: date-time */
    readonly createdAt?: string;
    description?: string;
    id: string;
    name: string;
    /** Format: int64 */
    priority: number;
    relationships?: {
      affectedRole?: {
        data?: {
          /** @example 33237c6057eedd7b8c978f77270af3b1 */
          id?: string;
          /** @example b2b_components_role */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /b2b-components-approval-rule/7181d2e3f46190b96b7cb8242c761a03/affectedRole
           */
          related?: string;
        };
      };
      businessPartnerCustomer?: {
        data?: {
          /** @example 798b3bbcdcbca2ce67fe2ef0d7d28cbf */
          id?: string;
          /** @example customer */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /b2b-components-approval-rule/7181d2e3f46190b96b7cb8242c761a03/businessPartnerCustomer
           */
          related?: string;
        };
      };
      reviewerRole?: {
        data?: {
          /** @example 06ec286ee4d03afb4028caa32c0ef40b */
          id?: string;
          /** @example b2b_components_role */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /b2b-components-approval-rule/7181d2e3f46190b96b7cb8242c761a03/reviewerRole
           */
          related?: string;
        };
      };
    };
    reviewerRoleId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  B2bComponentsPendingOrder: {
    addresses?: components["schemas"]["B2bComponentsPendingOrderAddress"][];
    /** Format: float */
    readonly amountNet?: number;
    /** Format: float */
    readonly amountTotal?: number;
    approvalRule?: components["schemas"]["B2bComponentsApprovalRule"];
    approvalRuleId?: string;
    /** Format: int64 */
    readonly autoIncrement?: number;
    billingAddress?: components["schemas"]["B2bComponentsPendingOrderAddress"];
    billingAddressId: string;
    cartPayload: string;
    country?: components["schemas"]["Country"];
    countryId: string;
    /** Format: date-time */
    readonly createdAt?: string;
    currency?: components["schemas"]["Currency"];
    currencyId: string;
    customer?: components["schemas"]["Customer"];
    customerId: string;
    customFields?: GenericRecord;
    decidedBy?: components["schemas"]["B2bEmployee"];
    decidedById?: string;
    designatedPayerIds?: string[];
    employee?: components["schemas"]["B2bEmployee"];
    employeeId: string;
    id: string;
    itemRounding: {
      /** Format: int64 */
      decimals: number;
      /** Format: float */
      interval: number;
      roundForNet: boolean;
    };
    language?: components["schemas"]["Language"];
    languageId: string;
    /** Format: int64 */
    lineItemCount: number;
    number: string;
    order?: components["schemas"]["Order"];
    orderId?: string;
    orderVersionId?: string;
    /** Format: float */
    originalPrice?: number;
    paymentMethod?: components["schemas"]["PaymentMethod"];
    paymentMethodId: string;
    price?: {
      calculatedTaxes?: GenericRecord;
      /** Format: float */
      netPrice: number;
      /** Format: float */
      positionPrice: number;
      /** Format: float */
      rawTotal: number;
      taxRules?: GenericRecord;
      taxStatus: string;
      /** Format: float */
      totalPrice: number;
    };
    reason?: string;
    salesChannel?: components["schemas"]["SalesChannel"];
    salesChannelId: string;
    shippingMethod?: components["schemas"]["ShippingMethod"];
    shippingMethodId: string;
    stateId: string;
    stateMachineState?: components["schemas"]["StateMachineState"];
    readonly taxStatus?: string;
    totalRounding: {
      /** Format: int64 */
      decimals: number;
      /** Format: float */
      interval: number;
      roundForNet: boolean;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  B2bComponentsPendingOrderAddress: {
    additionalAddressLine1?: string;
    additionalAddressLine2?: string;
    city: string;
    company?: string;
    country?: components["schemas"]["Country"];
    countryId: string;
    countryState?: components["schemas"]["CountryState"];
    countryStateId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    department?: string;
    firstName: string;
    id: string;
    lastName: string;
    pendingOrder?: components["schemas"]["B2bComponentsPendingOrder"];
    pendingOrderId: string;
    phoneNumber?: string;
    salutation?: components["schemas"]["Salutation"];
    salutationId?: string;
    street: string;
    title?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    vatId?: string;
    zipcode?: string;
  };
  B2bComponentsPendingOrderAddressJsonApi: components["schemas"]["resource"] & {
    additionalAddressLine1?: string;
    additionalAddressLine2?: string;
    city: string;
    company?: string;
    countryId: string;
    countryStateId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    department?: string;
    firstName: string;
    id: string;
    lastName: string;
    pendingOrderId: string;
    phoneNumber?: string;
    relationships?: {
      country?: {
        data?: {
          /** @example e909c2d7067ea37437cf97fe11d91bd0 */
          id?: string;
          /** @example country */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /b2b-components-pending-order-address/4fce37927007500103484410b28f4b34/country
           */
          related?: string;
        };
      };
      countryState?: {
        data?: {
          /** @example cb6a9764567191fb74fe28d8d6a4819d */
          id?: string;
          /** @example country_state */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /b2b-components-pending-order-address/4fce37927007500103484410b28f4b34/countryState
           */
          related?: string;
        };
      };
      pendingOrder?: {
        data?: {
          /** @example 1fd94955ea55110a2cf95eeb6fb1679f */
          id?: string;
          /** @example b2b_components_pending_order */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /b2b-components-pending-order-address/4fce37927007500103484410b28f4b34/pendingOrder
           */
          related?: string;
        };
      };
      salutation?: {
        data?: {
          /** @example 7a6efb02514153b5aa9a8f40c6f8bcc3 */
          id?: string;
          /** @example salutation */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /b2b-components-pending-order-address/4fce37927007500103484410b28f4b34/salutation
           */
          related?: string;
        };
      };
    };
    salutationId?: string;
    street: string;
    title?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    vatId?: string;
    zipcode?: string;
  };
  B2bComponentsPendingOrderJsonApi: components["schemas"]["resource"] & {
    /** Format: float */
    readonly amountNet?: number;
    /** Format: float */
    readonly amountTotal?: number;
    approvalRuleId?: string;
    /** Format: int64 */
    readonly autoIncrement?: number;
    billingAddressId: string;
    cartPayload: string;
    countryId: string;
    /** Format: date-time */
    readonly createdAt?: string;
    currencyId: string;
    customerId: string;
    customFields?: GenericRecord;
    decidedById?: string;
    designatedPayerIds?: string[];
    employeeId: string;
    id: string;
    itemRounding: {
      /** Format: int64 */
      decimals: number;
      /** Format: float */
      interval: number;
      roundForNet: boolean;
    };
    languageId: string;
    /** Format: int64 */
    lineItemCount: number;
    number: string;
    orderId?: string;
    orderVersionId?: string;
    /** Format: float */
    originalPrice?: number;
    paymentMethodId: string;
    price?: {
      calculatedTaxes?: GenericRecord;
      /** Format: float */
      netPrice: number;
      /** Format: float */
      positionPrice: number;
      /** Format: float */
      rawTotal: number;
      taxRules?: GenericRecord;
      taxStatus: string;
      /** Format: float */
      totalPrice: number;
    };
    reason?: string;
    relationships?: {
      addresses?: {
        data?: {
          /** @example 963e3a2fe559e393bad631f3dc686f69 */
          id?: string;
          /** @example b2b_components_pending_order_address */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /b2b-components-pending-order/e87c4279c6f83e4de2543a63bf59b373/addresses
           */
          related?: string;
        };
      };
      approvalRule?: {
        data?: {
          /** @example 2beeb3d6f9f7be5fb67d4cd9d9f9ba25 */
          id?: string;
          /** @example b2b_components_approval_rule */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /b2b-components-pending-order/e87c4279c6f83e4de2543a63bf59b373/approvalRule
           */
          related?: string;
        };
      };
      billingAddress?: {
        data?: {
          /** @example 7fee8ff88b768662dd8fc06e1b6997d2 */
          id?: string;
          /** @example b2b_components_pending_order_address */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /b2b-components-pending-order/e87c4279c6f83e4de2543a63bf59b373/billingAddress
           */
          related?: string;
        };
      };
      country?: {
        data?: {
          /** @example e909c2d7067ea37437cf97fe11d91bd0 */
          id?: string;
          /** @example country */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /b2b-components-pending-order/e87c4279c6f83e4de2543a63bf59b373/country
           */
          related?: string;
        };
      };
      currency?: {
        data?: {
          /** @example 1af0389838508d7016a9841eb6273962 */
          id?: string;
          /** @example currency */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /b2b-components-pending-order/e87c4279c6f83e4de2543a63bf59b373/currency
           */
          related?: string;
        };
      };
      customer?: {
        data?: {
          /** @example 91ec1f9324753048c0096d036a694f86 */
          id?: string;
          /** @example customer */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /b2b-components-pending-order/e87c4279c6f83e4de2543a63bf59b373/customer
           */
          related?: string;
        };
      };
      decidedBy?: {
        data?: {
          /** @example b293e6616bcffea8e393a4066a4a4230 */
          id?: string;
          /** @example b2b_employee */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /b2b-components-pending-order/e87c4279c6f83e4de2543a63bf59b373/decidedBy
           */
          related?: string;
        };
      };
      employee?: {
        data?: {
          /** @example fa5473530e4d1a5a1e1eb53d2fedb10c */
          id?: string;
          /** @example b2b_employee */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /b2b-components-pending-order/e87c4279c6f83e4de2543a63bf59b373/employee
           */
          related?: string;
        };
      };
      language?: {
        data?: {
          /** @example 8512ae7d57b1396273f76fe6ed341a23 */
          id?: string;
          /** @example language */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /b2b-components-pending-order/e87c4279c6f83e4de2543a63bf59b373/language
           */
          related?: string;
        };
      };
      order?: {
        data?: {
          /** @example 70a17ffa722a3985b86d30b034ad06d7 */
          id?: string;
          /** @example order */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /b2b-components-pending-order/e87c4279c6f83e4de2543a63bf59b373/order
           */
          related?: string;
        };
      };
      paymentMethod?: {
        data?: {
          /** @example 68ec1eeea9f1b7744e231b5bd0d97df0 */
          id?: string;
          /** @example payment_method */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /b2b-components-pending-order/e87c4279c6f83e4de2543a63bf59b373/paymentMethod
           */
          related?: string;
        };
      };
      salesChannel?: {
        data?: {
          /** @example ec3712a84143b57e0db620eaac6e55b8 */
          id?: string;
          /** @example sales_channel */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /b2b-components-pending-order/e87c4279c6f83e4de2543a63bf59b373/salesChannel
           */
          related?: string;
        };
      };
      shippingMethod?: {
        data?: {
          /** @example e97bfcdc0cae44bc9e4ab35762eaf0e1 */
          id?: string;
          /** @example shipping_method */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /b2b-components-pending-order/e87c4279c6f83e4de2543a63bf59b373/shippingMethod
           */
          related?: string;
        };
      };
      stateMachineState?: {
        data?: {
          /** @example 1ab22d393154f21e3be76aca3ec3ee31 */
          id?: string;
          /** @example state_machine_state */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /b2b-components-pending-order/e87c4279c6f83e4de2543a63bf59b373/stateMachineState
           */
          related?: string;
        };
      };
    };
    salesChannelId: string;
    shippingMethodId: string;
    stateId: string;
    readonly taxStatus?: string;
    totalRounding: {
      /** Format: int64 */
      decimals: number;
      /** Format: float */
      interval: number;
      roundForNet: boolean;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  B2bComponentsRole: {
    businessPartnerCustomer?: components["schemas"]["Customer"];
    businessPartnerCustomerId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    employees?: components["schemas"]["B2bEmployee"][];
    id: string;
    name: string;
    permissions?: GenericRecord[];
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  B2bComponentsRoleJsonApi: components["schemas"]["resource"] & {
    businessPartnerCustomerId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    id: string;
    name: string;
    permissions?: GenericRecord[];
    relationships?: {
      businessPartnerCustomer?: {
        data?: {
          /** @example 798b3bbcdcbca2ce67fe2ef0d7d28cbf */
          id?: string;
          /** @example customer */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /b2b-components-role/a2f4fa227c09d6222701f670a01bb0b0/businessPartnerCustomer
           */
          related?: string;
        };
      };
      employees?: {
        data?: {
          /** @example 582ca3f7cbaf4edcc1b445f8ea90b503 */
          id?: string;
          /** @example b2b_employee */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /b2b-components-role/a2f4fa227c09d6222701f670a01bb0b0/employees
           */
          related?: string;
        };
      };
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  B2bComponentsShoppingList: {
    active?: boolean;
    /** Format: date-time */
    readonly createdAt?: string;
    createdBy?: components["schemas"]["User"];
    createdById?: string;
    customer?: components["schemas"]["Customer"];
    customerId: string;
    customFields?: GenericRecord;
    employee?: components["schemas"]["B2bEmployee"];
    employeeId?: string;
    id: string;
    lineItems?: components["schemas"]["B2bComponentsShoppingListLineItem"][];
    name?: string;
    price?: components["schemas"]["Price"][];
    salesChannel?: components["schemas"]["SalesChannel"];
    salesChannelId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    updatedBy?: components["schemas"]["User"];
    updatedById?: string;
  };
  B2bComponentsShoppingListJsonApi: components["schemas"]["resource"] & {
    active?: boolean;
    /** Format: date-time */
    readonly createdAt?: string;
    createdById?: string;
    customerId: string;
    customFields?: GenericRecord;
    employeeId?: string;
    id: string;
    name?: string;
    price?: components["schemas"]["Price"][];
    relationships?: {
      createdBy?: {
        data?: {
          /** @example 34998857f537140306898d54d4b970dc */
          id?: string;
          /** @example user */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /b2b-components-shopping-list/23cb3bfda723e05b43cb25a427ee5a25/createdBy
           */
          related?: string;
        };
      };
      customer?: {
        data?: {
          /** @example 91ec1f9324753048c0096d036a694f86 */
          id?: string;
          /** @example customer */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /b2b-components-shopping-list/23cb3bfda723e05b43cb25a427ee5a25/customer
           */
          related?: string;
        };
      };
      employee?: {
        data?: {
          /** @example fa5473530e4d1a5a1e1eb53d2fedb10c */
          id?: string;
          /** @example b2b_employee */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /b2b-components-shopping-list/23cb3bfda723e05b43cb25a427ee5a25/employee
           */
          related?: string;
        };
      };
      lineItems?: {
        data?: {
          /** @example a042af1aa9f3853fe3cd7dabc065568f */
          id?: string;
          /** @example b2b_components_shopping_list_line_item */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /b2b-components-shopping-list/23cb3bfda723e05b43cb25a427ee5a25/lineItems
           */
          related?: string;
        };
      };
      salesChannel?: {
        data?: {
          /** @example ec3712a84143b57e0db620eaac6e55b8 */
          id?: string;
          /** @example sales_channel */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /b2b-components-shopping-list/23cb3bfda723e05b43cb25a427ee5a25/salesChannel
           */
          related?: string;
        };
      };
      updatedBy?: {
        data?: {
          /** @example 7ced3d0067ad61702af7db8ae260aa76 */
          id?: string;
          /** @example user */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /b2b-components-shopping-list/23cb3bfda723e05b43cb25a427ee5a25/updatedBy
           */
          related?: string;
        };
      };
    };
    salesChannelId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    updatedById?: string;
  };
  B2bComponentsShoppingListLineItem: {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    id: string;
    price?: components["schemas"]["Price"][];
    product?: components["schemas"]["Product"];
    productId?: string;
    productVersionId?: string;
    /** Format: int64 */
    quantity: number;
    shoppingList?: components["schemas"]["B2bComponentsShoppingList"];
    shoppingListId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  B2bComponentsShoppingListLineItemJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    id: string;
    price?: components["schemas"]["Price"][];
    productId?: string;
    productVersionId?: string;
    /** Format: int64 */
    quantity: number;
    relationships?: {
      product?: {
        data?: {
          /** @example f5bf48aa40cad7891eb709fcf1fde128 */
          id?: string;
          /** @example product */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /b2b-components-shopping-list-line-item/30d48c8d92682de24e11d3f72c5dd1ea/product
           */
          related?: string;
        };
      };
      shoppingList?: {
        data?: {
          /** @example 75cf6f56c85d6cbfe36939709500418b */
          id?: string;
          /** @example b2b_components_shopping_list */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /b2b-components-shopping-list-line-item/30d48c8d92682de24e11d3f72c5dd1ea/shoppingList
           */
          related?: string;
        };
      };
    };
    shoppingListId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  B2bEmployee: {
    active?: boolean;
    businessPartnerCustomer?: components["schemas"]["Customer"];
    businessPartnerCustomerId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    email: string;
    extensions?: {
      quotes?: {
        data?: {
          /** @example 2150fd65034a9bcdb357943b3900a918 */
          id?: string;
          /** @example quote_employee */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /b2b-employee/1131eb0b1859b37129289fe3bcc9e70b/quotes
           */
          related?: string;
        };
      };
    };
    firstName: string;
    id: string;
    language?: components["schemas"]["Language"];
    languageId: string;
    lastName: string;
    /** Format: date-time */
    recoveryTime?: string;
    role?: components["schemas"]["B2bComponentsRole"];
    roleId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  B2bEmployeeJsonApi: components["schemas"]["resource"] & {
    active?: boolean;
    businessPartnerCustomerId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    email: string;
    extensions?: {
      quotes?: {
        data?: {
          /** @example 2150fd65034a9bcdb357943b3900a918 */
          id?: string;
          /** @example quote_employee */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /b2b-employee/1131eb0b1859b37129289fe3bcc9e70b/quotes
           */
          related?: string;
        };
      };
    };
    firstName: string;
    id: string;
    languageId: string;
    lastName: string;
    /** Format: date-time */
    recoveryTime?: string;
    relationships?: {
      businessPartnerCustomer?: {
        data?: {
          /** @example 798b3bbcdcbca2ce67fe2ef0d7d28cbf */
          id?: string;
          /** @example customer */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /b2b-employee/1131eb0b1859b37129289fe3bcc9e70b/businessPartnerCustomer
           */
          related?: string;
        };
      };
      language?: {
        data?: {
          /** @example 8512ae7d57b1396273f76fe6ed341a23 */
          id?: string;
          /** @example language */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /b2b-employee/1131eb0b1859b37129289fe3bcc9e70b/language
           */
          related?: string;
        };
      };
      role?: {
        data?: {
          /** @example 29a7e96467b69a9f5a93332e29e9b0de */
          id?: string;
          /** @example b2b_components_role */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /b2b-employee/1131eb0b1859b37129289fe3bcc9e70b/role
           */
          related?: string;
        };
      };
    };
    roleId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  B2bOrderEmployee: {
    /** Format: date-time */
    readonly createdAt?: string;
    employee?: components["schemas"]["B2bEmployee"];
    employeeId: string;
    firstName: string;
    id: string;
    lastName: string;
    order?: components["schemas"]["Order"];
    orderId: string;
    orderVersionId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  B2bOrderEmployeeJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    employeeId: string;
    firstName: string;
    id: string;
    lastName: string;
    orderId: string;
    orderVersionId?: string;
    relationships?: {
      employee?: {
        data?: {
          /** @example fa5473530e4d1a5a1e1eb53d2fedb10c */
          id?: string;
          /** @example b2b_employee */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /b2b-order-employee/5e062ee52486b822aad4eb0918cff56d/employee
           */
          related?: string;
        };
      };
      order?: {
        data?: {
          /** @example 70a17ffa722a3985b86d30b034ad06d7 */
          id?: string;
          /** @example order */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /b2b-order-employee/5e062ee52486b822aad4eb0918cff56d/order
           */
          related?: string;
        };
      };
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  B2bPermission: {
    /** Format: date-time */
    readonly createdAt?: string;
    dependencies?: string[];
    group: string;
    id: string;
    name: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  B2bPermissionJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    dependencies?: string[];
    group: string;
    id: string;
    name: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  CalculatedPrice: {
    /** @enum {string} */
    apiAlias: "calculated_price";
    calculatedTaxes: {
      /** @enum {string} */
      apiAlias: "cart_tax_calculated";
      price: number;
      tax: number;
      taxRate: number;
    }[];
    hasRange: boolean;
    listPrice: components["schemas"]["CartListPrice"] | null;
    netPrice: number;
    positionPrice: number;
    quantity: number;
    rawTotal?: number;
    referencePrice: components["schemas"]["CartPriceReference"] | null;
    regulationPrice: {
      /** @enum {string} */
      apiAlias?: "cart_regulation_price";
      price?: number;
    } | null;
    /** Currently active tax rules and/or rates */
    taxRules: {
      name?: string;
      /** Format: float */
      taxRate?: number;
    }[];
    totalPrice: number;
    unitPrice: number;
    /** Format: ^[0-9a-f]{32}$ */
    variantId?: string | null;
  };
  Cart: {
    /** An affiliate tracking code */
    affiliateCode?: string | null;
    /** A campaign tracking code */
    campaignCode?: string | null;
    /** A comment that can be added to the cart. */
    customerComment?: string | null;
    deliveries?: components["schemas"]["CartDelivery"][];
    /** A list of all cart errors, such as insufficient stocks, invalid addresses or vouchers. */
    errors?: components["schemas"]["CartError"][];
    /** All items within the cart */
    lineItems?: components["schemas"]["LineItem"][];
    modified?: boolean;
    /** Name of the cart - for example `guest-cart` */
    name?: string;
    price?: components["schemas"]["CalculatedPrice"];
    /** Context token identifying the cart and the user session */
    token?: string;
    /** A list of all payment transactions associated with the current cart. */
    transactions?: {
      amount?: components["schemas"]["CalculatedPrice"];
      paymentMethodId?: string;
    }[];
  };
  CartDelivery: {
    deliveryDate?: {
      /** Format: date-time */
      earliest?: string;
      /** Format: date-time */
      latest?: string;
    };
    location?: {
      address?: components["schemas"]["CustomerAddress"];
      /** @enum {string} */
      apiAlias?: "cart_delivery_shipping_location";
      country?: components["schemas"]["Country"];
      state?: components["schemas"]["CountryState"];
    };
    positions?: components["schemas"]["CartDeliveryPosition"][];
    shippingCosts?: components["schemas"]["CalculatedPrice"];
    shippingMethod?: components["schemas"]["ShippingMethod"];
  };
  CartDeliveryInformation: {
    /** @enum {string} */
    apiAlias: "cart_delivery_information";
    deliveryTime?: {
      /** @enum {string} */
      apiAlias?: "cart_delivery_time";
      max?: number;
      min?: number;
      name?: string;
      unit?: string;
    };
    freeDelivery?: boolean;
    height?: number;
    length?: number;
    restockTime?: number;
    stock?: number;
    weight?: number;
    width?: number;
  };
  CartDeliveryPosition: {
    deliveryDate?: {
      /** Format: date-time */
      earliest?: string;
      /** Format: date-time */
      latest?: string;
    };
    identifier?: string;
    lineItem?: components["schemas"]["LineItem"];
    price?: components["schemas"]["CalculatedPrice"];
  };
  CartError: {
    items?: {
      key?: string;
      /**
       * * `0` - notice,
       *     * `10` - warning,
       *     * `20` - error
       * @enum {number}
       */
      level?: 0 | 10 | 20;
      message?: string;
      messageKey?: string;
    };
  };
  CartItems: {
    items?: components["schemas"]["LineItem"][];
  };
  CartListPrice: {
    /** @enum {string} */
    apiAlias: "cart_list_price";
    discount?: number;
    percentage?: number;
    price?: number;
  };
  CartPriceQuantity: {
    /** @enum {string} */
    apiAlias: "cart_price_quantity";
    isCalculated?: boolean;
    listPrice?: components["schemas"]["CartListPrice"];
    price?: number;
    quantity?: number;
    regulationPrice?: {
      /** Format: float */
      price?: number;
    };
    taxRules?: {
      name?: string;
      /** Format: float */
      taxRate?: number;
    }[];
    type?: string;
  };
  CartPriceReference: {
    /** @enum {string} */
    apiAlias: "cart_price_reference";
    hasRange: boolean;
    listPrice: components["schemas"]["CartListPrice"] | null;
    price?: number;
    purchaseUnit?: number;
    referenceUnit?: number;
    regulationPrice: {
      /** @enum {string} */
      apiAlias?: "cart_regulation_price";
      price?: number;
    } | null;
    unitName: string;
    /** Format: ^[0-9a-f]{32}$ */
    variantId?: string | null;
  };
  Category: {
    active?: boolean;
    afterCategoryId?: string;
    afterCategoryVersionId?: string;
    /** Format: int64 */
    readonly autoIncrement?: number;
    readonly breadcrumb?: GenericRecord[];
    /** Format: int64 */
    readonly childCount?: number;
    children?: components["schemas"]["Category"][];
    cmsPage?: components["schemas"]["CmsPage"];
    cmsPageId?: string;
    /** Runtime field, cannot be used as part of the criteria. */
    cmsPageIdSwitched?: boolean;
    cmsPageVersionId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customEntityTypeId?: string;
    customFields?: GenericRecord;
    description?: string;
    displayNestedProducts?: boolean;
    extensions?: {
      search?: GenericRecord;
      swagDynamicAccessRules?: {
        data?: {
          /** @example 05b9d828254c957dfa5224c581439c92 */
          id?: string;
          /** @example rule */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /category/3adbdb3ac060038aa0e6e6c138ef9873/swagDynamicAccessRules
           */
          related?: string;
        };
      };
    };
    externalLink?: string;
    footerSalesChannels?: components["schemas"]["SalesChannel"][];
    id: string;
    internalLink?: string;
    keywords?: string;
    /** Format: int64 */
    readonly level?: number;
    linkNewTab?: boolean;
    linkType?: string;
    mainCategories?: components["schemas"]["MainCategory"][];
    media?: components["schemas"]["Media"];
    mediaId?: string;
    metaDescription?: string;
    metaTitle?: string;
    name: string;
    navigationSalesChannels?: components["schemas"]["SalesChannel"][];
    nestedProducts?: components["schemas"]["Product"][];
    parent?: components["schemas"]["Category"];
    parentId?: string;
    parentVersionId?: string;
    readonly path?: string;
    productAssignmentType?: string;
    products?: components["schemas"]["Product"][];
    productStream?: components["schemas"]["ProductStream"];
    productStreamId?: string;
    seoUrls?: components["schemas"]["SeoUrl"][];
    serviceSalesChannels?: components["schemas"]["SalesChannel"][];
    slotConfig?: GenericRecord;
    tags?: components["schemas"]["Tag"][];
    translated: {
      afterCategoryId: string;
      afterCategoryVersionId: string;
      cmsPageId: string;
      cmsPageVersionId: string;
      customEntityTypeId: string;
      description: string;
      externalLink: string;
      internalLink: string;
      keywords: string;
      linkType: string;
      mediaId: string;
      metaDescription: string;
      metaTitle: string;
      name: string;
      parentId: string;
      parentVersionId: string;
      path: string;
      productAssignmentType: string;
      productStreamId: string;
      type: string;
      versionId: string;
    };
    type?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
    visible?: boolean;
    /**
     * Format: int64
     * Runtime field, cannot be used as part of the criteria.
     */
    visibleChildCount?: number;
  };
  CategoryJsonApi: components["schemas"]["resource"] & {
    active?: boolean;
    afterCategoryId?: string;
    afterCategoryVersionId?: string;
    /** Format: int64 */
    readonly autoIncrement?: number;
    readonly breadcrumb?: GenericRecord[];
    /** Format: int64 */
    readonly childCount?: number;
    cmsPageId?: string;
    /** Runtime field, cannot be used as part of the criteria. */
    cmsPageIdSwitched?: boolean;
    cmsPageVersionId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customEntityTypeId?: string;
    customFields?: GenericRecord;
    description?: string;
    displayNestedProducts?: boolean;
    extensions?: {
      search?: GenericRecord;
      swagDynamicAccessRules?: {
        data?: {
          /** @example 05b9d828254c957dfa5224c581439c92 */
          id?: string;
          /** @example rule */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /category/3adbdb3ac060038aa0e6e6c138ef9873/swagDynamicAccessRules
           */
          related?: string;
        };
      };
    };
    externalLink?: string;
    id: string;
    internalLink?: string;
    keywords?: string;
    /** Format: int64 */
    readonly level?: number;
    linkNewTab?: boolean;
    linkType?: string;
    mediaId?: string;
    metaDescription?: string;
    metaTitle?: string;
    name: string;
    parentId?: string;
    parentVersionId?: string;
    readonly path?: string;
    productAssignmentType?: string;
    productStreamId?: string;
    relationships?: {
      children?: {
        data?: {
          /** @example 268184c12df027f536154d099d497b31 */
          id?: string;
          /** @example category */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /category/3adbdb3ac060038aa0e6e6c138ef9873/children
           */
          related?: string;
        };
      };
      cmsPage?: {
        data?: {
          /** @example 7b1460918b1abb93311108f3dc021c9b */
          id?: string;
          /** @example cms_page */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /category/3adbdb3ac060038aa0e6e6c138ef9873/cmsPage
           */
          related?: string;
        };
      };
      footerSalesChannels?: {
        data?: {
          /** @example 57944aba1f6dea7ca9dacf66776e1755 */
          id?: string;
          /** @example sales_channel */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /category/3adbdb3ac060038aa0e6e6c138ef9873/footerSalesChannels
           */
          related?: string;
        };
      };
      mainCategories?: {
        data?: {
          /** @example 1fb731fc4139cbb575429e28846f0c39 */
          id?: string;
          /** @example main_category */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /category/3adbdb3ac060038aa0e6e6c138ef9873/mainCategories
           */
          related?: string;
        };
      };
      media?: {
        data?: {
          /** @example 62933a2951ef01f4eafd9bdf4d3cd2f0 */
          id?: string;
          /** @example media */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /category/3adbdb3ac060038aa0e6e6c138ef9873/media
           */
          related?: string;
        };
      };
      navigationSalesChannels?: {
        data?: {
          /** @example 04db458d860e0a4b455ae14b384a5e8a */
          id?: string;
          /** @example sales_channel */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /category/3adbdb3ac060038aa0e6e6c138ef9873/navigationSalesChannels
           */
          related?: string;
        };
      };
      nestedProducts?: {
        data?: {
          /** @example cf73cebf9ade7f94deba94ec71e66e43 */
          id?: string;
          /** @example product */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /category/3adbdb3ac060038aa0e6e6c138ef9873/nestedProducts
           */
          related?: string;
        };
      };
      parent?: {
        data?: {
          /** @example d0e45878043844ffc41aac437e86b602 */
          id?: string;
          /** @example category */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /category/3adbdb3ac060038aa0e6e6c138ef9873/parent
           */
          related?: string;
        };
      };
      products?: {
        data?: {
          /** @example 86024cad1e83101d97359d7351051156 */
          id?: string;
          /** @example product */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /category/3adbdb3ac060038aa0e6e6c138ef9873/products
           */
          related?: string;
        };
      };
      productStream?: {
        data?: {
          /** @example 49561f6faa0badfce831a183d2ec7c2f */
          id?: string;
          /** @example product_stream */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /category/3adbdb3ac060038aa0e6e6c138ef9873/productStream
           */
          related?: string;
        };
      };
      seoUrls?: {
        data?: {
          /** @example 5321b5a71127b8b98cdd4b068ad56c4c */
          id?: string;
          /** @example seo_url */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /category/3adbdb3ac060038aa0e6e6c138ef9873/seoUrls
           */
          related?: string;
        };
      };
      serviceSalesChannels?: {
        data?: {
          /** @example 1a79932fadba3b20baf6369181e45602 */
          id?: string;
          /** @example sales_channel */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /category/3adbdb3ac060038aa0e6e6c138ef9873/serviceSalesChannels
           */
          related?: string;
        };
      };
      tags?: {
        data?: {
          /** @example d57ac45256849d9b13e2422d91580fb9 */
          id?: string;
          /** @example tag */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /category/3adbdb3ac060038aa0e6e6c138ef9873/tags
           */
          related?: string;
        };
      };
    };
    slotConfig?: GenericRecord;
    translated: {
      afterCategoryId: string;
      afterCategoryVersionId: string;
      cmsPageId: string;
      cmsPageVersionId: string;
      customEntityTypeId: string;
      description: string;
      externalLink: string;
      internalLink: string;
      keywords: string;
      linkType: string;
      mediaId: string;
      metaDescription: string;
      metaTitle: string;
      name: string;
      parentId: string;
      parentVersionId: string;
      path: string;
      productAssignmentType: string;
      productStreamId: string;
      type: string;
      versionId: string;
    };
    type?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
    visible?: boolean;
    /**
     * Format: int64
     * Runtime field, cannot be used as part of the criteria.
     */
    visibleChildCount?: number;
  };
  CategoryTag: {
    category?: components["schemas"]["Category"];
    categoryId: string;
    categoryVersionId?: string;
    id?: string;
    tag?: components["schemas"]["Tag"];
    tagId: string;
  };
  CmsBlock: {
    backgroundColor?: string;
    backgroundMedia?: components["schemas"]["Media"];
    backgroundMediaId?: string;
    backgroundMediaMode?: string;
    cmsSectionVersionId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    cssClass?: string;
    customFields?: GenericRecord;
    extensions?: {
      swagCmsExtensionsBlockRule?: {
        data?: {
          /** @example c426e9e5d9031b933f89682d49bb02b1 */
          id?: string;
          /** @example swag_cms_extensions_block_rule */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /cms-block/9c16ffe823ddccc710bfb336c2ef30b6/swagCmsExtensionsBlockRule
           */
          related?: string;
        };
      };
      swagCmsExtensionsQuickview?: {
        data?: {
          /** @example fae098a43df8714eda5249176ffcf26c */
          id?: string;
          /** @example swag_cms_extensions_quickview */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /cms-block/9c16ffe823ddccc710bfb336c2ef30b6/swagCmsExtensionsQuickview
           */
          related?: string;
        };
      };
    };
    id: string;
    locked?: boolean;
    marginBottom?: string;
    marginLeft?: string;
    marginRight?: string;
    marginTop?: string;
    name?: string;
    /** Format: int64 */
    position: number;
    section?: components["schemas"]["CmsSection"];
    sectionId: string;
    sectionPosition?: string;
    slots?: components["schemas"]["CmsSlot"][];
    type: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
    visibility?: {
      desktop?: boolean;
      mobile?: boolean;
      tablet?: boolean;
    };
  };
  CmsBlockJsonApi: components["schemas"]["resource"] & {
    backgroundColor?: string;
    backgroundMediaId?: string;
    backgroundMediaMode?: string;
    cmsSectionVersionId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    cssClass?: string;
    customFields?: GenericRecord;
    extensions?: {
      swagCmsExtensionsBlockRule?: {
        data?: {
          /** @example c426e9e5d9031b933f89682d49bb02b1 */
          id?: string;
          /** @example swag_cms_extensions_block_rule */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /cms-block/9c16ffe823ddccc710bfb336c2ef30b6/swagCmsExtensionsBlockRule
           */
          related?: string;
        };
      };
      swagCmsExtensionsQuickview?: {
        data?: {
          /** @example fae098a43df8714eda5249176ffcf26c */
          id?: string;
          /** @example swag_cms_extensions_quickview */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /cms-block/9c16ffe823ddccc710bfb336c2ef30b6/swagCmsExtensionsQuickview
           */
          related?: string;
        };
      };
    };
    id: string;
    locked?: boolean;
    marginBottom?: string;
    marginLeft?: string;
    marginRight?: string;
    marginTop?: string;
    name?: string;
    /** Format: int64 */
    position: number;
    relationships?: {
      backgroundMedia?: {
        data?: {
          /** @example 9f63714a30b4d0292695bd4d27235a0b */
          id?: string;
          /** @example media */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /cms-block/9c16ffe823ddccc710bfb336c2ef30b6/backgroundMedia
           */
          related?: string;
        };
      };
      section?: {
        data?: {
          /** @example 73d5342eba070f636ac3246f319bf77f */
          id?: string;
          /** @example cms_section */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /cms-block/9c16ffe823ddccc710bfb336c2ef30b6/section
           */
          related?: string;
        };
      };
      slots?: {
        data?: {
          /** @example a8b72798beb911ae98c8c8907d45950a */
          id?: string;
          /** @example cms_slot */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /cms-block/9c16ffe823ddccc710bfb336c2ef30b6/slots
           */
          related?: string;
        };
      };
    };
    sectionId: string;
    sectionPosition?: string;
    type: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
    visibility?: {
      desktop?: boolean;
      mobile?: boolean;
      tablet?: boolean;
    };
  };
  CmsPage: {
    categories?: components["schemas"]["Category"][];
    config?: {
      backgroundColor?: string;
    };
    /** Format: date-time */
    readonly createdAt?: string;
    cssClass?: string;
    customFields?: GenericRecord;
    entity?: string;
    extensions?: {
      activities?: {
        data?: {
          /** @example 609f88983635a66fe4c8570afee066e0 */
          id?: string;
          /** @example cms_page_activity */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /cms-page/64bf107168bcd03626208c1764ce6890/activities
           */
          related?: string;
        };
      };
      createdBy?: {
        data?: {
          /** @example 34998857f537140306898d54d4b970dc */
          id?: string;
          /** @example user */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /cms-page/64bf107168bcd03626208c1764ce6890/createdBy
           */
          related?: string;
        };
      };
      drafts?: {
        data?: {
          /** @example 4a25fb4d024699c2d82bbd0a651eb766 */
          id?: string;
          /** @example cms_page_draft */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /cms-page/64bf107168bcd03626208c1764ce6890/drafts
           */
          related?: string;
        };
      };
      swagCmsExtensionsScrollNavigationPageSettings?: {
        data?: {
          /** @example 8b835206d09f3dec1b733f6a78c7ba33 */
          id?: string;
          /** @example swag_cms_extensions_scroll_navigation_page_settings */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /cms-page/64bf107168bcd03626208c1764ce6890/swagCmsExtensionsScrollNavigationPageSettings
           */
          related?: string;
        };
      };
    };
    homeSalesChannels?: components["schemas"]["SalesChannel"][];
    id: string;
    landingPages?: components["schemas"]["LandingPage"][];
    locked?: boolean;
    name?: string;
    previewMedia?: components["schemas"]["Media"];
    previewMediaId?: string;
    products?: components["schemas"]["Product"][];
    sections?: components["schemas"]["CmsSection"][];
    translated: {
      cssClass: string;
      entity: string;
      name: string;
      previewMediaId: string;
      type: string;
      versionId: string;
    };
    type: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  CmsPageActivity: {
    cmsPage?: components["schemas"]["CmsPage"];
    readonly cmsPageVersionId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    readonly details?: GenericRecord;
    readonly draftVersion?: string;
    id: string;
    readonly isDiscarded?: boolean;
    readonly isMerged?: boolean;
    readonly isReleasedAsNew?: boolean;
    readonly name?: string;
    readonly pageId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    user?: components["schemas"]["User"];
    readonly userId?: string;
  };
  CmsPageActivityJsonApi: components["schemas"]["resource"] & {
    readonly cmsPageVersionId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    readonly details?: GenericRecord;
    readonly draftVersion?: string;
    id: string;
    readonly isDiscarded?: boolean;
    readonly isMerged?: boolean;
    readonly isReleasedAsNew?: boolean;
    readonly name?: string;
    readonly pageId: string;
    relationships?: {
      cmsPage?: {
        data?: {
          /** @example 7b1460918b1abb93311108f3dc021c9b */
          id?: string;
          /** @example cms_page */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /cms-page-activity/83bfa4f502ca5ead8a54e16782b24f8d/cmsPage
           */
          related?: string;
        };
      };
      user?: {
        data?: {
          /** @example ee11cbb19052e40b07aac0ca060c23ee */
          id?: string;
          /** @example user */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /cms-page-activity/83bfa4f502ca5ead8a54e16782b24f8d/user
           */
          related?: string;
        };
      };
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    readonly userId?: string;
  };
  CmsPageDraft: {
    cmsPage?: components["schemas"]["CmsPage"];
    readonly cmsPageVersionId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    readonly deepLinkCode: string;
    readonly draftVersion: string;
    id: string;
    name: string;
    readonly ownerId?: string;
    readonly pageId: string;
    previewMedia?: components["schemas"]["Media"];
    readonly previewMediaId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    user?: components["schemas"]["User"];
  };
  CmsPageDraftJsonApi: components["schemas"]["resource"] & {
    readonly cmsPageVersionId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    readonly deepLinkCode: string;
    readonly draftVersion: string;
    id: string;
    name: string;
    readonly ownerId?: string;
    readonly pageId: string;
    readonly previewMediaId?: string;
    relationships?: {
      cmsPage?: {
        data?: {
          /** @example 7b1460918b1abb93311108f3dc021c9b */
          id?: string;
          /** @example cms_page */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /cms-page-draft/0478c327bbb2cd5c6f896c55a12e9961/cmsPage
           */
          related?: string;
        };
      };
      previewMedia?: {
        data?: {
          /** @example a7a817fb0e422cff87e878b8ff7ca914 */
          id?: string;
          /** @example media */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /cms-page-draft/0478c327bbb2cd5c6f896c55a12e9961/previewMedia
           */
          related?: string;
        };
      };
      user?: {
        data?: {
          /** @example ee11cbb19052e40b07aac0ca060c23ee */
          id?: string;
          /** @example user */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /cms-page-draft/0478c327bbb2cd5c6f896c55a12e9961/user
           */
          related?: string;
        };
      };
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  CmsPageJsonApi: components["schemas"]["resource"] & {
    config?: {
      backgroundColor?: string;
    };
    /** Format: date-time */
    readonly createdAt?: string;
    cssClass?: string;
    customFields?: GenericRecord;
    entity?: string;
    extensions?: {
      activities?: {
        data?: {
          /** @example 609f88983635a66fe4c8570afee066e0 */
          id?: string;
          /** @example cms_page_activity */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /cms-page/64bf107168bcd03626208c1764ce6890/activities
           */
          related?: string;
        };
      };
      createdBy?: {
        data?: {
          /** @example 34998857f537140306898d54d4b970dc */
          id?: string;
          /** @example user */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /cms-page/64bf107168bcd03626208c1764ce6890/createdBy
           */
          related?: string;
        };
      };
      drafts?: {
        data?: {
          /** @example 4a25fb4d024699c2d82bbd0a651eb766 */
          id?: string;
          /** @example cms_page_draft */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /cms-page/64bf107168bcd03626208c1764ce6890/drafts
           */
          related?: string;
        };
      };
      swagCmsExtensionsScrollNavigationPageSettings?: {
        data?: {
          /** @example 8b835206d09f3dec1b733f6a78c7ba33 */
          id?: string;
          /** @example swag_cms_extensions_scroll_navigation_page_settings */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /cms-page/64bf107168bcd03626208c1764ce6890/swagCmsExtensionsScrollNavigationPageSettings
           */
          related?: string;
        };
      };
    };
    id: string;
    locked?: boolean;
    name?: string;
    previewMediaId?: string;
    relationships?: {
      categories?: {
        data?: {
          /** @example b0b5ccb4a195a07fd3eed14affb8695f */
          id?: string;
          /** @example category */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /cms-page/64bf107168bcd03626208c1764ce6890/categories
           */
          related?: string;
        };
      };
      homeSalesChannels?: {
        data?: {
          /** @example 9aed0c38161f67f2d40a4a872cae045f */
          id?: string;
          /** @example sales_channel */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /cms-page/64bf107168bcd03626208c1764ce6890/homeSalesChannels
           */
          related?: string;
        };
      };
      landingPages?: {
        data?: {
          /** @example d60b77f2b3bd69591e3d5e3100926b4d */
          id?: string;
          /** @example landing_page */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /cms-page/64bf107168bcd03626208c1764ce6890/landingPages
           */
          related?: string;
        };
      };
      previewMedia?: {
        data?: {
          /** @example a7a817fb0e422cff87e878b8ff7ca914 */
          id?: string;
          /** @example media */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /cms-page/64bf107168bcd03626208c1764ce6890/previewMedia
           */
          related?: string;
        };
      };
      products?: {
        data?: {
          /** @example 86024cad1e83101d97359d7351051156 */
          id?: string;
          /** @example product */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /cms-page/64bf107168bcd03626208c1764ce6890/products
           */
          related?: string;
        };
      };
      sections?: {
        data?: {
          /** @example ff4dee88db82e98f0e0d524d965b9aa7 */
          id?: string;
          /** @example cms_section */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /cms-page/64bf107168bcd03626208c1764ce6890/sections
           */
          related?: string;
        };
      };
    };
    translated: {
      cssClass: string;
      entity: string;
      name: string;
      previewMediaId: string;
      type: string;
      versionId: string;
    };
    type: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  CmsSection: {
    backgroundColor?: string;
    backgroundMedia?: components["schemas"]["Media"];
    backgroundMediaId?: string;
    backgroundMediaMode?: string;
    blocks?: components["schemas"]["CmsBlock"][];
    cmsPageVersionId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    cssClass?: string;
    customFields?: GenericRecord;
    extensions?: {
      swagCmsExtensionsScrollNavigation?: {
        data?: {
          /** @example 425b8d6ec722d74191c6d39370af19dc */
          id?: string;
          /** @example swag_cms_extensions_scroll_navigation */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /cms-section/d08def49fa8924d6f4a32bdb448d5fba/swagCmsExtensionsScrollNavigation
           */
          related?: string;
        };
      };
    };
    id: string;
    locked?: boolean;
    mobileBehavior?: string;
    page?: components["schemas"]["CmsPage"];
    pageId: string;
    /** Format: int64 */
    position: number;
    sizingMode?: string;
    translated: {
      backgroundColor: string;
      backgroundMediaId: string;
      backgroundMediaMode: string;
      cmsPageVersionId: string;
      cssClass: string;
      mobileBehavior: string;
      pageId: string;
      sizingMode: string;
      type: string;
      versionId: string;
    };
    type: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
    visibility?: {
      desktop?: boolean;
      mobile?: boolean;
      tablet?: boolean;
    };
  };
  CmsSectionJsonApi: components["schemas"]["resource"] & {
    backgroundColor?: string;
    backgroundMediaId?: string;
    backgroundMediaMode?: string;
    cmsPageVersionId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    cssClass?: string;
    customFields?: GenericRecord;
    extensions?: {
      swagCmsExtensionsScrollNavigation?: {
        data?: {
          /** @example 425b8d6ec722d74191c6d39370af19dc */
          id?: string;
          /** @example swag_cms_extensions_scroll_navigation */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /cms-section/d08def49fa8924d6f4a32bdb448d5fba/swagCmsExtensionsScrollNavigation
           */
          related?: string;
        };
      };
    };
    id: string;
    locked?: boolean;
    mobileBehavior?: string;
    pageId: string;
    /** Format: int64 */
    position: number;
    relationships?: {
      backgroundMedia?: {
        data?: {
          /** @example 9f63714a30b4d0292695bd4d27235a0b */
          id?: string;
          /** @example media */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /cms-section/d08def49fa8924d6f4a32bdb448d5fba/backgroundMedia
           */
          related?: string;
        };
      };
      blocks?: {
        data?: {
          /** @example e734964953f880e5164e32827950ff92 */
          id?: string;
          /** @example cms_block */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /cms-section/d08def49fa8924d6f4a32bdb448d5fba/blocks
           */
          related?: string;
        };
      };
      page?: {
        data?: {
          /** @example 71860c77c6745379b0d44304d66b6a13 */
          id?: string;
          /** @example cms_page */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /cms-section/d08def49fa8924d6f4a32bdb448d5fba/page
           */
          related?: string;
        };
      };
    };
    sizingMode?: string;
    translated: {
      backgroundColor: string;
      backgroundMediaId: string;
      backgroundMediaMode: string;
      cmsPageVersionId: string;
      cssClass: string;
      mobileBehavior: string;
      pageId: string;
      sizingMode: string;
      type: string;
      versionId: string;
    };
    type: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
    visibility?: {
      desktop?: boolean;
      mobile?: boolean;
      tablet?: boolean;
    };
  };
  CmsSlot: {
    block?: components["schemas"]["CmsBlock"];
    blockId: string;
    cmsBlockVersionId?: string;
    config?: GenericRecord;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    readonly data?: GenericRecord;
    extensions?: {
      swagCmsExtensionsForm?: {
        data?: {
          /** @example 0654ad514da002e9d77fa24ee33acd95 */
          id?: string;
          /** @example swag_cms_extensions_form */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /cms-slot/ac5ca6960137c6b8a97c90c11b71d4bb/swagCmsExtensionsForm
           */
          related?: string;
        };
      };
    };
    fieldConfig?: GenericRecord;
    id: string;
    locked?: boolean;
    slot: string;
    translated: {
      blockId: string;
      cmsBlockVersionId: string;
      slot: string;
      type: string;
      versionId: string;
    };
    type: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  CmsSlotJsonApi: components["schemas"]["resource"] & {
    blockId: string;
    cmsBlockVersionId?: string;
    config?: GenericRecord;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    readonly data?: GenericRecord;
    extensions?: {
      swagCmsExtensionsForm?: {
        data?: {
          /** @example 0654ad514da002e9d77fa24ee33acd95 */
          id?: string;
          /** @example swag_cms_extensions_form */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /cms-slot/ac5ca6960137c6b8a97c90c11b71d4bb/swagCmsExtensionsForm
           */
          related?: string;
        };
      };
    };
    fieldConfig?: GenericRecord;
    id: string;
    locked?: boolean;
    relationships?: {
      block?: {
        data?: {
          /** @example 14511f2f5564650d129ca7cabc333278 */
          id?: string;
          /** @example cms_block */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /cms-slot/ac5ca6960137c6b8a97c90c11b71d4bb/block
           */
          related?: string;
        };
      };
    };
    slot: string;
    translated: {
      blockId: string;
      cmsBlockVersionId: string;
      slot: string;
      type: string;
      versionId: string;
    };
    type: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  Country: {
    active?: boolean;
    addressFormat: GenericRecord;
    advancedPostalCodePattern?: string;
    checkAdvancedPostalCodePattern?: boolean;
    checkPostalCodePattern?: boolean;
    checkVatIdPattern?: boolean;
    companyTax?: {
      /** Format: float */
      amount: number;
      currencyId: string;
      enabled: boolean;
    };
    /** Format: date-time */
    readonly createdAt?: string;
    currencyCountryRoundings?: components["schemas"]["CurrencyCountryRounding"][];
    customerAddresses?: components["schemas"]["CustomerAddress"][];
    customerTax?: {
      /** Format: float */
      amount: number;
      currencyId: string;
      enabled: boolean;
    };
    customFields?: GenericRecord;
    defaultPostalCodePattern?: string;
    displayStateInRegistration?: boolean;
    extensions?: {
      subscriptionCustomerAddresses?: {
        data?: {
          /** @example 8951627da0210d39cc55d1a91ae21b8d */
          id?: string;
          /** @example subscription_address */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /country/59716c97497eb9694541f7c3d37b1a4d/subscriptionCustomerAddresses
           */
          related?: string;
        };
      };
    };
    forceStateInRegistration?: boolean;
    id: string;
    isEu?: boolean;
    iso?: string;
    iso3?: string;
    name: string;
    orderAddresses?: components["schemas"]["OrderAddress"][];
    /** Format: int64 */
    position?: number;
    postalCodeRequired?: boolean;
    salesChannelDefaultAssignments?: components["schemas"]["SalesChannel"][];
    salesChannels?: components["schemas"]["SalesChannel"][];
    shippingAvailable?: boolean;
    states?: components["schemas"]["CountryState"][];
    taxRules?: components["schemas"]["TaxRule"][];
    translated: {
      advancedPostalCodePattern: string;
      defaultPostalCodePattern: string;
      iso: string;
      iso3: string;
      name: string;
      vatIdPattern: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    vatIdPattern?: string;
    vatIdRequired?: boolean;
  };
  CountryJsonApi: components["schemas"]["resource"] & {
    active?: boolean;
    addressFormat: GenericRecord;
    advancedPostalCodePattern?: string;
    checkAdvancedPostalCodePattern?: boolean;
    checkPostalCodePattern?: boolean;
    checkVatIdPattern?: boolean;
    companyTax?: {
      /** Format: float */
      amount: number;
      currencyId: string;
      enabled: boolean;
    };
    /** Format: date-time */
    readonly createdAt?: string;
    customerTax?: {
      /** Format: float */
      amount: number;
      currencyId: string;
      enabled: boolean;
    };
    customFields?: GenericRecord;
    defaultPostalCodePattern?: string;
    displayStateInRegistration?: boolean;
    extensions?: {
      subscriptionCustomerAddresses?: {
        data?: {
          /** @example 8951627da0210d39cc55d1a91ae21b8d */
          id?: string;
          /** @example subscription_address */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /country/59716c97497eb9694541f7c3d37b1a4d/subscriptionCustomerAddresses
           */
          related?: string;
        };
      };
    };
    forceStateInRegistration?: boolean;
    id: string;
    isEu?: boolean;
    iso?: string;
    iso3?: string;
    name: string;
    /** Format: int64 */
    position?: number;
    postalCodeRequired?: boolean;
    relationships?: {
      currencyCountryRoundings?: {
        data?: {
          /** @example 35ef8dd5459bf5f08d44cb278bf07cd4 */
          id?: string;
          /** @example currency_country_rounding */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /country/59716c97497eb9694541f7c3d37b1a4d/currencyCountryRoundings
           */
          related?: string;
        };
      };
      customerAddresses?: {
        data?: {
          /** @example 84ed5cbc10cd9f665a8c9f05e49095af */
          id?: string;
          /** @example customer_address */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /country/59716c97497eb9694541f7c3d37b1a4d/customerAddresses
           */
          related?: string;
        };
      };
      orderAddresses?: {
        data?: {
          /** @example c3182f0dc0cc20b4982616d3e0221747 */
          id?: string;
          /** @example order_address */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /country/59716c97497eb9694541f7c3d37b1a4d/orderAddresses
           */
          related?: string;
        };
      };
      salesChannelDefaultAssignments?: {
        data?: {
          /** @example b23663b2abc0909be9a8027a3fbff74b */
          id?: string;
          /** @example sales_channel */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /country/59716c97497eb9694541f7c3d37b1a4d/salesChannelDefaultAssignments
           */
          related?: string;
        };
      };
      salesChannels?: {
        data?: {
          /** @example 986f6f891e90ab91c091ff4a1a460777 */
          id?: string;
          /** @example sales_channel */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /country/59716c97497eb9694541f7c3d37b1a4d/salesChannels
           */
          related?: string;
        };
      };
      states?: {
        data?: {
          /** @example 34d955a0df5f7af9c9b4e4dccb3c3564 */
          id?: string;
          /** @example country_state */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /country/59716c97497eb9694541f7c3d37b1a4d/states
           */
          related?: string;
        };
      };
      taxRules?: {
        data?: {
          /** @example 1b93ada511aac379c19d3afcba4e4041 */
          id?: string;
          /** @example tax_rule */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /country/59716c97497eb9694541f7c3d37b1a4d/taxRules
           */
          related?: string;
        };
      };
    };
    shippingAvailable?: boolean;
    translated: {
      advancedPostalCodePattern: string;
      defaultPostalCodePattern: string;
      iso: string;
      iso3: string;
      name: string;
      vatIdPattern: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    vatIdPattern?: string;
    vatIdRequired?: boolean;
  };
  CountryState: {
    active?: boolean;
    country?: components["schemas"]["Country"];
    countryId: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customerAddresses?: components["schemas"]["CustomerAddress"][];
    customFields?: GenericRecord;
    extensions?: {
      subscriptionCustomerAddresses?: {
        data?: {
          /** @example 8951627da0210d39cc55d1a91ae21b8d */
          id?: string;
          /** @example subscription_address */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /country-state/e65d972da07a4e37b3d1f8c2f32d9c99/subscriptionCustomerAddresses
           */
          related?: string;
        };
      };
    };
    id: string;
    name: string;
    orderAddresses?: components["schemas"]["OrderAddress"][];
    /** Format: int64 */
    position?: number;
    shortCode: string;
    translated: {
      countryId: string;
      name: string;
      shortCode: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  CountryStateJsonApi: components["schemas"]["resource"] & {
    active?: boolean;
    countryId: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    extensions?: {
      subscriptionCustomerAddresses?: {
        data?: {
          /** @example 8951627da0210d39cc55d1a91ae21b8d */
          id?: string;
          /** @example subscription_address */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /country-state/e65d972da07a4e37b3d1f8c2f32d9c99/subscriptionCustomerAddresses
           */
          related?: string;
        };
      };
    };
    id: string;
    name: string;
    /** Format: int64 */
    position?: number;
    relationships?: {
      country?: {
        data?: {
          /** @example e909c2d7067ea37437cf97fe11d91bd0 */
          id?: string;
          /** @example country */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /country-state/e65d972da07a4e37b3d1f8c2f32d9c99/country
           */
          related?: string;
        };
      };
      customerAddresses?: {
        data?: {
          /** @example 84ed5cbc10cd9f665a8c9f05e49095af */
          id?: string;
          /** @example customer_address */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /country-state/e65d972da07a4e37b3d1f8c2f32d9c99/customerAddresses
           */
          related?: string;
        };
      };
      orderAddresses?: {
        data?: {
          /** @example c3182f0dc0cc20b4982616d3e0221747 */
          id?: string;
          /** @example order_address */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /country-state/e65d972da07a4e37b3d1f8c2f32d9c99/orderAddresses
           */
          related?: string;
        };
      };
    };
    shortCode: string;
    translated: {
      countryId: string;
      name: string;
      shortCode: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  Criteria: {
    /** Used to perform aggregations on the search result. For more information, see [Search Queries > Aggregations](https://shopware.stoplight.io/docs/store-api/docs/concepts/search-queries.md#aggregations) */
    aggregations?: components["schemas"]["Aggregations"];
    /** Used to fetch associations which are not fetched by default. */
    associations?: components["schemas"]["Association"];
    /** Fields which should be returned in the search result. */
    fields?: string[];
    /** List of filters to restrict the search result. For more information, see [Search Queries > Filter](https://shopware.stoplight.io/docs/store-api/docs/concepts/search-queries.md#filter) */
    filter?: (
      | {
          field: string;
          type: string;
          value: string;
        }
      | components["schemas"]["SimpleFilter"]
      | components["schemas"]["EqualsFilter"]
      | components["schemas"]["MultiNotFilter"]
      | components["schemas"]["RangeFilter"]
    )[];
    /** Perform groupings over certain fields */
    grouping?: string[];
    /** List of ids to search for */
    ids?: string[];
    includes?: components["schemas"]["Include"];
    /** Number of items per result page */
    limit?: number;
    /** Search result page */
    page?: number;
    /** Filters that applied without affecting aggregations. For more information, see [Search Queries > Post Filter](https://shopware.stoplight.io/docs/store-api/docs/concepts/search-queries.md#post-filter) */
    "post-filter"?: (
      | {
          field: string;
          type: string;
          value: string;
        }
      | components["schemas"]["SimpleFilter"]
      | components["schemas"]["EqualsFilter"]
      | components["schemas"]["MultiNotFilter"]
      | components["schemas"]["RangeFilter"]
    )[];
    /** The query string to search for */
    query?: string;
    /** Sorting in the search result. */
    sort?: {
      field: string;
      naturalSorting?: boolean;
      order?: string;
    }[];
    /**
     * Whether the total for the total number of hits should be determined for the search query. none = disabled total count, exact = calculate exact total amount (slow), next-pages = calculate only for next page (fast)
     * @default none
     * @enum {string}
     */
    "total-count-mode"?: "none" | "exact" | "next-pages";
  };
  Currency: {
    countryRoundings?: components["schemas"]["CurrencyCountryRounding"][];
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    extensions?: {
      quotes?: {
        data?: {
          /** @example 2150fd65034a9bcdb357943b3900a918 */
          id?: string;
          /** @example quote */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /currency/386c339d37e737a436499d423a77df0c/quotes
           */
          related?: string;
        };
      };
      socialShoppingSalesChannels?: {
        data?: {
          /** @example e581067f817be66449a3f4350dc327af */
          id?: string;
          /** @example swag_social_shopping_sales_channel */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /currency/386c339d37e737a436499d423a77df0c/socialShoppingSalesChannels
           */
          related?: string;
        };
      };
      subscriptions?: {
        data?: {
          /** @example 2d5d14f95af035cbd8437948de61f94c */
          id?: string;
          /** @example subscription */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /currency/386c339d37e737a436499d423a77df0c/subscriptions
           */
          related?: string;
        };
      };
    };
    /** Format: float */
    factor: number;
    id: string;
    isoCode: string;
    /** Runtime field, cannot be used as part of the criteria. */
    isSystemDefault?: boolean;
    itemRounding: {
      /** Format: int64 */
      decimals: number;
      /** Format: float */
      interval: number;
      roundForNet: boolean;
    };
    name: string;
    orders?: components["schemas"]["Order"][];
    /** Format: int64 */
    position?: number;
    productExports?: components["schemas"]["ProductExport"][];
    promotionDiscountPrices?: components["schemas"]["PromotionDiscountPrices"][];
    salesChannelDefaultAssignments?: components["schemas"]["SalesChannel"][];
    salesChannelDomains?: components["schemas"]["SalesChannelDomain"][];
    salesChannels?: components["schemas"]["SalesChannel"][];
    shortName: string;
    symbol: string;
    /** Format: float */
    taxFreeFrom?: number;
    totalRounding: {
      /** Format: int64 */
      decimals: number;
      /** Format: float */
      interval: number;
      roundForNet: boolean;
    };
    translated: {
      isoCode: string;
      name: string;
      shortName: string;
      symbol: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  CurrencyCountryRounding: {
    country?: components["schemas"]["Country"];
    countryId: string;
    /** Format: date-time */
    readonly createdAt?: string;
    currency?: components["schemas"]["Currency"];
    currencyId: string;
    id: string;
    itemRounding: {
      /** Format: int64 */
      decimals: number;
      /** Format: float */
      interval: number;
      roundForNet: boolean;
    };
    totalRounding: {
      /** Format: int64 */
      decimals: number;
      /** Format: float */
      interval: number;
      roundForNet: boolean;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  CurrencyCountryRoundingJsonApi: components["schemas"]["resource"] & {
    countryId: string;
    /** Format: date-time */
    readonly createdAt?: string;
    currencyId: string;
    id: string;
    itemRounding: {
      /** Format: int64 */
      decimals: number;
      /** Format: float */
      interval: number;
      roundForNet: boolean;
    };
    relationships?: {
      country?: {
        data?: {
          /** @example e909c2d7067ea37437cf97fe11d91bd0 */
          id?: string;
          /** @example country */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /currency-country-rounding/1d1957074c6776cfcf655c28fc42dc64/country
           */
          related?: string;
        };
      };
      currency?: {
        data?: {
          /** @example 1af0389838508d7016a9841eb6273962 */
          id?: string;
          /** @example currency */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /currency-country-rounding/1d1957074c6776cfcf655c28fc42dc64/currency
           */
          related?: string;
        };
      };
    };
    totalRounding: {
      /** Format: int64 */
      decimals: number;
      /** Format: float */
      interval: number;
      roundForNet: boolean;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  CurrencyJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    extensions?: {
      quotes?: {
        data?: {
          /** @example 2150fd65034a9bcdb357943b3900a918 */
          id?: string;
          /** @example quote */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /currency/386c339d37e737a436499d423a77df0c/quotes
           */
          related?: string;
        };
      };
      socialShoppingSalesChannels?: {
        data?: {
          /** @example e581067f817be66449a3f4350dc327af */
          id?: string;
          /** @example swag_social_shopping_sales_channel */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /currency/386c339d37e737a436499d423a77df0c/socialShoppingSalesChannels
           */
          related?: string;
        };
      };
      subscriptions?: {
        data?: {
          /** @example 2d5d14f95af035cbd8437948de61f94c */
          id?: string;
          /** @example subscription */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /currency/386c339d37e737a436499d423a77df0c/subscriptions
           */
          related?: string;
        };
      };
    };
    /** Format: float */
    factor: number;
    id: string;
    isoCode: string;
    /** Runtime field, cannot be used as part of the criteria. */
    isSystemDefault?: boolean;
    itemRounding: {
      /** Format: int64 */
      decimals: number;
      /** Format: float */
      interval: number;
      roundForNet: boolean;
    };
    name: string;
    /** Format: int64 */
    position?: number;
    relationships?: {
      countryRoundings?: {
        data?: {
          /** @example 3de4aa80c8c8822ea10d156a6f58d6f7 */
          id?: string;
          /** @example currency_country_rounding */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /currency/386c339d37e737a436499d423a77df0c/countryRoundings
           */
          related?: string;
        };
      };
      orders?: {
        data?: {
          /** @example 12c500ed0b7879105fb46af0f246be87 */
          id?: string;
          /** @example order */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /currency/386c339d37e737a436499d423a77df0c/orders
           */
          related?: string;
        };
      };
      productExports?: {
        data?: {
          /** @example 2cd8793787cda582174c0fc329fbc377 */
          id?: string;
          /** @example product_export */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /currency/386c339d37e737a436499d423a77df0c/productExports
           */
          related?: string;
        };
      };
      promotionDiscountPrices?: {
        data?: {
          /** @example 325723473ecab76b0f45e1554513f779 */
          id?: string;
          /** @example promotion_discount_prices */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /currency/386c339d37e737a436499d423a77df0c/promotionDiscountPrices
           */
          related?: string;
        };
      };
      salesChannelDefaultAssignments?: {
        data?: {
          /** @example b23663b2abc0909be9a8027a3fbff74b */
          id?: string;
          /** @example sales_channel */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /currency/386c339d37e737a436499d423a77df0c/salesChannelDefaultAssignments
           */
          related?: string;
        };
      };
      salesChannelDomains?: {
        data?: {
          /** @example b60ab8d110194bfe34ef9928ba48ab6d */
          id?: string;
          /** @example sales_channel_domain */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /currency/386c339d37e737a436499d423a77df0c/salesChannelDomains
           */
          related?: string;
        };
      };
      salesChannels?: {
        data?: {
          /** @example 986f6f891e90ab91c091ff4a1a460777 */
          id?: string;
          /** @example sales_channel */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /currency/386c339d37e737a436499d423a77df0c/salesChannels
           */
          related?: string;
        };
      };
    };
    shortName: string;
    symbol: string;
    /** Format: float */
    taxFreeFrom?: number;
    totalRounding: {
      /** Format: int64 */
      decimals: number;
      /** Format: float */
      interval: number;
      roundForNet: boolean;
    };
    translated: {
      isoCode: string;
      name: string;
      shortName: string;
      symbol: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  CustomEntity: {
    appId?: string;
    /** Runtime field, cannot be used as part of the criteria. */
    cmsAware?: boolean;
    /** Format: date-time */
    readonly createdAt?: string;
    customFieldsAware?: boolean;
    /** Format: date-time */
    deletedAt?: string;
    fields: GenericRecord;
    flags?: GenericRecord;
    id: string;
    labelProperty?: string;
    name: string;
    pluginId?: string;
    /** Runtime field, cannot be used as part of the criteria. */
    storeApiAware?: boolean;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  CustomEntityJsonApi: components["schemas"]["resource"] & {
    appId?: string;
    /** Runtime field, cannot be used as part of the criteria. */
    cmsAware?: boolean;
    /** Format: date-time */
    readonly createdAt?: string;
    customFieldsAware?: boolean;
    /** Format: date-time */
    deletedAt?: string;
    fields: GenericRecord;
    flags?: GenericRecord;
    id: string;
    labelProperty?: string;
    name: string;
    pluginId?: string;
    /** Runtime field, cannot be used as part of the criteria. */
    storeApiAware?: boolean;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  CustomField: {
    active?: boolean;
    allowCartExpose?: boolean;
    allowCustomerWrite?: boolean;
    config?: GenericRecord;
    /** Format: date-time */
    readonly createdAt?: string;
    customFieldSet?: components["schemas"]["CustomFieldSet"];
    customFieldSetId?: string;
    id: string;
    name: string;
    productSearchConfigFields?: components["schemas"]["ProductSearchConfigField"][];
    type: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  CustomFieldJsonApi: components["schemas"]["resource"] & {
    active?: boolean;
    allowCartExpose?: boolean;
    allowCustomerWrite?: boolean;
    config?: GenericRecord;
    /** Format: date-time */
    readonly createdAt?: string;
    customFieldSetId?: string;
    id: string;
    name: string;
    relationships?: {
      customFieldSet?: {
        data?: {
          /** @example df17e58b74fa5cb09c5e84f3b37141e1 */
          id?: string;
          /** @example custom_field_set */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /custom-field/8c9d2c73a2f564420ef091ee69b564b9/customFieldSet
           */
          related?: string;
        };
      };
      productSearchConfigFields?: {
        data?: {
          /** @example ae6a70432f71d6905502769f184399b1 */
          id?: string;
          /** @example product_search_config_field */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /custom-field/8c9d2c73a2f564420ef091ee69b564b9/productSearchConfigFields
           */
          related?: string;
        };
      };
    };
    type: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  CustomFieldSet: {
    active?: boolean;
    app?: components["schemas"]["App"];
    appId?: string;
    config?: GenericRecord;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: components["schemas"]["CustomField"][];
    global?: boolean;
    id: string;
    name: string;
    /** Format: int64 */
    position?: number;
    products?: components["schemas"]["Product"][];
    relations?: components["schemas"]["CustomFieldSetRelation"][];
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  CustomFieldSetJsonApi: components["schemas"]["resource"] & {
    active?: boolean;
    appId?: string;
    config?: GenericRecord;
    /** Format: date-time */
    readonly createdAt?: string;
    global?: boolean;
    id: string;
    name: string;
    /** Format: int64 */
    position?: number;
    relationships?: {
      app?: {
        data?: {
          /** @example d2a57dc1d883fd21fb9951699df71cc7 */
          id?: string;
          /** @example app */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /custom-field-set/9f7fdf62a1b51e5a8e6f99cb5e5e86b1/app
           */
          related?: string;
        };
      };
      customFields?: {
        data?: {
          /** @example 4e252ff73243c27b4df9002e452fc6a7 */
          id?: string;
          /** @example custom_field */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /custom-field-set/9f7fdf62a1b51e5a8e6f99cb5e5e86b1/customFields
           */
          related?: string;
        };
      };
      products?: {
        data?: {
          /** @example 86024cad1e83101d97359d7351051156 */
          id?: string;
          /** @example product */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /custom-field-set/9f7fdf62a1b51e5a8e6f99cb5e5e86b1/products
           */
          related?: string;
        };
      };
      relations?: {
        data?: {
          /** @example 06c5b10273a69992d8c6933e294909fa */
          id?: string;
          /** @example custom_field_set_relation */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /custom-field-set/9f7fdf62a1b51e5a8e6f99cb5e5e86b1/relations
           */
          related?: string;
        };
      };
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  CustomFieldSetRelation: {
    /** Format: date-time */
    readonly createdAt?: string;
    customFieldSet?: components["schemas"]["CustomFieldSet"];
    customFieldSetId: string;
    entityName: string;
    id: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  CustomFieldSetRelationJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    customFieldSetId: string;
    entityName: string;
    id: string;
    relationships?: {
      customFieldSet?: {
        data?: {
          /** @example df17e58b74fa5cb09c5e84f3b37141e1 */
          id?: string;
          /** @example custom_field_set */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /custom-field-set-relation/9686e510825802f328b6a861ccaa977e/customFieldSet
           */
          related?: string;
        };
      };
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  CustomPrice: {
    /** Format: date-time */
    readonly createdAt?: string;
    customer?: components["schemas"]["Customer"];
    customerGroup?: components["schemas"]["CustomerGroup"];
    customerGroupId?: string;
    customerId?: string;
    id: string;
    price: GenericRecord;
    product?: components["schemas"]["Product"];
    productId: string;
    productVersionId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  CustomPriceJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    customerGroupId?: string;
    customerId?: string;
    id: string;
    price: GenericRecord;
    productId: string;
    productVersionId?: string;
    relationships?: {
      customer?: {
        data?: {
          /** @example 91ec1f9324753048c0096d036a694f86 */
          id?: string;
          /** @example customer */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /custom-price/15ffcf0a24168224e50e7fa559015d05/customer
           */
          related?: string;
        };
      };
      customerGroup?: {
        data?: {
          /** @example 115091b01a7299f28a5ce7e1b712a222 */
          id?: string;
          /** @example customer_group */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /custom-price/15ffcf0a24168224e50e7fa559015d05/customerGroup
           */
          related?: string;
        };
      };
      product?: {
        data?: {
          /** @example f5bf48aa40cad7891eb709fcf1fde128 */
          id?: string;
          /** @example product */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /custom-price/15ffcf0a24168224e50e7fa559015d05/product
           */
          related?: string;
        };
      };
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  CustomPricingDeleteOperation: {
    /**
     * A specific verb defining what operation should be actioned for a specific data record
     * @enum {string}
     */
    action: "delete";
    /** Contains a list of changesets for an entity. If the action type is `delete`,
     *         a list of identifiers can be provided. */
    payload: (string[] | string[] | string[])[];
  };
  CustomPricingPrice: {
    price: {
      currencyId: string;
      gross: number;
      linked: boolean;
      listPrice?: {
        gross?: number;
        linked?: boolean;
        net?: number;
      };
      net: number;
      regulationPrice?: {
        gross?: number;
        linked?: boolean;
        net?: number;
      };
    }[];
    /** Format: int64 */
    quantityEnd?: number;
    /** Format: int64 */
    quantityStart: number;
  };
  CustomPricingResponse: {
    data: {
      extensions?: GenericRecord[];
      result?: {
        entities: [] | [string];
        /** A detailed error list addressing specific points in which sync payload does not meet system expectations (data types, structure etc.) */
        errors: string[];
      }[];
    }[];
    success: boolean;
  };
  CustomPricingUpsertOperation: {
    /**
     * A specific verb defining what operation should be actioned for a specific data record
     * @enum {string}
     */
    action: "upsert";
    /** Contains a list of changesets for an entity. If the action type is `delete`,
     *         a list of identifiers can be provided. */
    payload: {
      /** This parameter should be specified, or 'customerId', not both */
      customerGroupId?: string;
      /** This parameter should be specified, or 'customerGroupId', not both */
      customerId?: string;
      id?: string;
      price?: components["schemas"]["CustomPricingPrice"][];
      productId: string;
      productVersionId?: string;
    }[];
  };
  Customer: {
    accountType?: string;
    active?: boolean;
    addresses?: components["schemas"]["CustomerAddress"][];
    affiliateCode?: string;
    /** Format: int64 */
    readonly autoIncrement?: number;
    birthday?: string;
    boundSalesChannel?: components["schemas"]["SalesChannel"];
    boundSalesChannelId?: string;
    campaignCode?: string;
    company?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    createdBy?: components["schemas"]["User"];
    createdById?: string;
    customerNumber: string;
    customFields?: GenericRecord;
    defaultBillingAddress?: components["schemas"]["CustomerAddress"];
    defaultBillingAddressId: string;
    defaultPaymentMethod?: components["schemas"]["PaymentMethod"];
    defaultPaymentMethodId: string;
    defaultShippingAddress?: components["schemas"]["CustomerAddress"];
    defaultShippingAddressId: string;
    /** Format: date-time */
    doubleOptInConfirmDate?: string;
    /** Format: date-time */
    doubleOptInEmailSentDate?: string;
    doubleOptInRegistration?: boolean;
    email: string;
    extensions?: {
      attendee?: {
        data?: {
          /** @example b7ce8294183a0f2a6092b6cb2f17b9b5 */
          id?: string;
          /** @example dsr_appointment_attendee */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /customer/ce26601dac0dea138b7295f02b7620a7/attendee
           */
          related?: string;
        };
      };
      b2bBusinessPartner?: {
        data?: {
          /** @example c1736d678c9ca2f952db2f7894193bf3 */
          id?: string;
          /** @example b2b_business_partner */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /customer/ce26601dac0dea138b7295f02b7620a7/b2bBusinessPartner
           */
          related?: string;
        };
      };
      customPrice?: {
        data?: {
          /** @example 35ed8bfa9c73171a7b417f13ab07d57a */
          id?: string;
          /** @example custom_price */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /customer/ce26601dac0dea138b7295f02b7620a7/customPrice
           */
          related?: string;
        };
      };
      delayActions?: {
        data?: {
          /** @example edfed55799054673006c4b5a643489ac */
          id?: string;
          /** @example swag_delay_action */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /customer/ce26601dac0dea138b7295f02b7620a7/delayActions
           */
          related?: string;
        };
      };
      employees?: {
        data?: {
          /** @example 582ca3f7cbaf4edcc1b445f8ea90b503 */
          id?: string;
          /** @example b2b_employee */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /customer/ce26601dac0dea138b7295f02b7620a7/employees
           */
          related?: string;
        };
      };
      paypalVaultTokenMappings?: {
        data?: {
          /** @example 75fb7d13a771c74947402295ed591499 */
          id?: string;
          /** @example swag_paypal_vault_token_mapping */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /customer/ce26601dac0dea138b7295f02b7620a7/paypalVaultTokenMappings
           */
          related?: string;
        };
      };
      paypalVaultTokens?: {
        data?: {
          /** @example 7e423eeb595163d20591951433de150c */
          id?: string;
          /** @example swag_paypal_vault_token */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /customer/ce26601dac0dea138b7295f02b7620a7/paypalVaultTokens
           */
          related?: string;
        };
      };
      quoteComments?: {
        data?: {
          /** @example 98dec49a83119c512f84645e81ea52d8 */
          id?: string;
          /** @example quote_comment */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /customer/ce26601dac0dea138b7295f02b7620a7/quoteComments
           */
          related?: string;
        };
      };
      quotes?: {
        data?: {
          /** @example 2150fd65034a9bcdb357943b3900a918 */
          id?: string;
          /** @example quote */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /customer/ce26601dac0dea138b7295f02b7620a7/quotes
           */
          related?: string;
        };
      };
      roles?: {
        data?: {
          /** @example 4295e8065f2f640103f566df3329e17f */
          id?: string;
          /** @example b2b_components_role */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /customer/ce26601dac0dea138b7295f02b7620a7/roles
           */
          related?: string;
        };
      };
      specificFeatures?: {
        data?: {
          /** @example 5cfb6fcb7542e25892e1a35cd6a06c54 */
          id?: string;
          /** @example customer_specific_features */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /customer/ce26601dac0dea138b7295f02b7620a7/specificFeatures
           */
          related?: string;
        };
      };
      ssoProviderCustomers?: {
        data?: {
          /** @example 6f2bd941c85a0835cd1889fd0a2c835a */
          id?: string;
          /** @example sso_provider_customer */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /customer/ce26601dac0dea138b7295f02b7620a7/ssoProviderCustomers
           */
          related?: string;
        };
      };
      subscriptionCustomers?: {
        data?: {
          /** @example ee8811605866488e8f21308857e1e5a8 */
          id?: string;
          /** @example subscription_customer */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /customer/ce26601dac0dea138b7295f02b7620a7/subscriptionCustomers
           */
          related?: string;
        };
      };
      swagSocialShoppingCustomer?: {
        data?: {
          /** @example 70825a5dfabd078bce265301ba7d9cca */
          id?: string;
          /** @example swag_social_shopping_customer */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /customer/ce26601dac0dea138b7295f02b7620a7/swagSocialShoppingCustomer
           */
          related?: string;
        };
      };
    };
    /** Format: date-time */
    firstLogin?: string;
    firstName: string;
    group?: components["schemas"]["CustomerGroup"];
    groupId: string;
    guest?: boolean;
    hash?: string;
    id: string;
    language?: components["schemas"]["Language"];
    languageId: string;
    /** Format: date-time */
    lastLogin?: string;
    lastName: string;
    /** Format: date-time */
    readonly lastOrderDate?: string;
    lastPaymentMethod?: components["schemas"]["PaymentMethod"];
    lastPaymentMethodId?: string;
    /** Format: int64 */
    readonly orderCount?: number;
    orderCustomers?: components["schemas"]["OrderCustomer"][];
    /** Format: float */
    readonly orderTotalAmount?: number;
    productReviews?: components["schemas"]["ProductReview"][];
    promotions?: components["schemas"]["Promotion"][];
    recoveryCustomer?: components["schemas"]["CustomerRecovery"];
    remoteAddress?: string;
    requestedGroup?: components["schemas"]["CustomerGroup"];
    requestedGroupId?: string;
    /** Format: int64 */
    readonly reviewCount?: number;
    salesChannel?: components["schemas"]["SalesChannel"];
    salesChannelId: string;
    salutation?: components["schemas"]["Salutation"];
    salutationId?: string;
    readonly tagIds?: string[];
    tags?: components["schemas"]["Tag"][];
    title?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    updatedBy?: components["schemas"]["User"];
    updatedById?: string;
    vatIds?: string[];
    wishlists?: components["schemas"]["CustomerWishlist"][];
  };
  CustomerAddress: {
    additionalAddressLine1?: string;
    additionalAddressLine2?: string;
    city: string;
    company?: string;
    country?: components["schemas"]["Country"];
    countryId: string;
    countryState?: components["schemas"]["CountryState"];
    countryStateId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customer?: components["schemas"]["Customer"];
    customerId: string;
    customFields?: GenericRecord;
    department?: string;
    firstName: string;
    id: string;
    lastName: string;
    phoneNumber?: string;
    salutation?: components["schemas"]["Salutation"];
    salutationId?: string;
    street: string;
    title?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    zipcode?: string;
  };
  CustomerAddressJsonApi: components["schemas"]["resource"] & {
    additionalAddressLine1?: string;
    additionalAddressLine2?: string;
    city: string;
    company?: string;
    countryId: string;
    countryStateId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customerId: string;
    customFields?: GenericRecord;
    department?: string;
    firstName: string;
    id: string;
    lastName: string;
    phoneNumber?: string;
    relationships?: {
      country?: {
        data?: {
          /** @example e909c2d7067ea37437cf97fe11d91bd0 */
          id?: string;
          /** @example country */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /customer-address/1b4b031005f93d02d887e7d66efb653b/country
           */
          related?: string;
        };
      };
      countryState?: {
        data?: {
          /** @example cb6a9764567191fb74fe28d8d6a4819d */
          id?: string;
          /** @example country_state */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /customer-address/1b4b031005f93d02d887e7d66efb653b/countryState
           */
          related?: string;
        };
      };
      customer?: {
        data?: {
          /** @example 91ec1f9324753048c0096d036a694f86 */
          id?: string;
          /** @example customer */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /customer-address/1b4b031005f93d02d887e7d66efb653b/customer
           */
          related?: string;
        };
      };
      salutation?: {
        data?: {
          /** @example 7a6efb02514153b5aa9a8f40c6f8bcc3 */
          id?: string;
          /** @example salutation */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /customer-address/1b4b031005f93d02d887e7d66efb653b/salutation
           */
          related?: string;
        };
      };
    };
    salutationId?: string;
    street: string;
    title?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    zipcode?: string;
  };
  CustomerGroup: {
    /** Format: date-time */
    readonly createdAt?: string;
    customers?: components["schemas"]["Customer"][];
    customFields?: GenericRecord;
    displayGross?: boolean;
    extensions?: {
      customPrice?: {
        data?: {
          /** @example 35ed8bfa9c73171a7b417f13ab07d57a */
          id?: string;
          /** @example custom_price */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /customer-group/2c5176146d938e15c9f0e3d5203c19bf/customPrice
           */
          related?: string;
        };
      };
    };
    id: string;
    name: string;
    registrationActive?: boolean;
    registrationIntroduction?: string;
    registrationOnlyCompanyRegistration?: boolean;
    registrationSalesChannels?: components["schemas"]["SalesChannel"][];
    registrationSeoMetaDescription?: string;
    registrationTitle?: string;
    salesChannels?: components["schemas"]["SalesChannel"][];
    translated: {
      name: string;
      registrationIntroduction: string;
      registrationSeoMetaDescription: string;
      registrationTitle: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  CustomerGroupJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    displayGross?: boolean;
    extensions?: {
      customPrice?: {
        data?: {
          /** @example 35ed8bfa9c73171a7b417f13ab07d57a */
          id?: string;
          /** @example custom_price */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /customer-group/2c5176146d938e15c9f0e3d5203c19bf/customPrice
           */
          related?: string;
        };
      };
    };
    id: string;
    name: string;
    registrationActive?: boolean;
    registrationIntroduction?: string;
    registrationOnlyCompanyRegistration?: boolean;
    registrationSeoMetaDescription?: string;
    registrationTitle?: string;
    relationships?: {
      customers?: {
        data?: {
          /** @example 4b6f7d34a58ba399f077685951d06738 */
          id?: string;
          /** @example customer */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /customer-group/2c5176146d938e15c9f0e3d5203c19bf/customers
           */
          related?: string;
        };
      };
      registrationSalesChannels?: {
        data?: {
          /** @example ffc8e76c1fe257d563b9d0024a50620b */
          id?: string;
          /** @example sales_channel */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /customer-group/2c5176146d938e15c9f0e3d5203c19bf/registrationSalesChannels
           */
          related?: string;
        };
      };
      salesChannels?: {
        data?: {
          /** @example 986f6f891e90ab91c091ff4a1a460777 */
          id?: string;
          /** @example sales_channel */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /customer-group/2c5176146d938e15c9f0e3d5203c19bf/salesChannels
           */
          related?: string;
        };
      };
    };
    translated: {
      name: string;
      registrationIntroduction: string;
      registrationSeoMetaDescription: string;
      registrationTitle: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  CustomerGroupRegistrationSalesChannels: {
    /** Format: date-time */
    readonly createdAt?: string;
    customerGroup?: components["schemas"]["CustomerGroup"];
    customerGroupId: string;
    id?: string;
    salesChannel?: components["schemas"]["SalesChannel"];
    salesChannelId: string;
  };
  CustomerJsonApi: components["schemas"]["resource"] & {
    accountType?: string;
    active?: boolean;
    affiliateCode?: string;
    /** Format: int64 */
    readonly autoIncrement?: number;
    birthday?: string;
    boundSalesChannelId?: string;
    campaignCode?: string;
    company?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    createdById?: string;
    customerNumber: string;
    customFields?: GenericRecord;
    defaultBillingAddressId: string;
    defaultPaymentMethodId: string;
    defaultShippingAddressId: string;
    /** Format: date-time */
    doubleOptInConfirmDate?: string;
    /** Format: date-time */
    doubleOptInEmailSentDate?: string;
    doubleOptInRegistration?: boolean;
    email: string;
    extensions?: {
      attendee?: {
        data?: {
          /** @example b7ce8294183a0f2a6092b6cb2f17b9b5 */
          id?: string;
          /** @example dsr_appointment_attendee */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /customer/ce26601dac0dea138b7295f02b7620a7/attendee
           */
          related?: string;
        };
      };
      b2bBusinessPartner?: {
        data?: {
          /** @example c1736d678c9ca2f952db2f7894193bf3 */
          id?: string;
          /** @example b2b_business_partner */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /customer/ce26601dac0dea138b7295f02b7620a7/b2bBusinessPartner
           */
          related?: string;
        };
      };
      customPrice?: {
        data?: {
          /** @example 35ed8bfa9c73171a7b417f13ab07d57a */
          id?: string;
          /** @example custom_price */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /customer/ce26601dac0dea138b7295f02b7620a7/customPrice
           */
          related?: string;
        };
      };
      delayActions?: {
        data?: {
          /** @example edfed55799054673006c4b5a643489ac */
          id?: string;
          /** @example swag_delay_action */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /customer/ce26601dac0dea138b7295f02b7620a7/delayActions
           */
          related?: string;
        };
      };
      employees?: {
        data?: {
          /** @example 582ca3f7cbaf4edcc1b445f8ea90b503 */
          id?: string;
          /** @example b2b_employee */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /customer/ce26601dac0dea138b7295f02b7620a7/employees
           */
          related?: string;
        };
      };
      paypalVaultTokenMappings?: {
        data?: {
          /** @example 75fb7d13a771c74947402295ed591499 */
          id?: string;
          /** @example swag_paypal_vault_token_mapping */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /customer/ce26601dac0dea138b7295f02b7620a7/paypalVaultTokenMappings
           */
          related?: string;
        };
      };
      paypalVaultTokens?: {
        data?: {
          /** @example 7e423eeb595163d20591951433de150c */
          id?: string;
          /** @example swag_paypal_vault_token */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /customer/ce26601dac0dea138b7295f02b7620a7/paypalVaultTokens
           */
          related?: string;
        };
      };
      quoteComments?: {
        data?: {
          /** @example 98dec49a83119c512f84645e81ea52d8 */
          id?: string;
          /** @example quote_comment */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /customer/ce26601dac0dea138b7295f02b7620a7/quoteComments
           */
          related?: string;
        };
      };
      quotes?: {
        data?: {
          /** @example 2150fd65034a9bcdb357943b3900a918 */
          id?: string;
          /** @example quote */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /customer/ce26601dac0dea138b7295f02b7620a7/quotes
           */
          related?: string;
        };
      };
      roles?: {
        data?: {
          /** @example 4295e8065f2f640103f566df3329e17f */
          id?: string;
          /** @example b2b_components_role */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /customer/ce26601dac0dea138b7295f02b7620a7/roles
           */
          related?: string;
        };
      };
      specificFeatures?: {
        data?: {
          /** @example 5cfb6fcb7542e25892e1a35cd6a06c54 */
          id?: string;
          /** @example customer_specific_features */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /customer/ce26601dac0dea138b7295f02b7620a7/specificFeatures
           */
          related?: string;
        };
      };
      ssoProviderCustomers?: {
        data?: {
          /** @example 6f2bd941c85a0835cd1889fd0a2c835a */
          id?: string;
          /** @example sso_provider_customer */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /customer/ce26601dac0dea138b7295f02b7620a7/ssoProviderCustomers
           */
          related?: string;
        };
      };
      subscriptionCustomers?: {
        data?: {
          /** @example ee8811605866488e8f21308857e1e5a8 */
          id?: string;
          /** @example subscription_customer */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /customer/ce26601dac0dea138b7295f02b7620a7/subscriptionCustomers
           */
          related?: string;
        };
      };
      swagSocialShoppingCustomer?: {
        data?: {
          /** @example 70825a5dfabd078bce265301ba7d9cca */
          id?: string;
          /** @example swag_social_shopping_customer */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /customer/ce26601dac0dea138b7295f02b7620a7/swagSocialShoppingCustomer
           */
          related?: string;
        };
      };
    };
    /** Format: date-time */
    firstLogin?: string;
    firstName: string;
    groupId: string;
    guest?: boolean;
    hash?: string;
    id: string;
    languageId: string;
    /** Format: date-time */
    lastLogin?: string;
    lastName: string;
    /** Format: date-time */
    readonly lastOrderDate?: string;
    lastPaymentMethodId?: string;
    /** Format: int64 */
    readonly orderCount?: number;
    /** Format: float */
    readonly orderTotalAmount?: number;
    relationships?: {
      addresses?: {
        data?: {
          /** @example 963e3a2fe559e393bad631f3dc686f69 */
          id?: string;
          /** @example customer_address */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /customer/ce26601dac0dea138b7295f02b7620a7/addresses
           */
          related?: string;
        };
      };
      boundSalesChannel?: {
        data?: {
          /** @example dfe8aec35136b1f62669b388a291a4c7 */
          id?: string;
          /** @example sales_channel */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /customer/ce26601dac0dea138b7295f02b7620a7/boundSalesChannel
           */
          related?: string;
        };
      };
      createdBy?: {
        data?: {
          /** @example 34998857f537140306898d54d4b970dc */
          id?: string;
          /** @example user */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /customer/ce26601dac0dea138b7295f02b7620a7/createdBy
           */
          related?: string;
        };
      };
      defaultBillingAddress?: {
        data?: {
          /** @example 263d0f6e5d8d71fc4c288736f7c90990 */
          id?: string;
          /** @example customer_address */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /customer/ce26601dac0dea138b7295f02b7620a7/defaultBillingAddress
           */
          related?: string;
        };
      };
      defaultPaymentMethod?: {
        data?: {
          /** @example 8f35e31802b72bf010a333999b26f3a6 */
          id?: string;
          /** @example payment_method */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /customer/ce26601dac0dea138b7295f02b7620a7/defaultPaymentMethod
           */
          related?: string;
        };
      };
      defaultShippingAddress?: {
        data?: {
          /** @example 8218c377171d06883caea7e2baf67f31 */
          id?: string;
          /** @example customer_address */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /customer/ce26601dac0dea138b7295f02b7620a7/defaultShippingAddress
           */
          related?: string;
        };
      };
      group?: {
        data?: {
          /** @example db0f6f37ebeb6ea09489124345af2a45 */
          id?: string;
          /** @example customer_group */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /customer/ce26601dac0dea138b7295f02b7620a7/group
           */
          related?: string;
        };
      };
      language?: {
        data?: {
          /** @example 8512ae7d57b1396273f76fe6ed341a23 */
          id?: string;
          /** @example language */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /customer/ce26601dac0dea138b7295f02b7620a7/language
           */
          related?: string;
        };
      };
      lastPaymentMethod?: {
        data?: {
          /** @example bb083200005a374b86f6f5fbbff6f0e0 */
          id?: string;
          /** @example payment_method */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /customer/ce26601dac0dea138b7295f02b7620a7/lastPaymentMethod
           */
          related?: string;
        };
      };
      orderCustomers?: {
        data?: {
          /** @example 1e7dbe7e3bcb48d233fd80588f54c980 */
          id?: string;
          /** @example order_customer */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /customer/ce26601dac0dea138b7295f02b7620a7/orderCustomers
           */
          related?: string;
        };
      };
      productReviews?: {
        data?: {
          /** @example 01e78541ea343ed72424a5222796a4cd */
          id?: string;
          /** @example product_review */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /customer/ce26601dac0dea138b7295f02b7620a7/productReviews
           */
          related?: string;
        };
      };
      promotions?: {
        data?: {
          /** @example ea6aeb050f871384f25fba9c869cfe21 */
          id?: string;
          /** @example promotion */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /customer/ce26601dac0dea138b7295f02b7620a7/promotions
           */
          related?: string;
        };
      };
      recoveryCustomer?: {
        data?: {
          /** @example ce9d8d13e51bf43bc70a4be38950823b */
          id?: string;
          /** @example customer_recovery */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /customer/ce26601dac0dea138b7295f02b7620a7/recoveryCustomer
           */
          related?: string;
        };
      };
      requestedGroup?: {
        data?: {
          /** @example 46cf25a3f20102ff5e1e17526fb73b62 */
          id?: string;
          /** @example customer_group */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /customer/ce26601dac0dea138b7295f02b7620a7/requestedGroup
           */
          related?: string;
        };
      };
      salesChannel?: {
        data?: {
          /** @example ec3712a84143b57e0db620eaac6e55b8 */
          id?: string;
          /** @example sales_channel */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /customer/ce26601dac0dea138b7295f02b7620a7/salesChannel
           */
          related?: string;
        };
      };
      salutation?: {
        data?: {
          /** @example 7a6efb02514153b5aa9a8f40c6f8bcc3 */
          id?: string;
          /** @example salutation */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /customer/ce26601dac0dea138b7295f02b7620a7/salutation
           */
          related?: string;
        };
      };
      tags?: {
        data?: {
          /** @example d57ac45256849d9b13e2422d91580fb9 */
          id?: string;
          /** @example tag */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /customer/ce26601dac0dea138b7295f02b7620a7/tags
           */
          related?: string;
        };
      };
      updatedBy?: {
        data?: {
          /** @example 7ced3d0067ad61702af7db8ae260aa76 */
          id?: string;
          /** @example user */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /customer/ce26601dac0dea138b7295f02b7620a7/updatedBy
           */
          related?: string;
        };
      };
      wishlists?: {
        data?: {
          /** @example 4ec38c6b2208529c1fadccc7d55d7947 */
          id?: string;
          /** @example customer_wishlist */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /customer/ce26601dac0dea138b7295f02b7620a7/wishlists
           */
          related?: string;
        };
      };
    };
    remoteAddress?: string;
    requestedGroupId?: string;
    /** Format: int64 */
    readonly reviewCount?: number;
    salesChannelId: string;
    salutationId?: string;
    readonly tagIds?: string[];
    title?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    updatedById?: string;
    vatIds?: string[];
  };
  CustomerRecovery: {
    /** Format: date-time */
    readonly createdAt?: string;
    customer?: components["schemas"]["Customer"];
    customerId: string;
    hash: string;
    id: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  CustomerRecoveryJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    customerId: string;
    hash: string;
    id: string;
    relationships?: {
      customer?: {
        data?: {
          /** @example 91ec1f9324753048c0096d036a694f86 */
          id?: string;
          /** @example customer */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /customer-recovery/5c91cd3c845f51250c566f72e5fec3bf/customer
           */
          related?: string;
        };
      };
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  CustomerSpecificFeatures: {
    /** Format: date-time */
    readonly createdAt?: string;
    customer?: components["schemas"]["Customer"];
    customerId: string;
    features: GenericRecord;
    id: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  CustomerSpecificFeaturesJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    customerId: string;
    features: GenericRecord;
    id: string;
    relationships?: {
      customer?: {
        data?: {
          /** @example 91ec1f9324753048c0096d036a694f86 */
          id?: string;
          /** @example customer */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /customer-specific-features/e56b0d78d82e9de6aa5c6e3d37b4a360/customer
           */
          related?: string;
        };
      };
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  CustomerTag: {
    customer?: components["schemas"]["Customer"];
    customerId: string;
    id?: string;
    tag?: components["schemas"]["Tag"];
    tagId: string;
  };
  CustomerWishlist: {
    /** Format: date-time */
    readonly createdAt?: string;
    customer?: components["schemas"]["Customer"];
    customerId: string;
    customFields?: GenericRecord;
    id: string;
    products?: components["schemas"]["CustomerWishlistProduct"][];
    salesChannel?: components["schemas"]["SalesChannel"];
    salesChannelId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  CustomerWishlistJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    customerId: string;
    customFields?: GenericRecord;
    id: string;
    relationships?: {
      customer?: {
        data?: {
          /** @example 91ec1f9324753048c0096d036a694f86 */
          id?: string;
          /** @example customer */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /customer-wishlist/cae717e5aef3f7f9a2356eff6cb7fad1/customer
           */
          related?: string;
        };
      };
      products?: {
        data?: {
          /** @example 86024cad1e83101d97359d7351051156 */
          id?: string;
          /** @example customer_wishlist_product */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /customer-wishlist/cae717e5aef3f7f9a2356eff6cb7fad1/products
           */
          related?: string;
        };
      };
      salesChannel?: {
        data?: {
          /** @example ec3712a84143b57e0db620eaac6e55b8 */
          id?: string;
          /** @example sales_channel */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /customer-wishlist/cae717e5aef3f7f9a2356eff6cb7fad1/salesChannel
           */
          related?: string;
        };
      };
    };
    salesChannelId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  CustomerWishlistProduct: {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    product?: components["schemas"]["Product"];
    productId: string;
    productVersionId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    wishlist?: components["schemas"]["CustomerWishlist"];
    wishlistId: string;
  };
  CustomerWishlistProductJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    productId: string;
    productVersionId?: string;
    relationships?: {
      product?: {
        data?: {
          /** @example f5bf48aa40cad7891eb709fcf1fde128 */
          id?: string;
          /** @example product */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /customer-wishlist-product/d6e178a98d861482131b9e2356460d16/product
           */
          related?: string;
        };
      };
      wishlist?: {
        data?: {
          /** @example 723edf7c24638ed18d2fa831e647a5cc */
          id?: string;
          /** @example customer_wishlist */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /customer-wishlist-product/d6e178a98d861482131b9e2356460d16/wishlist
           */
          related?: string;
        };
      };
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    wishlistId: string;
  };
  DeliveryTime: {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    id: string;
    /** Format: int64 */
    max: number;
    /** Format: int64 */
    min: number;
    name: string;
    products?: components["schemas"]["Product"][];
    shippingMethods?: components["schemas"]["ShippingMethod"][];
    translated: {
      name: string;
      unit: string;
    };
    unit: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  DeliveryTimeJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    id: string;
    /** Format: int64 */
    max: number;
    /** Format: int64 */
    min: number;
    name: string;
    relationships?: {
      products?: {
        data?: {
          /** @example 86024cad1e83101d97359d7351051156 */
          id?: string;
          /** @example product */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /delivery-time/23679aa2a9d2aa429662de0be1213305/products
           */
          related?: string;
        };
      };
      shippingMethods?: {
        data?: {
          /** @example 8268b0a6c902fbde485094c2f627b854 */
          id?: string;
          /** @example shipping_method */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /delivery-time/23679aa2a9d2aa429662de0be1213305/shippingMethods
           */
          related?: string;
        };
      };
    };
    translated: {
      name: string;
      unit: string;
    };
    unit: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  Document: {
    config: GenericRecord;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    deepLinkCode: string;
    dependentDocuments?: components["schemas"]["Document"][];
    documentMediaFile?: components["schemas"]["Media"];
    documentMediaFileId?: string;
    documentNumber?: string;
    documentType?: components["schemas"]["DocumentType"];
    documentTypeId: string;
    fileType: string;
    id: string;
    order?: components["schemas"]["Order"];
    orderId: string;
    orderVersionId?: string;
    referencedDocument?: components["schemas"]["Document"];
    referencedDocumentId?: string;
    sent?: boolean;
    static?: boolean;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  DocumentBaseConfig: {
    config?: GenericRecord;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    documentNumber?: string;
    documentType?: components["schemas"]["DocumentType"];
    documentTypeId: string;
    filenamePrefix?: string;
    filenameSuffix?: string;
    global?: boolean;
    id: string;
    logo?: components["schemas"]["Media"];
    logoId?: string;
    name: string;
    salesChannels?: components["schemas"]["DocumentBaseConfigSalesChannel"][];
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  DocumentBaseConfigJsonApi: components["schemas"]["resource"] & {
    config?: GenericRecord;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    documentNumber?: string;
    documentTypeId: string;
    filenamePrefix?: string;
    filenameSuffix?: string;
    global?: boolean;
    id: string;
    logoId?: string;
    name: string;
    relationships?: {
      documentType?: {
        data?: {
          /** @example 2e45fec65781ec559e2aea39372a55cd */
          id?: string;
          /** @example document_type */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /document-base-config/4f8577ec262a1e35dfd795dc6bbde573/documentType
           */
          related?: string;
        };
      };
      logo?: {
        data?: {
          /** @example 96d6f2e7e1f705ab5e59c84a6dc009b2 */
          id?: string;
          /** @example media */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /document-base-config/4f8577ec262a1e35dfd795dc6bbde573/logo
           */
          related?: string;
        };
      };
      salesChannels?: {
        data?: {
          /** @example 986f6f891e90ab91c091ff4a1a460777 */
          id?: string;
          /** @example document_base_config_sales_channel */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /document-base-config/4f8577ec262a1e35dfd795dc6bbde573/salesChannels
           */
          related?: string;
        };
      };
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  DocumentBaseConfigSalesChannel: {
    /** Format: date-time */
    readonly createdAt?: string;
    documentBaseConfig?: components["schemas"]["DocumentBaseConfig"];
    documentBaseConfigId: string;
    documentType?: components["schemas"]["DocumentType"];
    documentTypeId?: string;
    id: string;
    salesChannel?: components["schemas"]["SalesChannel"];
    salesChannelId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  DocumentBaseConfigSalesChannelJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    documentBaseConfigId: string;
    documentTypeId?: string;
    id: string;
    relationships?: {
      documentBaseConfig?: {
        data?: {
          /** @example 56e59df02965ebf8eadea49fa0aadd47 */
          id?: string;
          /** @example document_base_config */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /document-base-config-sales-channel/02a1d1c4385bb5549fa51f219bb79824/documentBaseConfig
           */
          related?: string;
        };
      };
      documentType?: {
        data?: {
          /** @example 2e45fec65781ec559e2aea39372a55cd */
          id?: string;
          /** @example document_type */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /document-base-config-sales-channel/02a1d1c4385bb5549fa51f219bb79824/documentType
           */
          related?: string;
        };
      };
      salesChannel?: {
        data?: {
          /** @example ec3712a84143b57e0db620eaac6e55b8 */
          id?: string;
          /** @example sales_channel */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /document-base-config-sales-channel/02a1d1c4385bb5549fa51f219bb79824/salesChannel
           */
          related?: string;
        };
      };
    };
    salesChannelId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  DocumentJsonApi: components["schemas"]["resource"] & {
    config: GenericRecord;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    deepLinkCode: string;
    documentMediaFileId?: string;
    documentNumber?: string;
    documentTypeId: string;
    fileType: string;
    id: string;
    orderId: string;
    orderVersionId?: string;
    referencedDocumentId?: string;
    relationships?: {
      dependentDocuments?: {
        data?: {
          /** @example e74b269b7d5f269051463569677da2a0 */
          id?: string;
          /** @example document */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /document/0945359809dad1fbf3dea1c95a0da951/dependentDocuments
           */
          related?: string;
        };
      };
      documentMediaFile?: {
        data?: {
          /** @example ac7db1e6be481d6422fc63700e08279d */
          id?: string;
          /** @example media */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /document/0945359809dad1fbf3dea1c95a0da951/documentMediaFile
           */
          related?: string;
        };
      };
      documentType?: {
        data?: {
          /** @example 2e45fec65781ec559e2aea39372a55cd */
          id?: string;
          /** @example document_type */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /document/0945359809dad1fbf3dea1c95a0da951/documentType
           */
          related?: string;
        };
      };
      order?: {
        data?: {
          /** @example 70a17ffa722a3985b86d30b034ad06d7 */
          id?: string;
          /** @example order */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /document/0945359809dad1fbf3dea1c95a0da951/order
           */
          related?: string;
        };
      };
      referencedDocument?: {
        data?: {
          /** @example 75c3c346b0ef4f319e71925ce164a9ae */
          id?: string;
          /** @example document */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /document/0945359809dad1fbf3dea1c95a0da951/referencedDocument
           */
          related?: string;
        };
      };
    };
    sent?: boolean;
    static?: boolean;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  DocumentType: {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    documentBaseConfigs?: components["schemas"]["DocumentBaseConfig"][];
    documentBaseConfigSalesChannels?: components["schemas"]["DocumentBaseConfigSalesChannel"][];
    documents?: components["schemas"]["Document"][];
    extensions?: {
      quoteDocuments?: {
        data?: {
          /** @example 5f9aa016c99bbfdc16be8c44d885e7e4 */
          id?: string;
          /** @example quote_document */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /document-type/a3e4a918932e72ec84ec065eb5100c22/quoteDocuments
           */
          related?: string;
        };
      };
    };
    id: string;
    name: string;
    technicalName: string;
    translated: {
      name: string;
      technicalName: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  DocumentTypeJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    extensions?: {
      quoteDocuments?: {
        data?: {
          /** @example 5f9aa016c99bbfdc16be8c44d885e7e4 */
          id?: string;
          /** @example quote_document */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /document-type/a3e4a918932e72ec84ec065eb5100c22/quoteDocuments
           */
          related?: string;
        };
      };
    };
    id: string;
    name: string;
    relationships?: {
      documentBaseConfigs?: {
        data?: {
          /** @example 0e128fa41e6afdcd85baa8ee7b07b0e3 */
          id?: string;
          /** @example document_base_config */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /document-type/a3e4a918932e72ec84ec065eb5100c22/documentBaseConfigs
           */
          related?: string;
        };
      };
      documentBaseConfigSalesChannels?: {
        data?: {
          /** @example 9c990fde5b38ff70fc1a07bf84c12a17 */
          id?: string;
          /** @example document_base_config_sales_channel */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /document-type/a3e4a918932e72ec84ec065eb5100c22/documentBaseConfigSalesChannels
           */
          related?: string;
        };
      };
      documents?: {
        data?: {
          /** @example 21f64da1e5792c8295b964d159a14491 */
          id?: string;
          /** @example document */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /document-type/a3e4a918932e72ec84ec065eb5100c22/documents
           */
          related?: string;
        };
      };
    };
    technicalName: string;
    translated: {
      name: string;
      technicalName: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  DsrAppointment: {
    /** Format: date-time */
    accessibleFrom?: string;
    /** Format: date-time */
    accessibleTo?: string;
    active?: boolean;
    attendeeRestrictionType?: string;
    attendeeRuleIds?: GenericRecord;
    attendees?: components["schemas"]["DsrAppointmentAttendee"][];
    bookingLink?: string;
    canBookNewAppointment?: boolean;
    canSendRequestEmail?: boolean;
    /** Format: date-time */
    readonly createdAt?: string;
    createdBy?: components["schemas"]["User"];
    createdById: string;
    customFields?: GenericRecord;
    default?: boolean;
    dsrPresentationVersionId?: string;
    /** Format: date-time */
    endedAt?: string;
    guideUser?: components["schemas"]["User"];
    guideUserId?: string;
    id: string;
    isPreview?: boolean;
    message?: string;
    mode?: string;
    name: string;
    presentation?: components["schemas"]["DsrPresentation"];
    presentationId: string;
    presentationPath: string;
    salesChannelDomain?: components["schemas"]["SalesChannelDomain"];
    salesChannelDomainId: string;
    /** Format: date-time */
    startedAt?: string;
    translated: {
      accessibleFrom: string;
      accessibleTo: string;
      attendeeRestrictionType: string;
      bookingLink: string;
      createdById: string;
      dsrPresentationVersionId: string;
      endedAt: string;
      guideUserId: string;
      message: string;
      mode: string;
      name: string;
      presentationId: string;
      presentationPath: string;
      salesChannelDomainId: string;
      startedAt: string;
      updatedById: string;
      videoAudioSettings: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    updatedBy?: components["schemas"]["User"];
    updatedById?: string;
    videoAudioSettings?: string;
    videoChat?: components["schemas"]["DsrAppointmentVideoChat"];
  };
  DsrAppointmentAttendee: {
    appointment?: components["schemas"]["DsrAppointment"];
    appointmentId: string;
    attendeeEmail?: string;
    attendeeName?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customer?: components["schemas"]["Customer"];
    customerId?: string;
    guideCartPermissionsGranted?: boolean;
    id: string;
    interactions?: components["schemas"]["DsrInteraction"][];
    invitationStatus?: string;
    isBlocked?: boolean;
    /** Format: date-time */
    joinedAt?: string;
    /** Format: date-time */
    lastActive?: string;
    productCollections?: components["schemas"]["DsrAttendeeProductCollection"][];
    type: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    user?: components["schemas"]["User"];
    userId?: string;
    videoUserId?: string;
  };
  DsrAppointmentAttendeeJsonApi: components["schemas"]["resource"] & {
    appointmentId: string;
    attendeeEmail?: string;
    attendeeName?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customerId?: string;
    guideCartPermissionsGranted?: boolean;
    id: string;
    invitationStatus?: string;
    isBlocked?: boolean;
    /** Format: date-time */
    joinedAt?: string;
    /** Format: date-time */
    lastActive?: string;
    relationships?: {
      appointment?: {
        data?: {
          /** @example b1caa385c37f1fec467494c8fde4f49b */
          id?: string;
          /** @example dsr_appointment */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /dsr-appointment-attendee/6013089be5c669cea75294147f34dbc0/appointment
           */
          related?: string;
        };
      };
      customer?: {
        data?: {
          /** @example 91ec1f9324753048c0096d036a694f86 */
          id?: string;
          /** @example customer */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /dsr-appointment-attendee/6013089be5c669cea75294147f34dbc0/customer
           */
          related?: string;
        };
      };
      interactions?: {
        data?: {
          /** @example 85aa9c704a544e104741012bf72b6572 */
          id?: string;
          /** @example dsr_interaction */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /dsr-appointment-attendee/6013089be5c669cea75294147f34dbc0/interactions
           */
          related?: string;
        };
      };
      productCollections?: {
        data?: {
          /** @example 3fa1ecbee1fa3d24671a2e81d9b71d17 */
          id?: string;
          /** @example dsr_attendee_product_collection */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /dsr-appointment-attendee/6013089be5c669cea75294147f34dbc0/productCollections
           */
          related?: string;
        };
      };
      user?: {
        data?: {
          /** @example ee11cbb19052e40b07aac0ca060c23ee */
          id?: string;
          /** @example user */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /dsr-appointment-attendee/6013089be5c669cea75294147f34dbc0/user
           */
          related?: string;
        };
      };
    };
    type: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    userId?: string;
    videoUserId?: string;
  };
  DsrAppointmentJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    accessibleFrom?: string;
    /** Format: date-time */
    accessibleTo?: string;
    active?: boolean;
    attendeeRestrictionType?: string;
    attendeeRuleIds?: GenericRecord;
    bookingLink?: string;
    canBookNewAppointment?: boolean;
    canSendRequestEmail?: boolean;
    /** Format: date-time */
    readonly createdAt?: string;
    createdById: string;
    customFields?: GenericRecord;
    default?: boolean;
    dsrPresentationVersionId?: string;
    /** Format: date-time */
    endedAt?: string;
    guideUserId?: string;
    id: string;
    isPreview?: boolean;
    message?: string;
    mode?: string;
    name: string;
    presentationId: string;
    presentationPath: string;
    relationships?: {
      attendees?: {
        data?: {
          /** @example 4d77992a742c290d1e37290f3986fd4e */
          id?: string;
          /** @example dsr_appointment_attendee */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /dsr-appointment/d4b6eb231829bcaaa3d1e4689cded46e/attendees
           */
          related?: string;
        };
      };
      createdBy?: {
        data?: {
          /** @example 34998857f537140306898d54d4b970dc */
          id?: string;
          /** @example user */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /dsr-appointment/d4b6eb231829bcaaa3d1e4689cded46e/createdBy
           */
          related?: string;
        };
      };
      guideUser?: {
        data?: {
          /** @example 7d58fd6cf68b2c4c00b51069f10a25eb */
          id?: string;
          /** @example user */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /dsr-appointment/d4b6eb231829bcaaa3d1e4689cded46e/guideUser
           */
          related?: string;
        };
      };
      presentation?: {
        data?: {
          /** @example 2486923a98e77fd0740381d01acd1782 */
          id?: string;
          /** @example dsr_presentation */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /dsr-appointment/d4b6eb231829bcaaa3d1e4689cded46e/presentation
           */
          related?: string;
        };
      };
      salesChannelDomain?: {
        data?: {
          /** @example 29c8b34b04e94e35e95e8346954b7fb4 */
          id?: string;
          /** @example sales_channel_domain */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /dsr-appointment/d4b6eb231829bcaaa3d1e4689cded46e/salesChannelDomain
           */
          related?: string;
        };
      };
      updatedBy?: {
        data?: {
          /** @example 7ced3d0067ad61702af7db8ae260aa76 */
          id?: string;
          /** @example user */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /dsr-appointment/d4b6eb231829bcaaa3d1e4689cded46e/updatedBy
           */
          related?: string;
        };
      };
      videoChat?: {
        data?: {
          /** @example b23b1765cc6500512065f5a39a713b75 */
          id?: string;
          /** @example dsr_appointment_video_chat */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /dsr-appointment/d4b6eb231829bcaaa3d1e4689cded46e/videoChat
           */
          related?: string;
        };
      };
    };
    salesChannelDomainId: string;
    /** Format: date-time */
    startedAt?: string;
    translated: {
      accessibleFrom: string;
      accessibleTo: string;
      attendeeRestrictionType: string;
      bookingLink: string;
      createdById: string;
      dsrPresentationVersionId: string;
      endedAt: string;
      guideUserId: string;
      message: string;
      mode: string;
      name: string;
      presentationId: string;
      presentationPath: string;
      salesChannelDomainId: string;
      startedAt: string;
      updatedById: string;
      videoAudioSettings: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    updatedById?: string;
    videoAudioSettings?: string;
  };
  DsrAppointmentRequest: {
    appointment?: components["schemas"]["DsrAppointment"];
    appointmentId: string;
    companyName?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    emailAddress: string;
    firstName: string;
    handledById?: string;
    handler?: components["schemas"]["User"];
    id: string;
    lastName: string;
    message?: string;
    phoneNumber?: string;
    requestedById: string;
    requester?: components["schemas"]["DsrAppointmentAttendee"];
    salutation?: components["schemas"]["Salutation"];
    salutationId: string;
    subject: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  DsrAppointmentRequestJsonApi: components["schemas"]["resource"] & {
    appointmentId: string;
    companyName?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    emailAddress: string;
    firstName: string;
    handledById?: string;
    id: string;
    lastName: string;
    message?: string;
    phoneNumber?: string;
    relationships?: {
      appointment?: {
        data?: {
          /** @example b1caa385c37f1fec467494c8fde4f49b */
          id?: string;
          /** @example dsr_appointment */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /dsr-appointment-request/3c71739b4a19fe331ce2b32a35e8ef4d/appointment
           */
          related?: string;
        };
      };
      handler?: {
        data?: {
          /** @example c1cbfe271a40788a00e8bf8574d94d4b */
          id?: string;
          /** @example user */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /dsr-appointment-request/3c71739b4a19fe331ce2b32a35e8ef4d/handler
           */
          related?: string;
        };
      };
      requester?: {
        data?: {
          /** @example 0bc2b09c07005b410cae62912ae70206 */
          id?: string;
          /** @example dsr_appointment_attendee */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /dsr-appointment-request/3c71739b4a19fe331ce2b32a35e8ef4d/requester
           */
          related?: string;
        };
      };
      salutation?: {
        data?: {
          /** @example 7a6efb02514153b5aa9a8f40c6f8bcc3 */
          id?: string;
          /** @example salutation */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /dsr-appointment-request/3c71739b4a19fe331ce2b32a35e8ef4d/salutation
           */
          related?: string;
        };
      };
    };
    requestedById: string;
    salutationId: string;
    subject: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  DsrAppointmentVideoChat: {
    appointment?: components["schemas"]["DsrAppointment"];
    appointmentId: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    id: string;
    name?: string;
    ownerToken?: string;
    startAsBroadcast?: boolean;
    /** Format: date-time */
    readonly updatedAt?: string;
    url?: string;
    userToken?: string;
  };
  DsrAppointmentVideoChatJsonApi: components["schemas"]["resource"] & {
    appointmentId: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    id: string;
    name?: string;
    ownerToken?: string;
    relationships?: {
      appointment?: {
        data?: {
          /** @example b1caa385c37f1fec467494c8fde4f49b */
          id?: string;
          /** @example dsr_appointment */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /dsr-appointment-video-chat/21851f23492d55e9e0c82d97fd789730/appointment
           */
          related?: string;
        };
      };
    };
    startAsBroadcast?: boolean;
    /** Format: date-time */
    readonly updatedAt?: string;
    url?: string;
    userToken?: string;
  };
  DsrAttendeeProductCollection: {
    alias: string;
    attendee?: components["schemas"]["DsrAppointmentAttendee"];
    attendeeId: string;
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    product?: components["schemas"]["Product"];
    productId: string;
    productVersionId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  DsrAttendeeProductCollectionJsonApi: components["schemas"]["resource"] & {
    alias: string;
    attendeeId: string;
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    productId: string;
    productVersionId?: string;
    relationships?: {
      attendee?: {
        data?: {
          /** @example b7ce8294183a0f2a6092b6cb2f17b9b5 */
          id?: string;
          /** @example dsr_appointment_attendee */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /dsr-attendee-product-collection/a8b5d04acd1993d5f7b24baee1b1fc33/attendee
           */
          related?: string;
        };
      };
      product?: {
        data?: {
          /** @example f5bf48aa40cad7891eb709fcf1fde128 */
          id?: string;
          /** @example product */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /dsr-attendee-product-collection/a8b5d04acd1993d5f7b24baee1b1fc33/product
           */
          related?: string;
        };
      };
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  DsrInteraction: {
    attendee?: components["schemas"]["DsrAppointmentAttendee"];
    attendeeId: string;
    /** Format: date-time */
    readonly createdAt?: string;
    /** Format: date-time */
    expiresAt?: string;
    id: string;
    name: string;
    payload?: GenericRecord;
    /** Format: date-time */
    triggeredAt: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  DsrInteractionJsonApi: components["schemas"]["resource"] & {
    attendeeId: string;
    /** Format: date-time */
    readonly createdAt?: string;
    /** Format: date-time */
    expiresAt?: string;
    id: string;
    name: string;
    payload?: GenericRecord;
    relationships?: {
      attendee?: {
        data?: {
          /** @example b7ce8294183a0f2a6092b6cb2f17b9b5 */
          id?: string;
          /** @example dsr_appointment_attendee */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /dsr-interaction/3d3949b2e83fa3ca98a32f354273a62a/attendee
           */
          related?: string;
        };
      };
    };
    /** Format: date-time */
    triggeredAt: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  DsrPresentation: {
    active?: boolean;
    appointments?: components["schemas"]["DsrAppointment"][];
    cmsPages?: components["schemas"]["DsrPresentationCmsPage"][];
    /** Format: date-time */
    readonly createdAt?: string;
    createdBy?: components["schemas"]["User"];
    createdById: string;
    customFields?: GenericRecord;
    id: string;
    name: string;
    parent?: components["schemas"]["DsrPresentation"];
    parentId?: string;
    parentVersionId?: string;
    translated: {
      createdById: string;
      name: string;
      parentId: string;
      parentVersionId: string;
      updatedById: string;
      versionId: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    updatedBy?: components["schemas"]["User"];
    updatedById?: string;
    versionId?: string;
  };
  DsrPresentationCmsPage: {
    cmsPage?: components["schemas"]["CmsPage"];
    cmsPageId: string;
    cmsPageVersionId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    dsrPresentationVersionId?: string;
    id: string;
    isInstantListing?: boolean;
    pickedProductIds?: GenericRecord;
    /** Format: int64 */
    position?: number;
    presentation?: components["schemas"]["DsrPresentation"];
    presentationId: string;
    product?: components["schemas"]["Product"];
    productId?: string;
    productStream?: components["schemas"]["ProductStream"];
    productStreamId?: string;
    productVersionId?: string;
    slotConfig?: GenericRecord;
    title?: string;
    translated: {
      cmsPageId: string;
      cmsPageVersionId: string;
      dsrPresentationVersionId: string;
      presentationId: string;
      productId: string;
      productStreamId: string;
      productVersionId: string;
      title: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  DsrPresentationCmsPageJsonApi: components["schemas"]["resource"] & {
    cmsPageId: string;
    cmsPageVersionId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    dsrPresentationVersionId?: string;
    id: string;
    isInstantListing?: boolean;
    pickedProductIds?: GenericRecord;
    /** Format: int64 */
    position?: number;
    presentationId: string;
    productId?: string;
    productStreamId?: string;
    productVersionId?: string;
    relationships?: {
      cmsPage?: {
        data?: {
          /** @example 7b1460918b1abb93311108f3dc021c9b */
          id?: string;
          /** @example cms_page */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /dsr-presentation-cms-page/e8696be98208356b4da4a941d92738fe/cmsPage
           */
          related?: string;
        };
      };
      presentation?: {
        data?: {
          /** @example 2486923a98e77fd0740381d01acd1782 */
          id?: string;
          /** @example dsr_presentation */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /dsr-presentation-cms-page/e8696be98208356b4da4a941d92738fe/presentation
           */
          related?: string;
        };
      };
      product?: {
        data?: {
          /** @example f5bf48aa40cad7891eb709fcf1fde128 */
          id?: string;
          /** @example product */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /dsr-presentation-cms-page/e8696be98208356b4da4a941d92738fe/product
           */
          related?: string;
        };
      };
      productStream?: {
        data?: {
          /** @example 49561f6faa0badfce831a183d2ec7c2f */
          id?: string;
          /** @example product_stream */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /dsr-presentation-cms-page/e8696be98208356b4da4a941d92738fe/productStream
           */
          related?: string;
        };
      };
    };
    slotConfig?: GenericRecord;
    title?: string;
    translated: {
      cmsPageId: string;
      cmsPageVersionId: string;
      dsrPresentationVersionId: string;
      presentationId: string;
      productId: string;
      productStreamId: string;
      productVersionId: string;
      title: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  DsrPresentationJsonApi: components["schemas"]["resource"] & {
    active?: boolean;
    /** Format: date-time */
    readonly createdAt?: string;
    createdById: string;
    customFields?: GenericRecord;
    id: string;
    name: string;
    parentId?: string;
    parentVersionId?: string;
    relationships?: {
      appointments?: {
        data?: {
          /** @example 2417b53255206bdce189add39d85fca1 */
          id?: string;
          /** @example dsr_appointment */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /dsr-presentation/f770a896b93bc3b86dbb8be6f107a869/appointments
           */
          related?: string;
        };
      };
      cmsPages?: {
        data?: {
          /** @example e676148cc6ffb82b89b3903ecaed2d16 */
          id?: string;
          /** @example dsr_presentation_cms_page */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /dsr-presentation/f770a896b93bc3b86dbb8be6f107a869/cmsPages
           */
          related?: string;
        };
      };
      createdBy?: {
        data?: {
          /** @example 34998857f537140306898d54d4b970dc */
          id?: string;
          /** @example user */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /dsr-presentation/f770a896b93bc3b86dbb8be6f107a869/createdBy
           */
          related?: string;
        };
      };
      parent?: {
        data?: {
          /** @example d0e45878043844ffc41aac437e86b602 */
          id?: string;
          /** @example dsr_presentation */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /dsr-presentation/f770a896b93bc3b86dbb8be6f107a869/parent
           */
          related?: string;
        };
      };
      updatedBy?: {
        data?: {
          /** @example 7ced3d0067ad61702af7db8ae260aa76 */
          id?: string;
          /** @example user */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /dsr-presentation/f770a896b93bc3b86dbb8be6f107a869/updatedBy
           */
          related?: string;
        };
      };
    };
    translated: {
      createdById: string;
      name: string;
      parentId: string;
      parentVersionId: string;
      updatedById: string;
      versionId: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    updatedById?: string;
    versionId?: string;
  };
  DynamicPageOpenedPayload: components["schemas"]["AbstractDynamicPageOpenedPayload"];
  DynamicProductListingPageOpenedPayload: {
    /** Current page position in the pagination */
    page: number;
  };
  EqualsFilter: {
    field: string;
    /** @enum {string} */
    type: "equals";
    value: string | number | boolean | null;
  };
  Filters: (
    | components["schemas"]["SimpleFilter"]
    | components["schemas"]["EqualsFilter"]
    | components["schemas"]["MultiNotFilter"]
    | components["schemas"]["RangeFilter"]
  )[];
  Flow: {
    active?: boolean;
    appFlowEvent?: components["schemas"]["AppFlowEvent"];
    appFlowEventId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    description?: string;
    eventName: string;
    extensions?: {
      delayActions?: {
        data?: {
          /** @example edfed55799054673006c4b5a643489ac */
          id?: string;
          /** @example swag_delay_action */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /flow/f1a76f66cca677c6e628d9ca58a6c8fc/delayActions
           */
          related?: string;
        };
      };
    };
    id: string;
    readonly invalid?: boolean;
    name: string;
    /** Format: int64 */
    priority?: number;
    sequences?: components["schemas"]["FlowSequence"][];
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  FlowJsonApi: components["schemas"]["resource"] & {
    active?: boolean;
    appFlowEventId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    description?: string;
    eventName: string;
    extensions?: {
      delayActions?: {
        data?: {
          /** @example edfed55799054673006c4b5a643489ac */
          id?: string;
          /** @example swag_delay_action */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /flow/f1a76f66cca677c6e628d9ca58a6c8fc/delayActions
           */
          related?: string;
        };
      };
    };
    id: string;
    readonly invalid?: boolean;
    name: string;
    /** Format: int64 */
    priority?: number;
    relationships?: {
      appFlowEvent?: {
        data?: {
          /** @example d92d404135abc21e31337d9509cbe62f */
          id?: string;
          /** @example app_flow_event */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /flow/f1a76f66cca677c6e628d9ca58a6c8fc/appFlowEvent
           */
          related?: string;
        };
      };
      sequences?: {
        data?: {
          /** @example eb6710ddc89dae357ae94ca3974b1e38 */
          id?: string;
          /** @example flow_sequence */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /flow/f1a76f66cca677c6e628d9ca58a6c8fc/sequences
           */
          related?: string;
        };
      };
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  FlowSequence: {
    actionName?: string;
    appFlowAction?: components["schemas"]["AppFlowAction"];
    appFlowActionId?: string;
    children?: components["schemas"]["FlowSequence"][];
    config?: GenericRecord;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    /** Format: int64 */
    displayGroup?: number;
    extensions?: {
      delayActions?: {
        data?: {
          /** @example edfed55799054673006c4b5a643489ac */
          id?: string;
          /** @example swag_delay_action */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /flow-sequence/983754f96cad338b500181a31b737d47/delayActions
           */
          related?: string;
        };
      };
      webhookEventLogs?: {
        data?: {
          /** @example 82557f6f51ca956bee524cede1375331 */
          id?: string;
          /** @example webhook_event_log */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /flow-sequence/983754f96cad338b500181a31b737d47/webhookEventLogs
           */
          related?: string;
        };
      };
    };
    flow?: components["schemas"]["Flow"];
    flowId: string;
    id: string;
    parent?: components["schemas"]["FlowSequence"];
    parentId?: string;
    /** Format: int64 */
    position?: number;
    rule?: components["schemas"]["Rule"];
    ruleId?: string;
    trueCase?: boolean;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  FlowSequenceJsonApi: components["schemas"]["resource"] & {
    actionName?: string;
    appFlowActionId?: string;
    config?: GenericRecord;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    /** Format: int64 */
    displayGroup?: number;
    extensions?: {
      delayActions?: {
        data?: {
          /** @example edfed55799054673006c4b5a643489ac */
          id?: string;
          /** @example swag_delay_action */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /flow-sequence/983754f96cad338b500181a31b737d47/delayActions
           */
          related?: string;
        };
      };
      webhookEventLogs?: {
        data?: {
          /** @example 82557f6f51ca956bee524cede1375331 */
          id?: string;
          /** @example webhook_event_log */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /flow-sequence/983754f96cad338b500181a31b737d47/webhookEventLogs
           */
          related?: string;
        };
      };
    };
    flowId: string;
    id: string;
    parentId?: string;
    /** Format: int64 */
    position?: number;
    relationships?: {
      appFlowAction?: {
        data?: {
          /** @example 8ba9ae8a60ecf9be421e333b95703a68 */
          id?: string;
          /** @example app_flow_action */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /flow-sequence/983754f96cad338b500181a31b737d47/appFlowAction
           */
          related?: string;
        };
      };
      children?: {
        data?: {
          /** @example 268184c12df027f536154d099d497b31 */
          id?: string;
          /** @example flow_sequence */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /flow-sequence/983754f96cad338b500181a31b737d47/children
           */
          related?: string;
        };
      };
      flow?: {
        data?: {
          /** @example cff5497121104c2b8e0cb41ed2083a9b */
          id?: string;
          /** @example flow */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /flow-sequence/983754f96cad338b500181a31b737d47/flow
           */
          related?: string;
        };
      };
      parent?: {
        data?: {
          /** @example d0e45878043844ffc41aac437e86b602 */
          id?: string;
          /** @example flow_sequence */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /flow-sequence/983754f96cad338b500181a31b737d47/parent
           */
          related?: string;
        };
      };
      rule?: {
        data?: {
          /** @example 981c1e7b3795da18687613fbd66d4954 */
          id?: string;
          /** @example rule */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /flow-sequence/983754f96cad338b500181a31b737d47/rule
           */
          related?: string;
        };
      };
    };
    ruleId?: string;
    trueCase?: boolean;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  FlowTemplate: {
    config?: GenericRecord;
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    name: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  FlowTemplateJsonApi: components["schemas"]["resource"] & {
    config?: GenericRecord;
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    name: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  GetAttendeeInsightsResponse: {
    attendees?: components["schemas"]["AttendeeInsights"][];
    currencyId?: string;
    currencySymbol?: string;
  };
  GetCartInsightsResponse: {
    /** Sum of all products from all attenddees which were added to the cart during the appointment */
    cartSum?: number;
    /** The id from the shown currency */
    currencyId?: string;
    /** The currency symbol from the shown currency */
    currencySymbol?: string;
    /** Sum of all product quantities from all attendees which were added to the cart during the appointment */
    productCount?: number;
    topProducts?: {
      byQuantity: {
        /** The id from the product */
        productId: string;
        /** The quantity in carts of this product */
        value: number;
      }[];
      byRevenue: {
        /** The id from the product */
        productId: string;
        /** The net revenue in the shown currency in carts of this product */
        value: number;
      }[];
    };
  };
  GetListBodyRequest: {
    /** Max amount of resources to be returned in a page */
    limit?: number;
    /** The page to be returned */
    page?: number;
  };
  GuidePresentationStateResponse: {
    stateForAll?: components["schemas"]["StateForAll"];
    stateForClients?: components["schemas"]["StateForGuides"];
    stateForMe?: components["schemas"]["StateForMe"];
  };
  ImportExportFile: {
    accessToken?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    /** Format: date-time */
    expireDate: string;
    id: string;
    log?: components["schemas"]["ImportExportLog"];
    originalName: string;
    path: string;
    /** Format: int64 */
    size?: number;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  ImportExportFileJsonApi: components["schemas"]["resource"] & {
    accessToken?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    /** Format: date-time */
    expireDate: string;
    id: string;
    originalName: string;
    path: string;
    relationships?: {
      log?: {
        data?: {
          /** @example dc1d71bbb5c4d2a5e936db79ef10c19f */
          id?: string;
          /** @example import_export_log */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /import-export-file/1e0a4283354a721dbed68499ce2db333/log
           */
          related?: string;
        };
      };
    };
    /** Format: int64 */
    size?: number;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  ImportExportLog: {
    activity: string;
    config: GenericRecord;
    /** Format: date-time */
    readonly createdAt?: string;
    failedImportLog?: components["schemas"]["ImportExportLog"];
    file?: components["schemas"]["ImportExportFile"];
    fileId?: string;
    id: string;
    invalidRecordsLog?: components["schemas"]["ImportExportLog"];
    invalidRecordsLogId?: string;
    profile?: components["schemas"]["ImportExportProfile"];
    profileId?: string;
    profileName?: string;
    /** Format: int64 */
    records: number;
    result?: GenericRecord;
    state: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    user?: components["schemas"]["User"];
    userId?: string;
    username?: string;
  };
  ImportExportLogJsonApi: components["schemas"]["resource"] & {
    activity: string;
    config: GenericRecord;
    /** Format: date-time */
    readonly createdAt?: string;
    fileId?: string;
    id: string;
    invalidRecordsLogId?: string;
    profileId?: string;
    profileName?: string;
    /** Format: int64 */
    records: number;
    relationships?: {
      failedImportLog?: {
        data?: {
          /** @example 1d6996fa1560fc40e5faad086b07ad18 */
          id?: string;
          /** @example import_export_log */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /import-export-log/4996be2318bb0b26fe9a5c57459062fa/failedImportLog
           */
          related?: string;
        };
      };
      file?: {
        data?: {
          /** @example 8c7dd922ad47494fc02c388e12c00eac */
          id?: string;
          /** @example import_export_file */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /import-export-log/4996be2318bb0b26fe9a5c57459062fa/file
           */
          related?: string;
        };
      };
      invalidRecordsLog?: {
        data?: {
          /** @example 46eeeb74b58b97a6a05494fa0024c998 */
          id?: string;
          /** @example import_export_log */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /import-export-log/4996be2318bb0b26fe9a5c57459062fa/invalidRecordsLog
           */
          related?: string;
        };
      };
      profile?: {
        data?: {
          /** @example 7d97481b1fe66f4b51db90da7e794d9f */
          id?: string;
          /** @example import_export_profile */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /import-export-log/4996be2318bb0b26fe9a5c57459062fa/profile
           */
          related?: string;
        };
      };
      user?: {
        data?: {
          /** @example ee11cbb19052e40b07aac0ca060c23ee */
          id?: string;
          /** @example user */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /import-export-log/4996be2318bb0b26fe9a5c57459062fa/user
           */
          related?: string;
        };
      };
    };
    result?: GenericRecord;
    state: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    userId?: string;
    username?: string;
  };
  ImportExportProfile: {
    config?: GenericRecord;
    /** Format: date-time */
    readonly createdAt?: string;
    delimiter: string;
    enclosure: string;
    fileType: string;
    id: string;
    importExportLogs?: components["schemas"]["ImportExportLog"][];
    label: string;
    mapping?: GenericRecord;
    name?: string;
    sourceEntity: string;
    systemDefault?: boolean;
    technicalName?: string;
    translated: {
      delimiter: string;
      enclosure: string;
      fileType: string;
      label: string;
      name: string;
      sourceEntity: string;
      technicalName: string;
      type: string;
    };
    type?: string;
    updateBy?: GenericRecord;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  ImportExportProfileJsonApi: components["schemas"]["resource"] & {
    config?: GenericRecord;
    /** Format: date-time */
    readonly createdAt?: string;
    delimiter: string;
    enclosure: string;
    fileType: string;
    id: string;
    label: string;
    mapping?: GenericRecord;
    name?: string;
    relationships?: {
      importExportLogs?: {
        data?: {
          /** @example e4ca733e3c1da4bff4cd4b6078f2237a */
          id?: string;
          /** @example import_export_log */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /import-export-profile/59e9b5cef4e569ce1af9aaa1d37135fc/importExportLogs
           */
          related?: string;
        };
      };
    };
    sourceEntity: string;
    systemDefault?: boolean;
    technicalName?: string;
    translated: {
      delimiter: string;
      enclosure: string;
      fileType: string;
      label: string;
      name: string;
      sourceEntity: string;
      technicalName: string;
      type: string;
    };
    type?: string;
    updateBy?: GenericRecord;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  Include: {
    [key: string]: string[];
  };
  Integration: {
    accessKey: string;
    aclRoles?: components["schemas"]["AclRole"][];
    admin?: boolean;
    app?: components["schemas"]["App"];
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    /** Format: date-time */
    deletedAt?: string;
    extensions?: {
      createdNotifications?: {
        data?: {
          /** @example 04f88ea12127fe03b65beffbc2c96954 */
          id?: string;
          /** @example notification */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /integration/1115b855bb2a508bc2ca0609cc2d0f65/createdNotifications
           */
          related?: string;
        };
      };
    };
    id: string;
    label: string;
    /** Format: date-time */
    lastUsageAt?: string;
    secretAccessKey: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  IntegrationJsonApi: components["schemas"]["resource"] & {
    accessKey: string;
    admin?: boolean;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    /** Format: date-time */
    deletedAt?: string;
    extensions?: {
      createdNotifications?: {
        data?: {
          /** @example 04f88ea12127fe03b65beffbc2c96954 */
          id?: string;
          /** @example notification */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /integration/1115b855bb2a508bc2ca0609cc2d0f65/createdNotifications
           */
          related?: string;
        };
      };
    };
    id: string;
    label: string;
    /** Format: date-time */
    lastUsageAt?: string;
    relationships?: {
      aclRoles?: {
        data?: {
          /** @example e050a8081a3eb1d193c23cf0ef761183 */
          id?: string;
          /** @example acl_role */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /integration/1115b855bb2a508bc2ca0609cc2d0f65/aclRoles
           */
          related?: string;
        };
      };
      app?: {
        data?: {
          /** @example d2a57dc1d883fd21fb9951699df71cc7 */
          id?: string;
          /** @example app */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /integration/1115b855bb2a508bc2ca0609cc2d0f65/app
           */
          related?: string;
        };
      };
    };
    secretAccessKey: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  IntegrationRole: {
    aclRoleId: string;
    id?: string;
    integration?: components["schemas"]["Integration"];
    integrationId: string;
    role?: components["schemas"]["AclRole"];
  };
  JoinAppointmentResponse: {
    /** The name of the appointment */
    appointmentName?: string;
    /** The created Id for the attendee */
    attendeeId?: string;
    /** The appointment id */
    id?: string;
    /** To see if it's a preview appointment */
    isPreview?: boolean;
    /** The JWT mercure token to subscribe for updates */
    JWTMercurePublisherToken?: string | null;
    /** The JWT mercure token to publish updates */
    JWTMercureSubscriberToken?: string | null;
    /** The mercure hub url to connect for subscribing and updating */
    mercureHubPublicUrl?: string | null;
    /** The topic to which the attendee/guide can send updates */
    mercurePublisherTopic?: string | null;
    /** The topics to which the attendee/guide can subscribe for */
    mercureSubscriberTopics?: string[];
    /** The new context token */
    newContextToken?: string;
    /**
     * The type of the appointment
     * @enum {string}
     */
    presentationGuideMode?: "self" | "guided";
    /** The id of the current sales channel */
    salesChannelId?: string;
    /** The name of the current sales channel */
    salesChannelName?: string;
  };
  LandingPage: {
    active?: boolean;
    cmsPage?: components["schemas"]["CmsPage"];
    cmsPageId?: string;
    cmsPageVersionId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    extensions?: {
      swagDynamicAccessRules?: {
        data?: {
          /** @example 05b9d828254c957dfa5224c581439c92 */
          id?: string;
          /** @example rule */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /landing-page/815c27537bec3b60c50a2ae4d2ce875d/swagDynamicAccessRules
           */
          related?: string;
        };
      };
    };
    id: string;
    keywords?: string;
    metaDescription?: string;
    metaTitle?: string;
    name: string;
    salesChannels?: components["schemas"]["SalesChannel"][];
    seoUrls?: components["schemas"]["SeoUrl"][];
    slotConfig?: GenericRecord;
    tags?: components["schemas"]["Tag"][];
    translated: {
      cmsPageId: string;
      cmsPageVersionId: string;
      keywords: string;
      metaDescription: string;
      metaTitle: string;
      name: string;
      url: string;
      versionId: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    url: string;
    versionId?: string;
  };
  LandingPageJsonApi: components["schemas"]["resource"] & {
    active?: boolean;
    cmsPageId?: string;
    cmsPageVersionId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    extensions?: {
      swagDynamicAccessRules?: {
        data?: {
          /** @example 05b9d828254c957dfa5224c581439c92 */
          id?: string;
          /** @example rule */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /landing-page/815c27537bec3b60c50a2ae4d2ce875d/swagDynamicAccessRules
           */
          related?: string;
        };
      };
    };
    id: string;
    keywords?: string;
    metaDescription?: string;
    metaTitle?: string;
    name: string;
    relationships?: {
      cmsPage?: {
        data?: {
          /** @example 7b1460918b1abb93311108f3dc021c9b */
          id?: string;
          /** @example cms_page */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /landing-page/815c27537bec3b60c50a2ae4d2ce875d/cmsPage
           */
          related?: string;
        };
      };
      salesChannels?: {
        data?: {
          /** @example 986f6f891e90ab91c091ff4a1a460777 */
          id?: string;
          /** @example sales_channel */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /landing-page/815c27537bec3b60c50a2ae4d2ce875d/salesChannels
           */
          related?: string;
        };
      };
      seoUrls?: {
        data?: {
          /** @example 5321b5a71127b8b98cdd4b068ad56c4c */
          id?: string;
          /** @example seo_url */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /landing-page/815c27537bec3b60c50a2ae4d2ce875d/seoUrls
           */
          related?: string;
        };
      };
      tags?: {
        data?: {
          /** @example d57ac45256849d9b13e2422d91580fb9 */
          id?: string;
          /** @example tag */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /landing-page/815c27537bec3b60c50a2ae4d2ce875d/tags
           */
          related?: string;
        };
      };
    };
    slotConfig?: GenericRecord;
    translated: {
      cmsPageId: string;
      cmsPageVersionId: string;
      keywords: string;
      metaDescription: string;
      metaTitle: string;
      name: string;
      url: string;
      versionId: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    url: string;
    versionId?: string;
  };
  LandingPageSalesChannel: {
    id?: string;
    landingPage?: components["schemas"]["LandingPage"];
    landingPageId: string;
    landingPageVersionId?: string;
    salesChannel?: components["schemas"]["SalesChannel"];
    salesChannelId: string;
  };
  LandingPageTag: {
    id?: string;
    landingPage?: components["schemas"]["LandingPage"];
    landingPageId: string;
    landingPageVersionId?: string;
    tag?: components["schemas"]["Tag"];
    tagId: string;
  };
  Language: {
    children?: components["schemas"]["Language"][];
    /** Format: date-time */
    readonly createdAt?: string;
    customers?: components["schemas"]["Customer"][];
    customFields?: GenericRecord;
    extensions?: {
      mediaAiTagTranslation?: {
        data?: {
          /** @example e78da60cc3106508ef465909fa4cb138 */
          id?: string;
          /** @example media_ai_tag_translation */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /language/4994a8ffeba4ac3140beb89e8d41f174/mediaAiTagTranslation
           */
          related?: string;
        };
      };
      presentationTranslation?: {
        data?: {
          /** @example e22d79f2b1909484a375a5dc228ef751 */
          id?: string;
          /** @example dsr_presentation_translation */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /language/4994a8ffeba4ac3140beb89e8d41f174/presentationTranslation
           */
          related?: string;
        };
      };
      quotes?: {
        data?: {
          /** @example 2150fd65034a9bcdb357943b3900a918 */
          id?: string;
          /** @example quote */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /language/4994a8ffeba4ac3140beb89e8d41f174/quotes
           */
          related?: string;
        };
      };
      subscriptions?: {
        data?: {
          /** @example 2d5d14f95af035cbd8437948de61f94c */
          id?: string;
          /** @example subscription */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /language/4994a8ffeba4ac3140beb89e8d41f174/subscriptions
           */
          related?: string;
        };
      };
      swagLanguagePackLanguage?: {
        data?: {
          /** @example b0e2ae26691394a06d0fd87b9f97605b */
          id?: string;
          /** @example swag_language_pack_language */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /language/4994a8ffeba4ac3140beb89e8d41f174/swagLanguagePackLanguage
           */
          related?: string;
        };
      };
    };
    id: string;
    locale?: components["schemas"]["Locale"];
    localeId: string;
    name: string;
    newsletterRecipients?: components["schemas"]["NewsletterRecipient"][];
    orders?: components["schemas"]["Order"][];
    parent?: components["schemas"]["Language"];
    parentId?: string;
    productKeywordDictionaries?: components["schemas"]["ProductKeywordDictionary"][];
    productReviews?: components["schemas"]["ProductReview"][];
    productSearchConfig?: components["schemas"]["ProductSearchConfig"];
    productSearchKeywords?: components["schemas"]["ProductSearchKeyword"][];
    salesChannelDefaultAssignments?: components["schemas"]["SalesChannel"][];
    salesChannelDomains?: components["schemas"]["SalesChannelDomain"][];
    salesChannels?: components["schemas"]["SalesChannel"][];
    translationCode?: components["schemas"]["Locale"];
    translationCodeId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  LanguageJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    extensions?: {
      mediaAiTagTranslation?: {
        data?: {
          /** @example e78da60cc3106508ef465909fa4cb138 */
          id?: string;
          /** @example media_ai_tag_translation */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /language/4994a8ffeba4ac3140beb89e8d41f174/mediaAiTagTranslation
           */
          related?: string;
        };
      };
      presentationTranslation?: {
        data?: {
          /** @example e22d79f2b1909484a375a5dc228ef751 */
          id?: string;
          /** @example dsr_presentation_translation */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /language/4994a8ffeba4ac3140beb89e8d41f174/presentationTranslation
           */
          related?: string;
        };
      };
      quotes?: {
        data?: {
          /** @example 2150fd65034a9bcdb357943b3900a918 */
          id?: string;
          /** @example quote */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /language/4994a8ffeba4ac3140beb89e8d41f174/quotes
           */
          related?: string;
        };
      };
      subscriptions?: {
        data?: {
          /** @example 2d5d14f95af035cbd8437948de61f94c */
          id?: string;
          /** @example subscription */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /language/4994a8ffeba4ac3140beb89e8d41f174/subscriptions
           */
          related?: string;
        };
      };
      swagLanguagePackLanguage?: {
        data?: {
          /** @example b0e2ae26691394a06d0fd87b9f97605b */
          id?: string;
          /** @example swag_language_pack_language */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /language/4994a8ffeba4ac3140beb89e8d41f174/swagLanguagePackLanguage
           */
          related?: string;
        };
      };
    };
    id: string;
    localeId: string;
    name: string;
    parentId?: string;
    relationships?: {
      children?: {
        data?: {
          /** @example 268184c12df027f536154d099d497b31 */
          id?: string;
          /** @example language */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /language/4994a8ffeba4ac3140beb89e8d41f174/children
           */
          related?: string;
        };
      };
      customers?: {
        data?: {
          /** @example 4b6f7d34a58ba399f077685951d06738 */
          id?: string;
          /** @example customer */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /language/4994a8ffeba4ac3140beb89e8d41f174/customers
           */
          related?: string;
        };
      };
      locale?: {
        data?: {
          /** @example fb216d9e8791e63c8d12bdc420956839 */
          id?: string;
          /** @example locale */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /language/4994a8ffeba4ac3140beb89e8d41f174/locale
           */
          related?: string;
        };
      };
      newsletterRecipients?: {
        data?: {
          /** @example 2217f01dc5cddfd5b60387c39867f58e */
          id?: string;
          /** @example newsletter_recipient */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /language/4994a8ffeba4ac3140beb89e8d41f174/newsletterRecipients
           */
          related?: string;
        };
      };
      orders?: {
        data?: {
          /** @example 12c500ed0b7879105fb46af0f246be87 */
          id?: string;
          /** @example order */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /language/4994a8ffeba4ac3140beb89e8d41f174/orders
           */
          related?: string;
        };
      };
      parent?: {
        data?: {
          /** @example d0e45878043844ffc41aac437e86b602 */
          id?: string;
          /** @example language */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /language/4994a8ffeba4ac3140beb89e8d41f174/parent
           */
          related?: string;
        };
      };
      productKeywordDictionaries?: {
        data?: {
          /** @example 660e189a383ca4eb148e25eb0df85988 */
          id?: string;
          /** @example product_keyword_dictionary */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /language/4994a8ffeba4ac3140beb89e8d41f174/productKeywordDictionaries
           */
          related?: string;
        };
      };
      productReviews?: {
        data?: {
          /** @example 01e78541ea343ed72424a5222796a4cd */
          id?: string;
          /** @example product_review */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /language/4994a8ffeba4ac3140beb89e8d41f174/productReviews
           */
          related?: string;
        };
      };
      productSearchConfig?: {
        data?: {
          /** @example 8d4fbbaa71409309d308e57678de7d7a */
          id?: string;
          /** @example product_search_config */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /language/4994a8ffeba4ac3140beb89e8d41f174/productSearchConfig
           */
          related?: string;
        };
      };
      productSearchKeywords?: {
        data?: {
          /** @example ea9cb6522f347c9212c9459d63c645f4 */
          id?: string;
          /** @example product_search_keyword */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /language/4994a8ffeba4ac3140beb89e8d41f174/productSearchKeywords
           */
          related?: string;
        };
      };
      salesChannelDefaultAssignments?: {
        data?: {
          /** @example b23663b2abc0909be9a8027a3fbff74b */
          id?: string;
          /** @example sales_channel */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /language/4994a8ffeba4ac3140beb89e8d41f174/salesChannelDefaultAssignments
           */
          related?: string;
        };
      };
      salesChannelDomains?: {
        data?: {
          /** @example b60ab8d110194bfe34ef9928ba48ab6d */
          id?: string;
          /** @example sales_channel_domain */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /language/4994a8ffeba4ac3140beb89e8d41f174/salesChannelDomains
           */
          related?: string;
        };
      };
      salesChannels?: {
        data?: {
          /** @example 986f6f891e90ab91c091ff4a1a460777 */
          id?: string;
          /** @example sales_channel */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /language/4994a8ffeba4ac3140beb89e8d41f174/salesChannels
           */
          related?: string;
        };
      };
      translationCode?: {
        data?: {
          /** @example 6ef2035242b8fcb7b61c3a41850e60b3 */
          id?: string;
          /** @example locale */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /language/4994a8ffeba4ac3140beb89e8d41f174/translationCode
           */
          related?: string;
        };
      };
    };
    translationCodeId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  LineItem: {
    children?: components["schemas"]["LineItem"][];
    cover?: components["schemas"]["ProductMedia"];
    dataContextHash?: string;
    dataTimestamp?: string;
    deliveryInformation?: components["schemas"]["CartDeliveryInformation"];
    description?: string;
    good?: boolean;
    id: string;
    label?: string;
    modified?: boolean;
    modifiedByApp?: boolean;
    payload?: components["schemas"]["ProductJsonApi"];
    price?: {
      /** @enum {string} */
      apiAlias: "calculated_price";
      calculatedTaxes?: {
        /** @enum {string} */
        apiAlias: "cart_tax_calculated";
        price: number;
        tax: number;
        taxRate: number;
      }[];
      listPrice?: components["schemas"]["CartListPrice"] | null;
      quantity: number;
      referencePrice?: components["schemas"]["CartPriceReference"] | null;
      regulationPrice?: {
        /** @enum {string} */
        apiAlias?: "cart_regulation_price";
        price?: number;
      } | null;
      /** Currently active tax rules and/or rates */
      taxRules?: {
        name?: string;
        /** Format: float */
        taxRate?: number;
      }[];
      totalPrice: number;
      unitPrice: number;
    };
    priceDefinition?: components["schemas"]["CartPriceQuantity"];
    quantity?: number;
    quantityInformation?: {
      maxPurchase?: number;
      minPurchase?: number;
      purchaseSteps?: number;
    };
    referencedId?: string;
    removable?: boolean;
    stackable?: boolean;
    states?: ("is-physical" | "is-download")[];
    type: components["schemas"]["LineItemType"];
    uniqueIdentifier?: string;
  };
  LineItemType:
    | "product"
    | "credit"
    | "custom"
    | "promotion"
    | "discount"
    | "container"
    | "quantity";
  Locale: {
    code: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    id: string;
    languages?: components["schemas"]["Language"][];
    name: string;
    territory: string;
    translated: {
      code: string;
      name: string;
      territory: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    users?: components["schemas"]["User"][];
  };
  LocaleJsonApi: components["schemas"]["resource"] & {
    code: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    id: string;
    name: string;
    relationships?: {
      languages?: {
        data?: {
          /** @example f3e334d42863e8250c7d03efefbfd387 */
          id?: string;
          /** @example language */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /locale/911f0f24bdce6808f4614d6a263b143b/languages
           */
          related?: string;
        };
      };
      users?: {
        data?: {
          /** @example 9bc65c2abec141778ffaa729489f3e87 */
          id?: string;
          /** @example user */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /locale/911f0f24bdce6808f4614d6a263b143b/users
           */
          related?: string;
        };
      };
    };
    territory: string;
    translated: {
      code: string;
      name: string;
      territory: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  LogEntry: {
    channel?: string;
    context?: GenericRecord;
    /** Format: date-time */
    readonly createdAt?: string;
    extra?: GenericRecord;
    id: string;
    /** Format: int64 */
    level?: number;
    message?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  LogEntryJsonApi: components["schemas"]["resource"] & {
    channel?: string;
    context?: GenericRecord;
    /** Format: date-time */
    readonly createdAt?: string;
    extra?: GenericRecord;
    id: string;
    /** Format: int64 */
    level?: number;
    message?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  MailHeaderFooter: {
    /** Format: date-time */
    readonly createdAt?: string;
    description?: string;
    footerHtml?: string;
    footerPlain?: string;
    headerHtml?: string;
    headerPlain?: string;
    id: string;
    name: string;
    salesChannels?: components["schemas"]["SalesChannel"][];
    systemDefault?: boolean;
    translated: {
      description: string;
      footerHtml: string;
      footerPlain: string;
      headerHtml: string;
      headerPlain: string;
      name: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  MailHeaderFooterJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    description?: string;
    footerHtml?: string;
    footerPlain?: string;
    headerHtml?: string;
    headerPlain?: string;
    id: string;
    name: string;
    relationships?: {
      salesChannels?: {
        data?: {
          /** @example 986f6f891e90ab91c091ff4a1a460777 */
          id?: string;
          /** @example sales_channel */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /mail-header-footer/d4e12da612e348a322edb9e721a365ef/salesChannels
           */
          related?: string;
        };
      };
    };
    systemDefault?: boolean;
    translated: {
      description: string;
      footerHtml: string;
      footerPlain: string;
      headerHtml: string;
      headerPlain: string;
      name: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  MailTemplate: {
    contentHtml: string;
    contentPlain: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    description?: string;
    extensions?: {
      swagCmsExtensionsForms?: {
        data?: {
          /** @example a08561237fe1e2a012502c820a08405d */
          id?: string;
          /** @example swag_cms_extensions_form */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /mail-template/901aa1bf1715ad482f037eaa8b9cdc3a/swagCmsExtensionsForms
           */
          related?: string;
        };
      };
    };
    id: string;
    mailTemplateType?: components["schemas"]["MailTemplateType"];
    mailTemplateTypeId: string;
    media?: components["schemas"]["MailTemplateMedia"][];
    senderName?: string;
    subject: string;
    systemDefault?: boolean;
    translated: {
      contentHtml: string;
      contentPlain: string;
      description: string;
      mailTemplateTypeId: string;
      senderName: string;
      subject: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  MailTemplateJsonApi: components["schemas"]["resource"] & {
    contentHtml: string;
    contentPlain: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    description?: string;
    extensions?: {
      swagCmsExtensionsForms?: {
        data?: {
          /** @example a08561237fe1e2a012502c820a08405d */
          id?: string;
          /** @example swag_cms_extensions_form */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /mail-template/901aa1bf1715ad482f037eaa8b9cdc3a/swagCmsExtensionsForms
           */
          related?: string;
        };
      };
    };
    id: string;
    mailTemplateTypeId: string;
    relationships?: {
      mailTemplateType?: {
        data?: {
          /** @example f4e3707ad46065609def210a855620cd */
          id?: string;
          /** @example mail_template_type */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /mail-template/901aa1bf1715ad482f037eaa8b9cdc3a/mailTemplateType
           */
          related?: string;
        };
      };
      media?: {
        data?: {
          /** @example 62933a2951ef01f4eafd9bdf4d3cd2f0 */
          id?: string;
          /** @example mail_template_media */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /mail-template/901aa1bf1715ad482f037eaa8b9cdc3a/media
           */
          related?: string;
        };
      };
    };
    senderName?: string;
    subject: string;
    systemDefault?: boolean;
    translated: {
      contentHtml: string;
      contentPlain: string;
      description: string;
      mailTemplateTypeId: string;
      senderName: string;
      subject: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  MailTemplateMedia: {
    id: string;
    languageId: string;
    mailTemplate?: components["schemas"]["MailTemplate"];
    mailTemplateId: string;
    media?: components["schemas"]["Media"];
    mediaId: string;
    /** Format: int64 */
    position?: number;
  };
  MailTemplateType: {
    availableEntities?: GenericRecord;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    id: string;
    mailTemplates?: components["schemas"]["MailTemplate"][];
    name: string;
    technicalName: string;
    templateData?: GenericRecord;
    translated: {
      name: string;
      technicalName: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  MailTemplateTypeJsonApi: components["schemas"]["resource"] & {
    availableEntities?: GenericRecord;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    id: string;
    name: string;
    relationships?: {
      mailTemplates?: {
        data?: {
          /** @example e6f502f7d88de75db45325d22998cf6d */
          id?: string;
          /** @example mail_template */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /mail-template-type/e0107df21530abfba881ccec2728ac79/mailTemplates
           */
          related?: string;
        };
      };
    };
    technicalName: string;
    templateData?: GenericRecord;
    translated: {
      name: string;
      technicalName: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  MainCategory: {
    category?: components["schemas"]["Category"];
    categoryId: string;
    categoryVersionId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    product?: components["schemas"]["Product"];
    productId: string;
    productVersionId?: string;
    salesChannel?: components["schemas"]["SalesChannel"];
    salesChannelId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  MainCategoryJsonApi: components["schemas"]["resource"] & {
    categoryId: string;
    categoryVersionId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    productId: string;
    productVersionId?: string;
    relationships?: {
      category?: {
        data?: {
          /** @example c4ef352f74e502ef5e7bc98e6f4e493d */
          id?: string;
          /** @example category */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /main-category/ea5e6ad409757a2bf4b9f4c597fadc53/category
           */
          related?: string;
        };
      };
      product?: {
        data?: {
          /** @example f5bf48aa40cad7891eb709fcf1fde128 */
          id?: string;
          /** @example product */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /main-category/ea5e6ad409757a2bf4b9f4c597fadc53/product
           */
          related?: string;
        };
      };
      salesChannel?: {
        data?: {
          /** @example ec3712a84143b57e0db620eaac6e55b8 */
          id?: string;
          /** @example sales_channel */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /main-category/ea5e6ad409757a2bf4b9f4c597fadc53/salesChannel
           */
          related?: string;
        };
      };
    };
    salesChannelId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  Media: {
    alt?: string;
    appPaymentMethods?: components["schemas"]["AppPaymentMethod"][];
    appShippingMethods?: components["schemas"]["AppShippingMethod"][];
    avatarUsers?: components["schemas"]["User"][];
    categories?: components["schemas"]["Category"][];
    cmsBlocks?: components["schemas"]["CmsBlock"][];
    cmsPages?: components["schemas"]["CmsPage"][];
    cmsSections?: components["schemas"]["CmsSection"][];
    config?: GenericRecord;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    documentBaseConfigs?: components["schemas"]["DocumentBaseConfig"][];
    documents?: components["schemas"]["Document"][];
    extensions?: {
      cmsPageDrafts?: {
        data?: {
          /** @example 93c0df75844858f2b2a9359abc152f5d */
          id?: string;
          /** @example cms_page_draft */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /media/3b563524fdb17b4a86590470d40bef74/cmsPageDrafts
           */
          related?: string;
        };
      };
      mediaAiTag?: {
        data?: {
          /** @example 3c88197809d464216a8c40a8db191b38 */
          id?: string;
          /** @example media_ai_tag */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /media/3b563524fdb17b4a86590470d40bef74/mediaAiTag
           */
          related?: string;
        };
      };
      quoteDocuments?: {
        data?: {
          /** @example 5f9aa016c99bbfdc16be8c44d885e7e4 */
          id?: string;
          /** @example quote_document */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /media/3b563524fdb17b4a86590470d40bef74/quoteDocuments
           */
          related?: string;
        };
      };
      spatialObjects?: {
        data?: {
          /** @example ad6bd8458100c1c7b8a7d1478a4ba188 */
          id?: string;
          /** @example spatial_scene_object */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /media/3b563524fdb17b4a86590470d40bef74/spatialObjects
           */
          related?: string;
        };
      };
      ssoProviders?: {
        data?: {
          /** @example 520b66891556bf9309da72937c4f1f98 */
          id?: string;
          /** @example sso_provider */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /media/3b563524fdb17b4a86590470d40bef74/ssoProviders
           */
          related?: string;
        };
      };
      swagCustomizedProductsTemplate?: {
        data?: {
          /** @example 6e9fad30dd3cb84748a01bb8152f4769 */
          id?: string;
          /** @example swag_customized_products_template */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /media/3b563524fdb17b4a86590470d40bef74/swagCustomizedProductsTemplate
           */
          related?: string;
        };
      };
      themeMedia?: {
        data?: {
          /** @example 260be9ecb281c4ff04e7189bb18a35bd */
          id?: string;
          /** @example theme */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /media/3b563524fdb17b4a86590470d40bef74/themeMedia
           */
          related?: string;
        };
      };
      themes?: {
        data?: {
          /** @example fe021943dcda87150f590b3475afaded */
          id?: string;
          /** @example theme */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /media/3b563524fdb17b4a86590470d40bef74/themes
           */
          related?: string;
        };
      };
    };
    readonly fileExtension?: string;
    readonly fileName?: string;
    /** Format: int64 */
    readonly fileSize?: number;
    /** Runtime field, cannot be used as part of the criteria. */
    hasFile?: boolean;
    id: string;
    mailTemplateMedia?: components["schemas"]["MailTemplateMedia"][];
    mediaFolder?: components["schemas"]["MediaFolder"];
    mediaFolderId?: string;
    readonly mediaType?: GenericRecord;
    readonly metaData?: GenericRecord;
    readonly mimeType?: string;
    orderLineItemDownloads?: components["schemas"]["OrderLineItemDownload"][];
    orderLineItems?: components["schemas"]["OrderLineItem"][];
    path?: string;
    paymentMethods?: components["schemas"]["PaymentMethod"][];
    private?: boolean;
    productConfiguratorSettings?: components["schemas"]["ProductConfiguratorSetting"][];
    productDownloads?: components["schemas"]["ProductDownload"][];
    productManufacturers?: components["schemas"]["ProductManufacturer"][];
    productMedia?: components["schemas"]["ProductMedia"][];
    propertyGroupOptions?: components["schemas"]["PropertyGroupOption"][];
    shippingMethods?: components["schemas"]["ShippingMethod"][];
    tags?: components["schemas"]["Tag"][];
    thumbnails?: components["schemas"]["MediaThumbnail"][];
    title?: string;
    translated: {
      alt: string;
      fileExtension: string;
      fileName: string;
      mediaFolderId: string;
      mimeType: string;
      path: string;
      title: string;
      uploadedAt: string;
      url: string;
      userId: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    /** Format: date-time */
    readonly uploadedAt?: string;
    /** Runtime field, cannot be used as part of the criteria. */
    url?: string;
    user?: components["schemas"]["User"];
    userId?: string;
  };
  MediaAiTag: {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    media?: components["schemas"]["Media"];
    mediaId: string;
    readonly needsAnalysis?: boolean;
    tags?: GenericRecord[];
    translated: {
      mediaId: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  MediaAiTagJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    mediaId: string;
    readonly needsAnalysis?: boolean;
    relationships?: {
      media?: {
        data?: {
          /** @example 62933a2951ef01f4eafd9bdf4d3cd2f0 */
          id?: string;
          /** @example media */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /media-ai-tag/569e3d7be3a3ea0397be0e81cac3235d/media
           */
          related?: string;
        };
      };
    };
    tags?: GenericRecord[];
    translated: {
      mediaId: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  MediaDefaultFolder: {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    entity: string;
    folder?: components["schemas"]["MediaFolder"];
    id: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  MediaDefaultFolderJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    entity: string;
    id: string;
    relationships?: {
      folder?: {
        data?: {
          /** @example 851148b4fd8fd7ae74bd9100c5c0c898 */
          id?: string;
          /** @example media_folder */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /media-default-folder/8a4b9e9331eadf522da72638577cd527/folder
           */
          related?: string;
        };
      };
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  MediaFolder: {
    /** Format: int64 */
    readonly childCount?: number;
    children?: components["schemas"]["MediaFolder"][];
    configuration?: components["schemas"]["MediaFolderConfiguration"];
    configurationId: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    defaultFolder?: components["schemas"]["MediaDefaultFolder"];
    defaultFolderId?: string;
    id: string;
    media?: components["schemas"]["Media"][];
    name: string;
    parent?: components["schemas"]["MediaFolder"];
    parentId?: string;
    readonly path?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    useParentConfiguration?: boolean;
  };
  MediaFolderConfiguration: {
    /** Format: date-time */
    readonly createdAt?: string;
    createThumbnails?: boolean;
    customFields?: GenericRecord;
    id: string;
    keepAspectRatio?: boolean;
    mediaFolders?: components["schemas"]["MediaFolder"][];
    mediaThumbnailSizes?: components["schemas"]["MediaThumbnailSize"][];
    noAssociation?: boolean;
    private?: boolean;
    /** Format: int64 */
    thumbnailQuality?: number;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  MediaFolderConfigurationJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    createThumbnails?: boolean;
    customFields?: GenericRecord;
    id: string;
    keepAspectRatio?: boolean;
    noAssociation?: boolean;
    private?: boolean;
    relationships?: {
      mediaFolders?: {
        data?: {
          /** @example 6e8238687513bde2e85821c839c597c6 */
          id?: string;
          /** @example media_folder */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /media-folder-configuration/97dfbba6a3d961140a22cc5473030850/mediaFolders
           */
          related?: string;
        };
      };
      mediaThumbnailSizes?: {
        data?: {
          /** @example 44dee48a0006e8db2fcec2a5e1456449 */
          id?: string;
          /** @example media_thumbnail_size */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /media-folder-configuration/97dfbba6a3d961140a22cc5473030850/mediaThumbnailSizes
           */
          related?: string;
        };
      };
    };
    /** Format: int64 */
    thumbnailQuality?: number;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  MediaFolderConfigurationMediaThumbnailSize: {
    id?: string;
    mediaFolderConfiguration?: components["schemas"]["MediaFolderConfiguration"];
    mediaFolderConfigurationId: string;
    mediaThumbnailSize?: components["schemas"]["MediaThumbnailSize"];
    mediaThumbnailSizeId: string;
  };
  MediaFolderJsonApi: components["schemas"]["resource"] & {
    /** Format: int64 */
    readonly childCount?: number;
    configurationId: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    defaultFolderId?: string;
    id: string;
    name: string;
    parentId?: string;
    readonly path?: string;
    relationships?: {
      children?: {
        data?: {
          /** @example 268184c12df027f536154d099d497b31 */
          id?: string;
          /** @example media_folder */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /media-folder/8e24b126f2d2bd4373ca2681b47a405d/children
           */
          related?: string;
        };
      };
      configuration?: {
        data?: {
          /** @example ccd1066343c95877b75b79d47c36bebe */
          id?: string;
          /** @example media_folder_configuration */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /media-folder/8e24b126f2d2bd4373ca2681b47a405d/configuration
           */
          related?: string;
        };
      };
      defaultFolder?: {
        data?: {
          /** @example 251dcc9b1621d34e6b01ee14c26b3027 */
          id?: string;
          /** @example media_default_folder */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /media-folder/8e24b126f2d2bd4373ca2681b47a405d/defaultFolder
           */
          related?: string;
        };
      };
      media?: {
        data?: {
          /** @example 62933a2951ef01f4eafd9bdf4d3cd2f0 */
          id?: string;
          /** @example media */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /media-folder/8e24b126f2d2bd4373ca2681b47a405d/media
           */
          related?: string;
        };
      };
      parent?: {
        data?: {
          /** @example d0e45878043844ffc41aac437e86b602 */
          id?: string;
          /** @example media_folder */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /media-folder/8e24b126f2d2bd4373ca2681b47a405d/parent
           */
          related?: string;
        };
      };
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    useParentConfiguration?: boolean;
  };
  MediaJsonApi: components["schemas"]["resource"] & {
    alt?: string;
    config?: GenericRecord;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    extensions?: {
      cmsPageDrafts?: {
        data?: {
          /** @example 93c0df75844858f2b2a9359abc152f5d */
          id?: string;
          /** @example cms_page_draft */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /media/3b563524fdb17b4a86590470d40bef74/cmsPageDrafts
           */
          related?: string;
        };
      };
      mediaAiTag?: {
        data?: {
          /** @example 3c88197809d464216a8c40a8db191b38 */
          id?: string;
          /** @example media_ai_tag */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /media/3b563524fdb17b4a86590470d40bef74/mediaAiTag
           */
          related?: string;
        };
      };
      quoteDocuments?: {
        data?: {
          /** @example 5f9aa016c99bbfdc16be8c44d885e7e4 */
          id?: string;
          /** @example quote_document */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /media/3b563524fdb17b4a86590470d40bef74/quoteDocuments
           */
          related?: string;
        };
      };
      spatialObjects?: {
        data?: {
          /** @example ad6bd8458100c1c7b8a7d1478a4ba188 */
          id?: string;
          /** @example spatial_scene_object */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /media/3b563524fdb17b4a86590470d40bef74/spatialObjects
           */
          related?: string;
        };
      };
      ssoProviders?: {
        data?: {
          /** @example 520b66891556bf9309da72937c4f1f98 */
          id?: string;
          /** @example sso_provider */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /media/3b563524fdb17b4a86590470d40bef74/ssoProviders
           */
          related?: string;
        };
      };
      swagCustomizedProductsTemplate?: {
        data?: {
          /** @example 6e9fad30dd3cb84748a01bb8152f4769 */
          id?: string;
          /** @example swag_customized_products_template */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /media/3b563524fdb17b4a86590470d40bef74/swagCustomizedProductsTemplate
           */
          related?: string;
        };
      };
      themeMedia?: {
        data?: {
          /** @example 260be9ecb281c4ff04e7189bb18a35bd */
          id?: string;
          /** @example theme */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /media/3b563524fdb17b4a86590470d40bef74/themeMedia
           */
          related?: string;
        };
      };
      themes?: {
        data?: {
          /** @example fe021943dcda87150f590b3475afaded */
          id?: string;
          /** @example theme */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /media/3b563524fdb17b4a86590470d40bef74/themes
           */
          related?: string;
        };
      };
    };
    readonly fileExtension?: string;
    readonly fileName?: string;
    /** Format: int64 */
    readonly fileSize?: number;
    /** Runtime field, cannot be used as part of the criteria. */
    hasFile?: boolean;
    id: string;
    mediaFolderId?: string;
    readonly mediaType?: GenericRecord;
    readonly metaData?: GenericRecord;
    readonly mimeType?: string;
    path?: string;
    private?: boolean;
    relationships?: {
      appPaymentMethods?: {
        data?: {
          /** @example e53c737d351047e64a02b7a2a4caffe3 */
          id?: string;
          /** @example app_payment_method */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /media/3b563524fdb17b4a86590470d40bef74/appPaymentMethods
           */
          related?: string;
        };
      };
      appShippingMethods?: {
        data?: {
          /** @example 1ad05ee47064647ee5b2dc8c12b1041c */
          id?: string;
          /** @example app_shipping_method */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /media/3b563524fdb17b4a86590470d40bef74/appShippingMethods
           */
          related?: string;
        };
      };
      avatarUsers?: {
        data?: {
          /** @example 1fc09529f6c95370eb20b81318ff601f */
          id?: string;
          /** @example user */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /media/3b563524fdb17b4a86590470d40bef74/avatarUsers
           */
          related?: string;
        };
      };
      categories?: {
        data?: {
          /** @example b0b5ccb4a195a07fd3eed14affb8695f */
          id?: string;
          /** @example category */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /media/3b563524fdb17b4a86590470d40bef74/categories
           */
          related?: string;
        };
      };
      cmsBlocks?: {
        data?: {
          /** @example 3636c4901eab836dfb837e1a9a37d3c0 */
          id?: string;
          /** @example cms_block */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /media/3b563524fdb17b4a86590470d40bef74/cmsBlocks
           */
          related?: string;
        };
      };
      cmsPages?: {
        data?: {
          /** @example e676148cc6ffb82b89b3903ecaed2d16 */
          id?: string;
          /** @example cms_page */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /media/3b563524fdb17b4a86590470d40bef74/cmsPages
           */
          related?: string;
        };
      };
      cmsSections?: {
        data?: {
          /** @example 53be3cc1c4a8f41af67a90cf9fd09194 */
          id?: string;
          /** @example cms_section */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /media/3b563524fdb17b4a86590470d40bef74/cmsSections
           */
          related?: string;
        };
      };
      documentBaseConfigs?: {
        data?: {
          /** @example 0e128fa41e6afdcd85baa8ee7b07b0e3 */
          id?: string;
          /** @example document_base_config */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /media/3b563524fdb17b4a86590470d40bef74/documentBaseConfigs
           */
          related?: string;
        };
      };
      documents?: {
        data?: {
          /** @example 21f64da1e5792c8295b964d159a14491 */
          id?: string;
          /** @example document */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /media/3b563524fdb17b4a86590470d40bef74/documents
           */
          related?: string;
        };
      };
      mailTemplateMedia?: {
        data?: {
          /** @example 9970132c8439a2e630b655812b031459 */
          id?: string;
          /** @example mail_template_media */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /media/3b563524fdb17b4a86590470d40bef74/mailTemplateMedia
           */
          related?: string;
        };
      };
      mediaFolder?: {
        data?: {
          /** @example 70605921a592ee735964394f7948773b */
          id?: string;
          /** @example media_folder */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /media/3b563524fdb17b4a86590470d40bef74/mediaFolder
           */
          related?: string;
        };
      };
      orderLineItemDownloads?: {
        data?: {
          /** @example 8c0a5ecd281c97a912c27c0237b3848f */
          id?: string;
          /** @example order_line_item_download */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /media/3b563524fdb17b4a86590470d40bef74/orderLineItemDownloads
           */
          related?: string;
        };
      };
      orderLineItems?: {
        data?: {
          /** @example 6bd56ce4562ca1be86bf5b8d92c3c1ee */
          id?: string;
          /** @example order_line_item */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /media/3b563524fdb17b4a86590470d40bef74/orderLineItems
           */
          related?: string;
        };
      };
      paymentMethods?: {
        data?: {
          /** @example b631b1ab565525e892f9cdc1242cca14 */
          id?: string;
          /** @example payment_method */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /media/3b563524fdb17b4a86590470d40bef74/paymentMethods
           */
          related?: string;
        };
      };
      productConfiguratorSettings?: {
        data?: {
          /** @example 4d46eb45eaf392b26bd46f0ea8cb93e0 */
          id?: string;
          /** @example product_configurator_setting */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /media/3b563524fdb17b4a86590470d40bef74/productConfiguratorSettings
           */
          related?: string;
        };
      };
      productDownloads?: {
        data?: {
          /** @example 86db490c1f4f52d155dbdb978b1f45d3 */
          id?: string;
          /** @example product_download */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /media/3b563524fdb17b4a86590470d40bef74/productDownloads
           */
          related?: string;
        };
      };
      productManufacturers?: {
        data?: {
          /** @example 30e3a0f8868364c06aa4be63426c1c79 */
          id?: string;
          /** @example product_manufacturer */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /media/3b563524fdb17b4a86590470d40bef74/productManufacturers
           */
          related?: string;
        };
      };
      productMedia?: {
        data?: {
          /** @example 2b5e079404830806ea36b6c17438cffd */
          id?: string;
          /** @example product_media */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /media/3b563524fdb17b4a86590470d40bef74/productMedia
           */
          related?: string;
        };
      };
      propertyGroupOptions?: {
        data?: {
          /** @example 789104e3568fde835b6239b251d4aa07 */
          id?: string;
          /** @example property_group_option */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /media/3b563524fdb17b4a86590470d40bef74/propertyGroupOptions
           */
          related?: string;
        };
      };
      shippingMethods?: {
        data?: {
          /** @example 8268b0a6c902fbde485094c2f627b854 */
          id?: string;
          /** @example shipping_method */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /media/3b563524fdb17b4a86590470d40bef74/shippingMethods
           */
          related?: string;
        };
      };
      tags?: {
        data?: {
          /** @example d57ac45256849d9b13e2422d91580fb9 */
          id?: string;
          /** @example tag */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /media/3b563524fdb17b4a86590470d40bef74/tags
           */
          related?: string;
        };
      };
      thumbnails?: {
        data?: {
          /** @example 3b8779ba05b8f0aed49650f3ff8beb4b */
          id?: string;
          /** @example media_thumbnail */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /media/3b563524fdb17b4a86590470d40bef74/thumbnails
           */
          related?: string;
        };
      };
      user?: {
        data?: {
          /** @example ee11cbb19052e40b07aac0ca060c23ee */
          id?: string;
          /** @example user */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /media/3b563524fdb17b4a86590470d40bef74/user
           */
          related?: string;
        };
      };
    };
    title?: string;
    translated: {
      alt: string;
      fileExtension: string;
      fileName: string;
      mediaFolderId: string;
      mimeType: string;
      path: string;
      title: string;
      uploadedAt: string;
      url: string;
      userId: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    /** Format: date-time */
    readonly uploadedAt?: string;
    /** Runtime field, cannot be used as part of the criteria. */
    url?: string;
    userId?: string;
  };
  MediaTag: {
    id?: string;
    media?: components["schemas"]["Media"];
    mediaId: string;
    tag?: components["schemas"]["Tag"];
    tagId: string;
  };
  MediaThumbnail: {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    /** Format: int64 */
    readonly height: number;
    id?: string;
    media?: components["schemas"]["Media"];
    mediaId: string;
    path?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    /** Runtime field, cannot be used as part of the criteria. */
    url: string;
    /** Format: int64 */
    readonly width: number;
  };
  MediaThumbnailJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    /** Format: int64 */
    readonly height: number;
    id: string;
    mediaId: string;
    path?: string;
    relationships?: {
      media?: {
        data?: {
          /** @example 62933a2951ef01f4eafd9bdf4d3cd2f0 */
          id?: string;
          /** @example media */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /media-thumbnail/3863c110ff436b51dbc09a6ea14c56e0/media
           */
          related?: string;
        };
      };
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    /** Runtime field, cannot be used as part of the criteria. */
    url?: string;
    /** Format: int64 */
    readonly width: number;
  };
  MediaThumbnailSize: {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    /** Format: int64 */
    height: number;
    id: string;
    mediaFolderConfigurations?: components["schemas"]["MediaFolderConfiguration"][];
    /** Format: date-time */
    readonly updatedAt?: string;
    /** Format: int64 */
    width: number;
  };
  MediaThumbnailSizeJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    /** Format: int64 */
    height: number;
    id: string;
    relationships?: {
      mediaFolderConfigurations?: {
        data?: {
          /** @example 056df7a700173d83ebb685b1a890f09b */
          id?: string;
          /** @example media_folder_configuration */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /media-thumbnail-size/122652279edf3cc398ca024851b6f53f/mediaFolderConfigurations
           */
          related?: string;
        };
      };
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    /** Format: int64 */
    width: number;
  };
  MultiNotFilter: {
    /** @enum {string} */
    operator: "AND" | "OR" | "and" | "or";
    queries: components["schemas"]["Filters"];
    /** @enum {string} */
    type: "multi" | "not";
  };
  NewsletterRecipient: {
    city?: string;
    /** Format: date-time */
    confirmedAt?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    email: string;
    firstName?: string;
    hash: string;
    id: string;
    language?: components["schemas"]["Language"];
    languageId: string;
    lastName?: string;
    salesChannel?: components["schemas"]["SalesChannel"];
    salesChannelId: string;
    salutation?: components["schemas"]["Salutation"];
    salutationId?: string;
    status: string;
    street?: string;
    tags?: components["schemas"]["Tag"][];
    title?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    zipCode?: string;
  };
  NewsletterRecipientJsonApi: components["schemas"]["resource"] & {
    city?: string;
    /** Format: date-time */
    confirmedAt?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    email: string;
    firstName?: string;
    hash: string;
    id: string;
    languageId: string;
    lastName?: string;
    relationships?: {
      language?: {
        data?: {
          /** @example 8512ae7d57b1396273f76fe6ed341a23 */
          id?: string;
          /** @example language */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /newsletter-recipient/65cb0ac7d520ba60552fa3304e8a28c7/language
           */
          related?: string;
        };
      };
      salesChannel?: {
        data?: {
          /** @example ec3712a84143b57e0db620eaac6e55b8 */
          id?: string;
          /** @example sales_channel */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /newsletter-recipient/65cb0ac7d520ba60552fa3304e8a28c7/salesChannel
           */
          related?: string;
        };
      };
      salutation?: {
        data?: {
          /** @example 7a6efb02514153b5aa9a8f40c6f8bcc3 */
          id?: string;
          /** @example salutation */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /newsletter-recipient/65cb0ac7d520ba60552fa3304e8a28c7/salutation
           */
          related?: string;
        };
      };
      tags?: {
        data?: {
          /** @example d57ac45256849d9b13e2422d91580fb9 */
          id?: string;
          /** @example tag */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /newsletter-recipient/65cb0ac7d520ba60552fa3304e8a28c7/tags
           */
          related?: string;
        };
      };
    };
    salesChannelId: string;
    salutationId?: string;
    status: string;
    street?: string;
    title?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    zipCode?: string;
  };
  NewsletterRecipientTag: {
    id?: string;
    newsletterRecipient?: components["schemas"]["NewsletterRecipient"];
    newsletterRecipientId: string;
    tag?: components["schemas"]["Tag"];
    tagId: string;
  };
  Notification: {
    adminOnly?: boolean;
    /** Format: date-time */
    readonly createdAt?: string;
    createdByIntegration?: components["schemas"]["Integration"];
    createdByIntegrationId?: string;
    createdByUser?: components["schemas"]["User"];
    createdByUserId?: string;
    id: string;
    message: string;
    requiredPrivileges?: GenericRecord[];
    status: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  NotificationJsonApi: components["schemas"]["resource"] & {
    adminOnly?: boolean;
    /** Format: date-time */
    readonly createdAt?: string;
    createdByIntegrationId?: string;
    createdByUserId?: string;
    id: string;
    message: string;
    relationships?: {
      createdByIntegration?: {
        data?: {
          /** @example 4698501400b26be8a41def09646e1b59 */
          id?: string;
          /** @example integration */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /notification/96d008db67fc0b5551a926842bbb6a71/createdByIntegration
           */
          related?: string;
        };
      };
      createdByUser?: {
        data?: {
          /** @example 8a66af2fd5b68899934d19e078c9c111 */
          id?: string;
          /** @example user */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /notification/96d008db67fc0b5551a926842bbb6a71/createdByUser
           */
          related?: string;
        };
      };
    };
    requiredPrivileges?: GenericRecord[];
    status: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  NumberRange: {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    description?: string;
    global: boolean;
    id: string;
    name: string;
    numberRangeSalesChannels?: components["schemas"]["NumberRangeSalesChannel"][];
    pattern: string;
    /** Format: int64 */
    start: number;
    state?: components["schemas"]["NumberRangeState"];
    translated: {
      description: string;
      name: string;
      pattern: string;
      typeId: string;
    };
    type?: components["schemas"]["NumberRangeType"];
    typeId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  NumberRangeJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    description?: string;
    global: boolean;
    id: string;
    name: string;
    pattern: string;
    relationships?: {
      numberRangeSalesChannels?: {
        data?: {
          /** @example 62db021f1d56ae4688775365be68a04f */
          id?: string;
          /** @example number_range_sales_channel */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /number-range/5f5cfdaae1821fd1390bb63cf30cb1f2/numberRangeSalesChannels
           */
          related?: string;
        };
      };
      state?: {
        data?: {
          /** @example 9ed39e2ea931586b6a985a6942ef573e */
          id?: string;
          /** @example number_range_state */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /number-range/5f5cfdaae1821fd1390bb63cf30cb1f2/state
           */
          related?: string;
        };
      };
      type?: {
        data?: {
          /** @example 599dcce2998a6b40b1e38e8c6006cb0a */
          id?: string;
          /** @example number_range_type */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /number-range/5f5cfdaae1821fd1390bb63cf30cb1f2/type
           */
          related?: string;
        };
      };
    };
    /** Format: int64 */
    start: number;
    translated: {
      description: string;
      name: string;
      pattern: string;
      typeId: string;
    };
    typeId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  NumberRangeSalesChannel: {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    numberRange?: components["schemas"]["NumberRange"];
    numberRangeId: string;
    numberRangeType?: components["schemas"]["NumberRangeType"];
    numberRangeTypeId?: string;
    salesChannel?: components["schemas"]["SalesChannel"];
    salesChannelId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  NumberRangeSalesChannelJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    numberRangeId: string;
    numberRangeTypeId?: string;
    relationships?: {
      numberRange?: {
        data?: {
          /** @example 0345281f3553d43436c3f0cb4796f3c9 */
          id?: string;
          /** @example number_range */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /number-range-sales-channel/3ec3f602bd7f6198b92698a1ed8770ed/numberRange
           */
          related?: string;
        };
      };
      numberRangeType?: {
        data?: {
          /** @example 3d771a402fc5aa3349c2c15637058e8c */
          id?: string;
          /** @example number_range_type */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /number-range-sales-channel/3ec3f602bd7f6198b92698a1ed8770ed/numberRangeType
           */
          related?: string;
        };
      };
      salesChannel?: {
        data?: {
          /** @example ec3712a84143b57e0db620eaac6e55b8 */
          id?: string;
          /** @example sales_channel */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /number-range-sales-channel/3ec3f602bd7f6198b92698a1ed8770ed/salesChannel
           */
          related?: string;
        };
      };
    };
    salesChannelId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  NumberRangeState: {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    /** Format: int64 */
    lastValue: number;
    numberRange?: components["schemas"]["NumberRange"];
    numberRangeId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  NumberRangeStateJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    /** Format: int64 */
    lastValue: number;
    numberRangeId: string;
    relationships?: {
      numberRange?: {
        data?: {
          /** @example 0345281f3553d43436c3f0cb4796f3c9 */
          id?: string;
          /** @example number_range */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /number-range-state/152af4426362939471d98054e285f66d/numberRange
           */
          related?: string;
        };
      };
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  NumberRangeType: {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    global: boolean;
    id: string;
    numberRanges?: components["schemas"]["NumberRange"][];
    numberRangeSalesChannels?: components["schemas"]["NumberRangeSalesChannel"][];
    technicalName?: string;
    translated: {
      technicalName: string;
      typeName: string;
    };
    typeName: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  NumberRangeTypeJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    global: boolean;
    id: string;
    relationships?: {
      numberRanges?: {
        data?: {
          /** @example d28d88efea70a67487116019cff39002 */
          id?: string;
          /** @example number_range */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /number-range-type/1c05c24712e2a7f0a609a9f728a41a33/numberRanges
           */
          related?: string;
        };
      };
      numberRangeSalesChannels?: {
        data?: {
          /** @example 62db021f1d56ae4688775365be68a04f */
          id?: string;
          /** @example number_range_sales_channel */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /number-range-type/1c05c24712e2a7f0a609a9f728a41a33/numberRangeSalesChannels
           */
          related?: string;
        };
      };
    };
    technicalName?: string;
    translated: {
      technicalName: string;
      typeName: string;
    };
    typeName: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  OAuthClientCredentialsGrant: Omit<
    components["schemas"]["OAuthGrant"],
    "grant_type"
  > & {
    /** OAuth client id. */
    client_id: string;
    /** Password of the client that should be authenticated. */
    client_secret: string;
  } & {
    /**
     * discriminator enum property added by openapi-typescript
     * @enum {string}
     */
    grant_type: "client_credentials";
  };
  OAuthGrant: {
    /** OAuth grant type that should be requested. See [OAuth 2.0 grant](https://oauth2.thephpleague.com/authorization-server/which-grant/) for more information. */
    grant_type: string;
  };
  OAuthPasswordGrant: Omit<
    components["schemas"]["OAuthGrant"],
    "grant_type"
  > & {
    /**
     * OAuth client id.
     * @enum {string}
     */
    client_id: "administration";
    /** Password of the user that should be authenticated. */
    password: string;
    scopes: components["schemas"]["OAuthScopes"];
    /** Username of the user that should be authenticated. */
    username: string;
  } & {
    /**
     * discriminator enum property added by openapi-typescript
     * @enum {string}
     */
    grant_type: "password";
  };
  OAuthRefreshTokenGrant: Omit<
    components["schemas"]["OAuthGrant"],
    "grant_type"
  > & {
    /**
     * OAuth client id.
     * @enum {string}
     */
    client_id: "administration";
    /** The refresh token that should be used to refresh the access token. */
    refresh_token: string;
    scopes: components["schemas"]["OAuthScopes"];
  } & {
    /**
     * discriminator enum property added by openapi-typescript
     * @enum {string}
     */
    grant_type: "refresh_token";
  };
  OAuthScopes:
    | "write"
    | "user-verified"
    | "admin"
    | "write user-verified"
    | "write admin"
    | "user-verified admin"
    | "write user-verified admin";
  Order: {
    addresses?: components["schemas"]["OrderAddress"][];
    affiliateCode?: string;
    /** Format: float */
    readonly amountNet?: number;
    /** Format: float */
    readonly amountTotal?: number;
    /** Format: int64 */
    readonly autoIncrement?: number;
    billingAddress?: components["schemas"]["OrderAddress"];
    billingAddressId: string;
    billingAddressVersionId?: string;
    campaignCode?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    createdBy?: components["schemas"]["User"];
    createdById?: string;
    currency?: components["schemas"]["Currency"];
    /** Format: float */
    currencyFactor: number;
    currencyId: string;
    customerComment?: string;
    customFields?: GenericRecord;
    deepLinkCode?: string;
    deliveries?: components["schemas"]["OrderDelivery"][];
    documents?: components["schemas"]["Document"][];
    extensions?: {
      b2bPendingOrder?: {
        data?: {
          /** @example c7e0572188e2dec59215e8872024567e */
          id?: string;
          /** @example b2b_components_pending_order */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /order/a240fa27925a635b08dc28c9e4f9216d/b2bPendingOrder
           */
          related?: string;
        };
      };
      delayActions?: {
        data?: {
          /** @example edfed55799054673006c4b5a643489ac */
          id?: string;
          /** @example swag_delay_action */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /order/a240fa27925a635b08dc28c9e4f9216d/delayActions
           */
          related?: string;
        };
      };
      orderEmployee?: {
        data?: {
          /** @example 5ea451c08a87db806089c4031601c29a */
          id?: string;
          /** @example b2b_order_employee */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /order/a240fa27925a635b08dc28c9e4f9216d/orderEmployee
           */
          related?: string;
        };
      };
      returns?: {
        data?: {
          /** @example 7fff84525c6516919851a9005373f87e */
          id?: string;
          /** @example order_return */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /order/a240fa27925a635b08dc28c9e4f9216d/returns
           */
          related?: string;
        };
      };
      subscription?: {
        data?: {
          /** @example b48b13e73a6ac2a86dc54425dd24d9ff */
          id?: string;
          /** @example subscription */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /order/a240fa27925a635b08dc28c9e4f9216d/subscription
           */
          related?: string;
        };
      };
      swagSocialShoppingOrder?: {
        data?: {
          /** @example 829fa9441f5dea1e7ada99a9ae4a867f */
          id?: string;
          /** @example swag_social_shopping_order */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /order/a240fa27925a635b08dc28c9e4f9216d/swagSocialShoppingOrder
           */
          related?: string;
        };
      };
      warehouseGroups?: {
        data?: {
          /** @example 21191f2f6f4c30cd4ccc4714fa74ffea */
          id?: string;
          /** @example order_warehouse_group */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /order/a240fa27925a635b08dc28c9e4f9216d/warehouseGroups
           */
          related?: string;
        };
      };
      warehouseProducts?: {
        data?: {
          /** @example 702258c6879958a41dfc328ad5c00325 */
          id?: string;
          /** @example order_product_warehouse */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /order/a240fa27925a635b08dc28c9e4f9216d/warehouseProducts
           */
          related?: string;
        };
      };
    };
    id: string;
    itemRounding: {
      /** Format: int64 */
      decimals: number;
      /** Format: float */
      interval: number;
      roundForNet: boolean;
    };
    language?: components["schemas"]["Language"];
    languageId: string;
    lineItems?: components["schemas"]["OrderLineItem"][];
    orderCustomer?: components["schemas"]["OrderCustomer"];
    readonly orderDate?: string;
    /** Format: date-time */
    orderDateTime: string;
    orderNumber?: string;
    /** Format: float */
    readonly positionPrice?: number;
    price?: {
      calculatedTaxes?: GenericRecord;
      /** Format: float */
      netPrice: number;
      /** Format: float */
      positionPrice: number;
      /** Format: float */
      rawTotal: number;
      taxRules?: GenericRecord;
      taxStatus: string;
      /** Format: float */
      totalPrice: number;
    };
    ruleIds?: string[];
    salesChannel?: components["schemas"]["SalesChannel"];
    salesChannelId: string;
    shippingCosts?: {
      calculatedTaxes?: GenericRecord;
      listPrice?: {
        /** Format: float */
        discount?: number;
        /** Format: float */
        percentage?: number;
        /** Format: float */
        price?: number;
      };
      /** Format: int64 */
      quantity: number;
      referencePrice?: GenericRecord;
      regulationPrice?: {
        /** Format: float */
        price?: number;
      };
      taxRules?: GenericRecord;
      /** Format: float */
      totalPrice: number;
      /** Format: float */
      unitPrice: number;
    };
    /** Format: float */
    readonly shippingTotal?: number;
    source?: string;
    stateId: string;
    stateMachineState?: components["schemas"]["StateMachineState"];
    tags?: components["schemas"]["Tag"][];
    readonly taxStatus?: string;
    totalRounding: {
      /** Format: int64 */
      decimals: number;
      /** Format: float */
      interval: number;
      roundForNet: boolean;
    };
    transactions?: components["schemas"]["OrderTransaction"][];
    /** Format: date-time */
    readonly updatedAt?: string;
    updatedBy?: components["schemas"]["User"];
    updatedById?: string;
    versionId?: string;
  };
  OrderAddress: {
    additionalAddressLine1?: string;
    additionalAddressLine2?: string;
    city: string;
    company?: string;
    country?: components["schemas"]["Country"];
    countryId: string;
    countryState?: components["schemas"]["CountryState"];
    countryStateId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    department?: string;
    firstName: string;
    id: string;
    lastName: string;
    order?: components["schemas"]["Order"];
    orderDeliveries?: components["schemas"]["OrderDelivery"][];
    orderId: string;
    orderVersionId?: string;
    phoneNumber?: string;
    salutation?: components["schemas"]["Salutation"];
    salutationId?: string;
    street: string;
    title?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    vatId?: string;
    versionId?: string;
    zipcode?: string;
  };
  OrderAddressJsonApi: components["schemas"]["resource"] & {
    additionalAddressLine1?: string;
    additionalAddressLine2?: string;
    city: string;
    company?: string;
    countryId: string;
    countryStateId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    department?: string;
    firstName: string;
    id: string;
    lastName: string;
    orderId: string;
    orderVersionId?: string;
    phoneNumber?: string;
    relationships?: {
      country?: {
        data?: {
          /** @example e909c2d7067ea37437cf97fe11d91bd0 */
          id?: string;
          /** @example country */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /order-address/4751eee0d88e6475a9a766bb7a37ae43/country
           */
          related?: string;
        };
      };
      countryState?: {
        data?: {
          /** @example cb6a9764567191fb74fe28d8d6a4819d */
          id?: string;
          /** @example country_state */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /order-address/4751eee0d88e6475a9a766bb7a37ae43/countryState
           */
          related?: string;
        };
      };
      order?: {
        data?: {
          /** @example 70a17ffa722a3985b86d30b034ad06d7 */
          id?: string;
          /** @example order */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /order-address/4751eee0d88e6475a9a766bb7a37ae43/order
           */
          related?: string;
        };
      };
      orderDeliveries?: {
        data?: {
          /** @example 0ba472de56dd7ba2e7bb878434321e26 */
          id?: string;
          /** @example order_delivery */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /order-address/4751eee0d88e6475a9a766bb7a37ae43/orderDeliveries
           */
          related?: string;
        };
      };
      salutation?: {
        data?: {
          /** @example 7a6efb02514153b5aa9a8f40c6f8bcc3 */
          id?: string;
          /** @example salutation */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /order-address/4751eee0d88e6475a9a766bb7a37ae43/salutation
           */
          related?: string;
        };
      };
    };
    salutationId?: string;
    street: string;
    title?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    vatId?: string;
    versionId?: string;
    zipcode?: string;
  };
  OrderCustomer: {
    company?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customer?: components["schemas"]["Customer"];
    customerId?: string;
    customerNumber?: string;
    customFields?: GenericRecord;
    email: string;
    firstName: string;
    id: string;
    lastName: string;
    order?: components["schemas"]["Order"];
    orderId: string;
    orderVersionId?: string;
    remoteAddress?: string;
    salutation?: components["schemas"]["Salutation"];
    salutationId?: string;
    title?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    vatIds?: string[];
    versionId?: string;
  };
  OrderCustomerJsonApi: components["schemas"]["resource"] & {
    company?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customerId?: string;
    customerNumber?: string;
    customFields?: GenericRecord;
    email: string;
    firstName: string;
    id: string;
    lastName: string;
    orderId: string;
    orderVersionId?: string;
    relationships?: {
      customer?: {
        data?: {
          /** @example 91ec1f9324753048c0096d036a694f86 */
          id?: string;
          /** @example customer */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /order-customer/b7d3ba78e0695759b84a7f20a6f0c907/customer
           */
          related?: string;
        };
      };
      order?: {
        data?: {
          /** @example 70a17ffa722a3985b86d30b034ad06d7 */
          id?: string;
          /** @example order */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /order-customer/b7d3ba78e0695759b84a7f20a6f0c907/order
           */
          related?: string;
        };
      };
      salutation?: {
        data?: {
          /** @example 7a6efb02514153b5aa9a8f40c6f8bcc3 */
          id?: string;
          /** @example salutation */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /order-customer/b7d3ba78e0695759b84a7f20a6f0c907/salutation
           */
          related?: string;
        };
      };
    };
    remoteAddress?: string;
    salutationId?: string;
    title?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    vatIds?: string[];
    versionId?: string;
  };
  OrderDelivery: {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    id: string;
    order?: components["schemas"]["Order"];
    orderId: string;
    orderVersionId?: string;
    positions?: components["schemas"]["OrderDeliveryPosition"][];
    shippingCosts?: {
      calculatedTaxes?: GenericRecord;
      listPrice?: {
        /** Format: float */
        discount?: number;
        /** Format: float */
        percentage?: number;
        /** Format: float */
        price?: number;
      };
      /** Format: int64 */
      quantity: number;
      referencePrice?: GenericRecord;
      regulationPrice?: {
        /** Format: float */
        price?: number;
      };
      taxRules?: GenericRecord;
      /** Format: float */
      totalPrice: number;
      /** Format: float */
      unitPrice: number;
    };
    /** Format: date-time */
    shippingDateEarliest: string;
    /** Format: date-time */
    shippingDateLatest: string;
    shippingMethod?: components["schemas"]["ShippingMethod"];
    shippingMethodId: string;
    shippingOrderAddress?: components["schemas"]["OrderAddress"];
    shippingOrderAddressId: string;
    shippingOrderAddressVersionId?: string;
    stateId: string;
    stateMachineState?: components["schemas"]["StateMachineState"];
    trackingCodes?: string[];
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  OrderDeliveryJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    id: string;
    orderId: string;
    orderVersionId?: string;
    relationships?: {
      order?: {
        data?: {
          /** @example 70a17ffa722a3985b86d30b034ad06d7 */
          id?: string;
          /** @example order */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /order-delivery/ec47a00e89a14dee454b699af8831df4/order
           */
          related?: string;
        };
      };
      positions?: {
        data?: {
          /** @example 365a4a972db646c76d115b3897f2d4de */
          id?: string;
          /** @example order_delivery_position */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /order-delivery/ec47a00e89a14dee454b699af8831df4/positions
           */
          related?: string;
        };
      };
      shippingMethod?: {
        data?: {
          /** @example e97bfcdc0cae44bc9e4ab35762eaf0e1 */
          id?: string;
          /** @example shipping_method */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /order-delivery/ec47a00e89a14dee454b699af8831df4/shippingMethod
           */
          related?: string;
        };
      };
      shippingOrderAddress?: {
        data?: {
          /** @example 39a8592767b8b6a5d6b1dbc47e4058ca */
          id?: string;
          /** @example order_address */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /order-delivery/ec47a00e89a14dee454b699af8831df4/shippingOrderAddress
           */
          related?: string;
        };
      };
      stateMachineState?: {
        data?: {
          /** @example 1ab22d393154f21e3be76aca3ec3ee31 */
          id?: string;
          /** @example state_machine_state */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /order-delivery/ec47a00e89a14dee454b699af8831df4/stateMachineState
           */
          related?: string;
        };
      };
    };
    shippingCosts?: {
      calculatedTaxes?: GenericRecord;
      listPrice?: {
        /** Format: float */
        discount?: number;
        /** Format: float */
        percentage?: number;
        /** Format: float */
        price?: number;
      };
      /** Format: int64 */
      quantity: number;
      referencePrice?: GenericRecord;
      regulationPrice?: {
        /** Format: float */
        price?: number;
      };
      taxRules?: GenericRecord;
      /** Format: float */
      totalPrice: number;
      /** Format: float */
      unitPrice: number;
    };
    /** Format: date-time */
    shippingDateEarliest: string;
    /** Format: date-time */
    shippingDateLatest: string;
    shippingMethodId: string;
    shippingOrderAddressId: string;
    shippingOrderAddressVersionId?: string;
    stateId: string;
    trackingCodes?: string[];
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  OrderDeliveryPosition: {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    id: string;
    orderDelivery?: components["schemas"]["OrderDelivery"];
    orderDeliveryId: string;
    orderDeliveryVersionId?: string;
    orderLineItem?: components["schemas"]["OrderLineItem"];
    orderLineItemId: string;
    orderLineItemVersionId?: string;
    price?: {
      calculatedTaxes?: GenericRecord;
      listPrice?: {
        /** Format: float */
        discount?: number;
        /** Format: float */
        percentage?: number;
        /** Format: float */
        price?: number;
      };
      /** Format: int64 */
      quantity: number;
      referencePrice?: GenericRecord;
      regulationPrice?: {
        /** Format: float */
        price?: number;
      };
      taxRules?: GenericRecord;
      /** Format: float */
      totalPrice: number;
      /** Format: float */
      unitPrice: number;
    };
    /** Format: int64 */
    quantity?: number;
    /** Format: float */
    totalPrice?: number;
    /** Format: float */
    unitPrice?: number;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  OrderDeliveryPositionJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    id: string;
    orderDeliveryId: string;
    orderDeliveryVersionId?: string;
    orderLineItemId: string;
    orderLineItemVersionId?: string;
    price?: {
      calculatedTaxes?: GenericRecord;
      listPrice?: {
        /** Format: float */
        discount?: number;
        /** Format: float */
        percentage?: number;
        /** Format: float */
        price?: number;
      };
      /** Format: int64 */
      quantity: number;
      referencePrice?: GenericRecord;
      regulationPrice?: {
        /** Format: float */
        price?: number;
      };
      taxRules?: GenericRecord;
      /** Format: float */
      totalPrice: number;
      /** Format: float */
      unitPrice: number;
    };
    /** Format: int64 */
    quantity?: number;
    relationships?: {
      orderDelivery?: {
        data?: {
          /** @example 473c50bdac32ac0dc66364d121260dce */
          id?: string;
          /** @example order_delivery */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /order-delivery-position/e09b06c69231a14a01e186482e70f7b7/orderDelivery
           */
          related?: string;
        };
      };
      orderLineItem?: {
        data?: {
          /** @example 72c0cccf44b384eb8f91e0f7074252f8 */
          id?: string;
          /** @example order_line_item */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /order-delivery-position/e09b06c69231a14a01e186482e70f7b7/orderLineItem
           */
          related?: string;
        };
      };
    };
    /** Format: float */
    totalPrice?: number;
    /** Format: float */
    unitPrice?: number;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  OrderJsonApi: components["schemas"]["resource"] & {
    affiliateCode?: string;
    /** Format: float */
    readonly amountNet?: number;
    /** Format: float */
    readonly amountTotal?: number;
    /** Format: int64 */
    readonly autoIncrement?: number;
    billingAddressId: string;
    billingAddressVersionId?: string;
    campaignCode?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    createdById?: string;
    /** Format: float */
    currencyFactor: number;
    currencyId: string;
    customerComment?: string;
    customFields?: GenericRecord;
    deepLinkCode?: string;
    extensions?: {
      b2bPendingOrder?: {
        data?: {
          /** @example c7e0572188e2dec59215e8872024567e */
          id?: string;
          /** @example b2b_components_pending_order */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /order/a240fa27925a635b08dc28c9e4f9216d/b2bPendingOrder
           */
          related?: string;
        };
      };
      delayActions?: {
        data?: {
          /** @example edfed55799054673006c4b5a643489ac */
          id?: string;
          /** @example swag_delay_action */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /order/a240fa27925a635b08dc28c9e4f9216d/delayActions
           */
          related?: string;
        };
      };
      orderEmployee?: {
        data?: {
          /** @example 5ea451c08a87db806089c4031601c29a */
          id?: string;
          /** @example b2b_order_employee */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /order/a240fa27925a635b08dc28c9e4f9216d/orderEmployee
           */
          related?: string;
        };
      };
      returns?: {
        data?: {
          /** @example 7fff84525c6516919851a9005373f87e */
          id?: string;
          /** @example order_return */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /order/a240fa27925a635b08dc28c9e4f9216d/returns
           */
          related?: string;
        };
      };
      subscription?: {
        data?: {
          /** @example b48b13e73a6ac2a86dc54425dd24d9ff */
          id?: string;
          /** @example subscription */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /order/a240fa27925a635b08dc28c9e4f9216d/subscription
           */
          related?: string;
        };
      };
      swagSocialShoppingOrder?: {
        data?: {
          /** @example 829fa9441f5dea1e7ada99a9ae4a867f */
          id?: string;
          /** @example swag_social_shopping_order */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /order/a240fa27925a635b08dc28c9e4f9216d/swagSocialShoppingOrder
           */
          related?: string;
        };
      };
      warehouseGroups?: {
        data?: {
          /** @example 21191f2f6f4c30cd4ccc4714fa74ffea */
          id?: string;
          /** @example order_warehouse_group */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /order/a240fa27925a635b08dc28c9e4f9216d/warehouseGroups
           */
          related?: string;
        };
      };
      warehouseProducts?: {
        data?: {
          /** @example 702258c6879958a41dfc328ad5c00325 */
          id?: string;
          /** @example order_product_warehouse */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /order/a240fa27925a635b08dc28c9e4f9216d/warehouseProducts
           */
          related?: string;
        };
      };
    };
    id: string;
    itemRounding: {
      /** Format: int64 */
      decimals: number;
      /** Format: float */
      interval: number;
      roundForNet: boolean;
    };
    languageId: string;
    readonly orderDate?: string;
    /** Format: date-time */
    orderDateTime: string;
    orderNumber?: string;
    /** Format: float */
    readonly positionPrice?: number;
    price?: {
      calculatedTaxes?: GenericRecord;
      /** Format: float */
      netPrice: number;
      /** Format: float */
      positionPrice: number;
      /** Format: float */
      rawTotal: number;
      taxRules?: GenericRecord;
      taxStatus: string;
      /** Format: float */
      totalPrice: number;
    };
    relationships?: {
      addresses?: {
        data?: {
          /** @example 963e3a2fe559e393bad631f3dc686f69 */
          id?: string;
          /** @example order_address */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /order/a240fa27925a635b08dc28c9e4f9216d/addresses
           */
          related?: string;
        };
      };
      billingAddress?: {
        data?: {
          /** @example 7fee8ff88b768662dd8fc06e1b6997d2 */
          id?: string;
          /** @example order_address */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /order/a240fa27925a635b08dc28c9e4f9216d/billingAddress
           */
          related?: string;
        };
      };
      createdBy?: {
        data?: {
          /** @example 34998857f537140306898d54d4b970dc */
          id?: string;
          /** @example user */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /order/a240fa27925a635b08dc28c9e4f9216d/createdBy
           */
          related?: string;
        };
      };
      currency?: {
        data?: {
          /** @example 1af0389838508d7016a9841eb6273962 */
          id?: string;
          /** @example currency */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /order/a240fa27925a635b08dc28c9e4f9216d/currency
           */
          related?: string;
        };
      };
      deliveries?: {
        data?: {
          /** @example 6fc31b6b9cd717cc0dcb81152308f8af */
          id?: string;
          /** @example order_delivery */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /order/a240fa27925a635b08dc28c9e4f9216d/deliveries
           */
          related?: string;
        };
      };
      documents?: {
        data?: {
          /** @example 21f64da1e5792c8295b964d159a14491 */
          id?: string;
          /** @example document */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /order/a240fa27925a635b08dc28c9e4f9216d/documents
           */
          related?: string;
        };
      };
      language?: {
        data?: {
          /** @example 8512ae7d57b1396273f76fe6ed341a23 */
          id?: string;
          /** @example language */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /order/a240fa27925a635b08dc28c9e4f9216d/language
           */
          related?: string;
        };
      };
      lineItems?: {
        data?: {
          /** @example a042af1aa9f3853fe3cd7dabc065568f */
          id?: string;
          /** @example order_line_item */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /order/a240fa27925a635b08dc28c9e4f9216d/lineItems
           */
          related?: string;
        };
      };
      orderCustomer?: {
        data?: {
          /** @example e90c9c228c1510f5a25902f7a1e8426a */
          id?: string;
          /** @example order_customer */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /order/a240fa27925a635b08dc28c9e4f9216d/orderCustomer
           */
          related?: string;
        };
      };
      salesChannel?: {
        data?: {
          /** @example ec3712a84143b57e0db620eaac6e55b8 */
          id?: string;
          /** @example sales_channel */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /order/a240fa27925a635b08dc28c9e4f9216d/salesChannel
           */
          related?: string;
        };
      };
      stateMachineState?: {
        data?: {
          /** @example 1ab22d393154f21e3be76aca3ec3ee31 */
          id?: string;
          /** @example state_machine_state */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /order/a240fa27925a635b08dc28c9e4f9216d/stateMachineState
           */
          related?: string;
        };
      };
      tags?: {
        data?: {
          /** @example d57ac45256849d9b13e2422d91580fb9 */
          id?: string;
          /** @example tag */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /order/a240fa27925a635b08dc28c9e4f9216d/tags
           */
          related?: string;
        };
      };
      transactions?: {
        data?: {
          /** @example c15b977dd99332ca8623fbdfb86827e8 */
          id?: string;
          /** @example order_transaction */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /order/a240fa27925a635b08dc28c9e4f9216d/transactions
           */
          related?: string;
        };
      };
      updatedBy?: {
        data?: {
          /** @example 7ced3d0067ad61702af7db8ae260aa76 */
          id?: string;
          /** @example user */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /order/a240fa27925a635b08dc28c9e4f9216d/updatedBy
           */
          related?: string;
        };
      };
    };
    ruleIds?: string[];
    salesChannelId: string;
    shippingCosts?: {
      calculatedTaxes?: GenericRecord;
      listPrice?: {
        /** Format: float */
        discount?: number;
        /** Format: float */
        percentage?: number;
        /** Format: float */
        price?: number;
      };
      /** Format: int64 */
      quantity: number;
      referencePrice?: GenericRecord;
      regulationPrice?: {
        /** Format: float */
        price?: number;
      };
      taxRules?: GenericRecord;
      /** Format: float */
      totalPrice: number;
      /** Format: float */
      unitPrice: number;
    };
    /** Format: float */
    readonly shippingTotal?: number;
    source?: string;
    stateId: string;
    readonly taxStatus?: string;
    totalRounding: {
      /** Format: int64 */
      decimals: number;
      /** Format: float */
      interval: number;
      roundForNet: boolean;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    updatedById?: string;
    versionId?: string;
  };
  OrderLineItem: {
    children: components["schemas"]["OrderLineItem"][];
    cover?: components["schemas"]["Media"];
    coverId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    description?: string;
    downloads?: components["schemas"]["OrderLineItemDownload"][];
    extensions?: {
      returns?: {
        data?: {
          /** @example 7fff84525c6516919851a9005373f87e */
          id?: string;
          /** @example order_return_line_item */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /order-line-item/40b401ac0b29ac5c5c8ffce649fdef62/returns
           */
          related?: string;
        };
      };
      state?: {
        data?: {
          /** @example 9ed39e2ea931586b6a985a6942ef573e */
          id?: string;
          /** @example state_machine_state */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /order-line-item/40b401ac0b29ac5c5c8ffce649fdef62/state
           */
          related?: string;
        };
      };
    };
    good?: boolean;
    id: string;
    identifier: string;
    label: string;
    order?: components["schemas"]["Order"];
    orderDeliveryPositions?: components["schemas"]["OrderDeliveryPosition"][];
    orderId: string;
    orderTransactionCaptureRefundPositions?: components["schemas"]["OrderTransactionCaptureRefundPosition"][];
    orderVersionId?: string;
    parent?: components["schemas"]["OrderLineItem"];
    parentId?: string;
    parentVersionId?: string;
    payload?: GenericRecord;
    /** Format: int64 */
    position?: number;
    price: {
      calculatedTaxes?: GenericRecord;
      listPrice?: {
        /** Format: float */
        discount?: number;
        /** Format: float */
        percentage?: number;
        /** Format: float */
        price?: number;
      };
      /** Format: int64 */
      quantity: number;
      referencePrice?: GenericRecord;
      regulationPrice?: {
        /** Format: float */
        price?: number;
      };
      taxRules?: GenericRecord;
      /** Format: float */
      totalPrice: number;
      /** Format: float */
      unitPrice: number;
    };
    priceDefinition?: GenericRecord;
    product?: components["schemas"]["Product"];
    productId?: string;
    productVersionId?: string;
    promotion?: components["schemas"]["Promotion"];
    promotionId?: string;
    /** Format: int64 */
    quantity: number;
    referencedId?: string;
    removable?: boolean;
    stackable?: boolean;
    states: string[];
    /** Format: float */
    totalPrice?: number;
    type?: string;
    /** Format: float */
    unitPrice?: number;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  OrderLineItemDownload: {
    accessGranted: boolean;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    id: string;
    media?: components["schemas"]["Media"];
    mediaId: string;
    orderLineItem?: components["schemas"]["OrderLineItem"];
    orderLineItemId: string;
    orderLineItemVersionId?: string;
    /** Format: int64 */
    position: number;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  OrderLineItemDownloadJsonApi: components["schemas"]["resource"] & {
    accessGranted: boolean;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    id: string;
    mediaId: string;
    orderLineItemId: string;
    orderLineItemVersionId?: string;
    /** Format: int64 */
    position: number;
    relationships?: {
      media?: {
        data?: {
          /** @example 62933a2951ef01f4eafd9bdf4d3cd2f0 */
          id?: string;
          /** @example media */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /order-line-item-download/583247f605cf67a4124e4eb17a66094e/media
           */
          related?: string;
        };
      };
      orderLineItem?: {
        data?: {
          /** @example 72c0cccf44b384eb8f91e0f7074252f8 */
          id?: string;
          /** @example order_line_item */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /order-line-item-download/583247f605cf67a4124e4eb17a66094e/orderLineItem
           */
          related?: string;
        };
      };
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  OrderLineItemJsonApi: components["schemas"]["resource"] & {
    coverId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    description?: string;
    extensions?: {
      returns?: {
        data?: {
          /** @example 7fff84525c6516919851a9005373f87e */
          id?: string;
          /** @example order_return_line_item */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /order-line-item/40b401ac0b29ac5c5c8ffce649fdef62/returns
           */
          related?: string;
        };
      };
      state?: {
        data?: {
          /** @example 9ed39e2ea931586b6a985a6942ef573e */
          id?: string;
          /** @example state_machine_state */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /order-line-item/40b401ac0b29ac5c5c8ffce649fdef62/state
           */
          related?: string;
        };
      };
    };
    good?: boolean;
    id: string;
    identifier: string;
    label: string;
    orderId: string;
    orderVersionId?: string;
    parentId?: string;
    parentVersionId?: string;
    payload?: GenericRecord;
    /** Format: int64 */
    position?: number;
    price: {
      calculatedTaxes?: GenericRecord;
      listPrice?: {
        /** Format: float */
        discount?: number;
        /** Format: float */
        percentage?: number;
        /** Format: float */
        price?: number;
      };
      /** Format: int64 */
      quantity: number;
      referencePrice?: GenericRecord;
      regulationPrice?: {
        /** Format: float */
        price?: number;
      };
      taxRules?: GenericRecord;
      /** Format: float */
      totalPrice: number;
      /** Format: float */
      unitPrice: number;
    };
    priceDefinition?: GenericRecord;
    productId?: string;
    productVersionId?: string;
    promotionId?: string;
    /** Format: int64 */
    quantity: number;
    referencedId?: string;
    relationships?: {
      children?: {
        data?: {
          /** @example 268184c12df027f536154d099d497b31 */
          id?: string;
          /** @example order_line_item */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /order-line-item/40b401ac0b29ac5c5c8ffce649fdef62/children
           */
          related?: string;
        };
      };
      cover?: {
        data?: {
          /** @example 41d0e299ca1abeb2094852da042165c7 */
          id?: string;
          /** @example media */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /order-line-item/40b401ac0b29ac5c5c8ffce649fdef62/cover
           */
          related?: string;
        };
      };
      downloads?: {
        data?: {
          /** @example d07d50a751bc6ddf12bf3af0efee9b45 */
          id?: string;
          /** @example order_line_item_download */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /order-line-item/40b401ac0b29ac5c5c8ffce649fdef62/downloads
           */
          related?: string;
        };
      };
      order?: {
        data?: {
          /** @example 70a17ffa722a3985b86d30b034ad06d7 */
          id?: string;
          /** @example order */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /order-line-item/40b401ac0b29ac5c5c8ffce649fdef62/order
           */
          related?: string;
        };
      };
      orderDeliveryPositions?: {
        data?: {
          /** @example 76d4619a36f864b08f57415baaa685ec */
          id?: string;
          /** @example order_delivery_position */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /order-line-item/40b401ac0b29ac5c5c8ffce649fdef62/orderDeliveryPositions
           */
          related?: string;
        };
      };
      orderTransactionCaptureRefundPositions?: {
        data?: {
          /** @example c330b64e5adc1e48e07a78aa79e5b27a */
          id?: string;
          /** @example order_transaction_capture_refund_position */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /order-line-item/40b401ac0b29ac5c5c8ffce649fdef62/orderTransactionCaptureRefundPositions
           */
          related?: string;
        };
      };
      parent?: {
        data?: {
          /** @example d0e45878043844ffc41aac437e86b602 */
          id?: string;
          /** @example order_line_item */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /order-line-item/40b401ac0b29ac5c5c8ffce649fdef62/parent
           */
          related?: string;
        };
      };
      product?: {
        data?: {
          /** @example f5bf48aa40cad7891eb709fcf1fde128 */
          id?: string;
          /** @example product */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /order-line-item/40b401ac0b29ac5c5c8ffce649fdef62/product
           */
          related?: string;
        };
      };
      promotion?: {
        data?: {
          /** @example f8dcad058c9c44fdb6ffcb22d2d4c31f */
          id?: string;
          /** @example promotion */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /order-line-item/40b401ac0b29ac5c5c8ffce649fdef62/promotion
           */
          related?: string;
        };
      };
    };
    removable?: boolean;
    stackable?: boolean;
    states: string[];
    /** Format: float */
    totalPrice?: number;
    type?: string;
    /** Format: float */
    unitPrice?: number;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  OrderProductWarehouse: {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    order?: components["schemas"]["Order"];
    orderId: string;
    orderVersionId?: string;
    product?: components["schemas"]["Product"];
    productId: string;
    productVersionId?: string;
    /** Format: int64 */
    quantity?: number;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
    warehouseId: string;
    warehouses?: components["schemas"]["Warehouse"][];
  };
  OrderProductWarehouseJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    orderId: string;
    orderVersionId?: string;
    productId: string;
    productVersionId?: string;
    /** Format: int64 */
    quantity?: number;
    relationships?: {
      order?: {
        data?: {
          /** @example 70a17ffa722a3985b86d30b034ad06d7 */
          id?: string;
          /** @example order */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /order-product-warehouse/ef794dc5239b6857296e8e4ee4605a36/order
           */
          related?: string;
        };
      };
      product?: {
        data?: {
          /** @example f5bf48aa40cad7891eb709fcf1fde128 */
          id?: string;
          /** @example product */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /order-product-warehouse/ef794dc5239b6857296e8e4ee4605a36/product
           */
          related?: string;
        };
      };
      warehouses?: {
        data?: {
          /** @example 544959798565126142ca2820b4f56271 */
          id?: string;
          /** @example warehouse */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /order-product-warehouse/ef794dc5239b6857296e8e4ee4605a36/warehouses
           */
          related?: string;
        };
      };
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
    warehouseId: string;
  };
  OrderReturn: {
    /** Format: float */
    amountNet?: number;
    /** Format: float */
    amountTotal?: number;
    /** Format: date-time */
    readonly createdAt?: string;
    createdBy?: components["schemas"]["User"];
    createdById?: string;
    id: string;
    internalComment?: string;
    lineItems?: components["schemas"]["OrderReturnLineItem"][];
    order?: components["schemas"]["Order"];
    orderId: string;
    orderVersionId?: string;
    price?: {
      calculatedTaxes?: GenericRecord;
      /** Format: float */
      netPrice: number;
      /** Format: float */
      positionPrice: number;
      /** Format: float */
      rawTotal: number;
      taxRules?: GenericRecord;
      taxStatus: string;
      /** Format: float */
      totalPrice: number;
    };
    /** Format: date-time */
    requestedAt: string;
    returnNumber: string;
    shippingCosts?: {
      calculatedTaxes?: GenericRecord;
      listPrice?: {
        /** Format: float */
        discount?: number;
        /** Format: float */
        percentage?: number;
        /** Format: float */
        price?: number;
      };
      /** Format: int64 */
      quantity: number;
      referencePrice?: GenericRecord;
      regulationPrice?: {
        /** Format: float */
        price?: number;
      };
      taxRules?: GenericRecord;
      /** Format: float */
      totalPrice: number;
      /** Format: float */
      unitPrice: number;
    };
    state?: components["schemas"]["StateMachineState"];
    stateId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    updatedBy?: components["schemas"]["User"];
    updatedById?: string;
    versionId?: string;
  };
  OrderReturnJsonApi: components["schemas"]["resource"] & {
    /** Format: float */
    amountNet?: number;
    /** Format: float */
    amountTotal?: number;
    /** Format: date-time */
    readonly createdAt?: string;
    createdById?: string;
    id: string;
    internalComment?: string;
    orderId: string;
    orderVersionId?: string;
    price?: {
      calculatedTaxes?: GenericRecord;
      /** Format: float */
      netPrice: number;
      /** Format: float */
      positionPrice: number;
      /** Format: float */
      rawTotal: number;
      taxRules?: GenericRecord;
      taxStatus: string;
      /** Format: float */
      totalPrice: number;
    };
    relationships?: {
      createdBy?: {
        data?: {
          /** @example 34998857f537140306898d54d4b970dc */
          id?: string;
          /** @example user */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /order-return/f69f638340dfe19ae7ae215a7d5a8670/createdBy
           */
          related?: string;
        };
      };
      lineItems?: {
        data?: {
          /** @example a042af1aa9f3853fe3cd7dabc065568f */
          id?: string;
          /** @example order_return_line_item */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /order-return/f69f638340dfe19ae7ae215a7d5a8670/lineItems
           */
          related?: string;
        };
      };
      order?: {
        data?: {
          /** @example 70a17ffa722a3985b86d30b034ad06d7 */
          id?: string;
          /** @example order */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /order-return/f69f638340dfe19ae7ae215a7d5a8670/order
           */
          related?: string;
        };
      };
      state?: {
        data?: {
          /** @example 9ed39e2ea931586b6a985a6942ef573e */
          id?: string;
          /** @example state_machine_state */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /order-return/f69f638340dfe19ae7ae215a7d5a8670/state
           */
          related?: string;
        };
      };
      updatedBy?: {
        data?: {
          /** @example 7ced3d0067ad61702af7db8ae260aa76 */
          id?: string;
          /** @example user */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /order-return/f69f638340dfe19ae7ae215a7d5a8670/updatedBy
           */
          related?: string;
        };
      };
    };
    /** Format: date-time */
    requestedAt: string;
    returnNumber: string;
    shippingCosts?: {
      calculatedTaxes?: GenericRecord;
      listPrice?: {
        /** Format: float */
        discount?: number;
        /** Format: float */
        percentage?: number;
        /** Format: float */
        price?: number;
      };
      /** Format: int64 */
      quantity: number;
      referencePrice?: GenericRecord;
      regulationPrice?: {
        /** Format: float */
        price?: number;
      };
      taxRules?: GenericRecord;
      /** Format: float */
      totalPrice: number;
      /** Format: float */
      unitPrice: number;
    };
    stateId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    updatedById?: string;
    versionId?: string;
  };
  OrderReturnLineItem: {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    id: string;
    internalComment?: string;
    lineItem?: components["schemas"]["OrderLineItem"];
    orderLineItemId: string;
    orderLineItemVersionId?: string;
    orderReturnId: string;
    orderReturnVersionId?: string;
    price: {
      calculatedTaxes?: GenericRecord;
      listPrice?: {
        /** Format: float */
        discount?: number;
        /** Format: float */
        percentage?: number;
        /** Format: float */
        price?: number;
      };
      /** Format: int64 */
      quantity: number;
      referencePrice?: GenericRecord;
      regulationPrice?: {
        /** Format: float */
        price?: number;
      };
      taxRules?: GenericRecord;
      /** Format: float */
      totalPrice: number;
      /** Format: float */
      unitPrice: number;
    };
    /** Format: int64 */
    quantity: number;
    reason?: components["schemas"]["OrderReturnLineItemReason"];
    reasonId: string;
    /** Format: float */
    refundAmount?: number;
    /** Format: int64 */
    restockQuantity?: number;
    return?: components["schemas"]["OrderReturn"];
    state?: components["schemas"]["StateMachineState"];
    stateId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  OrderReturnLineItemJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    id: string;
    internalComment?: string;
    orderLineItemId: string;
    orderLineItemVersionId?: string;
    orderReturnId: string;
    orderReturnVersionId?: string;
    price: {
      calculatedTaxes?: GenericRecord;
      listPrice?: {
        /** Format: float */
        discount?: number;
        /** Format: float */
        percentage?: number;
        /** Format: float */
        price?: number;
      };
      /** Format: int64 */
      quantity: number;
      referencePrice?: GenericRecord;
      regulationPrice?: {
        /** Format: float */
        price?: number;
      };
      taxRules?: GenericRecord;
      /** Format: float */
      totalPrice: number;
      /** Format: float */
      unitPrice: number;
    };
    /** Format: int64 */
    quantity: number;
    reasonId: string;
    /** Format: float */
    refundAmount?: number;
    relationships?: {
      lineItem?: {
        data?: {
          /** @example 867cf1ff92974922abc5d5b045b4a2d8 */
          id?: string;
          /** @example order_line_item */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /order-return-line-item/82c86fa96448e66da162746de632d95f/lineItem
           */
          related?: string;
        };
      };
      reason?: {
        data?: {
          /** @example 40bea8d637cdf2c1b07fcf0630482b73 */
          id?: string;
          /** @example order_return_line_item_reason */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /order-return-line-item/82c86fa96448e66da162746de632d95f/reason
           */
          related?: string;
        };
      };
      return?: {
        data?: {
          /** @example e70c4df10ef0983b9c8c31bd06b2a2c3 */
          id?: string;
          /** @example order_return */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /order-return-line-item/82c86fa96448e66da162746de632d95f/return
           */
          related?: string;
        };
      };
      state?: {
        data?: {
          /** @example 9ed39e2ea931586b6a985a6942ef573e */
          id?: string;
          /** @example state_machine_state */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /order-return-line-item/82c86fa96448e66da162746de632d95f/state
           */
          related?: string;
        };
      };
    };
    /** Format: int64 */
    restockQuantity?: number;
    stateId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  OrderReturnLineItemReason: {
    content: string;
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    lineItems?: components["schemas"]["OrderReturnLineItem"][];
    reasonKey: string;
    translated: {
      content: string;
      reasonKey: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  OrderReturnLineItemReasonJsonApi: components["schemas"]["resource"] & {
    content: string;
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    reasonKey: string;
    relationships?: {
      lineItems?: {
        data?: {
          /** @example a042af1aa9f3853fe3cd7dabc065568f */
          id?: string;
          /** @example order_return_line_item */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /order-return-line-item-reason/56b9c90342150f40164af1328340bbac/lineItems
           */
          related?: string;
        };
      };
    };
    translated: {
      content: string;
      reasonKey: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  OrderTag: {
    id?: string;
    order?: components["schemas"]["Order"];
    orderId: string;
    orderVersionId?: string;
    tag?: components["schemas"]["Tag"];
    tagId: string;
  };
  OrderTransaction: {
    amount: {
      calculatedTaxes?: GenericRecord;
      listPrice?: {
        /** Format: float */
        discount?: number;
        /** Format: float */
        percentage?: number;
        /** Format: float */
        price?: number;
      };
      /** Format: int64 */
      quantity: number;
      referencePrice?: GenericRecord;
      regulationPrice?: {
        /** Format: float */
        price?: number;
      };
      taxRules?: GenericRecord;
      /** Format: float */
      totalPrice: number;
      /** Format: float */
      unitPrice: number;
    };
    captures?: components["schemas"]["OrderTransactionCapture"][];
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    id: string;
    order?: components["schemas"]["Order"];
    orderId: string;
    orderVersionId?: string;
    paymentMethod?: components["schemas"]["PaymentMethod"];
    paymentMethodId: string;
    stateId: string;
    stateMachineState?: components["schemas"]["StateMachineState"];
    /** Format: date-time */
    readonly updatedAt?: string;
    validationData?: GenericRecord;
    versionId?: string;
  };
  OrderTransactionCapture: {
    amount: {
      calculatedTaxes?: GenericRecord;
      listPrice?: {
        /** Format: float */
        discount?: number;
        /** Format: float */
        percentage?: number;
        /** Format: float */
        price?: number;
      };
      /** Format: int64 */
      quantity: number;
      referencePrice?: GenericRecord;
      regulationPrice?: {
        /** Format: float */
        price?: number;
      };
      taxRules?: GenericRecord;
      /** Format: float */
      totalPrice: number;
      /** Format: float */
      unitPrice: number;
    };
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    externalReference?: string;
    id: string;
    orderTransactionId: string;
    orderTransactionVersionId?: string;
    refunds?: components["schemas"]["OrderTransactionCaptureRefund"][];
    stateId: string;
    stateMachineState?: components["schemas"]["StateMachineState"];
    transaction?: components["schemas"]["OrderTransaction"];
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  OrderTransactionCaptureJsonApi: components["schemas"]["resource"] & {
    amount: {
      calculatedTaxes?: GenericRecord;
      listPrice?: {
        /** Format: float */
        discount?: number;
        /** Format: float */
        percentage?: number;
        /** Format: float */
        price?: number;
      };
      /** Format: int64 */
      quantity: number;
      referencePrice?: GenericRecord;
      regulationPrice?: {
        /** Format: float */
        price?: number;
      };
      taxRules?: GenericRecord;
      /** Format: float */
      totalPrice: number;
      /** Format: float */
      unitPrice: number;
    };
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    externalReference?: string;
    id: string;
    orderTransactionId: string;
    orderTransactionVersionId?: string;
    relationships?: {
      refunds?: {
        data?: {
          /** @example 0084ff716402199f733f841f5937d3ae */
          id?: string;
          /** @example order_transaction_capture_refund */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /order-transaction-capture/c63c3187538f020dbe3d0c9bd41c5fea/refunds
           */
          related?: string;
        };
      };
      stateMachineState?: {
        data?: {
          /** @example 1ab22d393154f21e3be76aca3ec3ee31 */
          id?: string;
          /** @example state_machine_state */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /order-transaction-capture/c63c3187538f020dbe3d0c9bd41c5fea/stateMachineState
           */
          related?: string;
        };
      };
      transaction?: {
        data?: {
          /** @example f4d5b76a2418eba4baeabc1ed9142b54 */
          id?: string;
          /** @example order_transaction */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /order-transaction-capture/c63c3187538f020dbe3d0c9bd41c5fea/transaction
           */
          related?: string;
        };
      };
    };
    stateId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  OrderTransactionCaptureRefund: {
    amount: {
      calculatedTaxes?: GenericRecord;
      listPrice?: {
        /** Format: float */
        discount?: number;
        /** Format: float */
        percentage?: number;
        /** Format: float */
        price?: number;
      };
      /** Format: int64 */
      quantity: number;
      referencePrice?: GenericRecord;
      regulationPrice?: {
        /** Format: float */
        price?: number;
      };
      taxRules?: GenericRecord;
      /** Format: float */
      totalPrice: number;
      /** Format: float */
      unitPrice: number;
    };
    captureId: string;
    captureVersionId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    externalReference?: string;
    id: string;
    positions?: components["schemas"]["OrderTransactionCaptureRefundPosition"][];
    reason?: string;
    stateId: string;
    stateMachineState?: components["schemas"]["StateMachineState"];
    transactionCapture?: components["schemas"]["OrderTransactionCapture"];
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  OrderTransactionCaptureRefundJsonApi: components["schemas"]["resource"] & {
    amount: {
      calculatedTaxes?: GenericRecord;
      listPrice?: {
        /** Format: float */
        discount?: number;
        /** Format: float */
        percentage?: number;
        /** Format: float */
        price?: number;
      };
      /** Format: int64 */
      quantity: number;
      referencePrice?: GenericRecord;
      regulationPrice?: {
        /** Format: float */
        price?: number;
      };
      taxRules?: GenericRecord;
      /** Format: float */
      totalPrice: number;
      /** Format: float */
      unitPrice: number;
    };
    captureId: string;
    captureVersionId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    externalReference?: string;
    id: string;
    reason?: string;
    relationships?: {
      positions?: {
        data?: {
          /** @example 365a4a972db646c76d115b3897f2d4de */
          id?: string;
          /** @example order_transaction_capture_refund_position */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /order-transaction-capture-refund/3024adb21b1ba17454cf7cc0cfa881d4/positions
           */
          related?: string;
        };
      };
      stateMachineState?: {
        data?: {
          /** @example 1ab22d393154f21e3be76aca3ec3ee31 */
          id?: string;
          /** @example state_machine_state */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /order-transaction-capture-refund/3024adb21b1ba17454cf7cc0cfa881d4/stateMachineState
           */
          related?: string;
        };
      };
      transactionCapture?: {
        data?: {
          /** @example 56b70ce76ce8e9bfbaf80ea040d456b5 */
          id?: string;
          /** @example order_transaction_capture */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /order-transaction-capture-refund/3024adb21b1ba17454cf7cc0cfa881d4/transactionCapture
           */
          related?: string;
        };
      };
    };
    stateId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  OrderTransactionCaptureRefundPosition: {
    amount: {
      calculatedTaxes?: GenericRecord;
      listPrice?: {
        /** Format: float */
        discount?: number;
        /** Format: float */
        percentage?: number;
        /** Format: float */
        price?: number;
      };
      /** Format: int64 */
      quantity: number;
      referencePrice?: GenericRecord;
      regulationPrice?: {
        /** Format: float */
        price?: number;
      };
      taxRules?: GenericRecord;
      /** Format: float */
      totalPrice: number;
      /** Format: float */
      unitPrice: number;
    };
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    externalReference?: string;
    id: string;
    orderLineItem?: components["schemas"]["OrderLineItem"];
    orderLineItemId: string;
    orderLineItemVersionId?: string;
    orderTransactionCaptureRefund?: components["schemas"]["OrderTransactionCaptureRefund"];
    /** Format: int64 */
    quantity?: number;
    reason?: string;
    refundId: string;
    refundVersionId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  OrderTransactionCaptureRefundPositionJsonApi: components["schemas"]["resource"] & {
    amount: {
      calculatedTaxes?: GenericRecord;
      listPrice?: {
        /** Format: float */
        discount?: number;
        /** Format: float */
        percentage?: number;
        /** Format: float */
        price?: number;
      };
      /** Format: int64 */
      quantity: number;
      referencePrice?: GenericRecord;
      regulationPrice?: {
        /** Format: float */
        price?: number;
      };
      taxRules?: GenericRecord;
      /** Format: float */
      totalPrice: number;
      /** Format: float */
      unitPrice: number;
    };
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    externalReference?: string;
    id: string;
    orderLineItemId: string;
    orderLineItemVersionId?: string;
    /** Format: int64 */
    quantity?: number;
    reason?: string;
    refundId: string;
    refundVersionId?: string;
    relationships?: {
      orderLineItem?: {
        data?: {
          /** @example 72c0cccf44b384eb8f91e0f7074252f8 */
          id?: string;
          /** @example order_line_item */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /order-transaction-capture-refund-position/dc9ea2968815c3064d57d506f542c4c1/orderLineItem
           */
          related?: string;
        };
      };
      orderTransactionCaptureRefund?: {
        data?: {
          /** @example 8e55f83da36c39263717541ec1f18de7 */
          id?: string;
          /** @example order_transaction_capture_refund */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /order-transaction-capture-refund-position/dc9ea2968815c3064d57d506f542c4c1/orderTransactionCaptureRefund
           */
          related?: string;
        };
      };
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  OrderTransactionJsonApi: components["schemas"]["resource"] & {
    amount: {
      calculatedTaxes?: GenericRecord;
      listPrice?: {
        /** Format: float */
        discount?: number;
        /** Format: float */
        percentage?: number;
        /** Format: float */
        price?: number;
      };
      /** Format: int64 */
      quantity: number;
      referencePrice?: GenericRecord;
      regulationPrice?: {
        /** Format: float */
        price?: number;
      };
      taxRules?: GenericRecord;
      /** Format: float */
      totalPrice: number;
      /** Format: float */
      unitPrice: number;
    };
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    id: string;
    orderId: string;
    orderVersionId?: string;
    paymentMethodId: string;
    relationships?: {
      captures?: {
        data?: {
          /** @example 8856ffdd044d57cd4124a6be5dcea329 */
          id?: string;
          /** @example order_transaction_capture */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /order-transaction/117c998b69fea8e51bd46a905f8cdbeb/captures
           */
          related?: string;
        };
      };
      order?: {
        data?: {
          /** @example 70a17ffa722a3985b86d30b034ad06d7 */
          id?: string;
          /** @example order */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /order-transaction/117c998b69fea8e51bd46a905f8cdbeb/order
           */
          related?: string;
        };
      };
      paymentMethod?: {
        data?: {
          /** @example 68ec1eeea9f1b7744e231b5bd0d97df0 */
          id?: string;
          /** @example payment_method */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /order-transaction/117c998b69fea8e51bd46a905f8cdbeb/paymentMethod
           */
          related?: string;
        };
      };
      stateMachineState?: {
        data?: {
          /** @example 1ab22d393154f21e3be76aca3ec3ee31 */
          id?: string;
          /** @example state_machine_state */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /order-transaction/117c998b69fea8e51bd46a905f8cdbeb/stateMachineState
           */
          related?: string;
        };
      };
    };
    stateId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    validationData?: GenericRecord;
    versionId?: string;
  };
  OrderWarehouseGroup: {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    order?: components["schemas"]["Order"];
    orderId: string;
    orderVersionId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
    warehouseGroup?: components["schemas"]["WarehouseGroup"];
    warehouseGroupId: string;
  };
  OrderWarehouseGroupJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    orderId: string;
    orderVersionId?: string;
    relationships?: {
      order?: {
        data?: {
          /** @example 70a17ffa722a3985b86d30b034ad06d7 */
          id?: string;
          /** @example order */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /order-warehouse-group/76d096c61d28159fe3efcbceced45044/order
           */
          related?: string;
        };
      };
      warehouseGroup?: {
        data?: {
          /** @example 1768e3071b62161d415e0c24332055ed */
          id?: string;
          /** @example warehouse_group */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /order-warehouse-group/76d096c61d28159fe3efcbceced45044/warehouseGroup
           */
          related?: string;
        };
      };
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
    warehouseGroupId: string;
  };
  PaymentMethod: {
    active?: boolean;
    afterOrderEnabled?: boolean;
    appPaymentMethod?: components["schemas"]["AppPaymentMethod"];
    /** Runtime field, cannot be used as part of the criteria. */
    readonly asynchronous?: boolean;
    availabilityRule?: components["schemas"]["Rule"];
    availabilityRuleId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customers?: components["schemas"]["Customer"][];
    customFields?: GenericRecord;
    description?: string;
    readonly distinguishableName?: string;
    extensions?: {
      paypalVaultTokenMappings?: {
        data?: {
          /** @example 75fb7d13a771c74947402295ed591499 */
          id?: string;
          /** @example swag_paypal_vault_token_mapping */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /payment-method/da8da1569e6bef3249a7064261df833f/paypalVaultTokenMappings
           */
          related?: string;
        };
      };
      paypalVaultTokens?: {
        data?: {
          /** @example 7e423eeb595163d20591951433de150c */
          id?: string;
          /** @example swag_paypal_vault_token */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /payment-method/da8da1569e6bef3249a7064261df833f/paypalVaultTokens
           */
          related?: string;
        };
      };
      quoteTransactions?: {
        data?: {
          /** @example c960fb2e8b7ef26229da52c7f7775e13 */
          id?: string;
          /** @example quote_transaction */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /payment-method/da8da1569e6bef3249a7064261df833f/quoteTransactions
           */
          related?: string;
        };
      };
      subscriptions?: {
        data?: {
          /** @example 2d5d14f95af035cbd8437948de61f94c */
          id?: string;
          /** @example subscription */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /payment-method/da8da1569e6bef3249a7064261df833f/subscriptions
           */
          related?: string;
        };
      };
    };
    /** Runtime field, cannot be used as part of the criteria. */
    readonly formattedHandlerIdentifier?: string;
    handlerIdentifier?: string;
    id: string;
    media?: components["schemas"]["Media"];
    mediaId?: string;
    name: string;
    orderTransactions?: components["schemas"]["OrderTransaction"][];
    plugin?: components["schemas"]["Plugin"];
    pluginId?: string;
    /** Format: int64 */
    position?: number;
    /** Runtime field, cannot be used as part of the criteria. */
    readonly prepared?: boolean;
    /** Runtime field, cannot be used as part of the criteria. */
    readonly recurring?: boolean;
    /** Runtime field, cannot be used as part of the criteria. */
    readonly refundable?: boolean;
    salesChannelDefaultAssignments?: components["schemas"]["SalesChannel"][];
    salesChannels?: components["schemas"]["SalesChannel"][];
    /** Runtime field, cannot be used as part of the criteria. */
    shortName?: string;
    /** Runtime field, cannot be used as part of the criteria. */
    readonly synchronous?: boolean;
    technicalName?: string;
    translated: {
      availabilityRuleId: string;
      description: string;
      distinguishableName: string;
      formattedHandlerIdentifier: string;
      handlerIdentifier: string;
      mediaId: string;
      name: string;
      pluginId: string;
      shortName: string;
      technicalName: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  PaymentMethodJsonApi: components["schemas"]["resource"] & {
    active?: boolean;
    afterOrderEnabled?: boolean;
    /** Runtime field, cannot be used as part of the criteria. */
    readonly asynchronous?: boolean;
    availabilityRuleId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    description?: string;
    readonly distinguishableName?: string;
    extensions?: {
      paypalVaultTokenMappings?: {
        data?: {
          /** @example 75fb7d13a771c74947402295ed591499 */
          id?: string;
          /** @example swag_paypal_vault_token_mapping */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /payment-method/da8da1569e6bef3249a7064261df833f/paypalVaultTokenMappings
           */
          related?: string;
        };
      };
      paypalVaultTokens?: {
        data?: {
          /** @example 7e423eeb595163d20591951433de150c */
          id?: string;
          /** @example swag_paypal_vault_token */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /payment-method/da8da1569e6bef3249a7064261df833f/paypalVaultTokens
           */
          related?: string;
        };
      };
      quoteTransactions?: {
        data?: {
          /** @example c960fb2e8b7ef26229da52c7f7775e13 */
          id?: string;
          /** @example quote_transaction */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /payment-method/da8da1569e6bef3249a7064261df833f/quoteTransactions
           */
          related?: string;
        };
      };
      subscriptions?: {
        data?: {
          /** @example 2d5d14f95af035cbd8437948de61f94c */
          id?: string;
          /** @example subscription */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /payment-method/da8da1569e6bef3249a7064261df833f/subscriptions
           */
          related?: string;
        };
      };
    };
    /** Runtime field, cannot be used as part of the criteria. */
    readonly formattedHandlerIdentifier?: string;
    handlerIdentifier?: string;
    id: string;
    mediaId?: string;
    name: string;
    pluginId?: string;
    /** Format: int64 */
    position?: number;
    /** Runtime field, cannot be used as part of the criteria. */
    readonly prepared?: boolean;
    /** Runtime field, cannot be used as part of the criteria. */
    readonly recurring?: boolean;
    /** Runtime field, cannot be used as part of the criteria. */
    readonly refundable?: boolean;
    relationships?: {
      appPaymentMethod?: {
        data?: {
          /** @example 30f64104cd0d0a7bb8a9e07fe4d12d88 */
          id?: string;
          /** @example app_payment_method */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /payment-method/da8da1569e6bef3249a7064261df833f/appPaymentMethod
           */
          related?: string;
        };
      };
      availabilityRule?: {
        data?: {
          /** @example 9fbb7961d1cb158094924c679e1b302c */
          id?: string;
          /** @example rule */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /payment-method/da8da1569e6bef3249a7064261df833f/availabilityRule
           */
          related?: string;
        };
      };
      customers?: {
        data?: {
          /** @example 4b6f7d34a58ba399f077685951d06738 */
          id?: string;
          /** @example customer */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /payment-method/da8da1569e6bef3249a7064261df833f/customers
           */
          related?: string;
        };
      };
      media?: {
        data?: {
          /** @example 62933a2951ef01f4eafd9bdf4d3cd2f0 */
          id?: string;
          /** @example media */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /payment-method/da8da1569e6bef3249a7064261df833f/media
           */
          related?: string;
        };
      };
      orderTransactions?: {
        data?: {
          /** @example 3bdb6a464fb3330bd1935325493c5f2c */
          id?: string;
          /** @example order_transaction */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /payment-method/da8da1569e6bef3249a7064261df833f/orderTransactions
           */
          related?: string;
        };
      };
      plugin?: {
        data?: {
          /** @example a24bcf2198b1b13ad985304483f7f324 */
          id?: string;
          /** @example plugin */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /payment-method/da8da1569e6bef3249a7064261df833f/plugin
           */
          related?: string;
        };
      };
      salesChannelDefaultAssignments?: {
        data?: {
          /** @example b23663b2abc0909be9a8027a3fbff74b */
          id?: string;
          /** @example sales_channel */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /payment-method/da8da1569e6bef3249a7064261df833f/salesChannelDefaultAssignments
           */
          related?: string;
        };
      };
      salesChannels?: {
        data?: {
          /** @example 986f6f891e90ab91c091ff4a1a460777 */
          id?: string;
          /** @example sales_channel */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /payment-method/da8da1569e6bef3249a7064261df833f/salesChannels
           */
          related?: string;
        };
      };
    };
    /** Runtime field, cannot be used as part of the criteria. */
    shortName?: string;
    /** Runtime field, cannot be used as part of the criteria. */
    readonly synchronous?: boolean;
    technicalName?: string;
    translated: {
      availabilityRuleId: string;
      description: string;
      distinguishableName: string;
      formattedHandlerIdentifier: string;
      handlerIdentifier: string;
      mediaId: string;
      name: string;
      pluginId: string;
      shortName: string;
      technicalName: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  Plugin: {
    active?: boolean;
    author?: string;
    autoload: GenericRecord;
    baseClass: string;
    composerName?: string;
    copyright?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    description?: string;
    /** Runtime field, cannot be used as part of the criteria. */
    readonly icon?: string;
    id: string;
    /** Format: date-time */
    installedAt?: string;
    label: string;
    license?: string;
    managedByComposer?: boolean;
    manufacturerLink?: string;
    name: string;
    path?: string;
    paymentMethods?: components["schemas"]["PaymentMethod"][];
    supportLink?: string;
    translated: {
      author: string;
      baseClass: string;
      composerName: string;
      copyright: string;
      description: string;
      icon: string;
      installedAt: string;
      label: string;
      license: string;
      manufacturerLink: string;
      name: string;
      path: string;
      supportLink: string;
      upgradedAt: string;
      upgradeVersion: string;
      version: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    /** Format: date-time */
    upgradedAt?: string;
    upgradeVersion?: string;
    version: string;
  };
  PluginJsonApi: components["schemas"]["resource"] & {
    active?: boolean;
    author?: string;
    autoload: GenericRecord;
    baseClass: string;
    composerName?: string;
    copyright?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    description?: string;
    /** Runtime field, cannot be used as part of the criteria. */
    readonly icon?: string;
    id: string;
    /** Format: date-time */
    installedAt?: string;
    label: string;
    license?: string;
    managedByComposer?: boolean;
    manufacturerLink?: string;
    name: string;
    path?: string;
    relationships?: {
      paymentMethods?: {
        data?: {
          /** @example b631b1ab565525e892f9cdc1242cca14 */
          id?: string;
          /** @example payment_method */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /plugin/409c1892b68cb394799262ac57f6d4f1/paymentMethods
           */
          related?: string;
        };
      };
    };
    supportLink?: string;
    translated: {
      author: string;
      baseClass: string;
      composerName: string;
      copyright: string;
      description: string;
      icon: string;
      installedAt: string;
      label: string;
      license: string;
      manufacturerLink: string;
      name: string;
      path: string;
      supportLink: string;
      upgradedAt: string;
      upgradeVersion: string;
      version: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    /** Format: date-time */
    upgradedAt?: string;
    upgradeVersion?: string;
    version: string;
  };
  PresentationCmsPage: {
    cmsPage?: components["schemas"]["CmsPage"];
    /** The CMS page id the presentation using */
    cmsPageId?: string;
    /** The CMS page version id the presentation using */
    cmsPageVersionId?: string;
    /** Format: date-time */
    createdAt?: string;
    customFields?: GenericRecord | null;
    dsrPresentationVersionId?: string;
    /** The presentation cms page id */
    id?: string;
    /** True if this slide is an instant listing */
    isInstantListing?: boolean;
    /** The product id is assigned to presentation if it's product listing or instant listing */
    pickedProductIds?: string[] | null;
    /** The position of slide */
    position?: number;
    /** The presentation using this presentation cms page */
    presentationId?: string;
    /** The product id is assigned to presentation if it's product detail */
    productId?: string | null;
    /** The product stream id is assigned to presentation if it's product listing */
    productStreamId?: string | null;
    /** The title of presentation cms page */
    title?: string | null;
    translated: {
      cmsPageId: string;
      cmsPageVersionId: string;
      dsrPresentationVersionId: string;
      presentationId: string;
      title?: string | null;
    };
    updatedAt?: string | null;
  };
  Price: {
    currencyId: string;
    gross: number;
    linked?: boolean;
    listPrice?: {
      currencyId?: string;
      gross: number;
      linked?: boolean;
      net: number;
    };
    net: number;
    regulationPrice?: {
      currencyId?: string;
      gross: number;
      linked?: boolean;
      net: number;
    };
  };
  Product: {
    active?: boolean;
    /** Format: int64 */
    readonly autoIncrement?: number;
    readonly available?: boolean;
    /** Format: int64 */
    readonly availableStock?: number;
    canonicalProduct?: components["schemas"]["Product"];
    canonicalProductId?: string;
    canonicalProductVersionId?: string;
    categories?: components["schemas"]["Category"][];
    categoriesRo?: components["schemas"]["Category"][];
    readonly categoryIds?: string[];
    readonly categoryTree?: string[];
    /** Format: int64 */
    readonly childCount?: number;
    children?: components["schemas"]["Product"][];
    cmsPage?: components["schemas"]["CmsPage"];
    cmsPageId?: string;
    cmsPageVersionId?: string;
    configuratorSettings?: components["schemas"]["ProductConfiguratorSetting"][];
    cover?: components["schemas"]["ProductMedia"];
    coverId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    crossSellingAssignedProducts?: components["schemas"]["ProductCrossSellingAssignedProducts"][];
    crossSellings?: components["schemas"]["ProductCrossSelling"][];
    customFields?: GenericRecord;
    customFieldSets?: components["schemas"]["CustomFieldSet"][];
    customFieldSetSelectionActive?: boolean;
    customSearchKeywords?: GenericRecord[];
    deliveryTime?: components["schemas"]["DeliveryTime"];
    deliveryTimeId?: string;
    description?: string;
    readonly displayGroup?: string;
    downloads?: components["schemas"]["ProductDownload"][];
    ean?: string;
    extensions?: {
      attendeeProductCollections?: {
        data?: {
          /** @example 0a7b3b2f4b81f36910a74f22826f35df */
          id?: string;
          /** @example dsr_attendee_product_collection */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/attendeeProductCollections
           */
          related?: string;
        };
      };
      customPrice?: {
        data?: {
          /** @example 35ed8bfa9c73171a7b417f13ab07d57a */
          id?: string;
          /** @example custom_price */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/customPrice
           */
          related?: string;
        };
      };
      orderWarehouses?: {
        data?: {
          /** @example 5331369e2f71d048521bd35d80975314 */
          id?: string;
          /** @example order_product_warehouse */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/orderWarehouses
           */
          related?: string;
        };
      };
      paypalPosLog?: {
        data?: {
          /** @example 7edfbc8f7a12c1d79b6de5b0154cf325 */
          id?: string;
          /** @example swag_paypal_pos_sales_channel_run_log */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/paypalPosLog
           */
          related?: string;
        };
      };
      paypalPosSync?: {
        data?: {
          /** @example 163c806e836f72f29f292c8ef2dfe61e */
          id?: string;
          /** @example swag_paypal_pos_sales_channel_product */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/paypalPosSync
           */
          related?: string;
        };
      };
      presentationCmsPages?: {
        data?: {
          /** @example 30c725082807b69914fddd7e82d0d741 */
          id?: string;
          /** @example dsr_presentation_cms_page */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/presentationCmsPages
           */
          related?: string;
        };
      };
      quoteLineItems?: {
        data?: {
          /** @example 6b1c17ad551ef636e491ab6848f68420 */
          id?: string;
          /** @example quote_line_item */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/quoteLineItems
           */
          related?: string;
        };
      };
      reviewSummaries?: {
        data?: {
          /** @example c9c718522e64ffa5effb26cef94f4849 */
          id?: string;
          /** @example product_review_summary */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/reviewSummaries
           */
          related?: string;
        };
      };
      search?: GenericRecord;
      shoppingListLineItems?: {
        data?: {
          /** @example ce593c6d1db236f22dc387a2ee20dfd6 */
          id?: string;
          /** @example b2b_components_shopping_list_line_item */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/shoppingListLineItems
           */
          related?: string;
        };
      };
      socialShoppingProductErrors?: {
        data?: {
          /** @example 74181afcb28901351a5f2676d1687de8 */
          id?: string;
          /** @example swag_social_shopping_product_error */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/socialShoppingProductErrors
           */
          related?: string;
        };
      };
      subscriptionPlans?: {
        data?: {
          /** @example ed94874505da2886dc66a3a3d3968972 */
          id?: string;
          /** @example subscription_plan */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/subscriptionPlans
           */
          related?: string;
        };
      };
      swagCustomizedProductsTemplate?: {
        data?: {
          /** @example 6e9fad30dd3cb84748a01bb8152f4769 */
          id?: string;
          /** @example swag_customized_products_template */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/swagCustomizedProductsTemplate
           */
          related?: string;
        };
      };
      swagDynamicAccessRules?: {
        data?: {
          /** @example 05b9d828254c957dfa5224c581439c92 */
          id?: string;
          /** @example rule */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/swagDynamicAccessRules
           */
          related?: string;
        };
      };
      warehouseGroups?: {
        data?: {
          /** @example 21191f2f6f4c30cd4ccc4714fa74ffea */
          id?: string;
          /** @example warehouse_group */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/warehouseGroups
           */
          related?: string;
        };
      };
      warehouses?: {
        data?: {
          /** @example 544959798565126142ca2820b4f56271 */
          id?: string;
          /** @example product_warehouse */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/warehouses
           */
          related?: string;
        };
      };
    };
    featureSet?: components["schemas"]["ProductFeatureSet"];
    featureSetId?: string;
    /** Format: float */
    height?: number;
    id: string;
    isCloseout?: boolean;
    keywords?: string;
    /** Format: float */
    length?: number;
    mainCategories?: components["schemas"]["MainCategory"][];
    manufacturer?: components["schemas"]["ProductManufacturer"];
    manufacturerId?: string;
    manufacturerNumber?: string;
    markAsTopseller?: boolean;
    /** Format: int64 */
    maxPurchase?: number;
    media?: components["schemas"]["ProductMedia"][];
    metaDescription?: string;
    metaTitle?: string;
    /** Format: int64 */
    minPurchase?: number;
    name: string;
    readonly optionIds?: string[];
    options?: components["schemas"]["PropertyGroupOption"][];
    orderLineItems?: components["schemas"]["OrderLineItem"][];
    packUnit?: string;
    packUnitPlural?: string;
    parent?: components["schemas"]["Product"];
    parentId?: string;
    parentVersionId?: string;
    price: components["schemas"]["Price"][];
    prices?: components["schemas"]["ProductPrice"][];
    productManufacturerVersionId?: string;
    productMediaVersionId?: string;
    productNumber: string;
    productReviews?: components["schemas"]["ProductReview"][];
    properties?: components["schemas"]["PropertyGroupOption"][];
    readonly propertyIds?: string[];
    purchasePrices?: components["schemas"]["Price"][];
    /** Format: int64 */
    purchaseSteps?: number;
    /** Format: float */
    purchaseUnit?: number;
    /** Format: float */
    readonly ratingAverage?: number;
    /** Format: float */
    referenceUnit?: number;
    /** Format: date-time */
    releaseDate?: string;
    /** Format: int64 */
    restockTime?: number;
    /** Format: int64 */
    readonly sales?: number;
    searchKeywords?: components["schemas"]["ProductSearchKeyword"][];
    seoUrls?: components["schemas"]["SeoUrl"][];
    shippingFree?: boolean;
    slotConfig?: GenericRecord;
    readonly states?: string[];
    /** Format: int64 */
    stock: number;
    readonly streamIds?: string[];
    streams?: components["schemas"]["ProductStream"][];
    readonly tagIds?: string[];
    tags?: components["schemas"]["Tag"][];
    tax?: components["schemas"]["Tax"];
    taxId: string;
    translated: {
      canonicalProductId: string;
      canonicalProductVersionId: string;
      cmsPageId: string;
      cmsPageVersionId: string;
      coverId: string;
      deliveryTimeId: string;
      description: string;
      displayGroup: string;
      ean: string;
      featureSetId: string;
      keywords: string;
      manufacturerId: string;
      manufacturerNumber: string;
      metaDescription: string;
      metaTitle: string;
      name: string;
      packUnit: string;
      packUnitPlural: string;
      parentId: string;
      parentVersionId: string;
      productManufacturerVersionId: string;
      productMediaVersionId: string;
      productNumber: string;
      releaseDate: string;
      taxId: string;
      unitId: string;
      versionId: string;
    };
    unit?: components["schemas"]["Unit"];
    unitId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    variantListingConfig?: GenericRecord;
    variantRestrictions?: GenericRecord;
    variation?: string[];
    versionId?: string;
    visibilities?: components["schemas"]["ProductVisibility"][];
    /** Format: float */
    weight?: number;
    /** Format: float */
    width?: number;
    wishlists?: components["schemas"]["CustomerWishlistProduct"][];
  };
  ProductCategory: {
    category?: components["schemas"]["Category"];
    categoryId: string;
    categoryVersionId?: string;
    id?: string;
    product?: components["schemas"]["Product"];
    productId: string;
    productVersionId?: string;
  };
  ProductCategoryTree: {
    category?: components["schemas"]["Category"];
    categoryId: string;
    categoryVersionId?: string;
    id?: string;
    product?: components["schemas"]["Product"];
    productId: string;
    productVersionId?: string;
  };
  ProductConfiguratorSetting: {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    id: string;
    media?: components["schemas"]["Media"];
    mediaId?: string;
    option?: components["schemas"]["PropertyGroupOption"];
    optionId: string;
    /** Format: int64 */
    position?: number;
    price?: GenericRecord;
    product?: components["schemas"]["Product"];
    productId: string;
    productVersionId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  ProductConfiguratorSettingJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    id: string;
    mediaId?: string;
    optionId: string;
    /** Format: int64 */
    position?: number;
    price?: GenericRecord;
    productId: string;
    productVersionId?: string;
    relationships?: {
      media?: {
        data?: {
          /** @example 62933a2951ef01f4eafd9bdf4d3cd2f0 */
          id?: string;
          /** @example media */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /product-configurator-setting/62bab37b1cdb1e5ffd2e0ea79ac515cb/media
           */
          related?: string;
        };
      };
      option?: {
        data?: {
          /** @example ef3e30e070f70244fd6578d88a6b77ac */
          id?: string;
          /** @example property_group_option */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /product-configurator-setting/62bab37b1cdb1e5ffd2e0ea79ac515cb/option
           */
          related?: string;
        };
      };
      product?: {
        data?: {
          /** @example f5bf48aa40cad7891eb709fcf1fde128 */
          id?: string;
          /** @example product */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /product-configurator-setting/62bab37b1cdb1e5ffd2e0ea79ac515cb/product
           */
          related?: string;
        };
      };
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  ProductCrossSelling: {
    active?: boolean;
    assignedProducts?: components["schemas"]["ProductCrossSellingAssignedProducts"][];
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    /** Format: int64 */
    limit?: number;
    name: string;
    /** Format: int64 */
    position?: number;
    product?: components["schemas"]["Product"];
    productId: string;
    productStream?: components["schemas"]["ProductStream"];
    productStreamId?: string;
    productVersionId?: string;
    sortBy?: string;
    sortDirection?: string;
    translated: {
      name: string;
      productId: string;
      productStreamId: string;
      productVersionId: string;
      sortBy: string;
      sortDirection: string;
      type: string;
    };
    type?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  ProductCrossSellingAssignedProducts: {
    /** Format: date-time */
    readonly createdAt?: string;
    crossSelling?: components["schemas"]["ProductCrossSelling"];
    crossSellingId: string;
    id: string;
    /** Format: int64 */
    position?: number;
    product?: components["schemas"]["Product"];
    productId: string;
    productVersionId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  ProductCrossSellingAssignedProductsJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    crossSellingId: string;
    id: string;
    /** Format: int64 */
    position?: number;
    productId: string;
    productVersionId?: string;
    relationships?: {
      crossSelling?: {
        data?: {
          /** @example ef23268669fb6d8a7def2b9f2da0aceb */
          id?: string;
          /** @example product_cross_selling */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /product-cross-selling-assigned-products/281cee27ae278acd6f5f2bc77ce12736/crossSelling
           */
          related?: string;
        };
      };
      product?: {
        data?: {
          /** @example f5bf48aa40cad7891eb709fcf1fde128 */
          id?: string;
          /** @example product */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /product-cross-selling-assigned-products/281cee27ae278acd6f5f2bc77ce12736/product
           */
          related?: string;
        };
      };
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  ProductCrossSellingJsonApi: components["schemas"]["resource"] & {
    active?: boolean;
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    /** Format: int64 */
    limit?: number;
    name: string;
    /** Format: int64 */
    position?: number;
    productId: string;
    productStreamId?: string;
    productVersionId?: string;
    relationships?: {
      assignedProducts?: {
        data?: {
          /** @example 5da5e10eda1b7026499bcd4747d6bdf8 */
          id?: string;
          /** @example product_cross_selling_assigned_products */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product-cross-selling/30f0355cd0686038f211fd5c8014c9b4/assignedProducts
           */
          related?: string;
        };
      };
      product?: {
        data?: {
          /** @example f5bf48aa40cad7891eb709fcf1fde128 */
          id?: string;
          /** @example product */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /product-cross-selling/30f0355cd0686038f211fd5c8014c9b4/product
           */
          related?: string;
        };
      };
      productStream?: {
        data?: {
          /** @example 49561f6faa0badfce831a183d2ec7c2f */
          id?: string;
          /** @example product_stream */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /product-cross-selling/30f0355cd0686038f211fd5c8014c9b4/productStream
           */
          related?: string;
        };
      };
    };
    sortBy?: string;
    sortDirection?: string;
    translated: {
      name: string;
      productId: string;
      productStreamId: string;
      productVersionId: string;
      sortBy: string;
      sortDirection: string;
      type: string;
    };
    type?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  ProductCustomFieldSet: {
    customFieldSet?: components["schemas"]["CustomFieldSet"];
    customFieldSetId: string;
    id?: string;
    product?: components["schemas"]["Product"];
    productId: string;
    productVersionId?: string;
  };
  ProductDownload: {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    id: string;
    media?: components["schemas"]["Media"];
    mediaId: string;
    /** Format: int64 */
    position?: number;
    product?: components["schemas"]["Product"];
    productId: string;
    productVersionId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  ProductDownloadJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    id: string;
    mediaId: string;
    /** Format: int64 */
    position?: number;
    productId: string;
    productVersionId?: string;
    relationships?: {
      media?: {
        data?: {
          /** @example 62933a2951ef01f4eafd9bdf4d3cd2f0 */
          id?: string;
          /** @example media */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /product-download/f1371d26b74fe7557f3d9b5aeb2653df/media
           */
          related?: string;
        };
      };
      product?: {
        data?: {
          /** @example f5bf48aa40cad7891eb709fcf1fde128 */
          id?: string;
          /** @example product */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /product-download/f1371d26b74fe7557f3d9b5aeb2653df/product
           */
          related?: string;
        };
      };
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  ProductExport: {
    accessKey: string;
    bodyTemplate?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    currency?: components["schemas"]["Currency"];
    currencyId: string;
    encoding: string;
    fileFormat: string;
    fileName: string;
    footerTemplate?: string;
    generateByCronjob: boolean;
    /** Format: date-time */
    generatedAt?: string;
    headerTemplate?: string;
    id: string;
    includeVariants?: boolean;
    /** Format: int64 */
    interval: number;
    isRunning?: boolean;
    pausedSchedule?: boolean;
    productStream?: components["schemas"]["ProductStream"];
    productStreamId: string;
    salesChannel?: components["schemas"]["SalesChannel"];
    salesChannelDomain?: components["schemas"]["SalesChannelDomain"];
    salesChannelDomainId: string;
    salesChannelId: string;
    storefrontSalesChannel?: components["schemas"]["SalesChannel"];
    storefrontSalesChannelId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  ProductExportJsonApi: components["schemas"]["resource"] & {
    accessKey: string;
    bodyTemplate?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    currencyId: string;
    encoding: string;
    fileFormat: string;
    fileName: string;
    footerTemplate?: string;
    generateByCronjob: boolean;
    /** Format: date-time */
    generatedAt?: string;
    headerTemplate?: string;
    id: string;
    includeVariants?: boolean;
    /** Format: int64 */
    interval: number;
    isRunning?: boolean;
    pausedSchedule?: boolean;
    productStreamId: string;
    relationships?: {
      currency?: {
        data?: {
          /** @example 1af0389838508d7016a9841eb6273962 */
          id?: string;
          /** @example currency */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /product-export/7a835b69a3e491d9a3be31d2de469f8a/currency
           */
          related?: string;
        };
      };
      productStream?: {
        data?: {
          /** @example 49561f6faa0badfce831a183d2ec7c2f */
          id?: string;
          /** @example product_stream */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /product-export/7a835b69a3e491d9a3be31d2de469f8a/productStream
           */
          related?: string;
        };
      };
      salesChannel?: {
        data?: {
          /** @example ec3712a84143b57e0db620eaac6e55b8 */
          id?: string;
          /** @example sales_channel */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /product-export/7a835b69a3e491d9a3be31d2de469f8a/salesChannel
           */
          related?: string;
        };
      };
      salesChannelDomain?: {
        data?: {
          /** @example 29c8b34b04e94e35e95e8346954b7fb4 */
          id?: string;
          /** @example sales_channel_domain */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /product-export/7a835b69a3e491d9a3be31d2de469f8a/salesChannelDomain
           */
          related?: string;
        };
      };
      storefrontSalesChannel?: {
        data?: {
          /** @example 5979d6e259ba5ec4c2b93cf79df6f2e5 */
          id?: string;
          /** @example sales_channel */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /product-export/7a835b69a3e491d9a3be31d2de469f8a/storefrontSalesChannel
           */
          related?: string;
        };
      };
    };
    salesChannelDomainId: string;
    salesChannelId: string;
    storefrontSalesChannelId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  ProductFeatureSet: {
    /** Format: date-time */
    readonly createdAt?: string;
    description?: string;
    features?: GenericRecord;
    id: string;
    name: string;
    products?: components["schemas"]["Product"][];
    translated: {
      description: string;
      name: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  ProductFeatureSetJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    description?: string;
    features?: GenericRecord;
    id: string;
    name: string;
    relationships?: {
      products?: {
        data?: {
          /** @example 86024cad1e83101d97359d7351051156 */
          id?: string;
          /** @example product */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product-feature-set/69d445ae065ef917cd50febab4b55db2/products
           */
          related?: string;
        };
      };
    };
    translated: {
      description: string;
      name: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  ProductJsonApi: components["schemas"]["resource"] & {
    active?: boolean;
    /** Format: int64 */
    readonly autoIncrement?: number;
    readonly available?: boolean;
    /** Format: int64 */
    readonly availableStock?: number;
    canonicalProductId?: string;
    canonicalProductVersionId?: string;
    readonly categoryIds?: string[];
    readonly categoryTree?: string[];
    /** Format: int64 */
    readonly childCount?: number;
    cmsPageId?: string;
    cmsPageVersionId?: string;
    coverId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    customFieldSetSelectionActive?: boolean;
    customSearchKeywords?: GenericRecord[];
    deliveryTimeId?: string;
    description?: string;
    readonly displayGroup?: string;
    ean?: string;
    extensions?: {
      attendeeProductCollections?: {
        data?: {
          /** @example 0a7b3b2f4b81f36910a74f22826f35df */
          id?: string;
          /** @example dsr_attendee_product_collection */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/attendeeProductCollections
           */
          related?: string;
        };
      };
      customPrice?: {
        data?: {
          /** @example 35ed8bfa9c73171a7b417f13ab07d57a */
          id?: string;
          /** @example custom_price */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/customPrice
           */
          related?: string;
        };
      };
      orderWarehouses?: {
        data?: {
          /** @example 5331369e2f71d048521bd35d80975314 */
          id?: string;
          /** @example order_product_warehouse */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/orderWarehouses
           */
          related?: string;
        };
      };
      paypalPosLog?: {
        data?: {
          /** @example 7edfbc8f7a12c1d79b6de5b0154cf325 */
          id?: string;
          /** @example swag_paypal_pos_sales_channel_run_log */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/paypalPosLog
           */
          related?: string;
        };
      };
      paypalPosSync?: {
        data?: {
          /** @example 163c806e836f72f29f292c8ef2dfe61e */
          id?: string;
          /** @example swag_paypal_pos_sales_channel_product */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/paypalPosSync
           */
          related?: string;
        };
      };
      presentationCmsPages?: {
        data?: {
          /** @example 30c725082807b69914fddd7e82d0d741 */
          id?: string;
          /** @example dsr_presentation_cms_page */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/presentationCmsPages
           */
          related?: string;
        };
      };
      quoteLineItems?: {
        data?: {
          /** @example 6b1c17ad551ef636e491ab6848f68420 */
          id?: string;
          /** @example quote_line_item */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/quoteLineItems
           */
          related?: string;
        };
      };
      reviewSummaries?: {
        data?: {
          /** @example c9c718522e64ffa5effb26cef94f4849 */
          id?: string;
          /** @example product_review_summary */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/reviewSummaries
           */
          related?: string;
        };
      };
      search?: GenericRecord;
      shoppingListLineItems?: {
        data?: {
          /** @example ce593c6d1db236f22dc387a2ee20dfd6 */
          id?: string;
          /** @example b2b_components_shopping_list_line_item */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/shoppingListLineItems
           */
          related?: string;
        };
      };
      socialShoppingProductErrors?: {
        data?: {
          /** @example 74181afcb28901351a5f2676d1687de8 */
          id?: string;
          /** @example swag_social_shopping_product_error */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/socialShoppingProductErrors
           */
          related?: string;
        };
      };
      subscriptionPlans?: {
        data?: {
          /** @example ed94874505da2886dc66a3a3d3968972 */
          id?: string;
          /** @example subscription_plan */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/subscriptionPlans
           */
          related?: string;
        };
      };
      swagCustomizedProductsTemplate?: {
        data?: {
          /** @example 6e9fad30dd3cb84748a01bb8152f4769 */
          id?: string;
          /** @example swag_customized_products_template */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/swagCustomizedProductsTemplate
           */
          related?: string;
        };
      };
      swagDynamicAccessRules?: {
        data?: {
          /** @example 05b9d828254c957dfa5224c581439c92 */
          id?: string;
          /** @example rule */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/swagDynamicAccessRules
           */
          related?: string;
        };
      };
      warehouseGroups?: {
        data?: {
          /** @example 21191f2f6f4c30cd4ccc4714fa74ffea */
          id?: string;
          /** @example warehouse_group */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/warehouseGroups
           */
          related?: string;
        };
      };
      warehouses?: {
        data?: {
          /** @example 544959798565126142ca2820b4f56271 */
          id?: string;
          /** @example product_warehouse */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/warehouses
           */
          related?: string;
        };
      };
    };
    featureSetId?: string;
    /** Format: float */
    height?: number;
    id: string;
    isCloseout?: boolean;
    keywords?: string;
    /** Format: float */
    length?: number;
    manufacturerId?: string;
    manufacturerNumber?: string;
    markAsTopseller?: boolean;
    /** Format: int64 */
    maxPurchase?: number;
    metaDescription?: string;
    metaTitle?: string;
    /** Format: int64 */
    minPurchase?: number;
    name: string;
    readonly optionIds?: string[];
    packUnit?: string;
    packUnitPlural?: string;
    parentId?: string;
    parentVersionId?: string;
    price: components["schemas"]["Price"][];
    productManufacturerVersionId?: string;
    productMediaVersionId?: string;
    productNumber: string;
    readonly propertyIds?: string[];
    purchasePrices?: components["schemas"]["Price"][];
    /** Format: int64 */
    purchaseSteps?: number;
    /** Format: float */
    purchaseUnit?: number;
    /** Format: float */
    readonly ratingAverage?: number;
    /** Format: float */
    referenceUnit?: number;
    relationships?: {
      canonicalProduct?: {
        data?: {
          /** @example 023995a50b56c0de077323e958b2bbcd */
          id?: string;
          /** @example product */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/canonicalProduct
           */
          related?: string;
        };
      };
      categories?: {
        data?: {
          /** @example b0b5ccb4a195a07fd3eed14affb8695f */
          id?: string;
          /** @example category */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/categories
           */
          related?: string;
        };
      };
      categoriesRo?: {
        data?: {
          /** @example 7f0702d3a90d965b8c9158c451f43fdb */
          id?: string;
          /** @example category */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/categoriesRo
           */
          related?: string;
        };
      };
      children?: {
        data?: {
          /** @example 268184c12df027f536154d099d497b31 */
          id?: string;
          /** @example product */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/children
           */
          related?: string;
        };
      };
      cmsPage?: {
        data?: {
          /** @example 7b1460918b1abb93311108f3dc021c9b */
          id?: string;
          /** @example cms_page */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/cmsPage
           */
          related?: string;
        };
      };
      configuratorSettings?: {
        data?: {
          /** @example c0827fee13725d41f1fd7e292243f5aa */
          id?: string;
          /** @example product_configurator_setting */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/configuratorSettings
           */
          related?: string;
        };
      };
      cover?: {
        data?: {
          /** @example 41d0e299ca1abeb2094852da042165c7 */
          id?: string;
          /** @example product_media */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/cover
           */
          related?: string;
        };
      };
      crossSellingAssignedProducts?: {
        data?: {
          /** @example 5ee26b69e515f51ece26912961283b6d */
          id?: string;
          /** @example product_cross_selling_assigned_products */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/crossSellingAssignedProducts
           */
          related?: string;
        };
      };
      crossSellings?: {
        data?: {
          /** @example 89936e14544d1b403cecef938101b6b0 */
          id?: string;
          /** @example product_cross_selling */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/crossSellings
           */
          related?: string;
        };
      };
      customFieldSets?: {
        data?: {
          /** @example 9b29ba872ce510f033b31364c8602760 */
          id?: string;
          /** @example custom_field_set */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/customFieldSets
           */
          related?: string;
        };
      };
      deliveryTime?: {
        data?: {
          /** @example 8c888ae25a7bd42057370e31f7e01044 */
          id?: string;
          /** @example delivery_time */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/deliveryTime
           */
          related?: string;
        };
      };
      downloads?: {
        data?: {
          /** @example d07d50a751bc6ddf12bf3af0efee9b45 */
          id?: string;
          /** @example product_download */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/downloads
           */
          related?: string;
        };
      };
      featureSet?: {
        data?: {
          /** @example 9cef0cd6ce1c52f0d29b23b7e40dbb17 */
          id?: string;
          /** @example product_feature_set */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/featureSet
           */
          related?: string;
        };
      };
      mainCategories?: {
        data?: {
          /** @example 1fb731fc4139cbb575429e28846f0c39 */
          id?: string;
          /** @example main_category */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/mainCategories
           */
          related?: string;
        };
      };
      manufacturer?: {
        data?: {
          /** @example c2904bca62b22443d6cf5e9d89cab204 */
          id?: string;
          /** @example product_manufacturer */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/manufacturer
           */
          related?: string;
        };
      };
      media?: {
        data?: {
          /** @example 62933a2951ef01f4eafd9bdf4d3cd2f0 */
          id?: string;
          /** @example product_media */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/media
           */
          related?: string;
        };
      };
      options?: {
        data?: {
          /** @example 93da65a9fd0004d9477aeac024e08e15 */
          id?: string;
          /** @example property_group_option */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/options
           */
          related?: string;
        };
      };
      orderLineItems?: {
        data?: {
          /** @example 6bd56ce4562ca1be86bf5b8d92c3c1ee */
          id?: string;
          /** @example order_line_item */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/orderLineItems
           */
          related?: string;
        };
      };
      parent?: {
        data?: {
          /** @example d0e45878043844ffc41aac437e86b602 */
          id?: string;
          /** @example product */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/parent
           */
          related?: string;
        };
      };
      prices?: {
        data?: {
          /** @example afae32efe0f84fece3f96b377b768b33 */
          id?: string;
          /** @example product_price */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/prices
           */
          related?: string;
        };
      };
      productReviews?: {
        data?: {
          /** @example 01e78541ea343ed72424a5222796a4cd */
          id?: string;
          /** @example product_review */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/productReviews
           */
          related?: string;
        };
      };
      properties?: {
        data?: {
          /** @example 74693d2fc58b46bd06410f278e39aa71 */
          id?: string;
          /** @example property_group_option */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/properties
           */
          related?: string;
        };
      };
      searchKeywords?: {
        data?: {
          /** @example effbcffaacb8111b531f15e6f4c796d1 */
          id?: string;
          /** @example product_search_keyword */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/searchKeywords
           */
          related?: string;
        };
      };
      seoUrls?: {
        data?: {
          /** @example 5321b5a71127b8b98cdd4b068ad56c4c */
          id?: string;
          /** @example seo_url */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/seoUrls
           */
          related?: string;
        };
      };
      streams?: {
        data?: {
          /** @example 2f6f4768f1c2d7c8f1f54823723f1a70 */
          id?: string;
          /** @example product_stream */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/streams
           */
          related?: string;
        };
      };
      tags?: {
        data?: {
          /** @example d57ac45256849d9b13e2422d91580fb9 */
          id?: string;
          /** @example tag */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/tags
           */
          related?: string;
        };
      };
      tax?: {
        data?: {
          /** @example 06565e5611f23fdf8cc43e5077b92b54 */
          id?: string;
          /** @example tax */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/tax
           */
          related?: string;
        };
      };
      unit?: {
        data?: {
          /** @example 3e34bdebd9bd5edda27e8728904a2552 */
          id?: string;
          /** @example unit */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/unit
           */
          related?: string;
        };
      };
      visibilities?: {
        data?: {
          /** @example 63226fcdfe3316ec1237ef07a8fe6732 */
          id?: string;
          /** @example product_visibility */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/visibilities
           */
          related?: string;
        };
      };
      wishlists?: {
        data?: {
          /** @example 4ec38c6b2208529c1fadccc7d55d7947 */
          id?: string;
          /** @example customer_wishlist_product */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product/deb10517653c255364175796ace3553f/wishlists
           */
          related?: string;
        };
      };
    };
    /** Format: date-time */
    releaseDate?: string;
    /** Format: int64 */
    restockTime?: number;
    /** Format: int64 */
    readonly sales?: number;
    shippingFree?: boolean;
    slotConfig?: GenericRecord;
    readonly states?: string[];
    /** Format: int64 */
    stock: number;
    readonly streamIds?: string[];
    readonly tagIds?: string[];
    taxId: string;
    translated: {
      canonicalProductId: string;
      canonicalProductVersionId: string;
      cmsPageId: string;
      cmsPageVersionId: string;
      coverId: string;
      deliveryTimeId: string;
      description: string;
      displayGroup: string;
      ean: string;
      featureSetId: string;
      keywords: string;
      manufacturerId: string;
      manufacturerNumber: string;
      metaDescription: string;
      metaTitle: string;
      name: string;
      packUnit: string;
      packUnitPlural: string;
      parentId: string;
      parentVersionId: string;
      productManufacturerVersionId: string;
      productMediaVersionId: string;
      productNumber: string;
      releaseDate: string;
      taxId: string;
      unitId: string;
      versionId: string;
    };
    unitId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    variantListingConfig?: GenericRecord;
    variantRestrictions?: GenericRecord;
    variation?: string[];
    versionId?: string;
    /** Format: float */
    weight?: number;
    /** Format: float */
    width?: number;
  };
  ProductKeywordDictionary: {
    id: string;
    keyword: string;
    language?: components["schemas"]["Language"];
    languageId: string;
    reversed?: string;
  };
  ProductKeywordDictionaryJsonApi: components["schemas"]["resource"] & {
    id: string;
    keyword: string;
    languageId: string;
    relationships?: {
      language?: {
        data?: {
          /** @example 8512ae7d57b1396273f76fe6ed341a23 */
          id?: string;
          /** @example language */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /product-keyword-dictionary/a1bc4695aa3e6f80fb42d62e6439296c/language
           */
          related?: string;
        };
      };
    };
    reversed?: string;
  };
  ProductManufacturer: {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    description?: string;
    extensions?: {
      search?: GenericRecord;
    };
    id: string;
    link?: string;
    media?: components["schemas"]["Media"];
    mediaId?: string;
    name: string;
    products?: components["schemas"]["Product"][];
    translated: {
      description: string;
      link: string;
      mediaId: string;
      name: string;
      versionId: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  ProductManufacturerJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    description?: string;
    extensions?: {
      search?: GenericRecord;
    };
    id: string;
    link?: string;
    mediaId?: string;
    name: string;
    relationships?: {
      media?: {
        data?: {
          /** @example 62933a2951ef01f4eafd9bdf4d3cd2f0 */
          id?: string;
          /** @example media */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /product-manufacturer/269f96011fc7a4e7a8c1fa87b45b8d1d/media
           */
          related?: string;
        };
      };
      products?: {
        data?: {
          /** @example 86024cad1e83101d97359d7351051156 */
          id?: string;
          /** @example product */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product-manufacturer/269f96011fc7a4e7a8c1fa87b45b8d1d/products
           */
          related?: string;
        };
      };
    };
    translated: {
      description: string;
      link: string;
      mediaId: string;
      name: string;
      versionId: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  ProductMedia: {
    coverProducts?: components["schemas"]["Product"][];
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    id: string;
    media?: components["schemas"]["Media"];
    mediaId: string;
    /** Format: int64 */
    position?: number;
    product?: components["schemas"]["Product"];
    productId: string;
    productVersionId?: string;
    thumbnails?: components["schemas"]["MediaThumbnail"];
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  ProductMediaJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    id: string;
    mediaId: string;
    /** Format: int64 */
    position?: number;
    productId: string;
    productVersionId?: string;
    relationships?: {
      coverProducts?: {
        data?: {
          /** @example 41f7b522ee6fd2f54469cf9ec8e1c8b0 */
          id?: string;
          /** @example product */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product-media/b93c38a6be7ba7db807d807adfff50a3/coverProducts
           */
          related?: string;
        };
      };
      media?: {
        data?: {
          /** @example 62933a2951ef01f4eafd9bdf4d3cd2f0 */
          id?: string;
          /** @example media */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /product-media/b93c38a6be7ba7db807d807adfff50a3/media
           */
          related?: string;
        };
      };
      product?: {
        data?: {
          /** @example f5bf48aa40cad7891eb709fcf1fde128 */
          id?: string;
          /** @example product */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /product-media/b93c38a6be7ba7db807d807adfff50a3/product
           */
          related?: string;
        };
      };
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  ProductOption: {
    id?: string;
    option?: components["schemas"]["PropertyGroupOption"];
    optionId: string;
    product?: components["schemas"]["Product"];
    productId: string;
    productVersionId?: string;
  };
  ProductPrice: {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    id: string;
    price: components["schemas"]["Price"][];
    product?: components["schemas"]["Product"];
    productId: string;
    productVersionId?: string;
    /** Format: int64 */
    quantityEnd?: number;
    /** Format: int64 */
    quantityStart: number;
    rule?: components["schemas"]["Rule"];
    ruleId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  ProductPriceJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    id: string;
    price: components["schemas"]["Price"][];
    productId: string;
    productVersionId?: string;
    /** Format: int64 */
    quantityEnd?: number;
    /** Format: int64 */
    quantityStart: number;
    relationships?: {
      product?: {
        data?: {
          /** @example f5bf48aa40cad7891eb709fcf1fde128 */
          id?: string;
          /** @example product */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /product-price/2003a59b6b10a56954d203e225f83585/product
           */
          related?: string;
        };
      };
      rule?: {
        data?: {
          /** @example 981c1e7b3795da18687613fbd66d4954 */
          id?: string;
          /** @example rule */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /product-price/2003a59b6b10a56954d203e225f83585/rule
           */
          related?: string;
        };
      };
    };
    ruleId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  ProductProperty: {
    id?: string;
    option?: components["schemas"]["PropertyGroupOption"];
    optionId: string;
    product?: components["schemas"]["Product"];
    productId: string;
    productVersionId?: string;
  };
  ProductReview: {
    comment?: string;
    content: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customer?: components["schemas"]["Customer"];
    customerId?: string;
    customFields?: GenericRecord;
    externalEmail?: string;
    externalUser?: string;
    id: string;
    language?: components["schemas"]["Language"];
    languageId: string;
    /** Format: float */
    points?: number;
    product?: components["schemas"]["Product"];
    productId: string;
    productVersionId?: string;
    salesChannel?: components["schemas"]["SalesChannel"];
    salesChannelId: string;
    status?: boolean;
    title: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  ProductReviewJsonApi: components["schemas"]["resource"] & {
    comment?: string;
    content: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customerId?: string;
    customFields?: GenericRecord;
    externalEmail?: string;
    externalUser?: string;
    id: string;
    languageId: string;
    /** Format: float */
    points?: number;
    productId: string;
    productVersionId?: string;
    relationships?: {
      customer?: {
        data?: {
          /** @example 91ec1f9324753048c0096d036a694f86 */
          id?: string;
          /** @example customer */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /product-review/0793b857a73beced20090eec19b11a3d/customer
           */
          related?: string;
        };
      };
      language?: {
        data?: {
          /** @example 8512ae7d57b1396273f76fe6ed341a23 */
          id?: string;
          /** @example language */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /product-review/0793b857a73beced20090eec19b11a3d/language
           */
          related?: string;
        };
      };
      product?: {
        data?: {
          /** @example f5bf48aa40cad7891eb709fcf1fde128 */
          id?: string;
          /** @example product */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /product-review/0793b857a73beced20090eec19b11a3d/product
           */
          related?: string;
        };
      };
      salesChannel?: {
        data?: {
          /** @example ec3712a84143b57e0db620eaac6e55b8 */
          id?: string;
          /** @example sales_channel */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /product-review/0793b857a73beced20090eec19b11a3d/salesChannel
           */
          related?: string;
        };
      };
    };
    salesChannelId: string;
    status?: boolean;
    title: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  ProductReviewSummary: {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    product?: components["schemas"]["Product"];
    productId: string;
    productVersionId?: string;
    salesChannel?: components["schemas"]["SalesChannel"];
    salesChannelId: string;
    summary?: string;
    translated: {
      productId: string;
      productVersionId: string;
      salesChannelId: string;
      summary: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    visible?: boolean;
  };
  ProductReviewSummaryJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    productId: string;
    productVersionId?: string;
    relationships?: {
      product?: {
        data?: {
          /** @example f5bf48aa40cad7891eb709fcf1fde128 */
          id?: string;
          /** @example product */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /product-review-summary/a4b5dac1755dd11ea772509278bbc072/product
           */
          related?: string;
        };
      };
      salesChannel?: {
        data?: {
          /** @example ec3712a84143b57e0db620eaac6e55b8 */
          id?: string;
          /** @example sales_channel */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /product-review-summary/a4b5dac1755dd11ea772509278bbc072/salesChannel
           */
          related?: string;
        };
      };
    };
    salesChannelId: string;
    summary?: string;
    translated: {
      productId: string;
      productVersionId: string;
      salesChannelId: string;
      summary: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    visible?: boolean;
  };
  ProductSearchConfig: {
    andLogic?: boolean;
    configFields?: components["schemas"]["ProductSearchConfigField"][];
    /** Format: date-time */
    readonly createdAt?: string;
    excludedTerms?: string[];
    id: string;
    language?: components["schemas"]["Language"];
    languageId: string;
    /** Format: int64 */
    minSearchLength?: number;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  ProductSearchConfigField: {
    /** Format: date-time */
    readonly createdAt?: string;
    customField?: components["schemas"]["CustomField"];
    customFieldId?: string;
    field: string;
    id: string;
    /** Format: int64 */
    ranking?: number;
    searchable?: boolean;
    searchConfig?: components["schemas"]["ProductSearchConfig"];
    searchConfigId: string;
    tokenize?: boolean;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  ProductSearchConfigFieldJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    customFieldId?: string;
    field: string;
    id: string;
    /** Format: int64 */
    ranking?: number;
    relationships?: {
      customField?: {
        data?: {
          /** @example ed2028a1c479c7e0065da597452d9c11 */
          id?: string;
          /** @example custom_field */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /product-search-config-field/38271ca1804968a1c9d07c12719453b8/customField
           */
          related?: string;
        };
      };
      searchConfig?: {
        data?: {
          /** @example bc8281d44069ce8ffd34144fbad1bddd */
          id?: string;
          /** @example product_search_config */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /product-search-config-field/38271ca1804968a1c9d07c12719453b8/searchConfig
           */
          related?: string;
        };
      };
    };
    searchable?: boolean;
    searchConfigId: string;
    tokenize?: boolean;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  ProductSearchConfigJsonApi: components["schemas"]["resource"] & {
    andLogic?: boolean;
    /** Format: date-time */
    readonly createdAt?: string;
    excludedTerms?: string[];
    id: string;
    languageId: string;
    /** Format: int64 */
    minSearchLength?: number;
    relationships?: {
      configFields?: {
        data?: {
          /** @example 5334117da647d3f2fb8a82948d56bcc3 */
          id?: string;
          /** @example product_search_config_field */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product-search-config/a150b98c1747cffb40453f0c15e18261/configFields
           */
          related?: string;
        };
      };
      language?: {
        data?: {
          /** @example 8512ae7d57b1396273f76fe6ed341a23 */
          id?: string;
          /** @example language */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /product-search-config/a150b98c1747cffb40453f0c15e18261/language
           */
          related?: string;
        };
      };
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  ProductSearchKeyword: {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    keyword: string;
    language?: components["schemas"]["Language"];
    languageId: string;
    product?: components["schemas"]["Product"];
    productId: string;
    productVersionId?: string;
    /** Format: float */
    ranking: number;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  ProductSearchKeywordJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    keyword: string;
    languageId: string;
    productId: string;
    productVersionId?: string;
    /** Format: float */
    ranking: number;
    relationships?: {
      language?: {
        data?: {
          /** @example 8512ae7d57b1396273f76fe6ed341a23 */
          id?: string;
          /** @example language */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /product-search-keyword/b704475cf722682ba73e11d9903e09a4/language
           */
          related?: string;
        };
      };
      product?: {
        data?: {
          /** @example f5bf48aa40cad7891eb709fcf1fde128 */
          id?: string;
          /** @example product */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /product-search-keyword/b704475cf722682ba73e11d9903e09a4/product
           */
          related?: string;
        };
      };
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  ProductSorting: {
    active: boolean;
    /** Format: date-time */
    readonly createdAt?: string;
    fields: GenericRecord;
    id: string;
    key: string;
    label: string;
    locked?: boolean;
    /** Format: int64 */
    priority: number;
    translated: {
      key: string;
      label: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  ProductSortingJsonApi: components["schemas"]["resource"] & {
    active: boolean;
    /** Format: date-time */
    readonly createdAt?: string;
    fields: GenericRecord;
    id: string;
    key: string;
    label: string;
    locked?: boolean;
    /** Format: int64 */
    priority: number;
    translated: {
      key: string;
      label: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  ProductStream: {
    readonly apiFilter?: GenericRecord;
    categories?: components["schemas"]["Category"][];
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    description?: string;
    extensions?: {
      paypalPosSalesChannels?: {
        data?: {
          /** @example 80dd7867f3205b7f1600d6c76438fb42 */
          id?: string;
          /** @example swag_paypal_pos_sales_channel */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product-stream/8f4cdc10a7afbd7f3948c6f8cd5c4801/paypalPosSalesChannels
           */
          related?: string;
        };
      };
      presentationCmsPages?: {
        data?: {
          /** @example 30c725082807b69914fddd7e82d0d741 */
          id?: string;
          /** @example dsr_presentation_cms_page */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product-stream/8f4cdc10a7afbd7f3948c6f8cd5c4801/presentationCmsPages
           */
          related?: string;
        };
      };
      socialShoppingSalesChannels?: {
        data?: {
          /** @example e581067f817be66449a3f4350dc327af */
          id?: string;
          /** @example swag_social_shopping_sales_channel */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product-stream/8f4cdc10a7afbd7f3948c6f8cd5c4801/socialShoppingSalesChannels
           */
          related?: string;
        };
      };
    };
    filters?: components["schemas"]["ProductStreamFilter"][];
    id: string;
    readonly invalid?: boolean;
    name: string;
    productCrossSellings?: components["schemas"]["ProductCrossSelling"][];
    productExports?: components["schemas"]["ProductExport"][];
    translated: {
      description: string;
      name: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  ProductStreamFilter: {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    field?: string;
    id: string;
    operator?: string;
    parameters?: GenericRecord;
    parent?: components["schemas"]["ProductStreamFilter"];
    parentId?: string;
    /** Format: int64 */
    position?: number;
    productStream?: components["schemas"]["ProductStream"];
    productStreamId: string;
    queries?: components["schemas"]["ProductStreamFilter"][];
    type: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    value?: string;
  };
  ProductStreamFilterJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    field?: string;
    id: string;
    operator?: string;
    parameters?: GenericRecord;
    parentId?: string;
    /** Format: int64 */
    position?: number;
    productStreamId: string;
    relationships?: {
      parent?: {
        data?: {
          /** @example d0e45878043844ffc41aac437e86b602 */
          id?: string;
          /** @example product_stream_filter */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /product-stream-filter/4e06c1fc9085cee6646a5e736395212d/parent
           */
          related?: string;
        };
      };
      productStream?: {
        data?: {
          /** @example 49561f6faa0badfce831a183d2ec7c2f */
          id?: string;
          /** @example product_stream */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /product-stream-filter/4e06c1fc9085cee6646a5e736395212d/productStream
           */
          related?: string;
        };
      };
      queries?: {
        data?: {
          /** @example 5da7eb4247add5dbd5776c9c0b38460a */
          id?: string;
          /** @example product_stream_filter */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product-stream-filter/4e06c1fc9085cee6646a5e736395212d/queries
           */
          related?: string;
        };
      };
    };
    type: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    value?: string;
  };
  ProductStreamJsonApi: components["schemas"]["resource"] & {
    readonly apiFilter?: GenericRecord;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    description?: string;
    extensions?: {
      paypalPosSalesChannels?: {
        data?: {
          /** @example 80dd7867f3205b7f1600d6c76438fb42 */
          id?: string;
          /** @example swag_paypal_pos_sales_channel */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product-stream/8f4cdc10a7afbd7f3948c6f8cd5c4801/paypalPosSalesChannels
           */
          related?: string;
        };
      };
      presentationCmsPages?: {
        data?: {
          /** @example 30c725082807b69914fddd7e82d0d741 */
          id?: string;
          /** @example dsr_presentation_cms_page */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product-stream/8f4cdc10a7afbd7f3948c6f8cd5c4801/presentationCmsPages
           */
          related?: string;
        };
      };
      socialShoppingSalesChannels?: {
        data?: {
          /** @example e581067f817be66449a3f4350dc327af */
          id?: string;
          /** @example swag_social_shopping_sales_channel */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product-stream/8f4cdc10a7afbd7f3948c6f8cd5c4801/socialShoppingSalesChannels
           */
          related?: string;
        };
      };
    };
    id: string;
    readonly invalid?: boolean;
    name: string;
    relationships?: {
      categories?: {
        data?: {
          /** @example b0b5ccb4a195a07fd3eed14affb8695f */
          id?: string;
          /** @example category */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product-stream/8f4cdc10a7afbd7f3948c6f8cd5c4801/categories
           */
          related?: string;
        };
      };
      filters?: {
        data?: {
          /** @example 2c9885d2b0c7e26971f60a90f33cf718 */
          id?: string;
          /** @example product_stream_filter */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product-stream/8f4cdc10a7afbd7f3948c6f8cd5c4801/filters
           */
          related?: string;
        };
      };
      productCrossSellings?: {
        data?: {
          /** @example 6fa3de1d94218e2ac5a51cbeaca7f846 */
          id?: string;
          /** @example product_cross_selling */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product-stream/8f4cdc10a7afbd7f3948c6f8cd5c4801/productCrossSellings
           */
          related?: string;
        };
      };
      productExports?: {
        data?: {
          /** @example 2cd8793787cda582174c0fc329fbc377 */
          id?: string;
          /** @example product_export */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /product-stream/8f4cdc10a7afbd7f3948c6f8cd5c4801/productExports
           */
          related?: string;
        };
      };
    };
    translated: {
      description: string;
      name: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  ProductStreamMapping: {
    id?: string;
    product?: components["schemas"]["Product"];
    productId: string;
    productStream?: components["schemas"]["ProductStream"];
    productStreamId: string;
    productVersionId?: string;
  };
  ProductTag: {
    id?: string;
    product?: components["schemas"]["Product"];
    productId: string;
    productVersionId?: string;
    tag?: components["schemas"]["Tag"];
    tagId: string;
  };
  ProductVisibility: {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    product?: components["schemas"]["Product"];
    productId: string;
    productVersionId?: string;
    salesChannel?: components["schemas"]["SalesChannel"];
    salesChannelId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    /** Format: int64 */
    visibility: number;
  };
  ProductVisibilityJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    productId: string;
    productVersionId?: string;
    relationships?: {
      product?: {
        data?: {
          /** @example f5bf48aa40cad7891eb709fcf1fde128 */
          id?: string;
          /** @example product */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /product-visibility/e965d09420555f52df9b20f904697d96/product
           */
          related?: string;
        };
      };
      salesChannel?: {
        data?: {
          /** @example ec3712a84143b57e0db620eaac6e55b8 */
          id?: string;
          /** @example sales_channel */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /product-visibility/e965d09420555f52df9b20f904697d96/salesChannel
           */
          related?: string;
        };
      };
    };
    salesChannelId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    /** Format: int64 */
    visibility: number;
  };
  ProductWarehouse: {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    product?: components["schemas"]["Product"];
    productId: string;
    productVersionId?: string;
    /** Format: int64 */
    stock: number;
    /** Format: date-time */
    readonly updatedAt?: string;
    warehouse?: components["schemas"]["Warehouse"];
    warehouseId: string;
  };
  ProductWarehouseGroup: {
    id?: string;
    product?: components["schemas"]["Product"];
    productId: string;
    productVersionId?: string;
    warehouseGroup?: components["schemas"]["WarehouseGroup"];
    warehouseGroupId: string;
  };
  ProductWarehouseJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    productId: string;
    productVersionId?: string;
    relationships?: {
      product?: {
        data?: {
          /** @example f5bf48aa40cad7891eb709fcf1fde128 */
          id?: string;
          /** @example product */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /product-warehouse/bb934215f15673b81755030f1d8cc000/product
           */
          related?: string;
        };
      };
      warehouse?: {
        data?: {
          /** @example 372d30dd2849813ef674855253900679 */
          id?: string;
          /** @example warehouse */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /product-warehouse/bb934215f15673b81755030f1d8cc000/warehouse
           */
          related?: string;
        };
      };
    };
    /** Format: int64 */
    stock: number;
    /** Format: date-time */
    readonly updatedAt?: string;
    warehouseId: string;
  };
  Promotion: {
    active?: boolean;
    cartRules?: components["schemas"]["Rule"][];
    code?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customerRestriction?: boolean;
    customFields?: GenericRecord;
    discounts?: components["schemas"]["PromotionDiscount"][];
    exclusionIds?: string[];
    exclusive?: boolean;
    extensions?: {
      quoteLineItems?: {
        data?: {
          /** @example 6b1c17ad551ef636e491ab6848f68420 */
          id?: string;
          /** @example quote_line_item */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /promotion/626a54d37d402d449d6d7541911e0952/quoteLineItems
           */
          related?: string;
        };
      };
    };
    id: string;
    individualCodePattern?: string;
    individualCodes?: components["schemas"]["PromotionIndividualCode"][];
    /** Format: int64 */
    maxRedemptionsGlobal?: number;
    /** Format: int64 */
    maxRedemptionsPerCustomer?: number;
    name: string;
    /** Format: int64 */
    readonly orderCount?: number;
    orderLineItems?: components["schemas"]["OrderLineItem"][];
    orderRules?: components["schemas"]["Rule"][];
    readonly ordersPerCustomerCount?: GenericRecord;
    personaCustomers?: components["schemas"]["Customer"][];
    personaRules?: components["schemas"]["Rule"][];
    preventCombination?: boolean;
    /** Format: int64 */
    priority?: number;
    salesChannels?: components["schemas"]["PromotionSalesChannel"][];
    setgroups?: components["schemas"]["PromotionSetgroup"][];
    translated: {
      code: string;
      individualCodePattern: string;
      name: string;
      validFrom: string;
      validUntil: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    useCodes?: boolean;
    useIndividualCodes?: boolean;
    useSetGroups?: boolean;
    /** Format: date-time */
    validFrom?: string;
    /** Format: date-time */
    validUntil?: string;
  };
  PromotionCartRule: {
    id?: string;
    promotion?: components["schemas"]["Promotion"];
    promotionId: string;
    rule?: components["schemas"]["Rule"];
    ruleId: string;
  };
  PromotionDiscount: {
    applierKey?: string;
    considerAdvancedRules: boolean;
    /** Format: date-time */
    readonly createdAt?: string;
    discountRules?: components["schemas"]["Rule"][];
    id: string;
    /** Format: float */
    maxValue?: number;
    pickerKey?: string;
    promotion?: components["schemas"]["Promotion"];
    promotionDiscountPrices?: components["schemas"]["PromotionDiscountPrices"][];
    promotionId: string;
    scope: string;
    sorterKey?: string;
    type: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    usageKey?: string;
    /** Format: float */
    value: number;
  };
  PromotionDiscountJsonApi: components["schemas"]["resource"] & {
    applierKey?: string;
    considerAdvancedRules: boolean;
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    /** Format: float */
    maxValue?: number;
    pickerKey?: string;
    promotionId: string;
    relationships?: {
      discountRules?: {
        data?: {
          /** @example d5a1e52263eb12172f7657376d7622c8 */
          id?: string;
          /** @example rule */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /promotion-discount/1d292bd1ccb9a6140bb16d3a9217a30c/discountRules
           */
          related?: string;
        };
      };
      promotion?: {
        data?: {
          /** @example f8dcad058c9c44fdb6ffcb22d2d4c31f */
          id?: string;
          /** @example promotion */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /promotion-discount/1d292bd1ccb9a6140bb16d3a9217a30c/promotion
           */
          related?: string;
        };
      };
      promotionDiscountPrices?: {
        data?: {
          /** @example 325723473ecab76b0f45e1554513f779 */
          id?: string;
          /** @example promotion_discount_prices */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /promotion-discount/1d292bd1ccb9a6140bb16d3a9217a30c/promotionDiscountPrices
           */
          related?: string;
        };
      };
    };
    scope: string;
    sorterKey?: string;
    type: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    usageKey?: string;
    /** Format: float */
    value: number;
  };
  PromotionDiscountPrices: {
    /** Format: date-time */
    readonly createdAt?: string;
    currency?: components["schemas"]["Currency"];
    currencyId: string;
    discountId: string;
    id: string;
    /** Format: float */
    price: number;
    promotionDiscount?: components["schemas"]["PromotionDiscount"];
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  PromotionDiscountPricesJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    currencyId: string;
    discountId: string;
    id: string;
    /** Format: float */
    price: number;
    relationships?: {
      currency?: {
        data?: {
          /** @example 1af0389838508d7016a9841eb6273962 */
          id?: string;
          /** @example currency */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /promotion-discount-prices/bed3b77da61f7bd4ccc1f6d17fa416df/currency
           */
          related?: string;
        };
      };
      promotionDiscount?: {
        data?: {
          /** @example eaeedb5c09dfc7dbf130657ed44ef33f */
          id?: string;
          /** @example promotion_discount */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /promotion-discount-prices/bed3b77da61f7bd4ccc1f6d17fa416df/promotionDiscount
           */
          related?: string;
        };
      };
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  PromotionDiscountRule: {
    discount?: components["schemas"]["PromotionDiscount"];
    discountId: string;
    id?: string;
    rule?: components["schemas"]["Rule"];
    ruleId: string;
  };
  PromotionIndividualCode: {
    code: string;
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    payload?: GenericRecord;
    promotion?: components["schemas"]["Promotion"];
    promotionId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  PromotionIndividualCodeJsonApi: components["schemas"]["resource"] & {
    code: string;
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    payload?: GenericRecord;
    promotionId: string;
    relationships?: {
      promotion?: {
        data?: {
          /** @example f8dcad058c9c44fdb6ffcb22d2d4c31f */
          id?: string;
          /** @example promotion */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /promotion-individual-code/139ddd829ed66162c831471f101e3823/promotion
           */
          related?: string;
        };
      };
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  PromotionJsonApi: components["schemas"]["resource"] & {
    active?: boolean;
    code?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customerRestriction?: boolean;
    customFields?: GenericRecord;
    exclusionIds?: string[];
    exclusive?: boolean;
    extensions?: {
      quoteLineItems?: {
        data?: {
          /** @example 6b1c17ad551ef636e491ab6848f68420 */
          id?: string;
          /** @example quote_line_item */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /promotion/626a54d37d402d449d6d7541911e0952/quoteLineItems
           */
          related?: string;
        };
      };
    };
    id: string;
    individualCodePattern?: string;
    /** Format: int64 */
    maxRedemptionsGlobal?: number;
    /** Format: int64 */
    maxRedemptionsPerCustomer?: number;
    name: string;
    /** Format: int64 */
    readonly orderCount?: number;
    readonly ordersPerCustomerCount?: GenericRecord;
    preventCombination?: boolean;
    /** Format: int64 */
    priority?: number;
    relationships?: {
      cartRules?: {
        data?: {
          /** @example 6549606ef529fde0a7628b4c0aa7c6ef */
          id?: string;
          /** @example rule */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /promotion/626a54d37d402d449d6d7541911e0952/cartRules
           */
          related?: string;
        };
      };
      discounts?: {
        data?: {
          /** @example 9544fa2fae515081e7fc27ef2d268642 */
          id?: string;
          /** @example promotion_discount */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /promotion/626a54d37d402d449d6d7541911e0952/discounts
           */
          related?: string;
        };
      };
      individualCodes?: {
        data?: {
          /** @example c777247035736c9eae54f8e5dfdcd2aa */
          id?: string;
          /** @example promotion_individual_code */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /promotion/626a54d37d402d449d6d7541911e0952/individualCodes
           */
          related?: string;
        };
      };
      orderLineItems?: {
        data?: {
          /** @example 6bd56ce4562ca1be86bf5b8d92c3c1ee */
          id?: string;
          /** @example order_line_item */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /promotion/626a54d37d402d449d6d7541911e0952/orderLineItems
           */
          related?: string;
        };
      };
      orderRules?: {
        data?: {
          /** @example ee517f71bf240d98dcf33db6e6ffa881 */
          id?: string;
          /** @example rule */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /promotion/626a54d37d402d449d6d7541911e0952/orderRules
           */
          related?: string;
        };
      };
      personaCustomers?: {
        data?: {
          /** @example b969a9b0d5772d70ea83383c1be06c82 */
          id?: string;
          /** @example customer */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /promotion/626a54d37d402d449d6d7541911e0952/personaCustomers
           */
          related?: string;
        };
      };
      personaRules?: {
        data?: {
          /** @example 382af96335a79de564c412e6b493d7f3 */
          id?: string;
          /** @example rule */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /promotion/626a54d37d402d449d6d7541911e0952/personaRules
           */
          related?: string;
        };
      };
      salesChannels?: {
        data?: {
          /** @example 986f6f891e90ab91c091ff4a1a460777 */
          id?: string;
          /** @example promotion_sales_channel */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /promotion/626a54d37d402d449d6d7541911e0952/salesChannels
           */
          related?: string;
        };
      };
      setgroups?: {
        data?: {
          /** @example 3c963571517f44e87274198cb8bb62a8 */
          id?: string;
          /** @example promotion_setgroup */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /promotion/626a54d37d402d449d6d7541911e0952/setgroups
           */
          related?: string;
        };
      };
    };
    translated: {
      code: string;
      individualCodePattern: string;
      name: string;
      validFrom: string;
      validUntil: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    useCodes?: boolean;
    useIndividualCodes?: boolean;
    useSetGroups?: boolean;
    /** Format: date-time */
    validFrom?: string;
    /** Format: date-time */
    validUntil?: string;
  };
  PromotionOrderRule: {
    id?: string;
    promotion?: components["schemas"]["Promotion"];
    promotionId: string;
    rule?: components["schemas"]["Rule"];
    ruleId: string;
  };
  PromotionPersonaCustomer: {
    customer?: components["schemas"]["Customer"];
    customerId: string;
    id?: string;
    promotion?: components["schemas"]["Promotion"];
    promotionId: string;
  };
  PromotionPersonaRule: {
    id?: string;
    promotion?: components["schemas"]["Promotion"];
    promotionId: string;
    rule?: components["schemas"]["Rule"];
    ruleId: string;
  };
  PromotionSalesChannel: {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    /** Format: int64 */
    priority: number;
    promotion?: components["schemas"]["Promotion"];
    promotionId: string;
    salesChannel?: components["schemas"]["SalesChannel"];
    salesChannelId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  PromotionSalesChannelJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    /** Format: int64 */
    priority: number;
    promotionId: string;
    relationships?: {
      promotion?: {
        data?: {
          /** @example f8dcad058c9c44fdb6ffcb22d2d4c31f */
          id?: string;
          /** @example promotion */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /promotion-sales-channel/2081c7fb87ec7bafc7a39bf0e33ebaa8/promotion
           */
          related?: string;
        };
      };
      salesChannel?: {
        data?: {
          /** @example ec3712a84143b57e0db620eaac6e55b8 */
          id?: string;
          /** @example sales_channel */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /promotion-sales-channel/2081c7fb87ec7bafc7a39bf0e33ebaa8/salesChannel
           */
          related?: string;
        };
      };
    };
    salesChannelId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  PromotionSetgroup: {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    packagerKey: string;
    promotion?: components["schemas"]["Promotion"];
    promotionId: string;
    setGroupRules?: components["schemas"]["Rule"][];
    sorterKey: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    /** Format: float */
    value: number;
  };
  PromotionSetgroupJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    packagerKey: string;
    promotionId: string;
    relationships?: {
      promotion?: {
        data?: {
          /** @example f8dcad058c9c44fdb6ffcb22d2d4c31f */
          id?: string;
          /** @example promotion */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /promotion-setgroup/d2e23a646d2a711e7af57757b8ff7d3f/promotion
           */
          related?: string;
        };
      };
      setGroupRules?: {
        data?: {
          /** @example a54c38d5a1d9180d689d11234afbbb32 */
          id?: string;
          /** @example rule */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /promotion-setgroup/d2e23a646d2a711e7af57757b8ff7d3f/setGroupRules
           */
          related?: string;
        };
      };
    };
    sorterKey: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    /** Format: float */
    value: number;
  };
  PromotionSetgroupRule: {
    id?: string;
    rule?: components["schemas"]["Rule"];
    ruleId: string;
    setgroup?: components["schemas"]["PromotionSetgroup"];
    setgroupId: string;
  };
  PropertyGroup: {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    description?: string;
    displayType?: string;
    filterable?: boolean;
    id: string;
    name: string;
    options?: components["schemas"]["PropertyGroupOption"][];
    /** Format: int64 */
    position?: number;
    sortingType?: string;
    translated: {
      description: string;
      displayType: string;
      name: string;
      sortingType: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    visibleOnProductDetailPage?: boolean;
  };
  PropertyGroupJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    description?: string;
    displayType?: string;
    filterable?: boolean;
    id: string;
    name: string;
    /** Format: int64 */
    position?: number;
    relationships?: {
      options?: {
        data?: {
          /** @example 93da65a9fd0004d9477aeac024e08e15 */
          id?: string;
          /** @example property_group_option */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /property-group/28691f41cd50e3065fd221390a457a56/options
           */
          related?: string;
        };
      };
    };
    sortingType?: string;
    translated: {
      description: string;
      displayType: string;
      name: string;
      sortingType: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    visibleOnProductDetailPage?: boolean;
  };
  PropertyGroupOption: {
    colorHexCode?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    group?: components["schemas"]["PropertyGroup"];
    groupId: string;
    id: string;
    media?: components["schemas"]["Media"];
    mediaId?: string;
    name: string;
    /** Format: int64 */
    position?: number;
    productConfiguratorSettings?: components["schemas"]["ProductConfiguratorSetting"][];
    productOptions?: components["schemas"]["Product"][];
    productProperties?: components["schemas"]["Product"][];
    translated: {
      colorHexCode: string;
      groupId: string;
      mediaId: string;
      name: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  PropertyGroupOptionJsonApi: components["schemas"]["resource"] & {
    colorHexCode?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    groupId: string;
    id: string;
    mediaId?: string;
    name: string;
    /** Format: int64 */
    position?: number;
    relationships?: {
      group?: {
        data?: {
          /** @example db0f6f37ebeb6ea09489124345af2a45 */
          id?: string;
          /** @example property_group */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /property-group-option/10f78a0d3f087d9d206956bca1cf72b1/group
           */
          related?: string;
        };
      };
      media?: {
        data?: {
          /** @example 62933a2951ef01f4eafd9bdf4d3cd2f0 */
          id?: string;
          /** @example media */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /property-group-option/10f78a0d3f087d9d206956bca1cf72b1/media
           */
          related?: string;
        };
      };
      productConfiguratorSettings?: {
        data?: {
          /** @example 4d46eb45eaf392b26bd46f0ea8cb93e0 */
          id?: string;
          /** @example product_configurator_setting */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /property-group-option/10f78a0d3f087d9d206956bca1cf72b1/productConfiguratorSettings
           */
          related?: string;
        };
      };
      productOptions?: {
        data?: {
          /** @example 2e96cc7eba692416e31a6af3230ebf88 */
          id?: string;
          /** @example product */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /property-group-option/10f78a0d3f087d9d206956bca1cf72b1/productOptions
           */
          related?: string;
        };
      };
      productProperties?: {
        data?: {
          /** @example bacd76b9cbbc26cb9854ec57f4d0fef3 */
          id?: string;
          /** @example product */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /property-group-option/10f78a0d3f087d9d206956bca1cf72b1/productProperties
           */
          related?: string;
        };
      };
    };
    translated: {
      colorHexCode: string;
      groupId: string;
      mediaId: string;
      name: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  Quote: {
    /** Format: float */
    readonly amountNet?: number;
    /** Format: float */
    readonly amountTotal?: number;
    /** Format: int64 */
    readonly autoIncrement?: number;
    comments?: components["schemas"]["QuoteComment"][];
    /** Format: date-time */
    readonly createdAt?: string;
    createdBy?: components["schemas"]["User"];
    createdById?: string;
    currency?: components["schemas"]["Currency"];
    currencyId: string;
    customer?: components["schemas"]["Customer"];
    customerId: string;
    customFields?: GenericRecord;
    deliveries?: components["schemas"]["QuoteDelivery"][];
    discount?: {
      type?: string;
      /** Format: float */
      value?: number;
    };
    documents?: components["schemas"]["QuoteDocument"][];
    /** Format: date-time */
    expirationDate?: string;
    id: string;
    itemRounding: {
      /** Format: int64 */
      decimals: number;
      /** Format: float */
      interval: number;
      roundForNet: boolean;
    };
    language?: components["schemas"]["Language"];
    languageId: string;
    lineItems?: components["schemas"]["QuoteLineItem"][];
    order?: components["schemas"]["Order"];
    orderId?: string;
    orderVersionId?: string;
    price?: {
      calculatedTaxes?: GenericRecord;
      /** Format: float */
      netPrice: number;
      /** Format: float */
      positionPrice: number;
      /** Format: float */
      rawTotal: number;
      taxRules?: GenericRecord;
      taxStatus: string;
      /** Format: float */
      totalPrice: number;
    };
    quoteEmployees?: components["schemas"]["QuoteEmployee"][];
    quoteNumber?: string;
    salesChannel?: components["schemas"]["SalesChannel"];
    salesChannelId: string;
    /** Format: date-time */
    sentAt?: string;
    shippingCosts?: {
      calculatedTaxes?: GenericRecord;
      listPrice?: {
        /** Format: float */
        discount?: number;
        /** Format: float */
        percentage?: number;
        /** Format: float */
        price?: number;
      };
      /** Format: int64 */
      quantity: number;
      referencePrice?: GenericRecord;
      regulationPrice?: {
        /** Format: float */
        price?: number;
      };
      taxRules?: GenericRecord;
      /** Format: float */
      totalPrice: number;
      /** Format: float */
      unitPrice: number;
    };
    stateId: string;
    stateMachineState?: components["schemas"]["StateMachineState"];
    /** Format: float */
    subtotalNet?: number;
    readonly taxStatus?: string;
    /** Format: float */
    totalDiscount?: number;
    totalRounding: {
      /** Format: int64 */
      decimals: number;
      /** Format: float */
      interval: number;
      roundForNet: boolean;
    };
    transactions?: components["schemas"]["QuoteTransaction"][];
    /** Format: date-time */
    readonly updatedAt?: string;
    updatedBy?: components["schemas"]["User"];
    updatedById?: string;
    user?: components["schemas"]["User"];
    userId?: string;
    versionId?: string;
  };
  QuoteComment: {
    comment: string;
    /** Format: date-time */
    readonly createdAt?: string;
    createdBy?: components["schemas"]["User"];
    createdById?: string;
    customer?: components["schemas"]["Customer"];
    customerId?: string;
    id: string;
    quote?: components["schemas"]["Quote"];
    quoteId: string;
    quoteVersionId?: string;
    /** Format: date-time */
    seenAt?: string;
    stateId?: string;
    stateMachineState?: components["schemas"]["StateMachineState"];
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  QuoteCommentJsonApi: components["schemas"]["resource"] & {
    comment: string;
    /** Format: date-time */
    readonly createdAt?: string;
    createdById?: string;
    customerId?: string;
    id: string;
    quoteId: string;
    quoteVersionId?: string;
    relationships?: {
      createdBy?: {
        data?: {
          /** @example 34998857f537140306898d54d4b970dc */
          id?: string;
          /** @example user */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /quote-comment/b3ef9135f573201be0dd21b395c6ec07/createdBy
           */
          related?: string;
        };
      };
      customer?: {
        data?: {
          /** @example 91ec1f9324753048c0096d036a694f86 */
          id?: string;
          /** @example customer */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /quote-comment/b3ef9135f573201be0dd21b395c6ec07/customer
           */
          related?: string;
        };
      };
      quote?: {
        data?: {
          /** @example 7a674c327bfa07f7c1204fb38ca6ef3b */
          id?: string;
          /** @example quote */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /quote-comment/b3ef9135f573201be0dd21b395c6ec07/quote
           */
          related?: string;
        };
      };
      stateMachineState?: {
        data?: {
          /** @example 1ab22d393154f21e3be76aca3ec3ee31 */
          id?: string;
          /** @example state_machine_state */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /quote-comment/b3ef9135f573201be0dd21b395c6ec07/stateMachineState
           */
          related?: string;
        };
      };
    };
    /** Format: date-time */
    seenAt?: string;
    stateId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  QuoteDelivery: {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    id: string;
    positions?: components["schemas"]["QuoteDeliveryPosition"][];
    quote?: components["schemas"]["Quote"];
    quoteId: string;
    quoteVersionId?: string;
    shippingCosts?: {
      calculatedTaxes?: GenericRecord;
      listPrice?: {
        /** Format: float */
        discount?: number;
        /** Format: float */
        percentage?: number;
        /** Format: float */
        price?: number;
      };
      /** Format: int64 */
      quantity: number;
      referencePrice?: GenericRecord;
      regulationPrice?: {
        /** Format: float */
        price?: number;
      };
      taxRules?: GenericRecord;
      /** Format: float */
      totalPrice: number;
      /** Format: float */
      unitPrice: number;
    };
    /** Format: date-time */
    shippingDateEarliest: string;
    /** Format: date-time */
    shippingDateLatest: string;
    shippingMethod?: components["schemas"]["ShippingMethod"];
    shippingMethodId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  QuoteDeliveryJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    id: string;
    quoteId: string;
    quoteVersionId?: string;
    relationships?: {
      positions?: {
        data?: {
          /** @example 365a4a972db646c76d115b3897f2d4de */
          id?: string;
          /** @example quote_delivery_position */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /quote-delivery/d2e61366180daeec11fe88b1cb03bbd6/positions
           */
          related?: string;
        };
      };
      quote?: {
        data?: {
          /** @example 7a674c327bfa07f7c1204fb38ca6ef3b */
          id?: string;
          /** @example quote */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /quote-delivery/d2e61366180daeec11fe88b1cb03bbd6/quote
           */
          related?: string;
        };
      };
      shippingMethod?: {
        data?: {
          /** @example e97bfcdc0cae44bc9e4ab35762eaf0e1 */
          id?: string;
          /** @example shipping_method */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /quote-delivery/d2e61366180daeec11fe88b1cb03bbd6/shippingMethod
           */
          related?: string;
        };
      };
    };
    shippingCosts?: {
      calculatedTaxes?: GenericRecord;
      listPrice?: {
        /** Format: float */
        discount?: number;
        /** Format: float */
        percentage?: number;
        /** Format: float */
        price?: number;
      };
      /** Format: int64 */
      quantity: number;
      referencePrice?: GenericRecord;
      regulationPrice?: {
        /** Format: float */
        price?: number;
      };
      taxRules?: GenericRecord;
      /** Format: float */
      totalPrice: number;
      /** Format: float */
      unitPrice: number;
    };
    /** Format: date-time */
    shippingDateEarliest: string;
    /** Format: date-time */
    shippingDateLatest: string;
    shippingMethodId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  QuoteDeliveryPosition: {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    id: string;
    price?: {
      calculatedTaxes?: GenericRecord;
      listPrice?: {
        /** Format: float */
        discount?: number;
        /** Format: float */
        percentage?: number;
        /** Format: float */
        price?: number;
      };
      /** Format: int64 */
      quantity: number;
      referencePrice?: GenericRecord;
      regulationPrice?: {
        /** Format: float */
        price?: number;
      };
      taxRules?: GenericRecord;
      /** Format: float */
      totalPrice: number;
      /** Format: float */
      unitPrice: number;
    };
    /** Format: int64 */
    quantity?: number;
    quoteDelivery?: components["schemas"]["QuoteDelivery"];
    quoteDeliveryId: string;
    quoteDeliveryVersionId?: string;
    quoteLineItem?: components["schemas"]["QuoteLineItem"];
    quoteLineItemId: string;
    quoteLineItemVersionId?: string;
    /** Format: float */
    totalPrice?: number;
    /** Format: float */
    unitPrice?: number;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  QuoteDeliveryPositionJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    id: string;
    price?: {
      calculatedTaxes?: GenericRecord;
      listPrice?: {
        /** Format: float */
        discount?: number;
        /** Format: float */
        percentage?: number;
        /** Format: float */
        price?: number;
      };
      /** Format: int64 */
      quantity: number;
      referencePrice?: GenericRecord;
      regulationPrice?: {
        /** Format: float */
        price?: number;
      };
      taxRules?: GenericRecord;
      /** Format: float */
      totalPrice: number;
      /** Format: float */
      unitPrice: number;
    };
    /** Format: int64 */
    quantity?: number;
    quoteDeliveryId: string;
    quoteDeliveryVersionId?: string;
    quoteLineItemId: string;
    quoteLineItemVersionId?: string;
    relationships?: {
      quoteDelivery?: {
        data?: {
          /** @example 19397469743ae5505500cb3fa99bc0b1 */
          id?: string;
          /** @example quote_delivery */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /quote-delivery-position/9bccead7211d7f905df800ef90888f07/quoteDelivery
           */
          related?: string;
        };
      };
      quoteLineItem?: {
        data?: {
          /** @example dbe619b4a557266e76679178cc13085b */
          id?: string;
          /** @example quote_line_item */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /quote-delivery-position/9bccead7211d7f905df800ef90888f07/quoteLineItem
           */
          related?: string;
        };
      };
    };
    /** Format: float */
    totalPrice?: number;
    /** Format: float */
    unitPrice?: number;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  QuoteDocument: {
    active?: boolean;
    config: GenericRecord;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    deepLinkCode: string;
    documentMediaFile?: components["schemas"]["Media"];
    documentMediaFileId?: string;
    documentNumber?: string;
    documentType?: components["schemas"]["DocumentType"];
    documentTypeId: string;
    fileType: string;
    id: string;
    quote?: components["schemas"]["Quote"];
    quoteId: string;
    quoteVersionId?: string;
    sent?: boolean;
    static?: boolean;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  QuoteDocumentJsonApi: components["schemas"]["resource"] & {
    active?: boolean;
    config: GenericRecord;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    deepLinkCode: string;
    documentMediaFileId?: string;
    documentNumber?: string;
    documentTypeId: string;
    fileType: string;
    id: string;
    quoteId: string;
    quoteVersionId?: string;
    relationships?: {
      documentMediaFile?: {
        data?: {
          /** @example ac7db1e6be481d6422fc63700e08279d */
          id?: string;
          /** @example media */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /quote-document/08e3c4797f89c301ce82e4bcfab6d266/documentMediaFile
           */
          related?: string;
        };
      };
      documentType?: {
        data?: {
          /** @example 2e45fec65781ec559e2aea39372a55cd */
          id?: string;
          /** @example document_type */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /quote-document/08e3c4797f89c301ce82e4bcfab6d266/documentType
           */
          related?: string;
        };
      };
      quote?: {
        data?: {
          /** @example 7a674c327bfa07f7c1204fb38ca6ef3b */
          id?: string;
          /** @example quote */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /quote-document/08e3c4797f89c301ce82e4bcfab6d266/quote
           */
          related?: string;
        };
      };
    };
    sent?: boolean;
    static?: boolean;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  QuoteEmployee: {
    /** Format: date-time */
    readonly createdAt?: string;
    employee?: components["schemas"]["B2bEmployee"];
    employeeId: string;
    firstName: string;
    id: string;
    lastName: string;
    quote?: components["schemas"]["Quote"];
    quoteId: string;
    quoteVersionId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  QuoteEmployeeJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    employeeId: string;
    firstName: string;
    id: string;
    lastName: string;
    quoteId: string;
    quoteVersionId?: string;
    relationships?: {
      employee?: {
        data?: {
          /** @example fa5473530e4d1a5a1e1eb53d2fedb10c */
          id?: string;
          /** @example b2b_employee */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /quote-employee/e4bf66af05d85640412ac7a8951252a3/employee
           */
          related?: string;
        };
      };
      quote?: {
        data?: {
          /** @example 7a674c327bfa07f7c1204fb38ca6ef3b */
          id?: string;
          /** @example quote */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /quote-employee/e4bf66af05d85640412ac7a8951252a3/quote
           */
          related?: string;
        };
      };
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  QuoteJsonApi: components["schemas"]["resource"] & {
    /** Format: float */
    readonly amountNet?: number;
    /** Format: float */
    readonly amountTotal?: number;
    /** Format: int64 */
    readonly autoIncrement?: number;
    /** Format: date-time */
    readonly createdAt?: string;
    createdById?: string;
    currencyId: string;
    customerId: string;
    customFields?: GenericRecord;
    discount?: {
      type?: string;
      /** Format: float */
      value?: number;
    };
    /** Format: date-time */
    expirationDate?: string;
    id: string;
    itemRounding: {
      /** Format: int64 */
      decimals: number;
      /** Format: float */
      interval: number;
      roundForNet: boolean;
    };
    languageId: string;
    orderId?: string;
    orderVersionId?: string;
    price?: {
      calculatedTaxes?: GenericRecord;
      /** Format: float */
      netPrice: number;
      /** Format: float */
      positionPrice: number;
      /** Format: float */
      rawTotal: number;
      taxRules?: GenericRecord;
      taxStatus: string;
      /** Format: float */
      totalPrice: number;
    };
    quoteNumber?: string;
    relationships?: {
      comments?: {
        data?: {
          /** @example a5d491060952aa8ad5fdee071be752de */
          id?: string;
          /** @example quote_comment */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /quote/c48e929b2b1eabba2ba036884433345e/comments
           */
          related?: string;
        };
      };
      createdBy?: {
        data?: {
          /** @example 34998857f537140306898d54d4b970dc */
          id?: string;
          /** @example user */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /quote/c48e929b2b1eabba2ba036884433345e/createdBy
           */
          related?: string;
        };
      };
      currency?: {
        data?: {
          /** @example 1af0389838508d7016a9841eb6273962 */
          id?: string;
          /** @example currency */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /quote/c48e929b2b1eabba2ba036884433345e/currency
           */
          related?: string;
        };
      };
      customer?: {
        data?: {
          /** @example 91ec1f9324753048c0096d036a694f86 */
          id?: string;
          /** @example customer */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /quote/c48e929b2b1eabba2ba036884433345e/customer
           */
          related?: string;
        };
      };
      deliveries?: {
        data?: {
          /** @example 6fc31b6b9cd717cc0dcb81152308f8af */
          id?: string;
          /** @example quote_delivery */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /quote/c48e929b2b1eabba2ba036884433345e/deliveries
           */
          related?: string;
        };
      };
      documents?: {
        data?: {
          /** @example 21f64da1e5792c8295b964d159a14491 */
          id?: string;
          /** @example quote_document */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /quote/c48e929b2b1eabba2ba036884433345e/documents
           */
          related?: string;
        };
      };
      language?: {
        data?: {
          /** @example 8512ae7d57b1396273f76fe6ed341a23 */
          id?: string;
          /** @example language */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /quote/c48e929b2b1eabba2ba036884433345e/language
           */
          related?: string;
        };
      };
      lineItems?: {
        data?: {
          /** @example a042af1aa9f3853fe3cd7dabc065568f */
          id?: string;
          /** @example quote_line_item */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /quote/c48e929b2b1eabba2ba036884433345e/lineItems
           */
          related?: string;
        };
      };
      order?: {
        data?: {
          /** @example 70a17ffa722a3985b86d30b034ad06d7 */
          id?: string;
          /** @example order */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /quote/c48e929b2b1eabba2ba036884433345e/order
           */
          related?: string;
        };
      };
      quoteEmployees?: {
        data?: {
          /** @example 2d59101091544ffd9a1d23090d6e2f0a */
          id?: string;
          /** @example quote_employee */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /quote/c48e929b2b1eabba2ba036884433345e/quoteEmployees
           */
          related?: string;
        };
      };
      salesChannel?: {
        data?: {
          /** @example ec3712a84143b57e0db620eaac6e55b8 */
          id?: string;
          /** @example sales_channel */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /quote/c48e929b2b1eabba2ba036884433345e/salesChannel
           */
          related?: string;
        };
      };
      stateMachineState?: {
        data?: {
          /** @example 1ab22d393154f21e3be76aca3ec3ee31 */
          id?: string;
          /** @example state_machine_state */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /quote/c48e929b2b1eabba2ba036884433345e/stateMachineState
           */
          related?: string;
        };
      };
      transactions?: {
        data?: {
          /** @example c15b977dd99332ca8623fbdfb86827e8 */
          id?: string;
          /** @example quote_transaction */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /quote/c48e929b2b1eabba2ba036884433345e/transactions
           */
          related?: string;
        };
      };
      updatedBy?: {
        data?: {
          /** @example 7ced3d0067ad61702af7db8ae260aa76 */
          id?: string;
          /** @example user */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /quote/c48e929b2b1eabba2ba036884433345e/updatedBy
           */
          related?: string;
        };
      };
      user?: {
        data?: {
          /** @example ee11cbb19052e40b07aac0ca060c23ee */
          id?: string;
          /** @example user */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /quote/c48e929b2b1eabba2ba036884433345e/user
           */
          related?: string;
        };
      };
    };
    salesChannelId: string;
    /** Format: date-time */
    sentAt?: string;
    shippingCosts?: {
      calculatedTaxes?: GenericRecord;
      listPrice?: {
        /** Format: float */
        discount?: number;
        /** Format: float */
        percentage?: number;
        /** Format: float */
        price?: number;
      };
      /** Format: int64 */
      quantity: number;
      referencePrice?: GenericRecord;
      regulationPrice?: {
        /** Format: float */
        price?: number;
      };
      taxRules?: GenericRecord;
      /** Format: float */
      totalPrice: number;
      /** Format: float */
      unitPrice: number;
    };
    stateId: string;
    /** Format: float */
    subtotalNet?: number;
    readonly taxStatus?: string;
    /** Format: float */
    totalDiscount?: number;
    totalRounding: {
      /** Format: int64 */
      decimals: number;
      /** Format: float */
      interval: number;
      roundForNet: boolean;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    updatedById?: string;
    userId?: string;
    versionId?: string;
  };
  QuoteLineItem: {
    children: components["schemas"]["QuoteLineItem"][];
    cover?: components["schemas"]["Media"];
    coverId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    description?: string;
    discount?: {
      type?: string;
      /** Format: int64 */
      value?: number;
    };
    good?: boolean;
    id: string;
    identifier: string;
    label: string;
    parent?: components["schemas"]["QuoteLineItem"];
    parentId?: string;
    parentVersionId?: string;
    payload?: GenericRecord;
    /** Format: int64 */
    position: number;
    price: {
      calculatedTaxes?: GenericRecord;
      listPrice?: {
        /** Format: float */
        discount?: number;
        /** Format: float */
        percentage?: number;
        /** Format: float */
        price?: number;
      };
      /** Format: int64 */
      quantity: number;
      referencePrice?: GenericRecord;
      regulationPrice?: {
        /** Format: float */
        price?: number;
      };
      taxRules?: GenericRecord;
      /** Format: float */
      totalPrice: number;
      /** Format: float */
      unitPrice: number;
    };
    priceDefinition?: GenericRecord;
    product?: components["schemas"]["Product"];
    productId?: string;
    productPrice?: components["schemas"]["Price"][];
    productVersionId?: string;
    promotion?: components["schemas"]["Promotion"];
    readonly promotionId?: string;
    purchasePrice?: components["schemas"]["Price"][];
    /** Format: int64 */
    quantity: number;
    quote?: components["schemas"]["Quote"];
    quoteId: string;
    quoteVersionId?: string;
    referencedId?: string;
    removable?: boolean;
    stackable?: boolean;
    states: string[];
    /** Format: float */
    totalPrice?: number;
    type?: string;
    /** Format: float */
    unitPrice?: number;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  QuoteLineItemJsonApi: components["schemas"]["resource"] & {
    coverId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    description?: string;
    discount?: {
      type?: string;
      /** Format: int64 */
      value?: number;
    };
    good?: boolean;
    id: string;
    identifier: string;
    label: string;
    parentId?: string;
    parentVersionId?: string;
    payload?: GenericRecord;
    /** Format: int64 */
    position: number;
    price: {
      calculatedTaxes?: GenericRecord;
      listPrice?: {
        /** Format: float */
        discount?: number;
        /** Format: float */
        percentage?: number;
        /** Format: float */
        price?: number;
      };
      /** Format: int64 */
      quantity: number;
      referencePrice?: GenericRecord;
      regulationPrice?: {
        /** Format: float */
        price?: number;
      };
      taxRules?: GenericRecord;
      /** Format: float */
      totalPrice: number;
      /** Format: float */
      unitPrice: number;
    };
    priceDefinition?: GenericRecord;
    productId?: string;
    productPrice?: components["schemas"]["Price"][];
    productVersionId?: string;
    readonly promotionId?: string;
    purchasePrice?: components["schemas"]["Price"][];
    /** Format: int64 */
    quantity: number;
    quoteId: string;
    quoteVersionId?: string;
    referencedId?: string;
    relationships?: {
      children?: {
        data?: {
          /** @example 268184c12df027f536154d099d497b31 */
          id?: string;
          /** @example quote_line_item */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /quote-line-item/c7917be23ddd01ec45871fc8c1e5e540/children
           */
          related?: string;
        };
      };
      cover?: {
        data?: {
          /** @example 41d0e299ca1abeb2094852da042165c7 */
          id?: string;
          /** @example media */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /quote-line-item/c7917be23ddd01ec45871fc8c1e5e540/cover
           */
          related?: string;
        };
      };
      parent?: {
        data?: {
          /** @example d0e45878043844ffc41aac437e86b602 */
          id?: string;
          /** @example quote_line_item */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /quote-line-item/c7917be23ddd01ec45871fc8c1e5e540/parent
           */
          related?: string;
        };
      };
      product?: {
        data?: {
          /** @example f5bf48aa40cad7891eb709fcf1fde128 */
          id?: string;
          /** @example product */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /quote-line-item/c7917be23ddd01ec45871fc8c1e5e540/product
           */
          related?: string;
        };
      };
      promotion?: {
        data?: {
          /** @example f8dcad058c9c44fdb6ffcb22d2d4c31f */
          id?: string;
          /** @example promotion */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /quote-line-item/c7917be23ddd01ec45871fc8c1e5e540/promotion
           */
          related?: string;
        };
      };
      quote?: {
        data?: {
          /** @example 7a674c327bfa07f7c1204fb38ca6ef3b */
          id?: string;
          /** @example quote */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /quote-line-item/c7917be23ddd01ec45871fc8c1e5e540/quote
           */
          related?: string;
        };
      };
    };
    removable?: boolean;
    stackable?: boolean;
    states: string[];
    /** Format: float */
    totalPrice?: number;
    type?: string;
    /** Format: float */
    unitPrice?: number;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  QuoteTransaction: {
    amount: {
      calculatedTaxes?: GenericRecord;
      listPrice?: {
        /** Format: float */
        discount?: number;
        /** Format: float */
        percentage?: number;
        /** Format: float */
        price?: number;
      };
      /** Format: int64 */
      quantity: number;
      referencePrice?: GenericRecord;
      regulationPrice?: {
        /** Format: float */
        price?: number;
      };
      taxRules?: GenericRecord;
      /** Format: float */
      totalPrice: number;
      /** Format: float */
      unitPrice: number;
    };
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    id: string;
    paymentMethod?: components["schemas"]["PaymentMethod"];
    paymentMethodId: string;
    quote?: components["schemas"]["Quote"];
    quoteId: string;
    quoteVersionId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  QuoteTransactionJsonApi: components["schemas"]["resource"] & {
    amount: {
      calculatedTaxes?: GenericRecord;
      listPrice?: {
        /** Format: float */
        discount?: number;
        /** Format: float */
        percentage?: number;
        /** Format: float */
        price?: number;
      };
      /** Format: int64 */
      quantity: number;
      referencePrice?: GenericRecord;
      regulationPrice?: {
        /** Format: float */
        price?: number;
      };
      taxRules?: GenericRecord;
      /** Format: float */
      totalPrice: number;
      /** Format: float */
      unitPrice: number;
    };
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    id: string;
    paymentMethodId: string;
    quoteId: string;
    quoteVersionId?: string;
    relationships?: {
      paymentMethod?: {
        data?: {
          /** @example 68ec1eeea9f1b7744e231b5bd0d97df0 */
          id?: string;
          /** @example payment_method */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /quote-transaction/ace75e8d17b730e2c18557ab7ea8abeb/paymentMethod
           */
          related?: string;
        };
      };
      quote?: {
        data?: {
          /** @example 7a674c327bfa07f7c1204fb38ca6ef3b */
          id?: string;
          /** @example quote */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /quote-transaction/ace75e8d17b730e2c18557ab7ea8abeb/quote
           */
          related?: string;
        };
      };
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  RangeFilter: {
    field: string;
    parameters: {
      gt?: number;
      gte?: number;
      lt?: number;
      lte?: number;
    };
    /** @enum {string} */
    type: "range";
  };
  Rule: {
    readonly areas?: GenericRecord[];
    cartPromotions?: components["schemas"]["Promotion"][];
    conditions?: components["schemas"]["RuleCondition"][];
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    description?: string;
    extensions?: {
      customizedProductsTemplateOptionPrices?: {
        data?: {
          /** @example 00ece6d939b90beadc47a301e8b87a9e */
          id?: string;
          /** @example swag_customized_products_template_option_price */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /rule/ab7a485ebe75b6dd7243ad719f23c7de/customizedProductsTemplateOptionPrices
           */
          related?: string;
        };
      };
      customizedProductsTemplateOptionValuePrices?: {
        data?: {
          /** @example 67d7fb8f29b1a418ccf772dd5dee13a8 */
          id?: string;
          /** @example swag_customized_products_template_option_value_price */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /rule/ab7a485ebe75b6dd7243ad719f23c7de/customizedProductsTemplateOptionValuePrices
           */
          related?: string;
        };
      };
      subscriptionIntervals?: {
        data?: {
          /** @example 28e0fbf8d26aa147681d2241c60ef075 */
          id?: string;
          /** @example subscription_interval */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /rule/ab7a485ebe75b6dd7243ad719f23c7de/subscriptionIntervals
           */
          related?: string;
        };
      };
      subscriptionPlans?: {
        data?: {
          /** @example ed94874505da2886dc66a3a3d3968972 */
          id?: string;
          /** @example subscription_plan */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /rule/ab7a485ebe75b6dd7243ad719f23c7de/subscriptionPlans
           */
          related?: string;
        };
      };
      swagCmsExtensionsBlockRules?: {
        data?: {
          /** @example ce0b9f43f8947576ee10c93d4d69a4c4 */
          id?: string;
          /** @example swag_cms_extensions_block_rule */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /rule/ab7a485ebe75b6dd7243ad719f23c7de/swagCmsExtensionsBlockRules
           */
          related?: string;
        };
      };
      swagDynamicAccessCategories?: {
        data?: {
          /** @example c9a96acd304adec0ef58961b00723adb */
          id?: string;
          /** @example category */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /rule/ab7a485ebe75b6dd7243ad719f23c7de/swagDynamicAccessCategories
           */
          related?: string;
        };
      };
      swagDynamicAccessLandingPages?: {
        data?: {
          /** @example 34fd45ab970fb4ad3e96509b1936ddfb */
          id?: string;
          /** @example landing_page */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /rule/ab7a485ebe75b6dd7243ad719f23c7de/swagDynamicAccessLandingPages
           */
          related?: string;
        };
      };
      swagDynamicAccessProducts?: {
        data?: {
          /** @example acfed6b188b8ace53d2d2bb8dac196f0 */
          id?: string;
          /** @example product */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /rule/ab7a485ebe75b6dd7243ad719f23c7de/swagDynamicAccessProducts
           */
          related?: string;
        };
      };
      warehouseGroup?: {
        data?: {
          /** @example 1768e3071b62161d415e0c24332055ed */
          id?: string;
          /** @example warehouse_group */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /rule/ab7a485ebe75b6dd7243ad719f23c7de/warehouseGroup
           */
          related?: string;
        };
      };
    };
    flowSequences?: components["schemas"]["FlowSequence"][];
    id: string;
    readonly invalid?: boolean;
    moduleTypes?: GenericRecord;
    name: string;
    orderPromotions?: components["schemas"]["Promotion"][];
    paymentMethods?: components["schemas"]["PaymentMethod"][];
    personaPromotions?: components["schemas"]["Promotion"][];
    /** Format: int64 */
    priority: number;
    productPrices?: components["schemas"]["ProductPrice"][];
    promotionDiscounts?: components["schemas"]["PromotionDiscount"][];
    promotionSetGroups?: components["schemas"]["PromotionSetgroup"][];
    shippingMethodPriceCalculations?: components["schemas"]["ShippingMethodPrice"][];
    shippingMethodPrices?: components["schemas"]["ShippingMethodPrice"][];
    shippingMethods?: components["schemas"]["ShippingMethod"][];
    tags?: components["schemas"]["Tag"][];
    taxProviders?: components["schemas"]["TaxProvider"][];
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  RuleCondition: {
    appScriptCondition?: components["schemas"]["AppScriptCondition"];
    children?: components["schemas"]["RuleCondition"][];
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    id: string;
    parent?: components["schemas"]["RuleCondition"];
    parentId?: string;
    /** Format: int64 */
    position?: number;
    rule?: components["schemas"]["Rule"];
    ruleId: string;
    scriptId?: string;
    type: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    value?: GenericRecord;
  };
  RuleConditionJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    id: string;
    parentId?: string;
    /** Format: int64 */
    position?: number;
    relationships?: {
      appScriptCondition?: {
        data?: {
          /** @example d84ccced9bafd192ec0c6b5a8a49bc07 */
          id?: string;
          /** @example app_script_condition */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /rule-condition/5e1af56f1ebb8e4b634d38961afe4930/appScriptCondition
           */
          related?: string;
        };
      };
      children?: {
        data?: {
          /** @example 268184c12df027f536154d099d497b31 */
          id?: string;
          /** @example rule_condition */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /rule-condition/5e1af56f1ebb8e4b634d38961afe4930/children
           */
          related?: string;
        };
      };
      parent?: {
        data?: {
          /** @example d0e45878043844ffc41aac437e86b602 */
          id?: string;
          /** @example rule_condition */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /rule-condition/5e1af56f1ebb8e4b634d38961afe4930/parent
           */
          related?: string;
        };
      };
      rule?: {
        data?: {
          /** @example 981c1e7b3795da18687613fbd66d4954 */
          id?: string;
          /** @example rule */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /rule-condition/5e1af56f1ebb8e4b634d38961afe4930/rule
           */
          related?: string;
        };
      };
    };
    ruleId: string;
    scriptId?: string;
    type: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    value?: GenericRecord;
  };
  RuleJsonApi: components["schemas"]["resource"] & {
    readonly areas?: GenericRecord[];
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    description?: string;
    extensions?: {
      customizedProductsTemplateOptionPrices?: {
        data?: {
          /** @example 00ece6d939b90beadc47a301e8b87a9e */
          id?: string;
          /** @example swag_customized_products_template_option_price */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /rule/ab7a485ebe75b6dd7243ad719f23c7de/customizedProductsTemplateOptionPrices
           */
          related?: string;
        };
      };
      customizedProductsTemplateOptionValuePrices?: {
        data?: {
          /** @example 67d7fb8f29b1a418ccf772dd5dee13a8 */
          id?: string;
          /** @example swag_customized_products_template_option_value_price */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /rule/ab7a485ebe75b6dd7243ad719f23c7de/customizedProductsTemplateOptionValuePrices
           */
          related?: string;
        };
      };
      subscriptionIntervals?: {
        data?: {
          /** @example 28e0fbf8d26aa147681d2241c60ef075 */
          id?: string;
          /** @example subscription_interval */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /rule/ab7a485ebe75b6dd7243ad719f23c7de/subscriptionIntervals
           */
          related?: string;
        };
      };
      subscriptionPlans?: {
        data?: {
          /** @example ed94874505da2886dc66a3a3d3968972 */
          id?: string;
          /** @example subscription_plan */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /rule/ab7a485ebe75b6dd7243ad719f23c7de/subscriptionPlans
           */
          related?: string;
        };
      };
      swagCmsExtensionsBlockRules?: {
        data?: {
          /** @example ce0b9f43f8947576ee10c93d4d69a4c4 */
          id?: string;
          /** @example swag_cms_extensions_block_rule */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /rule/ab7a485ebe75b6dd7243ad719f23c7de/swagCmsExtensionsBlockRules
           */
          related?: string;
        };
      };
      swagDynamicAccessCategories?: {
        data?: {
          /** @example c9a96acd304adec0ef58961b00723adb */
          id?: string;
          /** @example category */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /rule/ab7a485ebe75b6dd7243ad719f23c7de/swagDynamicAccessCategories
           */
          related?: string;
        };
      };
      swagDynamicAccessLandingPages?: {
        data?: {
          /** @example 34fd45ab970fb4ad3e96509b1936ddfb */
          id?: string;
          /** @example landing_page */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /rule/ab7a485ebe75b6dd7243ad719f23c7de/swagDynamicAccessLandingPages
           */
          related?: string;
        };
      };
      swagDynamicAccessProducts?: {
        data?: {
          /** @example acfed6b188b8ace53d2d2bb8dac196f0 */
          id?: string;
          /** @example product */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /rule/ab7a485ebe75b6dd7243ad719f23c7de/swagDynamicAccessProducts
           */
          related?: string;
        };
      };
      warehouseGroup?: {
        data?: {
          /** @example 1768e3071b62161d415e0c24332055ed */
          id?: string;
          /** @example warehouse_group */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /rule/ab7a485ebe75b6dd7243ad719f23c7de/warehouseGroup
           */
          related?: string;
        };
      };
    };
    id: string;
    readonly invalid?: boolean;
    moduleTypes?: GenericRecord;
    name: string;
    /** Format: int64 */
    priority: number;
    relationships?: {
      cartPromotions?: {
        data?: {
          /** @example 2ce52c5be33293c67fb55f29fa4046a7 */
          id?: string;
          /** @example promotion */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /rule/ab7a485ebe75b6dd7243ad719f23c7de/cartPromotions
           */
          related?: string;
        };
      };
      conditions?: {
        data?: {
          /** @example b5b399ec1fcfe753f58dbafa197efdc1 */
          id?: string;
          /** @example rule_condition */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /rule/ab7a485ebe75b6dd7243ad719f23c7de/conditions
           */
          related?: string;
        };
      };
      flowSequences?: {
        data?: {
          /** @example 3a0d70b6dd3624074e5e15cd07e7fa90 */
          id?: string;
          /** @example flow_sequence */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /rule/ab7a485ebe75b6dd7243ad719f23c7de/flowSequences
           */
          related?: string;
        };
      };
      orderPromotions?: {
        data?: {
          /** @example 82dea0f7981e729cd7f6303cc8a1c499 */
          id?: string;
          /** @example promotion */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /rule/ab7a485ebe75b6dd7243ad719f23c7de/orderPromotions
           */
          related?: string;
        };
      };
      paymentMethods?: {
        data?: {
          /** @example b631b1ab565525e892f9cdc1242cca14 */
          id?: string;
          /** @example payment_method */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /rule/ab7a485ebe75b6dd7243ad719f23c7de/paymentMethods
           */
          related?: string;
        };
      };
      personaPromotions?: {
        data?: {
          /** @example e6c8f116c04f26f18410d2d0dbd677db */
          id?: string;
          /** @example promotion */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /rule/ab7a485ebe75b6dd7243ad719f23c7de/personaPromotions
           */
          related?: string;
        };
      };
      productPrices?: {
        data?: {
          /** @example 186169119da6d813def53830287d0b9a */
          id?: string;
          /** @example product_price */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /rule/ab7a485ebe75b6dd7243ad719f23c7de/productPrices
           */
          related?: string;
        };
      };
      promotionDiscounts?: {
        data?: {
          /** @example 3ddb3f7d5ec4f032dc51f294409b68f9 */
          id?: string;
          /** @example promotion_discount */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /rule/ab7a485ebe75b6dd7243ad719f23c7de/promotionDiscounts
           */
          related?: string;
        };
      };
      promotionSetGroups?: {
        data?: {
          /** @example b71b82231d40fdedf42133c0e71384f8 */
          id?: string;
          /** @example promotion_setgroup */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /rule/ab7a485ebe75b6dd7243ad719f23c7de/promotionSetGroups
           */
          related?: string;
        };
      };
      shippingMethodPriceCalculations?: {
        data?: {
          /** @example b8ea8aac272229a90f9a6cb1fcada8d1 */
          id?: string;
          /** @example shipping_method_price */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /rule/ab7a485ebe75b6dd7243ad719f23c7de/shippingMethodPriceCalculations
           */
          related?: string;
        };
      };
      shippingMethodPrices?: {
        data?: {
          /** @example 3702bcc7b41585828b44acbbdcd83b23 */
          id?: string;
          /** @example shipping_method_price */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /rule/ab7a485ebe75b6dd7243ad719f23c7de/shippingMethodPrices
           */
          related?: string;
        };
      };
      shippingMethods?: {
        data?: {
          /** @example 8268b0a6c902fbde485094c2f627b854 */
          id?: string;
          /** @example shipping_method */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /rule/ab7a485ebe75b6dd7243ad719f23c7de/shippingMethods
           */
          related?: string;
        };
      };
      tags?: {
        data?: {
          /** @example d57ac45256849d9b13e2422d91580fb9 */
          id?: string;
          /** @example tag */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /rule/ab7a485ebe75b6dd7243ad719f23c7de/tags
           */
          related?: string;
        };
      };
      taxProviders?: {
        data?: {
          /** @example 01a1a9d428b6402dc8255d99c787a00e */
          id?: string;
          /** @example tax_provider */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /rule/ab7a485ebe75b6dd7243ad719f23c7de/taxProviders
           */
          related?: string;
        };
      };
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  RuleTag: {
    id?: string;
    rule?: components["schemas"]["Rule"];
    ruleId: string;
    tag?: components["schemas"]["Tag"];
    tagId: string;
  };
  SaasAppStorefrontConfig: {
    app?: components["schemas"]["App"];
    appId: string;
    appVersion: string;
    assetPaths?: string[];
    author?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    isTheme?: boolean;
    name?: string;
    previewMedia?: string;
    scriptFiles?: GenericRecord;
    storefrontEntryPath?: string;
    styleFiles?: GenericRecord;
    technicalName: string;
    themeConfig?: GenericRecord;
    themeJson?: GenericRecord;
    /** Format: date-time */
    readonly updatedAt?: string;
    viewInheritance?: string[];
  };
  SaasAppStorefrontConfigJsonApi: components["schemas"]["resource"] & {
    appId: string;
    appVersion: string;
    assetPaths?: string[];
    author?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    isTheme?: boolean;
    name?: string;
    previewMedia?: string;
    relationships?: {
      app?: {
        data?: {
          /** @example d2a57dc1d883fd21fb9951699df71cc7 */
          id?: string;
          /** @example app */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /saas-app-storefront-config/941d29c9ba5ba908e203784d6103906a/app
           */
          related?: string;
        };
      };
    };
    scriptFiles?: GenericRecord;
    storefrontEntryPath?: string;
    styleFiles?: GenericRecord;
    technicalName: string;
    themeConfig?: GenericRecord;
    themeJson?: GenericRecord;
    /** Format: date-time */
    readonly updatedAt?: string;
    viewInheritance?: string[];
  };
  SaasSbpUserData: {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    /** Format: date-time */
    readonly lastSbpStatusChange?: string;
    readonly sbpAccessToken?: GenericRecord;
    readonly sbpStatus?: string;
    /** Format: int64 */
    readonly sbpUserId: number;
    /** Format: date-time */
    readonly updatedAt?: string;
    user?: components["schemas"]["User"];
    readonly userId: string;
  };
  SaasSbpUserDataJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    /** Format: date-time */
    readonly lastSbpStatusChange?: string;
    relationships?: {
      user?: {
        data?: {
          /** @example ee11cbb19052e40b07aac0ca060c23ee */
          id?: string;
          /** @example user */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /saas-sbp-user-data/d271f61e3b0f14048b1d3280fbd44718/user
           */
          related?: string;
        };
      };
    };
    readonly sbpAccessToken?: GenericRecord;
    readonly sbpStatus?: string;
    /** Format: int64 */
    readonly sbpUserId: number;
    /** Format: date-time */
    readonly updatedAt?: string;
    readonly userId: string;
  };
  SaasStorefrontDemoToken: {
    /** Format: date-time */
    readonly createdAt?: string;
    /** Format: date-time */
    readonly expiresAt: string;
    id: string;
    readonly token: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    user?: components["schemas"]["User"];
    userId: string;
  };
  SaasStorefrontDemoTokenJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    /** Format: date-time */
    readonly expiresAt: string;
    id: string;
    relationships?: {
      user?: {
        data?: {
          /** @example ee11cbb19052e40b07aac0ca060c23ee */
          id?: string;
          /** @example user */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /saas-storefront-demo-token/6d788712a654b3860ec9cb23d47fe5d0/user
           */
          related?: string;
        };
      };
    };
    readonly token: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    userId: string;
  };
  SaasUserLoginToken: {
    /** Format: date-time */
    readonly createdAt?: string;
    /** Format: date-time */
    readonly expiresAt: string;
    id: string;
    readonly token: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    user?: components["schemas"]["User"];
    userId: string;
  };
  SaasUserLoginTokenJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    /** Format: date-time */
    readonly expiresAt: string;
    id: string;
    relationships?: {
      user?: {
        data?: {
          /** @example ee11cbb19052e40b07aac0ca060c23ee */
          id?: string;
          /** @example user */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /saas-user-login-token/57e8c4fa360d6f7647f64b6c2f53d3bc/user
           */
          related?: string;
        };
      };
    };
    readonly token: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    userId: string;
  };
  SalesChannel: {
    accessKey: string;
    active?: boolean;
    analytics?: components["schemas"]["SalesChannelAnalytics"];
    analyticsId?: string;
    boundCustomers?: components["schemas"]["Customer"][];
    configuration?: GenericRecord;
    countries?: components["schemas"]["Country"][];
    country?: components["schemas"]["Country"];
    countryId: string;
    /** Format: date-time */
    readonly createdAt?: string;
    currencies?: components["schemas"]["Currency"][];
    currency?: components["schemas"]["Currency"];
    currencyId: string;
    customerGroup?: components["schemas"]["CustomerGroup"];
    customerGroupId: string;
    customerGroupsRegistrations?: components["schemas"]["CustomerGroup"][];
    customers?: components["schemas"]["Customer"][];
    customFields?: GenericRecord;
    documentBaseConfigSalesChannels?: components["schemas"]["DocumentBaseConfigSalesChannel"][];
    domains?: components["schemas"]["SalesChannelDomain"][];
    extensions?: {
      paypalPosSalesChannel?: {
        data?: {
          /** @example 67ba77ec00554136bd30a09f2b79a091 */
          id?: string;
          /** @example swag_paypal_pos_sales_channel */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel/e497ee380a9e2a5e9812e9e0bf504045/paypalPosSalesChannel
           */
          related?: string;
        };
      };
      quotes?: {
        data?: {
          /** @example 2150fd65034a9bcdb357943b3900a918 */
          id?: string;
          /** @example quote */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel/e497ee380a9e2a5e9812e9e0bf504045/quotes
           */
          related?: string;
        };
      };
      socialShoppingProductErrors?: {
        data?: {
          /** @example 74181afcb28901351a5f2676d1687de8 */
          id?: string;
          /** @example swag_social_shopping_product_error */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel/e497ee380a9e2a5e9812e9e0bf504045/socialShoppingProductErrors
           */
          related?: string;
        };
      };
      socialShoppingSalesChannel?: {
        data?: {
          /** @example be7393dc9d5ee6da46b8ccdf1b316101 */
          id?: string;
          /** @example swag_social_shopping_sales_channel */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel/e497ee380a9e2a5e9812e9e0bf504045/socialShoppingSalesChannel
           */
          related?: string;
        };
      };
      subscriptions?: {
        data?: {
          /** @example 2d5d14f95af035cbd8437948de61f94c */
          id?: string;
          /** @example subscription */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel/e497ee380a9e2a5e9812e9e0bf504045/subscriptions
           */
          related?: string;
        };
      };
      swagSocialShoppingCustomer?: {
        data?: {
          /** @example 70825a5dfabd078bce265301ba7d9cca */
          id?: string;
          /** @example swag_social_shopping_customer */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel/e497ee380a9e2a5e9812e9e0bf504045/swagSocialShoppingCustomer
           */
          related?: string;
        };
      };
      swagSocialShoppingOrder?: {
        data?: {
          /** @example 829fa9441f5dea1e7ada99a9ae4a867f */
          id?: string;
          /** @example swag_social_shopping_order */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel/e497ee380a9e2a5e9812e9e0bf504045/swagSocialShoppingOrder
           */
          related?: string;
        };
      };
      themes?: {
        data?: {
          /** @example fe021943dcda87150f590b3475afaded */
          id?: string;
          /** @example theme */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel/e497ee380a9e2a5e9812e9e0bf504045/themes
           */
          related?: string;
        };
      };
    };
    footerCategory?: components["schemas"]["Category"];
    footerCategoryId?: string;
    footerCategoryVersionId?: string;
    homeCmsPage?: components["schemas"]["CmsPage"];
    homeCmsPageId?: string;
    homeCmsPageVersionId?: string;
    homeEnabled: boolean;
    homeKeywords?: string;
    homeMetaDescription?: string;
    homeMetaTitle?: string;
    homeName?: string;
    homeSlotConfig?: GenericRecord;
    hreflangActive?: boolean;
    hreflangDefaultDomain?: components["schemas"]["SalesChannelDomain"];
    hreflangDefaultDomainId?: string;
    id: string;
    landingPages?: components["schemas"]["LandingPage"][];
    language?: components["schemas"]["Language"];
    languageId: string;
    languages?: components["schemas"]["Language"][];
    mailHeaderFooter?: components["schemas"]["MailHeaderFooter"];
    mailHeaderFooterId?: string;
    mainCategories?: components["schemas"]["MainCategory"][];
    maintenance?: boolean;
    maintenanceIpWhitelist?: GenericRecord[];
    name: string;
    navigationCategory?: components["schemas"]["Category"];
    /** Format: int64 */
    navigationCategoryDepth?: number;
    navigationCategoryId: string;
    navigationCategoryVersionId?: string;
    newsletterRecipients?: components["schemas"]["NewsletterRecipient"][];
    numberRangeSalesChannels?: components["schemas"]["NumberRangeSalesChannel"][];
    orders?: components["schemas"]["Order"][];
    paymentMethod?: components["schemas"]["PaymentMethod"];
    paymentMethodId: string;
    readonly paymentMethodIds?: string[];
    paymentMethods?: components["schemas"]["PaymentMethod"][];
    productExports?: components["schemas"]["ProductExport"][];
    productReviews?: components["schemas"]["ProductReview"][];
    productVisibilities?: components["schemas"]["ProductVisibility"][];
    promotionSalesChannels?: components["schemas"]["PromotionSalesChannel"][];
    seoUrls?: components["schemas"]["SeoUrl"][];
    seoUrlTemplates?: components["schemas"]["SeoUrlTemplate"][];
    serviceCategory?: components["schemas"]["Category"];
    serviceCategoryId?: string;
    serviceCategoryVersionId?: string;
    shippingMethod?: components["schemas"]["ShippingMethod"];
    shippingMethodId: string;
    shippingMethods?: components["schemas"]["ShippingMethod"][];
    shortName?: string;
    systemConfigs?: components["schemas"]["SystemConfig"][];
    taxCalculationType?: string;
    translated: {
      accessKey: string;
      analyticsId: string;
      countryId: string;
      currencyId: string;
      customerGroupId: string;
      footerCategoryId: string;
      footerCategoryVersionId: string;
      homeCmsPageId: string;
      homeCmsPageVersionId: string;
      homeKeywords: string;
      homeMetaDescription: string;
      homeMetaTitle: string;
      homeName: string;
      hreflangDefaultDomainId: string;
      languageId: string;
      mailHeaderFooterId: string;
      name: string;
      navigationCategoryId: string;
      navigationCategoryVersionId: string;
      paymentMethodId: string;
      serviceCategoryId: string;
      serviceCategoryVersionId: string;
      shippingMethodId: string;
      shortName: string;
      taxCalculationType: string;
      typeId: string;
    };
    type?: components["schemas"]["SalesChannelType"];
    typeId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    wishlists?: components["schemas"]["CustomerWishlist"][];
  };
  SalesChannelAnalytics: {
    active?: boolean;
    anonymizeIp?: boolean;
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    salesChannel?: components["schemas"]["SalesChannel"];
    trackingId?: string;
    trackOrders?: boolean;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SalesChannelAnalyticsJsonApi: components["schemas"]["resource"] & {
    active?: boolean;
    anonymizeIp?: boolean;
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    relationships?: {
      salesChannel?: {
        data?: {
          /** @example ec3712a84143b57e0db620eaac6e55b8 */
          id?: string;
          /** @example sales_channel */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel-analytics/d2c88e9b92761eeb97980a50c7d2cdc0/salesChannel
           */
          related?: string;
        };
      };
    };
    trackingId?: string;
    trackOrders?: boolean;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SalesChannelCountry: {
    country?: components["schemas"]["Country"];
    countryId: string;
    id?: string;
    salesChannel?: components["schemas"]["SalesChannel"];
    salesChannelId: string;
  };
  SalesChannelCurrency: {
    currency?: components["schemas"]["Currency"];
    currencyId: string;
    id?: string;
    salesChannel?: components["schemas"]["SalesChannel"];
    salesChannelId: string;
  };
  SalesChannelDomain: {
    /** Format: date-time */
    readonly createdAt?: string;
    currency?: components["schemas"]["Currency"];
    currencyId: string;
    customFields?: GenericRecord;
    extensions?: {
      dsrAppointmentGuideSalesChannelDomain?: {
        data?: {
          /** @example d68bf355eb36d46d6fa55a4db7696181 */
          id?: string;
          /** @example dsr_appointment */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel-domain/e8e8de5eb87653b51534931bb0714095/dsrAppointmentGuideSalesChannelDomain
           */
          related?: string;
        };
      };
      socialShoppingSalesChannels?: {
        data?: {
          /** @example e581067f817be66449a3f4350dc327af */
          id?: string;
          /** @example swag_social_shopping_sales_channel */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel-domain/e8e8de5eb87653b51534931bb0714095/socialShoppingSalesChannels
           */
          related?: string;
        };
      };
    };
    hreflangUseOnlyLocale?: boolean;
    id: string;
    language?: components["schemas"]["Language"];
    languageId: string;
    productExports?: components["schemas"]["ProductExport"][];
    salesChannel?: components["schemas"]["SalesChannel"];
    salesChannelDefaultHreflang?: components["schemas"]["SalesChannel"];
    salesChannelId: string;
    snippetSet?: components["schemas"]["SnippetSet"];
    snippetSetId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    url: string;
  };
  SalesChannelDomainJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    currencyId: string;
    customFields?: GenericRecord;
    extensions?: {
      dsrAppointmentGuideSalesChannelDomain?: {
        data?: {
          /** @example d68bf355eb36d46d6fa55a4db7696181 */
          id?: string;
          /** @example dsr_appointment */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel-domain/e8e8de5eb87653b51534931bb0714095/dsrAppointmentGuideSalesChannelDomain
           */
          related?: string;
        };
      };
      socialShoppingSalesChannels?: {
        data?: {
          /** @example e581067f817be66449a3f4350dc327af */
          id?: string;
          /** @example swag_social_shopping_sales_channel */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel-domain/e8e8de5eb87653b51534931bb0714095/socialShoppingSalesChannels
           */
          related?: string;
        };
      };
    };
    hreflangUseOnlyLocale?: boolean;
    id: string;
    languageId: string;
    relationships?: {
      currency?: {
        data?: {
          /** @example 1af0389838508d7016a9841eb6273962 */
          id?: string;
          /** @example currency */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel-domain/e8e8de5eb87653b51534931bb0714095/currency
           */
          related?: string;
        };
      };
      language?: {
        data?: {
          /** @example 8512ae7d57b1396273f76fe6ed341a23 */
          id?: string;
          /** @example language */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel-domain/e8e8de5eb87653b51534931bb0714095/language
           */
          related?: string;
        };
      };
      productExports?: {
        data?: {
          /** @example 2cd8793787cda582174c0fc329fbc377 */
          id?: string;
          /** @example product_export */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel-domain/e8e8de5eb87653b51534931bb0714095/productExports
           */
          related?: string;
        };
      };
      salesChannel?: {
        data?: {
          /** @example ec3712a84143b57e0db620eaac6e55b8 */
          id?: string;
          /** @example sales_channel */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel-domain/e8e8de5eb87653b51534931bb0714095/salesChannel
           */
          related?: string;
        };
      };
      salesChannelDefaultHreflang?: {
        data?: {
          /** @example 8d7b798a77667d73c422fb222603234c */
          id?: string;
          /** @example sales_channel */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel-domain/e8e8de5eb87653b51534931bb0714095/salesChannelDefaultHreflang
           */
          related?: string;
        };
      };
      snippetSet?: {
        data?: {
          /** @example 543af5fd1912efc00742534f621046d3 */
          id?: string;
          /** @example snippet_set */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel-domain/e8e8de5eb87653b51534931bb0714095/snippetSet
           */
          related?: string;
        };
      };
    };
    salesChannelId: string;
    snippetSetId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    url: string;
  };
  SalesChannelJsonApi: components["schemas"]["resource"] & {
    accessKey: string;
    active?: boolean;
    analyticsId?: string;
    configuration?: GenericRecord;
    countryId: string;
    /** Format: date-time */
    readonly createdAt?: string;
    currencyId: string;
    customerGroupId: string;
    customFields?: GenericRecord;
    extensions?: {
      paypalPosSalesChannel?: {
        data?: {
          /** @example 67ba77ec00554136bd30a09f2b79a091 */
          id?: string;
          /** @example swag_paypal_pos_sales_channel */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel/e497ee380a9e2a5e9812e9e0bf504045/paypalPosSalesChannel
           */
          related?: string;
        };
      };
      quotes?: {
        data?: {
          /** @example 2150fd65034a9bcdb357943b3900a918 */
          id?: string;
          /** @example quote */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel/e497ee380a9e2a5e9812e9e0bf504045/quotes
           */
          related?: string;
        };
      };
      socialShoppingProductErrors?: {
        data?: {
          /** @example 74181afcb28901351a5f2676d1687de8 */
          id?: string;
          /** @example swag_social_shopping_product_error */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel/e497ee380a9e2a5e9812e9e0bf504045/socialShoppingProductErrors
           */
          related?: string;
        };
      };
      socialShoppingSalesChannel?: {
        data?: {
          /** @example be7393dc9d5ee6da46b8ccdf1b316101 */
          id?: string;
          /** @example swag_social_shopping_sales_channel */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel/e497ee380a9e2a5e9812e9e0bf504045/socialShoppingSalesChannel
           */
          related?: string;
        };
      };
      subscriptions?: {
        data?: {
          /** @example 2d5d14f95af035cbd8437948de61f94c */
          id?: string;
          /** @example subscription */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel/e497ee380a9e2a5e9812e9e0bf504045/subscriptions
           */
          related?: string;
        };
      };
      swagSocialShoppingCustomer?: {
        data?: {
          /** @example 70825a5dfabd078bce265301ba7d9cca */
          id?: string;
          /** @example swag_social_shopping_customer */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel/e497ee380a9e2a5e9812e9e0bf504045/swagSocialShoppingCustomer
           */
          related?: string;
        };
      };
      swagSocialShoppingOrder?: {
        data?: {
          /** @example 829fa9441f5dea1e7ada99a9ae4a867f */
          id?: string;
          /** @example swag_social_shopping_order */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel/e497ee380a9e2a5e9812e9e0bf504045/swagSocialShoppingOrder
           */
          related?: string;
        };
      };
      themes?: {
        data?: {
          /** @example fe021943dcda87150f590b3475afaded */
          id?: string;
          /** @example theme */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel/e497ee380a9e2a5e9812e9e0bf504045/themes
           */
          related?: string;
        };
      };
    };
    footerCategoryId?: string;
    footerCategoryVersionId?: string;
    homeCmsPageId?: string;
    homeCmsPageVersionId?: string;
    homeEnabled: boolean;
    homeKeywords?: string;
    homeMetaDescription?: string;
    homeMetaTitle?: string;
    homeName?: string;
    homeSlotConfig?: GenericRecord;
    hreflangActive?: boolean;
    hreflangDefaultDomainId?: string;
    id: string;
    languageId: string;
    mailHeaderFooterId?: string;
    maintenance?: boolean;
    maintenanceIpWhitelist?: GenericRecord[];
    name: string;
    /** Format: int64 */
    navigationCategoryDepth?: number;
    navigationCategoryId: string;
    navigationCategoryVersionId?: string;
    paymentMethodId: string;
    readonly paymentMethodIds?: string[];
    relationships?: {
      analytics?: {
        data?: {
          /** @example 68c4283db8074b12df1660b31c0220a9 */
          id?: string;
          /** @example sales_channel_analytics */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel/e497ee380a9e2a5e9812e9e0bf504045/analytics
           */
          related?: string;
        };
      };
      boundCustomers?: {
        data?: {
          /** @example 770f1f7d01437434bcdf89eee15d4bd2 */
          id?: string;
          /** @example customer */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel/e497ee380a9e2a5e9812e9e0bf504045/boundCustomers
           */
          related?: string;
        };
      };
      countries?: {
        data?: {
          /** @example 71bee43a7a930f904d6194833b9619c9 */
          id?: string;
          /** @example country */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel/e497ee380a9e2a5e9812e9e0bf504045/countries
           */
          related?: string;
        };
      };
      country?: {
        data?: {
          /** @example e909c2d7067ea37437cf97fe11d91bd0 */
          id?: string;
          /** @example country */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel/e497ee380a9e2a5e9812e9e0bf504045/country
           */
          related?: string;
        };
      };
      currencies?: {
        data?: {
          /** @example 7f24d9fc4140045241b3f97bcf36bf03 */
          id?: string;
          /** @example currency */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel/e497ee380a9e2a5e9812e9e0bf504045/currencies
           */
          related?: string;
        };
      };
      currency?: {
        data?: {
          /** @example 1af0389838508d7016a9841eb6273962 */
          id?: string;
          /** @example currency */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel/e497ee380a9e2a5e9812e9e0bf504045/currency
           */
          related?: string;
        };
      };
      customerGroup?: {
        data?: {
          /** @example 115091b01a7299f28a5ce7e1b712a222 */
          id?: string;
          /** @example customer_group */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel/e497ee380a9e2a5e9812e9e0bf504045/customerGroup
           */
          related?: string;
        };
      };
      customerGroupsRegistrations?: {
        data?: {
          /** @example ea52a61e886aa27d777ef201c6fb7fff */
          id?: string;
          /** @example customer_group */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel/e497ee380a9e2a5e9812e9e0bf504045/customerGroupsRegistrations
           */
          related?: string;
        };
      };
      customers?: {
        data?: {
          /** @example 4b6f7d34a58ba399f077685951d06738 */
          id?: string;
          /** @example customer */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel/e497ee380a9e2a5e9812e9e0bf504045/customers
           */
          related?: string;
        };
      };
      documentBaseConfigSalesChannels?: {
        data?: {
          /** @example 9c990fde5b38ff70fc1a07bf84c12a17 */
          id?: string;
          /** @example document_base_config_sales_channel */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel/e497ee380a9e2a5e9812e9e0bf504045/documentBaseConfigSalesChannels
           */
          related?: string;
        };
      };
      domains?: {
        data?: {
          /** @example e4e46deb7f9cc58c7abfb32e5570b6f3 */
          id?: string;
          /** @example sales_channel_domain */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel/e497ee380a9e2a5e9812e9e0bf504045/domains
           */
          related?: string;
        };
      };
      footerCategory?: {
        data?: {
          /** @example a609a222a2767cf322ee21d72a0ddb3e */
          id?: string;
          /** @example category */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel/e497ee380a9e2a5e9812e9e0bf504045/footerCategory
           */
          related?: string;
        };
      };
      homeCmsPage?: {
        data?: {
          /** @example 00bba78f79ca4792a3162942ac65c768 */
          id?: string;
          /** @example cms_page */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel/e497ee380a9e2a5e9812e9e0bf504045/homeCmsPage
           */
          related?: string;
        };
      };
      hreflangDefaultDomain?: {
        data?: {
          /** @example 7e80830860b9b8e5b8fc8d67262680b5 */
          id?: string;
          /** @example sales_channel_domain */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel/e497ee380a9e2a5e9812e9e0bf504045/hreflangDefaultDomain
           */
          related?: string;
        };
      };
      landingPages?: {
        data?: {
          /** @example d60b77f2b3bd69591e3d5e3100926b4d */
          id?: string;
          /** @example landing_page */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel/e497ee380a9e2a5e9812e9e0bf504045/landingPages
           */
          related?: string;
        };
      };
      language?: {
        data?: {
          /** @example 8512ae7d57b1396273f76fe6ed341a23 */
          id?: string;
          /** @example language */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel/e497ee380a9e2a5e9812e9e0bf504045/language
           */
          related?: string;
        };
      };
      languages?: {
        data?: {
          /** @example f3e334d42863e8250c7d03efefbfd387 */
          id?: string;
          /** @example language */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel/e497ee380a9e2a5e9812e9e0bf504045/languages
           */
          related?: string;
        };
      };
      mailHeaderFooter?: {
        data?: {
          /** @example a21fbb0e023f5e68d5be77b969e1eb09 */
          id?: string;
          /** @example mail_header_footer */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel/e497ee380a9e2a5e9812e9e0bf504045/mailHeaderFooter
           */
          related?: string;
        };
      };
      mainCategories?: {
        data?: {
          /** @example 1fb731fc4139cbb575429e28846f0c39 */
          id?: string;
          /** @example main_category */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel/e497ee380a9e2a5e9812e9e0bf504045/mainCategories
           */
          related?: string;
        };
      };
      navigationCategory?: {
        data?: {
          /** @example 2194fe03b676158bb7a3a03f1b98b80e */
          id?: string;
          /** @example category */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel/e497ee380a9e2a5e9812e9e0bf504045/navigationCategory
           */
          related?: string;
        };
      };
      newsletterRecipients?: {
        data?: {
          /** @example 2217f01dc5cddfd5b60387c39867f58e */
          id?: string;
          /** @example newsletter_recipient */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel/e497ee380a9e2a5e9812e9e0bf504045/newsletterRecipients
           */
          related?: string;
        };
      };
      numberRangeSalesChannels?: {
        data?: {
          /** @example 62db021f1d56ae4688775365be68a04f */
          id?: string;
          /** @example number_range_sales_channel */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel/e497ee380a9e2a5e9812e9e0bf504045/numberRangeSalesChannels
           */
          related?: string;
        };
      };
      orders?: {
        data?: {
          /** @example 12c500ed0b7879105fb46af0f246be87 */
          id?: string;
          /** @example order */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel/e497ee380a9e2a5e9812e9e0bf504045/orders
           */
          related?: string;
        };
      };
      paymentMethod?: {
        data?: {
          /** @example 68ec1eeea9f1b7744e231b5bd0d97df0 */
          id?: string;
          /** @example payment_method */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel/e497ee380a9e2a5e9812e9e0bf504045/paymentMethod
           */
          related?: string;
        };
      };
      paymentMethods?: {
        data?: {
          /** @example b631b1ab565525e892f9cdc1242cca14 */
          id?: string;
          /** @example payment_method */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel/e497ee380a9e2a5e9812e9e0bf504045/paymentMethods
           */
          related?: string;
        };
      };
      productExports?: {
        data?: {
          /** @example 2cd8793787cda582174c0fc329fbc377 */
          id?: string;
          /** @example product_export */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel/e497ee380a9e2a5e9812e9e0bf504045/productExports
           */
          related?: string;
        };
      };
      productReviews?: {
        data?: {
          /** @example 01e78541ea343ed72424a5222796a4cd */
          id?: string;
          /** @example product_review */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel/e497ee380a9e2a5e9812e9e0bf504045/productReviews
           */
          related?: string;
        };
      };
      productVisibilities?: {
        data?: {
          /** @example a3534dc8df51f93286fcf577a5f8b153 */
          id?: string;
          /** @example product_visibility */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel/e497ee380a9e2a5e9812e9e0bf504045/productVisibilities
           */
          related?: string;
        };
      };
      promotionSalesChannels?: {
        data?: {
          /** @example ede6dfd9f261361e1f3ada8c5385d064 */
          id?: string;
          /** @example promotion_sales_channel */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel/e497ee380a9e2a5e9812e9e0bf504045/promotionSalesChannels
           */
          related?: string;
        };
      };
      seoUrls?: {
        data?: {
          /** @example 5321b5a71127b8b98cdd4b068ad56c4c */
          id?: string;
          /** @example seo_url */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel/e497ee380a9e2a5e9812e9e0bf504045/seoUrls
           */
          related?: string;
        };
      };
      seoUrlTemplates?: {
        data?: {
          /** @example 02cde325fef3e680f529875e8abd60bb */
          id?: string;
          /** @example seo_url_template */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel/e497ee380a9e2a5e9812e9e0bf504045/seoUrlTemplates
           */
          related?: string;
        };
      };
      serviceCategory?: {
        data?: {
          /** @example bc70a595d052072b5d94cffea6d8d5bb */
          id?: string;
          /** @example category */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel/e497ee380a9e2a5e9812e9e0bf504045/serviceCategory
           */
          related?: string;
        };
      };
      shippingMethod?: {
        data?: {
          /** @example e97bfcdc0cae44bc9e4ab35762eaf0e1 */
          id?: string;
          /** @example shipping_method */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel/e497ee380a9e2a5e9812e9e0bf504045/shippingMethod
           */
          related?: string;
        };
      };
      shippingMethods?: {
        data?: {
          /** @example 8268b0a6c902fbde485094c2f627b854 */
          id?: string;
          /** @example shipping_method */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel/e497ee380a9e2a5e9812e9e0bf504045/shippingMethods
           */
          related?: string;
        };
      };
      systemConfigs?: {
        data?: {
          /** @example dbcfb7a885e393eeb296543d06485547 */
          id?: string;
          /** @example system_config */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel/e497ee380a9e2a5e9812e9e0bf504045/systemConfigs
           */
          related?: string;
        };
      };
      type?: {
        data?: {
          /** @example 599dcce2998a6b40b1e38e8c6006cb0a */
          id?: string;
          /** @example sales_channel_type */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel/e497ee380a9e2a5e9812e9e0bf504045/type
           */
          related?: string;
        };
      };
      wishlists?: {
        data?: {
          /** @example 4ec38c6b2208529c1fadccc7d55d7947 */
          id?: string;
          /** @example customer_wishlist */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel/e497ee380a9e2a5e9812e9e0bf504045/wishlists
           */
          related?: string;
        };
      };
    };
    serviceCategoryId?: string;
    serviceCategoryVersionId?: string;
    shippingMethodId: string;
    shortName?: string;
    taxCalculationType?: string;
    translated: {
      accessKey: string;
      analyticsId: string;
      countryId: string;
      currencyId: string;
      customerGroupId: string;
      footerCategoryId: string;
      footerCategoryVersionId: string;
      homeCmsPageId: string;
      homeCmsPageVersionId: string;
      homeKeywords: string;
      homeMetaDescription: string;
      homeMetaTitle: string;
      homeName: string;
      hreflangDefaultDomainId: string;
      languageId: string;
      mailHeaderFooterId: string;
      name: string;
      navigationCategoryId: string;
      navigationCategoryVersionId: string;
      paymentMethodId: string;
      serviceCategoryId: string;
      serviceCategoryVersionId: string;
      shippingMethodId: string;
      shortName: string;
      taxCalculationType: string;
      typeId: string;
    };
    typeId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SalesChannelLanguage: {
    id?: string;
    language?: components["schemas"]["Language"];
    languageId: string;
    salesChannel?: components["schemas"]["SalesChannel"];
    salesChannelId: string;
  };
  SalesChannelPaymentMethod: {
    id?: string;
    paymentMethod?: components["schemas"]["PaymentMethod"];
    paymentMethodId: string;
    salesChannel?: components["schemas"]["SalesChannel"];
    salesChannelId: string;
  };
  SalesChannelShippingMethod: {
    id?: string;
    salesChannel?: components["schemas"]["SalesChannel"];
    salesChannelId: string;
    shippingMethod?: components["schemas"]["ShippingMethod"];
    shippingMethodId: string;
  };
  SalesChannelType: {
    coverUrl?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    description?: string;
    descriptionLong?: string;
    iconName?: string;
    id: string;
    manufacturer?: string;
    name: string;
    salesChannels?: components["schemas"]["SalesChannel"][];
    screenshotUrls?: string[];
    translated: {
      coverUrl: string;
      description: string;
      descriptionLong: string;
      iconName: string;
      manufacturer: string;
      name: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SalesChannelTypeJsonApi: components["schemas"]["resource"] & {
    coverUrl?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    description?: string;
    descriptionLong?: string;
    iconName?: string;
    id: string;
    manufacturer?: string;
    name: string;
    relationships?: {
      salesChannels?: {
        data?: {
          /** @example 986f6f891e90ab91c091ff4a1a460777 */
          id?: string;
          /** @example sales_channel */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /sales-channel-type/569a394914261338c70075564274cb38/salesChannels
           */
          related?: string;
        };
      };
    };
    screenshotUrls?: string[];
    translated: {
      coverUrl: string;
      description: string;
      descriptionLong: string;
      iconName: string;
      manufacturer: string;
      name: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  Salutation: {
    /** Format: date-time */
    readonly createdAt?: string;
    customerAddresses?: components["schemas"]["CustomerAddress"][];
    customers?: components["schemas"]["Customer"][];
    customFields?: GenericRecord;
    displayName: string;
    extensions?: {
      subscriptionCustomerAddresses?: {
        data?: {
          /** @example 8951627da0210d39cc55d1a91ae21b8d */
          id?: string;
          /** @example subscription_address */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /salutation/c69a98e13eae87bc0ca8735329bf3a5d/subscriptionCustomerAddresses
           */
          related?: string;
        };
      };
      subscriptionCustomers?: {
        data?: {
          /** @example ee8811605866488e8f21308857e1e5a8 */
          id?: string;
          /** @example subscription_customer */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /salutation/c69a98e13eae87bc0ca8735329bf3a5d/subscriptionCustomers
           */
          related?: string;
        };
      };
    };
    id: string;
    letterName: string;
    newsletterRecipients?: components["schemas"]["NewsletterRecipient"][];
    orderAddresses?: components["schemas"]["OrderAddress"][];
    orderCustomers?: components["schemas"]["OrderCustomer"][];
    salutationKey: string;
    translated: {
      displayName: string;
      letterName: string;
      salutationKey: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SalutationJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    displayName: string;
    extensions?: {
      subscriptionCustomerAddresses?: {
        data?: {
          /** @example 8951627da0210d39cc55d1a91ae21b8d */
          id?: string;
          /** @example subscription_address */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /salutation/c69a98e13eae87bc0ca8735329bf3a5d/subscriptionCustomerAddresses
           */
          related?: string;
        };
      };
      subscriptionCustomers?: {
        data?: {
          /** @example ee8811605866488e8f21308857e1e5a8 */
          id?: string;
          /** @example subscription_customer */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /salutation/c69a98e13eae87bc0ca8735329bf3a5d/subscriptionCustomers
           */
          related?: string;
        };
      };
    };
    id: string;
    letterName: string;
    relationships?: {
      customerAddresses?: {
        data?: {
          /** @example 84ed5cbc10cd9f665a8c9f05e49095af */
          id?: string;
          /** @example customer_address */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /salutation/c69a98e13eae87bc0ca8735329bf3a5d/customerAddresses
           */
          related?: string;
        };
      };
      customers?: {
        data?: {
          /** @example 4b6f7d34a58ba399f077685951d06738 */
          id?: string;
          /** @example customer */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /salutation/c69a98e13eae87bc0ca8735329bf3a5d/customers
           */
          related?: string;
        };
      };
      newsletterRecipients?: {
        data?: {
          /** @example 2217f01dc5cddfd5b60387c39867f58e */
          id?: string;
          /** @example newsletter_recipient */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /salutation/c69a98e13eae87bc0ca8735329bf3a5d/newsletterRecipients
           */
          related?: string;
        };
      };
      orderAddresses?: {
        data?: {
          /** @example c3182f0dc0cc20b4982616d3e0221747 */
          id?: string;
          /** @example order_address */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /salutation/c69a98e13eae87bc0ca8735329bf3a5d/orderAddresses
           */
          related?: string;
        };
      };
      orderCustomers?: {
        data?: {
          /** @example 1e7dbe7e3bcb48d233fd80588f54c980 */
          id?: string;
          /** @example order_customer */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /salutation/c69a98e13eae87bc0ca8735329bf3a5d/orderCustomers
           */
          related?: string;
        };
      };
    };
    salutationKey: string;
    translated: {
      displayName: string;
      letterName: string;
      salutationKey: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  ScheduledTask: {
    /** Format: date-time */
    readonly createdAt?: string;
    /** Format: int64 */
    defaultRunInterval: number;
    id: string;
    /** Format: date-time */
    lastExecutionTime?: string;
    name: string;
    /** Format: date-time */
    nextExecutionTime?: string;
    /** Format: int64 */
    runInterval: number;
    scheduledTaskClass: string;
    status: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  ScheduledTaskJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    /** Format: int64 */
    defaultRunInterval: number;
    id: string;
    /** Format: date-time */
    lastExecutionTime?: string;
    name: string;
    /** Format: date-time */
    nextExecutionTime?: string;
    /** Format: int64 */
    runInterval: number;
    scheduledTaskClass: string;
    status: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  Script: {
    active: boolean;
    app?: components["schemas"]["App"];
    appId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    hook: string;
    id: string;
    name: string;
    script: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  ScriptJsonApi: components["schemas"]["resource"] & {
    active: boolean;
    appId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    hook: string;
    id: string;
    name: string;
    relationships?: {
      app?: {
        data?: {
          /** @example d2a57dc1d883fd21fb9951699df71cc7 */
          id?: string;
          /** @example app */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /script/f907e651164789346ae0a1e257c462d8/app
           */
          related?: string;
        };
      };
    };
    script: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SeoUrl: {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    /** Runtime field, cannot be used as part of the criteria. */
    error?: string;
    foreignKey: string;
    id: string;
    isCanonical?: boolean;
    isDeleted?: boolean;
    isModified?: boolean;
    language?: components["schemas"]["Language"];
    languageId: string;
    pathInfo: string;
    routeName: string;
    salesChannel?: components["schemas"]["SalesChannel"];
    salesChannelId?: string;
    seoPathInfo: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    /** Runtime field, cannot be used as part of the criteria. */
    url?: string;
  };
  SeoUrlJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    /** Runtime field, cannot be used as part of the criteria. */
    error?: string;
    foreignKey: string;
    id: string;
    isCanonical?: boolean;
    isDeleted?: boolean;
    isModified?: boolean;
    languageId: string;
    pathInfo: string;
    relationships?: {
      language?: {
        data?: {
          /** @example 8512ae7d57b1396273f76fe6ed341a23 */
          id?: string;
          /** @example language */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /seo-url/da349d0533b621e1f2a0c00b3a04cd46/language
           */
          related?: string;
        };
      };
      salesChannel?: {
        data?: {
          /** @example ec3712a84143b57e0db620eaac6e55b8 */
          id?: string;
          /** @example sales_channel */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /seo-url/da349d0533b621e1f2a0c00b3a04cd46/salesChannel
           */
          related?: string;
        };
      };
    };
    routeName: string;
    salesChannelId?: string;
    seoPathInfo: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    /** Runtime field, cannot be used as part of the criteria. */
    url?: string;
  };
  SeoUrlTemplate: {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    entityName: string;
    id: string;
    isValid?: boolean;
    routeName: string;
    salesChannel?: components["schemas"]["SalesChannel"];
    salesChannelId?: string;
    template?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SeoUrlTemplateJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    entityName: string;
    id: string;
    isValid?: boolean;
    relationships?: {
      salesChannel?: {
        data?: {
          /** @example ec3712a84143b57e0db620eaac6e55b8 */
          id?: string;
          /** @example sales_channel */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /seo-url-template/58940688e95c02f54877a72861f930bb/salesChannel
           */
          related?: string;
        };
      };
    };
    routeName: string;
    salesChannelId?: string;
    template?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  ShippingMethod: {
    active?: boolean;
    appShippingMethod?: components["schemas"]["AppShippingMethod"];
    availabilityRule?: components["schemas"]["Rule"];
    availabilityRuleId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    deliveryTime?: components["schemas"]["DeliveryTime"];
    deliveryTimeId: string;
    description?: string;
    extensions?: {
      quoteDeliveries?: {
        data?: {
          /** @example 2aabe64723fb0f621446cd7b5c04f15e */
          id?: string;
          /** @example quote_delivery */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /shipping-method/d72e7a227a27328b28342b32fc66b6bf/quoteDeliveries
           */
          related?: string;
        };
      };
      subscriptions?: {
        data?: {
          /** @example 2d5d14f95af035cbd8437948de61f94c */
          id?: string;
          /** @example subscription */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /shipping-method/d72e7a227a27328b28342b32fc66b6bf/subscriptions
           */
          related?: string;
        };
      };
    };
    id: string;
    media?: components["schemas"]["Media"];
    mediaId?: string;
    name: string;
    orderDeliveries?: components["schemas"]["OrderDelivery"][];
    /** Format: int64 */
    position?: number;
    prices?: components["schemas"]["ShippingMethodPrice"][];
    salesChannelDefaultAssignments?: components["schemas"]["SalesChannel"][];
    salesChannels?: components["schemas"]["SalesChannel"][];
    tags?: components["schemas"]["Tag"][];
    tax?: components["schemas"]["Tax"];
    taxId?: string;
    taxType?: string;
    technicalName?: string;
    trackingUrl?: string;
    translated: {
      availabilityRuleId: string;
      deliveryTimeId: string;
      description: string;
      mediaId: string;
      name: string;
      taxId: string;
      taxType: string;
      technicalName: string;
      trackingUrl: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  ShippingMethodJsonApi: components["schemas"]["resource"] & {
    active?: boolean;
    availabilityRuleId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    deliveryTimeId: string;
    description?: string;
    extensions?: {
      quoteDeliveries?: {
        data?: {
          /** @example 2aabe64723fb0f621446cd7b5c04f15e */
          id?: string;
          /** @example quote_delivery */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /shipping-method/d72e7a227a27328b28342b32fc66b6bf/quoteDeliveries
           */
          related?: string;
        };
      };
      subscriptions?: {
        data?: {
          /** @example 2d5d14f95af035cbd8437948de61f94c */
          id?: string;
          /** @example subscription */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /shipping-method/d72e7a227a27328b28342b32fc66b6bf/subscriptions
           */
          related?: string;
        };
      };
    };
    id: string;
    mediaId?: string;
    name: string;
    /** Format: int64 */
    position?: number;
    relationships?: {
      appShippingMethod?: {
        data?: {
          /** @example 09f1214e961760dbae11d49b2bf9fa2c */
          id?: string;
          /** @example app_shipping_method */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /shipping-method/d72e7a227a27328b28342b32fc66b6bf/appShippingMethod
           */
          related?: string;
        };
      };
      availabilityRule?: {
        data?: {
          /** @example 9fbb7961d1cb158094924c679e1b302c */
          id?: string;
          /** @example rule */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /shipping-method/d72e7a227a27328b28342b32fc66b6bf/availabilityRule
           */
          related?: string;
        };
      };
      deliveryTime?: {
        data?: {
          /** @example 8c888ae25a7bd42057370e31f7e01044 */
          id?: string;
          /** @example delivery_time */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /shipping-method/d72e7a227a27328b28342b32fc66b6bf/deliveryTime
           */
          related?: string;
        };
      };
      media?: {
        data?: {
          /** @example 62933a2951ef01f4eafd9bdf4d3cd2f0 */
          id?: string;
          /** @example media */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /shipping-method/d72e7a227a27328b28342b32fc66b6bf/media
           */
          related?: string;
        };
      };
      orderDeliveries?: {
        data?: {
          /** @example 0ba472de56dd7ba2e7bb878434321e26 */
          id?: string;
          /** @example order_delivery */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /shipping-method/d72e7a227a27328b28342b32fc66b6bf/orderDeliveries
           */
          related?: string;
        };
      };
      prices?: {
        data?: {
          /** @example afae32efe0f84fece3f96b377b768b33 */
          id?: string;
          /** @example shipping_method_price */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /shipping-method/d72e7a227a27328b28342b32fc66b6bf/prices
           */
          related?: string;
        };
      };
      salesChannelDefaultAssignments?: {
        data?: {
          /** @example b23663b2abc0909be9a8027a3fbff74b */
          id?: string;
          /** @example sales_channel */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /shipping-method/d72e7a227a27328b28342b32fc66b6bf/salesChannelDefaultAssignments
           */
          related?: string;
        };
      };
      salesChannels?: {
        data?: {
          /** @example 986f6f891e90ab91c091ff4a1a460777 */
          id?: string;
          /** @example sales_channel */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /shipping-method/d72e7a227a27328b28342b32fc66b6bf/salesChannels
           */
          related?: string;
        };
      };
      tags?: {
        data?: {
          /** @example d57ac45256849d9b13e2422d91580fb9 */
          id?: string;
          /** @example tag */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /shipping-method/d72e7a227a27328b28342b32fc66b6bf/tags
           */
          related?: string;
        };
      };
      tax?: {
        data?: {
          /** @example 06565e5611f23fdf8cc43e5077b92b54 */
          id?: string;
          /** @example tax */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /shipping-method/d72e7a227a27328b28342b32fc66b6bf/tax
           */
          related?: string;
        };
      };
    };
    taxId?: string;
    taxType?: string;
    technicalName?: string;
    trackingUrl?: string;
    translated: {
      availabilityRuleId: string;
      deliveryTimeId: string;
      description: string;
      mediaId: string;
      name: string;
      taxId: string;
      taxType: string;
      technicalName: string;
      trackingUrl: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  ShippingMethodPrice: {
    /** Format: int64 */
    calculation?: number;
    calculationRule?: components["schemas"]["Rule"];
    calculationRuleId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    currencyPrice?: components["schemas"]["Price"][];
    customFields?: GenericRecord;
    id: string;
    /** Format: float */
    quantityEnd?: number;
    /** Format: float */
    quantityStart?: number;
    rule?: components["schemas"]["Rule"];
    ruleId?: string;
    shippingMethod?: components["schemas"]["ShippingMethod"];
    shippingMethodId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  ShippingMethodPriceJsonApi: components["schemas"]["resource"] & {
    /** Format: int64 */
    calculation?: number;
    calculationRuleId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    currencyPrice?: components["schemas"]["Price"][];
    customFields?: GenericRecord;
    id: string;
    /** Format: float */
    quantityEnd?: number;
    /** Format: float */
    quantityStart?: number;
    relationships?: {
      calculationRule?: {
        data?: {
          /** @example 01b78fd34df634d784131ceefffbac99 */
          id?: string;
          /** @example rule */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /shipping-method-price/db327935c14793601a943097a4852a7b/calculationRule
           */
          related?: string;
        };
      };
      rule?: {
        data?: {
          /** @example 981c1e7b3795da18687613fbd66d4954 */
          id?: string;
          /** @example rule */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /shipping-method-price/db327935c14793601a943097a4852a7b/rule
           */
          related?: string;
        };
      };
      shippingMethod?: {
        data?: {
          /** @example e97bfcdc0cae44bc9e4ab35762eaf0e1 */
          id?: string;
          /** @example shipping_method */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /shipping-method-price/db327935c14793601a943097a4852a7b/shippingMethod
           */
          related?: string;
        };
      };
    };
    ruleId?: string;
    shippingMethodId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  ShippingMethodTag: {
    id?: string;
    shippingMethod?: components["schemas"]["ShippingMethod"];
    shippingMethodId: string;
    tag?: components["schemas"]["Tag"];
    tagId: string;
  };
  SimpleFilter: {
    field: string;
    /** @enum {string} */
    type: "contains" | "equalsAny" | "prefix" | "suffix";
    value: string;
  };
  Snippet: {
    author: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    id: string;
    set?: components["schemas"]["SnippetSet"];
    setId: string;
    translationKey: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    value: string;
  };
  SnippetJsonApi: components["schemas"]["resource"] & {
    author: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    id: string;
    relationships?: {
      set?: {
        data?: {
          /** @example cdaeeeba9b4a4c5ebf042c0215a7bb0e */
          id?: string;
          /** @example snippet_set */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /snippet/c437bb5adb99c55aa0754151c5a61e3d/set
           */
          related?: string;
        };
      };
    };
    setId: string;
    translationKey: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    value: string;
  };
  SnippetSet: {
    baseFile: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    id: string;
    iso: string;
    name: string;
    salesChannelDomains?: components["schemas"]["SalesChannelDomain"][];
    snippets?: components["schemas"]["Snippet"][];
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SnippetSetJsonApi: components["schemas"]["resource"] & {
    baseFile: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    id: string;
    iso: string;
    name: string;
    relationships?: {
      salesChannelDomains?: {
        data?: {
          /** @example b60ab8d110194bfe34ef9928ba48ab6d */
          id?: string;
          /** @example sales_channel_domain */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /snippet-set/9f6e11952dab122bb6c007faaa8d4880/salesChannelDomains
           */
          related?: string;
        };
      };
      snippets?: {
        data?: {
          /** @example 67be68a348da3b850fb7daa10b034528 */
          id?: string;
          /** @example snippet */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /snippet-set/9f6e11952dab122bb6c007faaa8d4880/snippets
           */
          related?: string;
        };
      };
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  Sort: {
    field: string;
    naturalSorting?: boolean;
    /** @enum {string} */
    order: "ASC" | "DESC";
    type?: string;
  };
  SpatialRenderConfigSize: {
    /** Format: date-time */
    readonly createdAt?: string;
    /** Format: int64 */
    height: number;
    id: string;
    name: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    /** Format: int64 */
    width: number;
  };
  SpatialRenderConfigSizeJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    /** Format: int64 */
    height: number;
    id: string;
    name: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    /** Format: int64 */
    width: number;
  };
  SpatialScene: {
    backgroundColor?: string;
    backgroundEnabled?: boolean;
    cameras?: components["schemas"]["SpatialSceneCamera"][];
    /** Format: date-time */
    readonly createdAt?: string;
    description?: string;
    floorColor?: string;
    floorEnabled?: boolean;
    id: string;
    lights?: components["schemas"]["SpatialSceneLight"][];
    name: string;
    objects?: components["schemas"]["SpatialSceneObject"][];
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SpatialSceneCamera: {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    name: string;
    position?: GenericRecord;
    scene?: components["schemas"]["SpatialScene"];
    sceneId: string;
    target?: GenericRecord;
    type: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SpatialSceneCameraJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    name: string;
    position?: GenericRecord;
    relationships?: {
      scene?: {
        data?: {
          /** @example 1e7f604b86415ade94e15fef8627609b */
          id?: string;
          /** @example spatial_scene */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /spatial-scene-camera/d7d65fbdb516f0fc0e32feb511de5c33/scene
           */
          related?: string;
        };
      };
    };
    sceneId: string;
    target?: GenericRecord;
    type: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SpatialSceneJsonApi: components["schemas"]["resource"] & {
    backgroundColor?: string;
    backgroundEnabled?: boolean;
    /** Format: date-time */
    readonly createdAt?: string;
    description?: string;
    floorColor?: string;
    floorEnabled?: boolean;
    id: string;
    name: string;
    relationships?: {
      cameras?: {
        data?: {
          /** @example 036651ad64ffb926ca7a2759af327a8a */
          id?: string;
          /** @example spatial_scene_camera */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /spatial-scene/fbe2b606c76b0075eced631365324623/cameras
           */
          related?: string;
        };
      };
      lights?: {
        data?: {
          /** @example 278e59671a1a559c4bc61d226cd217cd */
          id?: string;
          /** @example spatial_scene_light */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /spatial-scene/fbe2b606c76b0075eced631365324623/lights
           */
          related?: string;
        };
      };
      objects?: {
        data?: {
          /** @example 5891da2d64975cae48d175d1e001f5da */
          id?: string;
          /** @example spatial_scene_object */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /spatial-scene/fbe2b606c76b0075eced631365324623/objects
           */
          related?: string;
        };
      };
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SpatialSceneLight: {
    color?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    enabled?: boolean;
    id: string;
    /** Format: float */
    intensity?: number;
    name: string;
    position?: GenericRecord;
    rotation?: GenericRecord;
    scene?: components["schemas"]["SpatialScene"];
    sceneId: string;
    type: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SpatialSceneLightJsonApi: components["schemas"]["resource"] & {
    color?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    enabled?: boolean;
    id: string;
    /** Format: float */
    intensity?: number;
    name: string;
    position?: GenericRecord;
    relationships?: {
      scene?: {
        data?: {
          /** @example 1e7f604b86415ade94e15fef8627609b */
          id?: string;
          /** @example spatial_scene */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /spatial-scene-light/fb2a55d47b419c2709f04f235c4eb7fe/scene
           */
          related?: string;
        };
      };
    };
    rotation?: GenericRecord;
    sceneId: string;
    type: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SpatialSceneObject: {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    media?: components["schemas"]["Media"];
    mediaId: string;
    name: string;
    position?: GenericRecord;
    rotation?: GenericRecord;
    scale?: GenericRecord;
    scene?: components["schemas"]["SpatialScene"];
    sceneId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    visible?: boolean;
  };
  SpatialSceneObjectJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    mediaId: string;
    name: string;
    position?: GenericRecord;
    relationships?: {
      media?: {
        data?: {
          /** @example 62933a2951ef01f4eafd9bdf4d3cd2f0 */
          id?: string;
          /** @example media */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /spatial-scene-object/c632bfed18543c7114e7a93456a28d9c/media
           */
          related?: string;
        };
      };
      scene?: {
        data?: {
          /** @example 1e7f604b86415ade94e15fef8627609b */
          id?: string;
          /** @example spatial_scene */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /spatial-scene-object/c632bfed18543c7114e7a93456a28d9c/scene
           */
          related?: string;
        };
      };
    };
    rotation?: GenericRecord;
    scale?: GenericRecord;
    sceneId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    visible?: boolean;
  };
  SsoProvider: {
    active: boolean;
    config: GenericRecord;
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    media?: components["schemas"]["Media"];
    mediaId?: string;
    name: string;
    ssoProviderCustomers?: components["schemas"]["SsoProviderCustomer"][];
    type: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SsoProviderCustomer: {
    /** Format: date-time */
    readonly createdAt?: string;
    customer?: components["schemas"]["Customer"];
    customerId: string;
    id: string;
    ssoProvider?: components["schemas"]["SsoProvider"];
    ssoProviderId: string;
    subject: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SsoProviderCustomerJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    customerId: string;
    id: string;
    relationships?: {
      customer?: {
        data?: {
          /** @example 91ec1f9324753048c0096d036a694f86 */
          id?: string;
          /** @example customer */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /sso-provider-customer/bfea076e6e55c14790133b1314edcdb2/customer
           */
          related?: string;
        };
      };
      ssoProvider?: {
        data?: {
          /** @example 643b6966b5e1ecd3029a10a40f7b85ff */
          id?: string;
          /** @example sso_provider */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /sso-provider-customer/bfea076e6e55c14790133b1314edcdb2/ssoProvider
           */
          related?: string;
        };
      };
    };
    ssoProviderId: string;
    subject: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SsoProviderJsonApi: components["schemas"]["resource"] & {
    active: boolean;
    config: GenericRecord;
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    mediaId?: string;
    name: string;
    relationships?: {
      media?: {
        data?: {
          /** @example 62933a2951ef01f4eafd9bdf4d3cd2f0 */
          id?: string;
          /** @example media */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /sso-provider/179b43520e8619ff3a0ff51723f7e827/media
           */
          related?: string;
        };
      };
      ssoProviderCustomers?: {
        data?: {
          /** @example 6f2bd941c85a0835cd1889fd0a2c835a */
          id?: string;
          /** @example sso_provider_customer */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /sso-provider/179b43520e8619ff3a0ff51723f7e827/ssoProviderCustomers
           */
          related?: string;
        };
      };
    };
    type: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  StateForAll: {
    accessibleFrom?: string | null;
    accessibleTo?: string | null;
    /** @default false */
    allowScreenSharing?: boolean;
    /** @default false */
    allowUserActionsForGuide?: boolean;
    /** @enum {string} */
    appointmentMode?: "guided" | "self";
    attendeeRestrictionType?: ("open" | "customer" | "rules") | null;
    /** @default false */
    broadcastMode?: boolean;
    currentDynamicPage?: components["schemas"]["DynamicPageOpenedPayload"];
    currentGuideProductId?: string | null;
    currentPageId?: string | null;
    currentSectionId?: string | null;
    /** @default 0 */
    currentSlideAlias?: number;
    currentSlideData?:
      | components["schemas"]["DynamicProductListingPageOpenedPayload"]
      | null;
    /** @default false */
    ended?: boolean;
    endedAt?: string | null;
    /** @default [] */
    extensions?: unknown[];
    lastActiveGuideSection?: string | null;
    productDetailDefaultPageId?: string | null;
    productListingDefaultPageId?: string | null;
    quickviewPageId?: string | null;
    /** @default false */
    running?: boolean;
    /** @default false */
    started?: boolean;
    startedAt?: string | null;
    /**
     * @default none
     * @enum {string}
     */
    videoAudioSettings?: "both" | "none" | "audio-only";
    /** @default  */
    videoRoomUrl?: string;
    /**
     * @default presentation
     * @enum {string}
     */
    viewMode?: "onlyYou" | "presentation" | "videoGrid";
  };
  StateForGuides: {
    /** @default [] */
    clients?: string[];
    /** @default [] */
    extensions?: unknown[];
    /** @default [] */
    guides?: string[];
    /** @default [] */
    inactiveClients?: string[];
    /** @default [] */
    quickViewState?: string[];
    videoGuideToken?: string | null;
  };
  StateForMe: {
    attendeeId?: string | null;
    attendeeName?: string | null;
    /** @default [] */
    extensions?: unknown[];
    /** @default false */
    guideCartPermissionGranted?: boolean;
    videoUserId?: string | null;
  };
  StateMachine: {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    historyEntries?: components["schemas"]["StateMachineHistory"][];
    id: string;
    initialStateId?: string;
    name: string;
    states?: components["schemas"]["StateMachineState"][];
    technicalName: string;
    transitions?: components["schemas"]["StateMachineTransition"][];
    translated: {
      initialStateId: string;
      name: string;
      technicalName: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  StateMachineHistory: {
    /** Format: date-time */
    readonly createdAt?: string;
    entityName: string;
    fromStateId: string;
    fromStateMachineState?: components["schemas"]["StateMachineState"];
    id: string;
    referencedId: string;
    referencedVersionId: string;
    stateMachine?: components["schemas"]["StateMachine"];
    stateMachineId: string;
    toStateId: string;
    toStateMachineState?: components["schemas"]["StateMachineState"];
    transitionActionName?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    user?: components["schemas"]["User"];
    userId?: string;
  };
  StateMachineHistoryJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    entityName: string;
    fromStateId: string;
    id: string;
    referencedId: string;
    referencedVersionId: string;
    relationships?: {
      fromStateMachineState?: {
        data?: {
          /** @example b108a2a0d303fafc83ef06f6790722e8 */
          id?: string;
          /** @example state_machine_state */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /state-machine-history/2981354377022484094791c3f19ffec8/fromStateMachineState
           */
          related?: string;
        };
      };
      stateMachine?: {
        data?: {
          /** @example 341364a811428a3ed8c355c2c4fe6990 */
          id?: string;
          /** @example state_machine */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /state-machine-history/2981354377022484094791c3f19ffec8/stateMachine
           */
          related?: string;
        };
      };
      toStateMachineState?: {
        data?: {
          /** @example d04a8a7ce57fa3ec0bc44aa1cb095713 */
          id?: string;
          /** @example state_machine_state */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /state-machine-history/2981354377022484094791c3f19ffec8/toStateMachineState
           */
          related?: string;
        };
      };
      user?: {
        data?: {
          /** @example ee11cbb19052e40b07aac0ca060c23ee */
          id?: string;
          /** @example user */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /state-machine-history/2981354377022484094791c3f19ffec8/user
           */
          related?: string;
        };
      };
    };
    stateMachineId: string;
    toStateId: string;
    transitionActionName?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    userId?: string;
  };
  StateMachineJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    id: string;
    initialStateId?: string;
    name: string;
    relationships?: {
      historyEntries?: {
        data?: {
          /** @example 83f6d6b77ef224687b7b34cfe4296bea */
          id?: string;
          /** @example state_machine_history */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /state-machine/e33d8b3de97b8246976dde33ff4abd48/historyEntries
           */
          related?: string;
        };
      };
      states?: {
        data?: {
          /** @example 34d955a0df5f7af9c9b4e4dccb3c3564 */
          id?: string;
          /** @example state_machine_state */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /state-machine/e33d8b3de97b8246976dde33ff4abd48/states
           */
          related?: string;
        };
      };
      transitions?: {
        data?: {
          /** @example 34fe3c1def90f54754c23fb8df6dbeb0 */
          id?: string;
          /** @example state_machine_transition */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /state-machine/e33d8b3de97b8246976dde33ff4abd48/transitions
           */
          related?: string;
        };
      };
    };
    technicalName: string;
    translated: {
      initialStateId: string;
      name: string;
      technicalName: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  StateMachineState: {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    extensions?: {
      orderLineItems?: {
        data?: {
          /** @example 6bd56ce4562ca1be86bf5b8d92c3c1ee */
          id?: string;
          /** @example order_line_item */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /state-machine-state/1e364983d1f17d332d360ae797efc181/orderLineItems
           */
          related?: string;
        };
      };
      orderReturnLineItems?: {
        data?: {
          /** @example 56ae6981fe0ca866f2bedad1b47ddcc3 */
          id?: string;
          /** @example order_return_line_item */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /state-machine-state/1e364983d1f17d332d360ae797efc181/orderReturnLineItems
           */
          related?: string;
        };
      };
      orderReturns?: {
        data?: {
          /** @example e062ff5da223b1e61bb4f72a7808b23b */
          id?: string;
          /** @example order_return */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /state-machine-state/1e364983d1f17d332d360ae797efc181/orderReturns
           */
          related?: string;
        };
      };
      quoteComments?: {
        data?: {
          /** @example 98dec49a83119c512f84645e81ea52d8 */
          id?: string;
          /** @example quote_comment */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /state-machine-state/1e364983d1f17d332d360ae797efc181/quoteComments
           */
          related?: string;
        };
      };
      quotes?: {
        data?: {
          /** @example 2150fd65034a9bcdb357943b3900a918 */
          id?: string;
          /** @example quote */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /state-machine-state/1e364983d1f17d332d360ae797efc181/quotes
           */
          related?: string;
        };
      };
      subscriptions?: {
        data?: {
          /** @example 2d5d14f95af035cbd8437948de61f94c */
          id?: string;
          /** @example subscription */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /state-machine-state/1e364983d1f17d332d360ae797efc181/subscriptions
           */
          related?: string;
        };
      };
    };
    fromStateMachineHistoryEntries?: components["schemas"]["StateMachineHistory"][];
    fromStateMachineTransitions?: components["schemas"]["StateMachineTransition"][];
    id: string;
    name: string;
    orderDeliveries?: components["schemas"]["OrderDelivery"][];
    orders?: components["schemas"]["Order"][];
    orderTransactionCaptureRefunds?: components["schemas"]["OrderTransactionCaptureRefund"][];
    orderTransactionCaptures?: components["schemas"]["OrderTransactionCapture"][];
    orderTransactions?: components["schemas"]["OrderTransaction"][];
    stateMachine?: components["schemas"]["StateMachine"];
    stateMachineId: string;
    technicalName: string;
    toStateMachineHistoryEntries?: components["schemas"]["StateMachineHistory"][];
    toStateMachineTransitions?: components["schemas"]["StateMachineTransition"][];
    translated: {
      name: string;
      stateMachineId: string;
      technicalName: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  StateMachineStateJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    extensions?: {
      orderLineItems?: {
        data?: {
          /** @example 6bd56ce4562ca1be86bf5b8d92c3c1ee */
          id?: string;
          /** @example order_line_item */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /state-machine-state/1e364983d1f17d332d360ae797efc181/orderLineItems
           */
          related?: string;
        };
      };
      orderReturnLineItems?: {
        data?: {
          /** @example 56ae6981fe0ca866f2bedad1b47ddcc3 */
          id?: string;
          /** @example order_return_line_item */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /state-machine-state/1e364983d1f17d332d360ae797efc181/orderReturnLineItems
           */
          related?: string;
        };
      };
      orderReturns?: {
        data?: {
          /** @example e062ff5da223b1e61bb4f72a7808b23b */
          id?: string;
          /** @example order_return */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /state-machine-state/1e364983d1f17d332d360ae797efc181/orderReturns
           */
          related?: string;
        };
      };
      quoteComments?: {
        data?: {
          /** @example 98dec49a83119c512f84645e81ea52d8 */
          id?: string;
          /** @example quote_comment */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /state-machine-state/1e364983d1f17d332d360ae797efc181/quoteComments
           */
          related?: string;
        };
      };
      quotes?: {
        data?: {
          /** @example 2150fd65034a9bcdb357943b3900a918 */
          id?: string;
          /** @example quote */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /state-machine-state/1e364983d1f17d332d360ae797efc181/quotes
           */
          related?: string;
        };
      };
      subscriptions?: {
        data?: {
          /** @example 2d5d14f95af035cbd8437948de61f94c */
          id?: string;
          /** @example subscription */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /state-machine-state/1e364983d1f17d332d360ae797efc181/subscriptions
           */
          related?: string;
        };
      };
    };
    id: string;
    name: string;
    relationships?: {
      fromStateMachineHistoryEntries?: {
        data?: {
          /** @example 6e4fe8b42b9cffa16c3e7b7e4a2a836d */
          id?: string;
          /** @example state_machine_history */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /state-machine-state/1e364983d1f17d332d360ae797efc181/fromStateMachineHistoryEntries
           */
          related?: string;
        };
      };
      fromStateMachineTransitions?: {
        data?: {
          /** @example 80afc3e35f99674237f602b393d3b2ba */
          id?: string;
          /** @example state_machine_transition */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /state-machine-state/1e364983d1f17d332d360ae797efc181/fromStateMachineTransitions
           */
          related?: string;
        };
      };
      orderDeliveries?: {
        data?: {
          /** @example 0ba472de56dd7ba2e7bb878434321e26 */
          id?: string;
          /** @example order_delivery */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /state-machine-state/1e364983d1f17d332d360ae797efc181/orderDeliveries
           */
          related?: string;
        };
      };
      orders?: {
        data?: {
          /** @example 12c500ed0b7879105fb46af0f246be87 */
          id?: string;
          /** @example order */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /state-machine-state/1e364983d1f17d332d360ae797efc181/orders
           */
          related?: string;
        };
      };
      orderTransactionCaptureRefunds?: {
        data?: {
          /** @example 24fe1cc759f5450a1d5984a61ad20bda */
          id?: string;
          /** @example order_transaction_capture_refund */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /state-machine-state/1e364983d1f17d332d360ae797efc181/orderTransactionCaptureRefunds
           */
          related?: string;
        };
      };
      orderTransactionCaptures?: {
        data?: {
          /** @example a32c8bdb9e1154cf4e138a0c8faa7159 */
          id?: string;
          /** @example order_transaction_capture */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /state-machine-state/1e364983d1f17d332d360ae797efc181/orderTransactionCaptures
           */
          related?: string;
        };
      };
      orderTransactions?: {
        data?: {
          /** @example 3bdb6a464fb3330bd1935325493c5f2c */
          id?: string;
          /** @example order_transaction */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /state-machine-state/1e364983d1f17d332d360ae797efc181/orderTransactions
           */
          related?: string;
        };
      };
      stateMachine?: {
        data?: {
          /** @example 341364a811428a3ed8c355c2c4fe6990 */
          id?: string;
          /** @example state_machine */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /state-machine-state/1e364983d1f17d332d360ae797efc181/stateMachine
           */
          related?: string;
        };
      };
      toStateMachineHistoryEntries?: {
        data?: {
          /** @example 01326b3b7d7c9c9182eb3940bb456c50 */
          id?: string;
          /** @example state_machine_history */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /state-machine-state/1e364983d1f17d332d360ae797efc181/toStateMachineHistoryEntries
           */
          related?: string;
        };
      };
      toStateMachineTransitions?: {
        data?: {
          /** @example eb2ca150be27264985d0fcf20d53408d */
          id?: string;
          /** @example state_machine_transition */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /state-machine-state/1e364983d1f17d332d360ae797efc181/toStateMachineTransitions
           */
          related?: string;
        };
      };
    };
    stateMachineId: string;
    technicalName: string;
    translated: {
      name: string;
      stateMachineId: string;
      technicalName: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  StateMachineTransition: {
    actionName: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    fromStateId: string;
    fromStateMachineState?: components["schemas"]["StateMachineState"];
    id: string;
    stateMachine?: components["schemas"]["StateMachine"];
    stateMachineId: string;
    toStateId: string;
    toStateMachineState?: components["schemas"]["StateMachineState"];
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  StateMachineTransitionJsonApi: components["schemas"]["resource"] & {
    actionName: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    fromStateId: string;
    id: string;
    relationships?: {
      fromStateMachineState?: {
        data?: {
          /** @example b108a2a0d303fafc83ef06f6790722e8 */
          id?: string;
          /** @example state_machine_state */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /state-machine-transition/72d87bcb11bdd3adcb321d14ee8c6515/fromStateMachineState
           */
          related?: string;
        };
      };
      stateMachine?: {
        data?: {
          /** @example 341364a811428a3ed8c355c2c4fe6990 */
          id?: string;
          /** @example state_machine */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /state-machine-transition/72d87bcb11bdd3adcb321d14ee8c6515/stateMachine
           */
          related?: string;
        };
      };
      toStateMachineState?: {
        data?: {
          /** @example d04a8a7ce57fa3ec0bc44aa1cb095713 */
          id?: string;
          /** @example state_machine_state */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /state-machine-transition/72d87bcb11bdd3adcb321d14ee8c6515/toStateMachineState
           */
          related?: string;
        };
      };
    };
    stateMachineId: string;
    toStateId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SubAggregations: {
    aggregation?:
      | components["schemas"]["AggregationMetrics"]
      | components["schemas"]["AggregationEntity"]
      | components["schemas"]["AggregationFilter"]
      | components["schemas"]["AggregationTerms"]
      | components["schemas"]["AggregationHistogram"]
      | components["schemas"]["AggregationRange"];
  };
  Subscription: {
    addresses?: components["schemas"]["SubscriptionAddress"][];
    /** Format: int64 */
    readonly autoIncrement?: number;
    billingAddress?: components["schemas"]["SubscriptionAddress"];
    billingAddressId: string;
    convertedOrder: GenericRecord;
    /** Format: date-time */
    readonly createdAt?: string;
    cronInterval: string;
    currency?: components["schemas"]["Currency"];
    currencyId: string;
    customFields?: GenericRecord;
    dateInterval: string;
    id: string;
    /** Format: int64 */
    initialExecutionCount?: number;
    itemRounding: {
      /** Format: int64 */
      decimals: number;
      /** Format: float */
      interval: number;
      roundForNet: boolean;
    };
    language?: components["schemas"]["Language"];
    languageId: string;
    /** Format: date-time */
    nextSchedule: string;
    orders?: components["schemas"]["Order"][];
    paymentMethod?: components["schemas"]["PaymentMethod"];
    paymentMethodId: string;
    /** Format: int64 */
    remainingExecutionCount?: number;
    salesChannel?: components["schemas"]["SalesChannel"];
    salesChannelId: string;
    shippingAddress?: components["schemas"]["SubscriptionAddress"];
    shippingAddressId: string;
    shippingMethod?: components["schemas"]["ShippingMethod"];
    shippingMethodId: string;
    stateId: string;
    stateMachineState?: components["schemas"]["StateMachineState"];
    subscriptionCustomer?: components["schemas"]["SubscriptionCustomer"];
    subscriptionInterval?: components["schemas"]["SubscriptionInterval"];
    subscriptionIntervalId?: string;
    subscriptionIntervalName: string;
    subscriptionNumber: string;
    subscriptionPlan?: components["schemas"]["SubscriptionPlan"];
    subscriptionPlanId?: string;
    subscriptionPlanName: string;
    tags?: components["schemas"]["Tag"][];
    totalRounding: {
      /** Format: int64 */
      decimals: number;
      /** Format: float */
      interval: number;
      roundForNet: boolean;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SubscriptionAddress: {
    additionalAddressLine1?: string;
    additionalAddressLine2?: string;
    billingSubscription?: components["schemas"]["Subscription"];
    city: string;
    company?: string;
    country?: components["schemas"]["Country"];
    countryId: string;
    countryState?: components["schemas"]["CountryState"];
    countryStateId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    department?: string;
    firstName: string;
    id: string;
    lastName: string;
    phoneNumber?: string;
    salutation?: components["schemas"]["Salutation"];
    salutationId?: string;
    shippingSubscription?: components["schemas"]["Subscription"];
    street: string;
    subscription?: components["schemas"]["Subscription"];
    subscriptionId: string;
    title?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    vatId?: string;
    zipcode?: string;
  };
  SubscriptionAddressJsonApi: components["schemas"]["resource"] & {
    additionalAddressLine1?: string;
    additionalAddressLine2?: string;
    city: string;
    company?: string;
    countryId: string;
    countryStateId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    department?: string;
    firstName: string;
    id: string;
    lastName: string;
    phoneNumber?: string;
    relationships?: {
      billingSubscription?: {
        data?: {
          /** @example 5c80db3824a615a8c5494779f006418d */
          id?: string;
          /** @example subscription */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /subscription-address/63f6fea69c128c002aa378821b168c76/billingSubscription
           */
          related?: string;
        };
      };
      country?: {
        data?: {
          /** @example e909c2d7067ea37437cf97fe11d91bd0 */
          id?: string;
          /** @example country */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /subscription-address/63f6fea69c128c002aa378821b168c76/country
           */
          related?: string;
        };
      };
      countryState?: {
        data?: {
          /** @example cb6a9764567191fb74fe28d8d6a4819d */
          id?: string;
          /** @example country_state */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /subscription-address/63f6fea69c128c002aa378821b168c76/countryState
           */
          related?: string;
        };
      };
      salutation?: {
        data?: {
          /** @example 7a6efb02514153b5aa9a8f40c6f8bcc3 */
          id?: string;
          /** @example salutation */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /subscription-address/63f6fea69c128c002aa378821b168c76/salutation
           */
          related?: string;
        };
      };
      shippingSubscription?: {
        data?: {
          /** @example 45791ef15bb346d90a50fc87adbabbbc */
          id?: string;
          /** @example subscription */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /subscription-address/63f6fea69c128c002aa378821b168c76/shippingSubscription
           */
          related?: string;
        };
      };
      subscription?: {
        data?: {
          /** @example b48b13e73a6ac2a86dc54425dd24d9ff */
          id?: string;
          /** @example subscription */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /subscription-address/63f6fea69c128c002aa378821b168c76/subscription
           */
          related?: string;
        };
      };
    };
    salutationId?: string;
    street: string;
    subscriptionId: string;
    title?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    vatId?: string;
    zipcode?: string;
  };
  SubscriptionCustomer: {
    company?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customer?: components["schemas"]["Customer"];
    customerId?: string;
    customerNumber?: string;
    customFields?: GenericRecord;
    email: string;
    firstName: string;
    id: string;
    lastName: string;
    remoteAddress?: string;
    salutation?: components["schemas"]["Salutation"];
    salutationId: string;
    subscription?: components["schemas"]["Subscription"];
    subscriptionId: string;
    title?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    vatIds?: string[];
  };
  SubscriptionCustomerJsonApi: components["schemas"]["resource"] & {
    company?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customerId?: string;
    customerNumber?: string;
    customFields?: GenericRecord;
    email: string;
    firstName: string;
    id: string;
    lastName: string;
    relationships?: {
      customer?: {
        data?: {
          /** @example 91ec1f9324753048c0096d036a694f86 */
          id?: string;
          /** @example customer */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /subscription-customer/2bbf8cc18dfb0a95c32f2a79905723d9/customer
           */
          related?: string;
        };
      };
      salutation?: {
        data?: {
          /** @example 7a6efb02514153b5aa9a8f40c6f8bcc3 */
          id?: string;
          /** @example salutation */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /subscription-customer/2bbf8cc18dfb0a95c32f2a79905723d9/salutation
           */
          related?: string;
        };
      };
      subscription?: {
        data?: {
          /** @example b48b13e73a6ac2a86dc54425dd24d9ff */
          id?: string;
          /** @example subscription */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /subscription-customer/2bbf8cc18dfb0a95c32f2a79905723d9/subscription
           */
          related?: string;
        };
      };
    };
    remoteAddress?: string;
    salutationId: string;
    subscriptionId: string;
    title?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    vatIds?: string[];
  };
  SubscriptionInterval: {
    active?: boolean;
    availabilityRule?: components["schemas"]["Rule"];
    availabilityRuleId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    cronInterval?: string;
    dateInterval?: string;
    id: string;
    name: string;
    subscriptionPlans?: components["schemas"]["SubscriptionPlan"][];
    subscriptions?: components["schemas"]["Subscription"][];
    translated: {
      availabilityRuleId: string;
      cronInterval: string;
      dateInterval: string;
      name: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SubscriptionIntervalJsonApi: components["schemas"]["resource"] & {
    active?: boolean;
    availabilityRuleId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    cronInterval?: string;
    dateInterval?: string;
    id: string;
    name: string;
    relationships?: {
      availabilityRule?: {
        data?: {
          /** @example 9fbb7961d1cb158094924c679e1b302c */
          id?: string;
          /** @example rule */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /subscription-interval/6908067ce08a164d022b6a07940ebc7b/availabilityRule
           */
          related?: string;
        };
      };
      subscriptionPlans?: {
        data?: {
          /** @example ed94874505da2886dc66a3a3d3968972 */
          id?: string;
          /** @example subscription_plan */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /subscription-interval/6908067ce08a164d022b6a07940ebc7b/subscriptionPlans
           */
          related?: string;
        };
      };
      subscriptions?: {
        data?: {
          /** @example 2d5d14f95af035cbd8437948de61f94c */
          id?: string;
          /** @example subscription */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /subscription-interval/6908067ce08a164d022b6a07940ebc7b/subscriptions
           */
          related?: string;
        };
      };
    };
    translated: {
      availabilityRuleId: string;
      cronInterval: string;
      dateInterval: string;
      name: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SubscriptionJsonApi: components["schemas"]["resource"] & {
    /** Format: int64 */
    readonly autoIncrement?: number;
    billingAddressId: string;
    convertedOrder: GenericRecord;
    /** Format: date-time */
    readonly createdAt?: string;
    cronInterval: string;
    currencyId: string;
    customFields?: GenericRecord;
    dateInterval: string;
    id: string;
    /** Format: int64 */
    initialExecutionCount?: number;
    itemRounding: {
      /** Format: int64 */
      decimals: number;
      /** Format: float */
      interval: number;
      roundForNet: boolean;
    };
    languageId: string;
    /** Format: date-time */
    nextSchedule: string;
    paymentMethodId: string;
    relationships?: {
      addresses?: {
        data?: {
          /** @example 963e3a2fe559e393bad631f3dc686f69 */
          id?: string;
          /** @example subscription_address */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /subscription/787ad0b7a17de4ad6b1711bbf8d79fcb/addresses
           */
          related?: string;
        };
      };
      billingAddress?: {
        data?: {
          /** @example 7fee8ff88b768662dd8fc06e1b6997d2 */
          id?: string;
          /** @example subscription_address */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /subscription/787ad0b7a17de4ad6b1711bbf8d79fcb/billingAddress
           */
          related?: string;
        };
      };
      currency?: {
        data?: {
          /** @example 1af0389838508d7016a9841eb6273962 */
          id?: string;
          /** @example currency */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /subscription/787ad0b7a17de4ad6b1711bbf8d79fcb/currency
           */
          related?: string;
        };
      };
      language?: {
        data?: {
          /** @example 8512ae7d57b1396273f76fe6ed341a23 */
          id?: string;
          /** @example language */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /subscription/787ad0b7a17de4ad6b1711bbf8d79fcb/language
           */
          related?: string;
        };
      };
      orders?: {
        data?: {
          /** @example 12c500ed0b7879105fb46af0f246be87 */
          id?: string;
          /** @example order */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /subscription/787ad0b7a17de4ad6b1711bbf8d79fcb/orders
           */
          related?: string;
        };
      };
      paymentMethod?: {
        data?: {
          /** @example 68ec1eeea9f1b7744e231b5bd0d97df0 */
          id?: string;
          /** @example payment_method */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /subscription/787ad0b7a17de4ad6b1711bbf8d79fcb/paymentMethod
           */
          related?: string;
        };
      };
      salesChannel?: {
        data?: {
          /** @example ec3712a84143b57e0db620eaac6e55b8 */
          id?: string;
          /** @example sales_channel */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /subscription/787ad0b7a17de4ad6b1711bbf8d79fcb/salesChannel
           */
          related?: string;
        };
      };
      shippingAddress?: {
        data?: {
          /** @example 8ced05ad5d4ac52bbf7f4b1413f35521 */
          id?: string;
          /** @example subscription_address */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /subscription/787ad0b7a17de4ad6b1711bbf8d79fcb/shippingAddress
           */
          related?: string;
        };
      };
      shippingMethod?: {
        data?: {
          /** @example e97bfcdc0cae44bc9e4ab35762eaf0e1 */
          id?: string;
          /** @example shipping_method */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /subscription/787ad0b7a17de4ad6b1711bbf8d79fcb/shippingMethod
           */
          related?: string;
        };
      };
      stateMachineState?: {
        data?: {
          /** @example 1ab22d393154f21e3be76aca3ec3ee31 */
          id?: string;
          /** @example state_machine_state */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /subscription/787ad0b7a17de4ad6b1711bbf8d79fcb/stateMachineState
           */
          related?: string;
        };
      };
      subscriptionCustomer?: {
        data?: {
          /** @example 6b5e1e89a3d596fceff0f09fdbb41770 */
          id?: string;
          /** @example subscription_customer */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /subscription/787ad0b7a17de4ad6b1711bbf8d79fcb/subscriptionCustomer
           */
          related?: string;
        };
      };
      subscriptionInterval?: {
        data?: {
          /** @example 411797824a15b44b931bc4b9e614fb79 */
          id?: string;
          /** @example subscription_interval */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /subscription/787ad0b7a17de4ad6b1711bbf8d79fcb/subscriptionInterval
           */
          related?: string;
        };
      };
      subscriptionPlan?: {
        data?: {
          /** @example cc77ba4ffd2f2fe79753e342bf273e18 */
          id?: string;
          /** @example subscription_plan */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /subscription/787ad0b7a17de4ad6b1711bbf8d79fcb/subscriptionPlan
           */
          related?: string;
        };
      };
      tags?: {
        data?: {
          /** @example d57ac45256849d9b13e2422d91580fb9 */
          id?: string;
          /** @example tag */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /subscription/787ad0b7a17de4ad6b1711bbf8d79fcb/tags
           */
          related?: string;
        };
      };
    };
    /** Format: int64 */
    remainingExecutionCount?: number;
    salesChannelId: string;
    shippingAddressId: string;
    shippingMethodId: string;
    stateId: string;
    subscriptionIntervalId?: string;
    subscriptionIntervalName: string;
    subscriptionNumber: string;
    subscriptionPlanId?: string;
    subscriptionPlanName: string;
    totalRounding: {
      /** Format: int64 */
      decimals: number;
      /** Format: float */
      interval: number;
      roundForNet: boolean;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SubscriptionPlan: {
    active?: boolean;
    activeStorefrontLabel?: boolean;
    availabilityRule?: components["schemas"]["Rule"];
    availabilityRuleId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    description?: string;
    /** Format: float */
    discountPercentage?: number;
    id: string;
    label?: string;
    /** Format: int64 */
    minimumExecutionCount?: number;
    name: string;
    products?: components["schemas"]["Product"][];
    subscriptionIntervals?: components["schemas"]["SubscriptionInterval"][];
    subscriptions?: components["schemas"]["Subscription"][];
    translated: {
      availabilityRuleId: string;
      description: string;
      label: string;
      name: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SubscriptionPlanIntervalMapping: {
    id?: string;
    subscriptionInterval?: components["schemas"]["SubscriptionInterval"];
    subscriptionIntervalId: string;
    subscriptionPlan?: components["schemas"]["SubscriptionPlan"];
    subscriptionPlanId: string;
  };
  SubscriptionPlanJsonApi: components["schemas"]["resource"] & {
    active?: boolean;
    activeStorefrontLabel?: boolean;
    availabilityRuleId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    description?: string;
    /** Format: float */
    discountPercentage?: number;
    id: string;
    label?: string;
    /** Format: int64 */
    minimumExecutionCount?: number;
    name: string;
    relationships?: {
      availabilityRule?: {
        data?: {
          /** @example 9fbb7961d1cb158094924c679e1b302c */
          id?: string;
          /** @example rule */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /subscription-plan/5e63f9057837020694081b9412211bfb/availabilityRule
           */
          related?: string;
        };
      };
      products?: {
        data?: {
          /** @example 86024cad1e83101d97359d7351051156 */
          id?: string;
          /** @example product */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /subscription-plan/5e63f9057837020694081b9412211bfb/products
           */
          related?: string;
        };
      };
      subscriptionIntervals?: {
        data?: {
          /** @example 28e0fbf8d26aa147681d2241c60ef075 */
          id?: string;
          /** @example subscription_interval */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /subscription-plan/5e63f9057837020694081b9412211bfb/subscriptionIntervals
           */
          related?: string;
        };
      };
      subscriptions?: {
        data?: {
          /** @example 2d5d14f95af035cbd8437948de61f94c */
          id?: string;
          /** @example subscription */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /subscription-plan/5e63f9057837020694081b9412211bfb/subscriptions
           */
          related?: string;
        };
      };
    };
    translated: {
      availabilityRuleId: string;
      description: string;
      label: string;
      name: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SubscriptionPlanProductMapping: {
    id?: string;
    product?: components["schemas"]["Product"];
    productId: string;
    productVersionId?: string;
    subscriptionPlan?: components["schemas"]["SubscriptionPlan"];
    subscriptionPlanId: string;
  };
  SubscriptionTagMapping: {
    id?: string;
    subscription?: components["schemas"]["Subscription"];
    subscriptionId: string;
    tag?: components["schemas"]["Tag"];
    tagId: string;
  };
  SwagCmsExtensionsBlockRule: {
    cmsBlock?: components["schemas"]["CmsBlock"];
    cmsBlockId: string;
    cmsBlockVersionId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    inverted?: boolean;
    /** Format: date-time */
    readonly updatedAt?: string;
    visibilityRule?: components["schemas"]["Rule"];
    visibilityRuleId?: string;
  };
  SwagCmsExtensionsBlockRuleJsonApi: components["schemas"]["resource"] & {
    cmsBlockId: string;
    cmsBlockVersionId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    inverted?: boolean;
    relationships?: {
      cmsBlock?: {
        data?: {
          /** @example 87a71f31728ecc19c2e87fbe9face4b2 */
          id?: string;
          /** @example cms_block */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-cms-extensions-block-rule/f36890a9656215be0edf2204ba8dc876/cmsBlock
           */
          related?: string;
        };
      };
      visibilityRule?: {
        data?: {
          /** @example 6efc965839211c3f91ba4d7d2a3fc9f3 */
          id?: string;
          /** @example rule */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-cms-extensions-block-rule/f36890a9656215be0edf2204ba8dc876/visibilityRule
           */
          related?: string;
        };
      };
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    visibilityRuleId?: string;
  };
  SwagCmsExtensionsForm: {
    cmsSlot?: components["schemas"]["CmsSlot"];
    cmsSlotId?: string;
    cmsSlotVersionId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    groups?: components["schemas"]["SwagCmsExtensionsFormGroup"][];
    id: string;
    isTemplate?: boolean;
    mailTemplate?: components["schemas"]["MailTemplate"];
    mailTemplateId: string;
    receivers?: GenericRecord;
    successMessage?: string;
    technicalName: string;
    title?: string;
    translated: {
      cmsSlotId: string;
      cmsSlotVersionId: string;
      mailTemplateId: string;
      successMessage: string;
      technicalName: string;
      title: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagCmsExtensionsFormGroup: {
    /** Format: date-time */
    readonly createdAt?: string;
    fields?: components["schemas"]["SwagCmsExtensionsFormGroupField"][];
    form?: components["schemas"]["SwagCmsExtensionsForm"];
    formId?: string;
    id: string;
    /** Format: int64 */
    position: number;
    technicalName: string;
    title?: string;
    translated: {
      formId: string;
      technicalName: string;
      title: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagCmsExtensionsFormGroupField: {
    config?: GenericRecord;
    /** Format: date-time */
    readonly createdAt?: string;
    errorMessage?: string;
    group?: components["schemas"]["SwagCmsExtensionsFormGroup"];
    groupId?: string;
    id: string;
    label: string;
    placeholder?: string;
    /** Format: int64 */
    position: number;
    required?: boolean;
    technicalName: string;
    translated: {
      errorMessage: string;
      groupId: string;
      label: string;
      placeholder: string;
      technicalName: string;
      type: string;
    };
    type: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    /** Format: int64 */
    width: number;
  };
  SwagCmsExtensionsFormGroupFieldJsonApi: components["schemas"]["resource"] & {
    config?: GenericRecord;
    /** Format: date-time */
    readonly createdAt?: string;
    errorMessage?: string;
    groupId?: string;
    id: string;
    label: string;
    placeholder?: string;
    /** Format: int64 */
    position: number;
    relationships?: {
      group?: {
        data?: {
          /** @example db0f6f37ebeb6ea09489124345af2a45 */
          id?: string;
          /** @example swag_cms_extensions_form_group */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-cms-extensions-form-group-field/8c53232660618aa34371b17b0fddac3d/group
           */
          related?: string;
        };
      };
    };
    required?: boolean;
    technicalName: string;
    translated: {
      errorMessage: string;
      groupId: string;
      label: string;
      placeholder: string;
      technicalName: string;
      type: string;
    };
    type: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    /** Format: int64 */
    width: number;
  };
  SwagCmsExtensionsFormGroupJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    formId?: string;
    id: string;
    /** Format: int64 */
    position: number;
    relationships?: {
      fields?: {
        data?: {
          /** @example d05b6ed7d2345020440df396d6da7f73 */
          id?: string;
          /** @example swag_cms_extensions_form_group_field */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-cms-extensions-form-group/468e2351f66daae01feec5952fa04897/fields
           */
          related?: string;
        };
      };
      form?: {
        data?: {
          /** @example 3fcdb73d36d54f2cc22d0f68e6b6e182 */
          id?: string;
          /** @example swag_cms_extensions_form */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-cms-extensions-form-group/468e2351f66daae01feec5952fa04897/form
           */
          related?: string;
        };
      };
    };
    technicalName: string;
    title?: string;
    translated: {
      formId: string;
      technicalName: string;
      title: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagCmsExtensionsFormJsonApi: components["schemas"]["resource"] & {
    cmsSlotId?: string;
    cmsSlotVersionId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    isTemplate?: boolean;
    mailTemplateId: string;
    receivers?: GenericRecord;
    relationships?: {
      cmsSlot?: {
        data?: {
          /** @example e1306ba9f900039b95359c03fa95dd8b */
          id?: string;
          /** @example cms_slot */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-cms-extensions-form/f06a6b72709adae43e1e94ef1caa8e5f/cmsSlot
           */
          related?: string;
        };
      };
      groups?: {
        data?: {
          /** @example 1471e4e05a4db95d353cc867fe317314 */
          id?: string;
          /** @example swag_cms_extensions_form_group */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-cms-extensions-form/f06a6b72709adae43e1e94ef1caa8e5f/groups
           */
          related?: string;
        };
      };
      mailTemplate?: {
        data?: {
          /** @example 246e2bdec01d63875c35f120d7b05092 */
          id?: string;
          /** @example mail_template */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-cms-extensions-form/f06a6b72709adae43e1e94ef1caa8e5f/mailTemplate
           */
          related?: string;
        };
      };
    };
    successMessage?: string;
    technicalName: string;
    title?: string;
    translated: {
      cmsSlotId: string;
      cmsSlotVersionId: string;
      mailTemplateId: string;
      successMessage: string;
      technicalName: string;
      title: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagCmsExtensionsQuickview: {
    active?: boolean;
    cmsBlock?: components["schemas"]["CmsBlock"];
    cmsBlockId?: string;
    cmsBlockVersionId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagCmsExtensionsQuickviewJsonApi: components["schemas"]["resource"] & {
    active?: boolean;
    cmsBlockId?: string;
    cmsBlockVersionId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    relationships?: {
      cmsBlock?: {
        data?: {
          /** @example 87a71f31728ecc19c2e87fbe9face4b2 */
          id?: string;
          /** @example cms_block */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-cms-extensions-quickview/93c1c8d93a2120d8141e5fed74a16dce/cmsBlock
           */
          related?: string;
        };
      };
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagCmsExtensionsScrollNavigation: {
    active?: boolean;
    cmsSection?: components["schemas"]["CmsSection"];
    cmsSectionId?: string;
    cmsSectionVersionId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    displayName?: string;
    id: string;
    translated: {
      cmsSectionId: string;
      cmsSectionVersionId: string;
      displayName: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagCmsExtensionsScrollNavigationJsonApi: components["schemas"]["resource"] & {
    active?: boolean;
    cmsSectionId?: string;
    cmsSectionVersionId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    displayName?: string;
    id: string;
    relationships?: {
      cmsSection?: {
        data?: {
          /** @example 212545e6991db0675b783d4574ab20dc */
          id?: string;
          /** @example cms_section */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-cms-extensions-scroll-navigation/fe6e0a5fca8ed3c312de3ba20a10be99/cmsSection
           */
          related?: string;
        };
      };
    };
    translated: {
      cmsSectionId: string;
      cmsSectionVersionId: string;
      displayName: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagCmsExtensionsScrollNavigationPageSettings: {
    active?: boolean;
    bouncy?: boolean;
    cmsPage?: components["schemas"]["CmsPage"];
    cmsPageId?: string;
    cmsPageVersionId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    /** Format: int64 */
    duration?: number;
    easing?: string;
    /** Format: int64 */
    easingDegree?: number;
    id: string;
    nativeScrolling: boolean;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagCmsExtensionsScrollNavigationPageSettingsJsonApi: components["schemas"]["resource"] & {
    active?: boolean;
    bouncy?: boolean;
    cmsPageId?: string;
    cmsPageVersionId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    /** Format: int64 */
    duration?: number;
    easing?: string;
    /** Format: int64 */
    easingDegree?: number;
    id: string;
    nativeScrolling: boolean;
    relationships?: {
      cmsPage?: {
        data?: {
          /** @example 7b1460918b1abb93311108f3dc021c9b */
          id?: string;
          /** @example cms_page */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-cms-extensions-scroll-navigation-page-settings/ee67f9f8361095c164fecc7e32aace8d/cmsPage
           */
          related?: string;
        };
      };
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagCustomizedProductsTemplate: {
    active?: boolean;
    configurations?: components["schemas"]["SwagCustomizedProductsTemplateConfiguration"][];
    confirmInput?: boolean;
    /** Format: date-time */
    readonly createdAt?: string;
    readonly decisionTree?: GenericRecord;
    description?: string;
    displayName: string;
    exclusions?: components["schemas"]["SwagCustomizedProductsTemplateExclusion"][];
    id: string;
    internalName: string;
    media?: components["schemas"]["Media"];
    mediaId?: string;
    options?: components["schemas"]["SwagCustomizedProductsTemplateOption"][];
    optionsAutoCollapse?: boolean;
    parentVersionId?: string;
    products?: components["schemas"]["Product"][];
    stepByStep?: boolean;
    translated: {
      description: string;
      displayName: string;
      internalName: string;
      mediaId: string;
      parentVersionId: string;
      versionId: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  SwagCustomizedProductsTemplateConfiguration: {
    configuration: GenericRecord;
    /** Format: date-time */
    readonly createdAt?: string;
    hash: string;
    id: string;
    template?: components["schemas"]["SwagCustomizedProductsTemplate"];
    templateConfigurationShares?: components["schemas"]["SwagCustomizedProductsTemplateConfigurationShare"][];
    templateId: string;
    templateVersionId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  SwagCustomizedProductsTemplateConfigurationJsonApi: components["schemas"]["resource"] & {
    configuration: GenericRecord;
    /** Format: date-time */
    readonly createdAt?: string;
    hash: string;
    id: string;
    relationships?: {
      template?: {
        data?: {
          /** @example 66f6181bcb4cff4cd38fbc804a036db6 */
          id?: string;
          /** @example swag_customized_products_template */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-customized-products-template-configuration/ab78fa5f6df63876a7c6575bdf517fe2/template
           */
          related?: string;
        };
      };
      templateConfigurationShares?: {
        data?: {
          /** @example 81a31c81fde24f296e176502d32baa6d */
          id?: string;
          /** @example swag_customized_products_template_configuration_share */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-customized-products-template-configuration/ab78fa5f6df63876a7c6575bdf517fe2/templateConfigurationShares
           */
          related?: string;
        };
      };
    };
    templateId: string;
    templateVersionId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  SwagCustomizedProductsTemplateConfigurationShare: {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    oneTime?: boolean;
    templateConfiguration?: components["schemas"]["SwagCustomizedProductsTemplateConfiguration"];
    templateConfigurationId: string;
    templateConfigurationVersionId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  SwagCustomizedProductsTemplateConfigurationShareJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    oneTime?: boolean;
    relationships?: {
      templateConfiguration?: {
        data?: {
          /** @example 82a3b2de8107d3e15a17f2d4278c849c */
          id?: string;
          /** @example swag_customized_products_template_configuration */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-customized-products-template-configuration-share/9ed7d8ec8fa2b6e96c0ab1803eb42789/templateConfiguration
           */
          related?: string;
        };
      };
    };
    templateConfigurationId: string;
    templateConfigurationVersionId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  SwagCustomizedProductsTemplateExclusion: {
    conditions?: components["schemas"]["SwagCustomizedProductsTemplateExclusionCondition"][];
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    name: string;
    template?: components["schemas"]["SwagCustomizedProductsTemplate"];
    templateId: string;
    templateVersionId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  SwagCustomizedProductsTemplateExclusionCondition: {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    templateExclusion?: components["schemas"]["SwagCustomizedProductsTemplateExclusion"];
    templateExclusionId: string;
    templateExclusionOperator?: components["schemas"]["SwagCustomizedProductsTemplateExclusionOperator"];
    templateExclusionOperatorId: string;
    templateExclusionVersionId?: string;
    templateOption?: components["schemas"]["SwagCustomizedProductsTemplateOption"];
    templateOptionId: string;
    templateOptionValues?: components["schemas"]["SwagCustomizedProductsTemplateOptionValue"][];
    templateOptionVersionId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  SwagCustomizedProductsTemplateExclusionConditionJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    relationships?: {
      templateExclusion?: {
        data?: {
          /** @example 13cbb51fc716b7cdd04a5e995b57cce4 */
          id?: string;
          /** @example swag_customized_products_template_exclusion */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-customized-products-template-exclusion-condition/7fb5a2315280913d00c5ff5a0415afcf/templateExclusion
           */
          related?: string;
        };
      };
      templateExclusionOperator?: {
        data?: {
          /** @example 8a3c6855d1712345c9fe9468425bfe2e */
          id?: string;
          /** @example swag_customized_products_template_exclusion_operator */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-customized-products-template-exclusion-condition/7fb5a2315280913d00c5ff5a0415afcf/templateExclusionOperator
           */
          related?: string;
        };
      };
      templateOption?: {
        data?: {
          /** @example 6891a002a90a39e71e67c4fc148db8df */
          id?: string;
          /** @example swag_customized_products_template_option */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-customized-products-template-exclusion-condition/7fb5a2315280913d00c5ff5a0415afcf/templateOption
           */
          related?: string;
        };
      };
      templateOptionValues?: {
        data?: {
          /** @example 7d3eaa0fb0118db414750bb30b0582b6 */
          id?: string;
          /** @example swag_customized_products_template_option_value */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-customized-products-template-exclusion-condition/7fb5a2315280913d00c5ff5a0415afcf/templateOptionValues
           */
          related?: string;
        };
      };
    };
    templateExclusionId: string;
    templateExclusionOperatorId: string;
    templateExclusionVersionId?: string;
    templateOptionId: string;
    templateOptionVersionId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  SwagCustomizedProductsTemplateExclusionConditionValues: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    swagCustomizedProductsTemplateExclusionConditionVersionId?: string;
    swagCustomizedProductsTemplateOptionValueVersionId?: string;
    templateExclusionCondition?: components["schemas"]["SwagCustomizedProductsTemplateExclusionCondition"];
    templateExclusionConditionId: string;
    templateOptionValue?: components["schemas"]["SwagCustomizedProductsTemplateOptionValue"];
    templateOptionValueId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagCustomizedProductsTemplateExclusionJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    name: string;
    relationships?: {
      conditions?: {
        data?: {
          /** @example b5b399ec1fcfe753f58dbafa197efdc1 */
          id?: string;
          /** @example swag_customized_products_template_exclusion_condition */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-customized-products-template-exclusion/d28221401a2fa711c59f4bb8cbd9d06e/conditions
           */
          related?: string;
        };
      };
      template?: {
        data?: {
          /** @example 66f6181bcb4cff4cd38fbc804a036db6 */
          id?: string;
          /** @example swag_customized_products_template */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-customized-products-template-exclusion/d28221401a2fa711c59f4bb8cbd9d06e/template
           */
          related?: string;
        };
      };
    };
    templateId: string;
    templateVersionId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  SwagCustomizedProductsTemplateExclusionOperator: {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    label: string;
    operator: string;
    templateExclusionConditions?: components["schemas"]["SwagCustomizedProductsTemplateExclusionCondition"][];
    templateOptionType: string;
    translated: {
      label: string;
      operator: string;
      templateOptionType: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagCustomizedProductsTemplateExclusionOperatorJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    label: string;
    operator: string;
    relationships?: {
      templateExclusionConditions?: {
        data?: {
          /** @example 57e853a74b92e339ec2e302b015e60f3 */
          id?: string;
          /** @example swag_customized_products_template_exclusion_condition */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-customized-products-template-exclusion-operator/df2936b0a1e725c8000f04817f4545f7/templateExclusionConditions
           */
          related?: string;
        };
      };
    };
    templateOptionType: string;
    translated: {
      label: string;
      operator: string;
      templateOptionType: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagCustomizedProductsTemplateJsonApi: components["schemas"]["resource"] & {
    active?: boolean;
    confirmInput?: boolean;
    /** Format: date-time */
    readonly createdAt?: string;
    readonly decisionTree?: GenericRecord;
    description?: string;
    displayName: string;
    id: string;
    internalName: string;
    mediaId?: string;
    optionsAutoCollapse?: boolean;
    parentVersionId?: string;
    relationships?: {
      configurations?: {
        data?: {
          /** @example 86f23519571eb918e8812e1979d55409 */
          id?: string;
          /** @example swag_customized_products_template_configuration */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-customized-products-template/4751e4cb483e992aa073494b9cfa9be6/configurations
           */
          related?: string;
        };
      };
      exclusions?: {
        data?: {
          /** @example c6fc0a7508c1a1fe9e233e81d31133b8 */
          id?: string;
          /** @example swag_customized_products_template_exclusion */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-customized-products-template/4751e4cb483e992aa073494b9cfa9be6/exclusions
           */
          related?: string;
        };
      };
      media?: {
        data?: {
          /** @example 62933a2951ef01f4eafd9bdf4d3cd2f0 */
          id?: string;
          /** @example media */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-customized-products-template/4751e4cb483e992aa073494b9cfa9be6/media
           */
          related?: string;
        };
      };
      options?: {
        data?: {
          /** @example 93da65a9fd0004d9477aeac024e08e15 */
          id?: string;
          /** @example swag_customized_products_template_option */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-customized-products-template/4751e4cb483e992aa073494b9cfa9be6/options
           */
          related?: string;
        };
      };
      products?: {
        data?: {
          /** @example 86024cad1e83101d97359d7351051156 */
          id?: string;
          /** @example product */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-customized-products-template/4751e4cb483e992aa073494b9cfa9be6/products
           */
          related?: string;
        };
      };
    };
    stepByStep?: boolean;
    translated: {
      description: string;
      displayName: string;
      internalName: string;
      mediaId: string;
      parentVersionId: string;
      versionId: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  SwagCustomizedProductsTemplateOption: {
    advancedSurcharge?: boolean;
    calculatedPrice?: GenericRecord;
    /** Format: date-time */
    readonly createdAt?: string;
    description?: string;
    displayName: string;
    id: string;
    itemNumber?: string;
    oneTimeSurcharge?: boolean;
    /** Format: float */
    percentageSurcharge?: number;
    placeholder?: string;
    /** Format: int64 */
    position?: number;
    price?: components["schemas"]["Price"][];
    prices?: components["schemas"]["SwagCustomizedProductsTemplateOptionPrice"][];
    relativeSurcharge?: boolean;
    required?: boolean;
    tax?: components["schemas"]["Tax"];
    taxId?: string;
    template?: components["schemas"]["SwagCustomizedProductsTemplate"];
    templateExclusionConditions?: components["schemas"]["SwagCustomizedProductsTemplateExclusionCondition"][];
    templateId: string;
    templateVersionId?: string;
    translated: {
      description: string;
      displayName: string;
      itemNumber: string;
      placeholder: string;
      taxId: string;
      templateId: string;
      templateVersionId: string;
      type: string;
      versionId: string;
    };
    type: string;
    typeProperties?: GenericRecord;
    /** Format: date-time */
    readonly updatedAt?: string;
    values?: components["schemas"]["SwagCustomizedProductsTemplateOptionValue"][];
    versionId?: string;
  };
  SwagCustomizedProductsTemplateOptionJsonApi: components["schemas"]["resource"] & {
    advancedSurcharge?: boolean;
    calculatedPrice?: GenericRecord;
    /** Format: date-time */
    readonly createdAt?: string;
    description?: string;
    displayName: string;
    id: string;
    itemNumber?: string;
    oneTimeSurcharge?: boolean;
    /** Format: float */
    percentageSurcharge?: number;
    placeholder?: string;
    /** Format: int64 */
    position?: number;
    price?: components["schemas"]["Price"][];
    relationships?: {
      prices?: {
        data?: {
          /** @example afae32efe0f84fece3f96b377b768b33 */
          id?: string;
          /** @example swag_customized_products_template_option_price */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-customized-products-template-option/6342f0c20b443cb5408ec0fc12430bcb/prices
           */
          related?: string;
        };
      };
      tax?: {
        data?: {
          /** @example 06565e5611f23fdf8cc43e5077b92b54 */
          id?: string;
          /** @example tax */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-customized-products-template-option/6342f0c20b443cb5408ec0fc12430bcb/tax
           */
          related?: string;
        };
      };
      template?: {
        data?: {
          /** @example 66f6181bcb4cff4cd38fbc804a036db6 */
          id?: string;
          /** @example swag_customized_products_template */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-customized-products-template-option/6342f0c20b443cb5408ec0fc12430bcb/template
           */
          related?: string;
        };
      };
      templateExclusionConditions?: {
        data?: {
          /** @example 57e853a74b92e339ec2e302b015e60f3 */
          id?: string;
          /** @example swag_customized_products_template_exclusion_condition */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-customized-products-template-option/6342f0c20b443cb5408ec0fc12430bcb/templateExclusionConditions
           */
          related?: string;
        };
      };
      values?: {
        data?: {
          /** @example f09cc7ee3a9a93273f4b80601cafb00c */
          id?: string;
          /** @example swag_customized_products_template_option_value */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-customized-products-template-option/6342f0c20b443cb5408ec0fc12430bcb/values
           */
          related?: string;
        };
      };
    };
    relativeSurcharge?: boolean;
    required?: boolean;
    taxId?: string;
    templateId: string;
    templateVersionId?: string;
    translated: {
      description: string;
      displayName: string;
      itemNumber: string;
      placeholder: string;
      taxId: string;
      templateId: string;
      templateVersionId: string;
      type: string;
      versionId: string;
    };
    type: string;
    typeProperties?: GenericRecord;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  SwagCustomizedProductsTemplateOptionPrice: {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    /** Format: float */
    percentageSurcharge?: number;
    price?: components["schemas"]["Price"][];
    rule?: components["schemas"]["Rule"];
    ruleId?: string;
    templateOption?: components["schemas"]["SwagCustomizedProductsTemplateOption"];
    templateOptionId: string;
    templateOptionVersionId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  SwagCustomizedProductsTemplateOptionPriceJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    /** Format: float */
    percentageSurcharge?: number;
    price?: components["schemas"]["Price"][];
    relationships?: {
      rule?: {
        data?: {
          /** @example 981c1e7b3795da18687613fbd66d4954 */
          id?: string;
          /** @example rule */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-customized-products-template-option-price/a27c46432f56bc59ae059a4bfe5145c0/rule
           */
          related?: string;
        };
      };
      templateOption?: {
        data?: {
          /** @example 6891a002a90a39e71e67c4fc148db8df */
          id?: string;
          /** @example swag_customized_products_template_option */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-customized-products-template-option-price/a27c46432f56bc59ae059a4bfe5145c0/templateOption
           */
          related?: string;
        };
      };
    };
    ruleId?: string;
    templateOptionId: string;
    templateOptionVersionId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  SwagCustomizedProductsTemplateOptionValue: {
    advancedSurcharge?: boolean;
    /** Format: date-time */
    readonly createdAt?: string;
    default?: boolean;
    displayName: string;
    id: string;
    itemNumber?: string;
    oneTimeSurcharge?: boolean;
    /** Format: float */
    percentageSurcharge?: number;
    /** Format: int64 */
    position: number;
    price?: components["schemas"]["Price"][];
    prices?: components["schemas"]["SwagCustomizedProductsTemplateOptionValuePrice"][];
    relativeSurcharge?: boolean;
    tax?: components["schemas"]["Tax"];
    taxId?: string;
    templateExclusionConditions?: components["schemas"]["SwagCustomizedProductsTemplateExclusionCondition"][];
    templateOption?: components["schemas"]["SwagCustomizedProductsTemplateOption"];
    templateOptionId: string;
    templateOptionVersionId?: string;
    translated: {
      displayName: string;
      itemNumber: string;
      taxId: string;
      templateOptionId: string;
      templateOptionVersionId: string;
      versionId: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    value?: GenericRecord;
    versionId?: string;
  };
  SwagCustomizedProductsTemplateOptionValueJsonApi: components["schemas"]["resource"] & {
    advancedSurcharge?: boolean;
    /** Format: date-time */
    readonly createdAt?: string;
    default?: boolean;
    displayName: string;
    id: string;
    itemNumber?: string;
    oneTimeSurcharge?: boolean;
    /** Format: float */
    percentageSurcharge?: number;
    /** Format: int64 */
    position: number;
    price?: components["schemas"]["Price"][];
    relationships?: {
      prices?: {
        data?: {
          /** @example afae32efe0f84fece3f96b377b768b33 */
          id?: string;
          /** @example swag_customized_products_template_option_value_price */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-customized-products-template-option-value/b57f26a8362182be3e67a815927b7f37/prices
           */
          related?: string;
        };
      };
      tax?: {
        data?: {
          /** @example 06565e5611f23fdf8cc43e5077b92b54 */
          id?: string;
          /** @example tax */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-customized-products-template-option-value/b57f26a8362182be3e67a815927b7f37/tax
           */
          related?: string;
        };
      };
      templateExclusionConditions?: {
        data?: {
          /** @example 57e853a74b92e339ec2e302b015e60f3 */
          id?: string;
          /** @example swag_customized_products_template_exclusion_condition */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-customized-products-template-option-value/b57f26a8362182be3e67a815927b7f37/templateExclusionConditions
           */
          related?: string;
        };
      };
      templateOption?: {
        data?: {
          /** @example 6891a002a90a39e71e67c4fc148db8df */
          id?: string;
          /** @example swag_customized_products_template_option */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-customized-products-template-option-value/b57f26a8362182be3e67a815927b7f37/templateOption
           */
          related?: string;
        };
      };
    };
    relativeSurcharge?: boolean;
    taxId?: string;
    templateOptionId: string;
    templateOptionVersionId?: string;
    translated: {
      displayName: string;
      itemNumber: string;
      taxId: string;
      templateOptionId: string;
      templateOptionVersionId: string;
      versionId: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    value?: GenericRecord;
    versionId?: string;
  };
  SwagCustomizedProductsTemplateOptionValuePrice: {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    /** Format: float */
    percentageSurcharge?: number;
    price?: components["schemas"]["Price"][];
    rule?: components["schemas"]["Rule"];
    ruleId?: string;
    templateOptionValue?: components["schemas"]["SwagCustomizedProductsTemplateOptionValue"];
    templateOptionValueId: string;
    templateOptionValueVersionId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  SwagCustomizedProductsTemplateOptionValuePriceJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    /** Format: float */
    percentageSurcharge?: number;
    price?: components["schemas"]["Price"][];
    relationships?: {
      rule?: {
        data?: {
          /** @example 981c1e7b3795da18687613fbd66d4954 */
          id?: string;
          /** @example rule */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-customized-products-template-option-value-price/db366966e64f89b2bba004a12d76d7af/rule
           */
          related?: string;
        };
      };
      templateOptionValue?: {
        data?: {
          /** @example 376d05104f693cb58e93bed5fe8a7cad */
          id?: string;
          /** @example swag_customized_products_template_option_value */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-customized-products-template-option-value-price/db366966e64f89b2bba004a12d76d7af/templateOptionValue
           */
          related?: string;
        };
      };
    };
    ruleId?: string;
    templateOptionValueId: string;
    templateOptionValueVersionId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  SwagDelayAction: {
    /** Format: date-time */
    readonly createdAt?: string;
    customer?: components["schemas"]["Customer"];
    customerId?: string;
    delaySequenceId?: string;
    eventName?: string;
    /** Format: date-time */
    executionTime: string;
    expired?: boolean;
    flow?: components["schemas"]["Flow"];
    flowId: string;
    id: string;
    order?: components["schemas"]["Order"];
    orderId?: string;
    orderVersionId?: string;
    sequence?: components["schemas"]["FlowSequence"];
    stored: GenericRecord;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagDelayActionJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    customerId?: string;
    delaySequenceId?: string;
    eventName?: string;
    /** Format: date-time */
    executionTime: string;
    expired?: boolean;
    flowId: string;
    id: string;
    orderId?: string;
    orderVersionId?: string;
    relationships?: {
      customer?: {
        data?: {
          /** @example 91ec1f9324753048c0096d036a694f86 */
          id?: string;
          /** @example customer */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-delay-action/70d03dd9ed2b3fc83b562c9baae3df7b/customer
           */
          related?: string;
        };
      };
      flow?: {
        data?: {
          /** @example cff5497121104c2b8e0cb41ed2083a9b */
          id?: string;
          /** @example flow */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-delay-action/70d03dd9ed2b3fc83b562c9baae3df7b/flow
           */
          related?: string;
        };
      };
      order?: {
        data?: {
          /** @example 70a17ffa722a3985b86d30b034ad06d7 */
          id?: string;
          /** @example order */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-delay-action/70d03dd9ed2b3fc83b562c9baae3df7b/order
           */
          related?: string;
        };
      };
      sequence?: {
        data?: {
          /** @example fa1c731ead93e333a9180e16f968c01e */
          id?: string;
          /** @example flow_sequence */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-delay-action/70d03dd9ed2b3fc83b562c9baae3df7b/sequence
           */
          related?: string;
        };
      };
    };
    stored: GenericRecord;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagDynamicAccessCategoryRule: {
    category?: components["schemas"]["Category"];
    categoryId: string;
    categoryVersionId?: string;
    id?: string;
    rule?: components["schemas"]["Rule"];
    ruleId: string;
  };
  SwagDynamicAccessLandingPageRule: {
    id?: string;
    landingPage?: components["schemas"]["LandingPage"];
    landingPageId: string;
    landingPageVersionId?: string;
    rule?: components["schemas"]["Rule"];
    ruleId: string;
  };
  SwagDynamicAccessProductRule: {
    id?: string;
    product?: components["schemas"]["Product"];
    productId: string;
    productVersionId?: string;
    rule?: components["schemas"]["Rule"];
    ruleId: string;
  };
  SwagLanguagePackLanguage: {
    administrationActive?: boolean;
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    language?: components["schemas"]["Language"];
    languageId: string;
    salesChannelActive?: boolean;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagLanguagePackLanguageJsonApi: components["schemas"]["resource"] & {
    administrationActive?: boolean;
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    languageId: string;
    relationships?: {
      language?: {
        data?: {
          /** @example 8512ae7d57b1396273f76fe6ed341a23 */
          id?: string;
          /** @example language */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-language-pack-language/a31be60242ded43ddd1a483395e69359/language
           */
          related?: string;
        };
      };
    };
    salesChannelActive?: boolean;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagMigrationConnection: {
    /** Format: date-time */
    readonly createdAt?: string;
    readonly credentialFields?: GenericRecord;
    gatewayName: string;
    id: string;
    mappings?: components["schemas"]["SwagMigrationMapping"][];
    name: string;
    premapping?: GenericRecord;
    profileName: string;
    runs?: components["schemas"]["SwagMigrationRun"][];
    settings?: components["schemas"]["SwagMigrationGeneralSetting"][];
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagMigrationConnectionJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    readonly credentialFields?: GenericRecord;
    gatewayName: string;
    id: string;
    name: string;
    premapping?: GenericRecord;
    profileName: string;
    relationships?: {
      mappings?: {
        data?: {
          /** @example d8e23b791f4ced4d23db067b32520236 */
          id?: string;
          /** @example swag_migration_mapping */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-migration-connection/9b4cd5ca287134a108c3d94d44ed2e05/mappings
           */
          related?: string;
        };
      };
      runs?: {
        data?: {
          /** @example 878983117a2370e5b702db49786da067 */
          id?: string;
          /** @example swag_migration_run */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-migration-connection/9b4cd5ca287134a108c3d94d44ed2e05/runs
           */
          related?: string;
        };
      };
      settings?: {
        data?: {
          /** @example 2e5d8aa3dfa8ef34ca5131d20f9dad51 */
          id?: string;
          /** @example swag_migration_general_setting */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-migration-connection/9b4cd5ca287134a108c3d94d44ed2e05/settings
           */
          related?: string;
        };
      };
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagMigrationData: {
    /** Format: int64 */
    readonly autoIncrement?: number;
    converted?: GenericRecord;
    convertFailure?: boolean;
    /** Format: date-time */
    readonly createdAt?: string;
    entity: string;
    id: string;
    mappingUuid?: string;
    raw: GenericRecord;
    run?: components["schemas"]["SwagMigrationRun"];
    runId: string;
    unmapped?: GenericRecord;
    /** Format: date-time */
    readonly updatedAt?: string;
    writeFailure?: boolean;
    written?: boolean;
  };
  SwagMigrationDataJsonApi: components["schemas"]["resource"] & {
    /** Format: int64 */
    readonly autoIncrement?: number;
    converted?: GenericRecord;
    convertFailure?: boolean;
    /** Format: date-time */
    readonly createdAt?: string;
    entity: string;
    id: string;
    mappingUuid?: string;
    raw: GenericRecord;
    relationships?: {
      run?: {
        data?: {
          /** @example a53108f7543b75adbb34afc035d4cdf6 */
          id?: string;
          /** @example swag_migration_run */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-migration-data/ef2fb6f2b4f336b801810dd506c09a28/run
           */
          related?: string;
        };
      };
    };
    runId: string;
    unmapped?: GenericRecord;
    /** Format: date-time */
    readonly updatedAt?: string;
    writeFailure?: boolean;
    written?: boolean;
  };
  SwagMigrationGeneralSetting: {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    isReset?: boolean;
    selectedConnection?: components["schemas"]["SwagMigrationConnection"];
    selectedConnectionId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagMigrationGeneralSettingJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    isReset?: boolean;
    relationships?: {
      selectedConnection?: {
        data?: {
          /** @example 82d96df3e87e20b1f52236d17e286761 */
          id?: string;
          /** @example swag_migration_connection */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-migration-general-setting/7739a73800e4f4674c4c550f9c2af035/selectedConnection
           */
          related?: string;
        };
      };
    };
    selectedConnectionId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagMigrationLogging: {
    /** Format: int64 */
    readonly autoIncrement?: number;
    code: string;
    /** Format: date-time */
    readonly createdAt?: string;
    description: string;
    descriptionSnippet: string;
    entity?: string;
    id: string;
    level: string;
    parameters: GenericRecord;
    run?: components["schemas"]["SwagMigrationRun"];
    runId?: string;
    sourceId?: string;
    title: string;
    titleSnippet: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagMigrationLoggingJsonApi: components["schemas"]["resource"] & {
    /** Format: int64 */
    readonly autoIncrement?: number;
    code: string;
    /** Format: date-time */
    readonly createdAt?: string;
    description: string;
    descriptionSnippet: string;
    entity?: string;
    id: string;
    level: string;
    parameters: GenericRecord;
    relationships?: {
      run?: {
        data?: {
          /** @example a53108f7543b75adbb34afc035d4cdf6 */
          id?: string;
          /** @example swag_migration_run */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-migration-logging/ae841195106900928cb59970ff05b1b2/run
           */
          related?: string;
        };
      };
    };
    runId?: string;
    sourceId?: string;
    title: string;
    titleSnippet: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagMigrationMapping: {
    additionalData?: GenericRecord;
    checksum?: string;
    connection?: components["schemas"]["SwagMigrationConnection"];
    connectionId: string;
    /** Format: date-time */
    readonly createdAt?: string;
    entity: string;
    entityUuid?: string;
    entityValue?: string;
    id: string;
    oldIdentifier?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagMigrationMappingJsonApi: components["schemas"]["resource"] & {
    additionalData?: GenericRecord;
    checksum?: string;
    connectionId: string;
    /** Format: date-time */
    readonly createdAt?: string;
    entity: string;
    entityUuid?: string;
    entityValue?: string;
    id: string;
    oldIdentifier?: string;
    relationships?: {
      connection?: {
        data?: {
          /** @example 4717d53ebfdfea8477f780ec66151dcb */
          id?: string;
          /** @example swag_migration_connection */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-migration-mapping/804cc61b5d3a72021ea5d6f60fa7a450/connection
           */
          related?: string;
        };
      };
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagMigrationMediaFile: {
    /** Format: date-time */
    readonly createdAt?: string;
    entity: string;
    fileName: string;
    /** Format: int64 */
    fileSize: number;
    id: string;
    mediaId: string;
    processed?: boolean;
    processFailure?: boolean;
    run?: components["schemas"]["SwagMigrationRun"];
    runId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    uri: string;
    written?: boolean;
  };
  SwagMigrationMediaFileJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    entity: string;
    fileName: string;
    /** Format: int64 */
    fileSize: number;
    id: string;
    mediaId: string;
    processed?: boolean;
    processFailure?: boolean;
    relationships?: {
      run?: {
        data?: {
          /** @example a53108f7543b75adbb34afc035d4cdf6 */
          id?: string;
          /** @example swag_migration_run */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-migration-media-file/8915313832bc55b48888b768abe6f87c/run
           */
          related?: string;
        };
      };
    };
    runId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    uri: string;
    written?: boolean;
  };
  SwagMigrationRun: {
    connection?: components["schemas"]["SwagMigrationConnection"];
    connectionId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    data?: components["schemas"]["SwagMigrationData"][];
    environmentInformation?: GenericRecord;
    id: string;
    logs?: components["schemas"]["SwagMigrationLogging"][];
    mediaFiles?: components["schemas"]["SwagMigrationMediaFile"][];
    progress?: {
      currentEntity: string;
      /** Format: int64 */
      currentEntityProgress: number;
      dataSets?: GenericRecord[];
      /** Format: int64 */
      exceptionCount: number;
      isAborted: boolean;
      /** Format: int64 */
      progress: number;
      /** Format: int64 */
      total: number;
    };
    step: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagMigrationRunJsonApi: components["schemas"]["resource"] & {
    connectionId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    environmentInformation?: GenericRecord;
    id: string;
    progress?: {
      currentEntity: string;
      /** Format: int64 */
      currentEntityProgress: number;
      dataSets?: GenericRecord[];
      /** Format: int64 */
      exceptionCount: number;
      isAborted: boolean;
      /** Format: int64 */
      progress: number;
      /** Format: int64 */
      total: number;
    };
    relationships?: {
      connection?: {
        data?: {
          /** @example 4717d53ebfdfea8477f780ec66151dcb */
          id?: string;
          /** @example swag_migration_connection */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-migration-run/dc7ebb549cf146b2f3bc154621cf4d2f/connection
           */
          related?: string;
        };
      };
      data?: {
        data?: {
          /** @example 8d777f385d3dfec8815d20f7496026dc */
          id?: string;
          /** @example swag_migration_data */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-migration-run/dc7ebb549cf146b2f3bc154621cf4d2f/data
           */
          related?: string;
        };
      };
      logs?: {
        data?: {
          /** @example 2165e4fa5bddb65a31f6a0c495c2fa37 */
          id?: string;
          /** @example swag_migration_logging */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-migration-run/dc7ebb549cf146b2f3bc154621cf4d2f/logs
           */
          related?: string;
        };
      };
      mediaFiles?: {
        data?: {
          /** @example 0ff9a5da8eb40da0b7784847ec9d83e8 */
          id?: string;
          /** @example swag_migration_media_file */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-migration-run/dc7ebb549cf146b2f3bc154621cf4d2f/mediaFiles
           */
          related?: string;
        };
      };
    };
    step: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagPaypalPosSalesChannel: {
    apiKey: string;
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    mediaDomain?: string;
    productStream?: components["schemas"]["ProductStream"];
    productStreamId?: string;
    /** Format: int64 */
    replace?: number;
    salesChannel?: components["schemas"]["SalesChannel"];
    salesChannelId: string;
    syncPrices?: boolean;
    /** Format: date-time */
    readonly updatedAt?: string;
    webhookSigningKey?: string;
  };
  SwagPaypalPosSalesChannelInventory: {
    id?: string;
    product?: components["schemas"]["Product"];
    productId: string;
    productVersionId?: string;
    salesChannelId: string;
    /** Format: int64 */
    stock: number;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagPaypalPosSalesChannelJsonApi: components["schemas"]["resource"] & {
    apiKey: string;
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    mediaDomain?: string;
    productStreamId?: string;
    relationships?: {
      productStream?: {
        data?: {
          /** @example 49561f6faa0badfce831a183d2ec7c2f */
          id?: string;
          /** @example product_stream */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-paypal-pos-sales-channel/132fed17638687e1cc65e90247be70f7/productStream
           */
          related?: string;
        };
      };
      salesChannel?: {
        data?: {
          /** @example ec3712a84143b57e0db620eaac6e55b8 */
          id?: string;
          /** @example sales_channel */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-paypal-pos-sales-channel/132fed17638687e1cc65e90247be70f7/salesChannel
           */
          related?: string;
        };
      };
    };
    /** Format: int64 */
    replace?: number;
    salesChannelId: string;
    syncPrices?: boolean;
    /** Format: date-time */
    readonly updatedAt?: string;
    webhookSigningKey?: string;
  };
  SwagPaypalPosSalesChannelMedia: {
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    lookupKey?: string;
    media?: components["schemas"]["Media"];
    mediaId: string;
    salesChannelId: string;
    url?: string;
  };
  SwagPaypalPosSalesChannelProduct: {
    checksum: string;
    /** Format: date-time */
    readonly createdAt?: string;
    id?: string;
    product?: components["schemas"]["Product"];
    productId: string;
    productVersionId?: string;
    salesChannelId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagPaypalPosSalesChannelRun: {
    /** Format: date-time */
    readonly createdAt?: string;
    /** Format: date-time */
    finishedAt?: string;
    id: string;
    logs?: components["schemas"]["SwagPaypalPosSalesChannelRunLog"][];
    /** Format: int64 */
    messageCount?: number;
    salesChannelId: string;
    status?: string;
    /** Format: int64 */
    stepIndex?: number;
    steps: GenericRecord;
    task: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagPaypalPosSalesChannelRunJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    /** Format: date-time */
    finishedAt?: string;
    id: string;
    /** Format: int64 */
    messageCount?: number;
    relationships?: {
      logs?: {
        data?: {
          /** @example 2165e4fa5bddb65a31f6a0c495c2fa37 */
          id?: string;
          /** @example swag_paypal_pos_sales_channel_run_log */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-paypal-pos-sales-channel-run/b76976c435509bec6879d50ac4d90782/logs
           */
          related?: string;
        };
      };
    };
    salesChannelId: string;
    status?: string;
    /** Format: int64 */
    stepIndex?: number;
    steps: GenericRecord;
    task: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagPaypalPosSalesChannelRunLog: {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    /** Format: int64 */
    level: number;
    message: string;
    posSalesChannelRun?: components["schemas"]["SwagPaypalPosSalesChannelRun"];
    productId?: string;
    productVersionId?: string;
    runId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagPaypalPosSalesChannelRunLogJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    /** Format: int64 */
    level: number;
    message: string;
    productId?: string;
    productVersionId?: string;
    relationships?: {
      posSalesChannelRun?: {
        data?: {
          /** @example 140259e47ae052d4bb99572342db1448 */
          id?: string;
          /** @example swag_paypal_pos_sales_channel_run */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-paypal-pos-sales-channel-run-log/b0323556f4973e4d61a168a39cbed319/posSalesChannelRun
           */
          related?: string;
        };
      };
    };
    runId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagPaypalTransactionReport: {
    /** Format: date-time */
    readonly createdAt?: string;
    currencyIso: string;
    id?: string;
    orderTransaction?: components["schemas"]["OrderTransaction"];
    orderTransactionId: string;
    orderTransactionVersionId?: string;
    /** Format: float */
    totalPrice: number;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagPaypalTransactionReportJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    currencyIso: string;
    id?: string;
    orderTransactionId: string;
    orderTransactionVersionId?: string;
    relationships?: {
      orderTransaction?: {
        data?: {
          /** @example 7d80e6b0ba7e22cf746c767f19873b8f */
          id?: string;
          /** @example order_transaction */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-paypal-transaction-report/02de0229f33a31b3839208f09069fadd/orderTransaction
           */
          related?: string;
        };
      };
    };
    /** Format: float */
    totalPrice: number;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagPaypalVaultToken: {
    /** Format: date-time */
    readonly createdAt?: string;
    customer?: components["schemas"]["Customer"];
    customerId: string;
    id: string;
    identifier: string;
    mainMapping?: components["schemas"]["SwagPaypalVaultTokenMapping"];
    paymentMethod?: components["schemas"]["PaymentMethod"];
    paymentMethodId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagPaypalVaultTokenJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    customerId: string;
    id: string;
    identifier: string;
    paymentMethodId: string;
    relationships?: {
      customer?: {
        data?: {
          /** @example 91ec1f9324753048c0096d036a694f86 */
          id?: string;
          /** @example customer */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-paypal-vault-token/fde7456018e5f3d68d7f7cedd814c892/customer
           */
          related?: string;
        };
      };
      mainMapping?: {
        data?: {
          /** @example e8768174312011419754aa9085d8a9d7 */
          id?: string;
          /** @example swag_paypal_vault_token_mapping */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-paypal-vault-token/fde7456018e5f3d68d7f7cedd814c892/mainMapping
           */
          related?: string;
        };
      };
      paymentMethod?: {
        data?: {
          /** @example 68ec1eeea9f1b7744e231b5bd0d97df0 */
          id?: string;
          /** @example payment_method */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-paypal-vault-token/fde7456018e5f3d68d7f7cedd814c892/paymentMethod
           */
          related?: string;
        };
      };
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagPaypalVaultTokenMapping: {
    /** Format: date-time */
    readonly createdAt?: string;
    customer?: components["schemas"]["Customer"];
    customerId: string;
    id?: string;
    paymentMethod?: components["schemas"]["PaymentMethod"];
    paymentMethodId: string;
    token?: components["schemas"]["SwagPaypalVaultToken"];
    tokenId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagPaypalVaultTokenMappingJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    customerId: string;
    id?: string;
    paymentMethodId: string;
    relationships?: {
      customer?: {
        data?: {
          /** @example 91ec1f9324753048c0096d036a694f86 */
          id?: string;
          /** @example customer */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-paypal-vault-token-mapping/f80653150e29d7e8e53a0a345ee5a75f/customer
           */
          related?: string;
        };
      };
      paymentMethod?: {
        data?: {
          /** @example 68ec1eeea9f1b7744e231b5bd0d97df0 */
          id?: string;
          /** @example payment_method */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-paypal-vault-token-mapping/f80653150e29d7e8e53a0a345ee5a75f/paymentMethod
           */
          related?: string;
        };
      };
      token?: {
        data?: {
          /** @example 94a08da1fecbb6e8b46990538c7b50b2 */
          id?: string;
          /** @example swag_paypal_vault_token */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-paypal-vault-token-mapping/f80653150e29d7e8e53a0a345ee5a75f/token
           */
          related?: string;
        };
      };
    };
    tokenId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagSequenceWebhookEventLog: {
    flowSequence?: components["schemas"]["FlowSequence"];
    id?: string;
    sequenceId: string;
    webhookEventLog?: components["schemas"]["WebhookEventLog"];
    webhookEventLogId: string;
  };
  SwagSocialShoppingCustomer: {
    /** Format: date-time */
    readonly createdAt?: string;
    customer?: components["schemas"]["Customer"];
    customerId: string;
    id: string;
    referralCode: string;
    salesChannel?: components["schemas"]["SalesChannel"];
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagSocialShoppingCustomerJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    customerId: string;
    id: string;
    referralCode: string;
    relationships?: {
      customer?: {
        data?: {
          /** @example 91ec1f9324753048c0096d036a694f86 */
          id?: string;
          /** @example customer */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-social-shopping-customer/dd006533dded680c6de287a39d562c04/customer
           */
          related?: string;
        };
      };
      salesChannel?: {
        data?: {
          /** @example ec3712a84143b57e0db620eaac6e55b8 */
          id?: string;
          /** @example sales_channel */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-social-shopping-customer/dd006533dded680c6de287a39d562c04/salesChannel
           */
          related?: string;
        };
      };
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagSocialShoppingOrder: {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    order?: components["schemas"]["Order"];
    orderId: string;
    orderVersionId?: string;
    referralCode: string;
    salesChannel?: components["schemas"]["SalesChannel"];
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  SwagSocialShoppingOrderJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    orderId: string;
    orderVersionId?: string;
    referralCode: string;
    relationships?: {
      order?: {
        data?: {
          /** @example 70a17ffa722a3985b86d30b034ad06d7 */
          id?: string;
          /** @example order */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-social-shopping-order/dbc494901d9806bb09916e7bc87fa549/order
           */
          related?: string;
        };
      };
      salesChannel?: {
        data?: {
          /** @example ec3712a84143b57e0db620eaac6e55b8 */
          id?: string;
          /** @example sales_channel */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-social-shopping-order/dbc494901d9806bb09916e7bc87fa549/salesChannel
           */
          related?: string;
        };
      };
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    versionId?: string;
  };
  SwagSocialShoppingProductError: {
    /** Format: date-time */
    readonly createdAt?: string;
    errors: GenericRecord;
    id: string;
    product?: components["schemas"]["Product"];
    productId: string;
    productVersionId?: string;
    salesChannel?: components["schemas"]["SalesChannel"];
    salesChannelId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagSocialShoppingProductErrorJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    errors: GenericRecord;
    id: string;
    productId: string;
    productVersionId?: string;
    relationships?: {
      product?: {
        data?: {
          /** @example f5bf48aa40cad7891eb709fcf1fde128 */
          id?: string;
          /** @example product */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-social-shopping-product-error/da06f26280a08ad5cc8dc81990613070/product
           */
          related?: string;
        };
      };
      salesChannel?: {
        data?: {
          /** @example ec3712a84143b57e0db620eaac6e55b8 */
          id?: string;
          /** @example sales_channel */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-social-shopping-product-error/da06f26280a08ad5cc8dc81990613070/salesChannel
           */
          related?: string;
        };
      };
    };
    salesChannelId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagSocialShoppingSalesChannel: {
    configuration?: GenericRecord;
    /** Format: date-time */
    readonly createdAt?: string;
    currency?: components["schemas"]["Currency"];
    currencyId?: string;
    id: string;
    isValidating?: boolean;
    /** Format: date-time */
    lastValidation?: string;
    network: string;
    productStream?: components["schemas"]["ProductStream"];
    productStreamId?: string;
    salesChannel?: components["schemas"]["SalesChannel"];
    salesChannelDomain?: components["schemas"]["SalesChannelDomain"];
    salesChannelDomainId: string;
    salesChannelId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SwagSocialShoppingSalesChannelJsonApi: components["schemas"]["resource"] & {
    configuration?: GenericRecord;
    /** Format: date-time */
    readonly createdAt?: string;
    currencyId?: string;
    id: string;
    isValidating?: boolean;
    /** Format: date-time */
    lastValidation?: string;
    network: string;
    productStreamId?: string;
    relationships?: {
      currency?: {
        data?: {
          /** @example 1af0389838508d7016a9841eb6273962 */
          id?: string;
          /** @example currency */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-social-shopping-sales-channel/4fd0d9d0cef562d4ab72dd4b2818e4d9/currency
           */
          related?: string;
        };
      };
      productStream?: {
        data?: {
          /** @example 49561f6faa0badfce831a183d2ec7c2f */
          id?: string;
          /** @example product_stream */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-social-shopping-sales-channel/4fd0d9d0cef562d4ab72dd4b2818e4d9/productStream
           */
          related?: string;
        };
      };
      salesChannel?: {
        data?: {
          /** @example ec3712a84143b57e0db620eaac6e55b8 */
          id?: string;
          /** @example sales_channel */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-social-shopping-sales-channel/4fd0d9d0cef562d4ab72dd4b2818e4d9/salesChannel
           */
          related?: string;
        };
      };
      salesChannelDomain?: {
        data?: {
          /** @example 29c8b34b04e94e35e95e8346954b7fb4 */
          id?: string;
          /** @example sales_channel_domain */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /swag-social-shopping-sales-channel/4fd0d9d0cef562d4ab72dd4b2818e4d9/salesChannelDomain
           */
          related?: string;
        };
      };
    };
    salesChannelDomainId: string;
    salesChannelId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SystemConfig: {
    configurationKey: string;
    configurationValue: {
      _value?: GenericRecord;
    };
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    salesChannel?: components["schemas"]["SalesChannel"];
    salesChannelId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  SystemConfigJsonApi: components["schemas"]["resource"] & {
    configurationKey: string;
    configurationValue: {
      _value?: GenericRecord;
    };
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    relationships?: {
      salesChannel?: {
        data?: {
          /** @example ec3712a84143b57e0db620eaac6e55b8 */
          id?: string;
          /** @example sales_channel */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /system-config/a59948b9e45358eaaaa1b13d9cedc248/salesChannel
           */
          related?: string;
        };
      };
    };
    salesChannelId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  Tag: {
    categories?: components["schemas"]["Category"][];
    /** Format: date-time */
    readonly createdAt?: string;
    customers?: components["schemas"]["Customer"][];
    extensions?: {
      subscriptions?: {
        data?: {
          /** @example 2d5d14f95af035cbd8437948de61f94c */
          id?: string;
          /** @example subscription */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /tag/c101058e7ea21bbbf2a5ac893088e90b/subscriptions
           */
          related?: string;
        };
      };
    };
    id: string;
    landingPages?: components["schemas"]["LandingPage"][];
    media?: components["schemas"]["Media"][];
    name: string;
    newsletterRecipients?: components["schemas"]["NewsletterRecipient"][];
    orders?: components["schemas"]["Order"][];
    products?: components["schemas"]["Product"][];
    rules?: components["schemas"]["Rule"][];
    shippingMethods?: components["schemas"]["ShippingMethod"][];
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  TagJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    extensions?: {
      subscriptions?: {
        data?: {
          /** @example 2d5d14f95af035cbd8437948de61f94c */
          id?: string;
          /** @example subscription */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /tag/c101058e7ea21bbbf2a5ac893088e90b/subscriptions
           */
          related?: string;
        };
      };
    };
    id: string;
    name: string;
    relationships?: {
      categories?: {
        data?: {
          /** @example b0b5ccb4a195a07fd3eed14affb8695f */
          id?: string;
          /** @example category */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /tag/c101058e7ea21bbbf2a5ac893088e90b/categories
           */
          related?: string;
        };
      };
      customers?: {
        data?: {
          /** @example 4b6f7d34a58ba399f077685951d06738 */
          id?: string;
          /** @example customer */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /tag/c101058e7ea21bbbf2a5ac893088e90b/customers
           */
          related?: string;
        };
      };
      landingPages?: {
        data?: {
          /** @example d60b77f2b3bd69591e3d5e3100926b4d */
          id?: string;
          /** @example landing_page */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /tag/c101058e7ea21bbbf2a5ac893088e90b/landingPages
           */
          related?: string;
        };
      };
      media?: {
        data?: {
          /** @example 62933a2951ef01f4eafd9bdf4d3cd2f0 */
          id?: string;
          /** @example media */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /tag/c101058e7ea21bbbf2a5ac893088e90b/media
           */
          related?: string;
        };
      };
      newsletterRecipients?: {
        data?: {
          /** @example 2217f01dc5cddfd5b60387c39867f58e */
          id?: string;
          /** @example newsletter_recipient */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /tag/c101058e7ea21bbbf2a5ac893088e90b/newsletterRecipients
           */
          related?: string;
        };
      };
      orders?: {
        data?: {
          /** @example 12c500ed0b7879105fb46af0f246be87 */
          id?: string;
          /** @example order */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /tag/c101058e7ea21bbbf2a5ac893088e90b/orders
           */
          related?: string;
        };
      };
      products?: {
        data?: {
          /** @example 86024cad1e83101d97359d7351051156 */
          id?: string;
          /** @example product */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /tag/c101058e7ea21bbbf2a5ac893088e90b/products
           */
          related?: string;
        };
      };
      rules?: {
        data?: {
          /** @example a4f86f7bfc24194b276c22e0ef158197 */
          id?: string;
          /** @example rule */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /tag/c101058e7ea21bbbf2a5ac893088e90b/rules
           */
          related?: string;
        };
      };
      shippingMethods?: {
        data?: {
          /** @example 8268b0a6c902fbde485094c2f627b854 */
          id?: string;
          /** @example shipping_method */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /tag/c101058e7ea21bbbf2a5ac893088e90b/shippingMethods
           */
          related?: string;
        };
      };
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  Tax: {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    extensions?: {
      customizedProductsOptions?: {
        data?: {
          /** @example 687cffacb8fb6b0e985310daeafaaecc */
          id?: string;
          /** @example swag_customized_products_template_option */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /tax/4b78ac8eb158840e9638a3aeb26c4a9d/customizedProductsOptions
           */
          related?: string;
        };
      };
      customizedProductsOptionValues?: {
        data?: {
          /** @example 627d98c94bb4151da667d1e9b26e9807 */
          id?: string;
          /** @example swag_customized_products_template_option_value */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /tax/4b78ac8eb158840e9638a3aeb26c4a9d/customizedProductsOptionValues
           */
          related?: string;
        };
      };
    };
    id: string;
    name: string;
    /**
     * Format: int64
     * Added since version: 6.4.0.0.
     */
    position?: number;
    products?: components["schemas"]["Product"][];
    rules?: components["schemas"]["TaxRule"][];
    shippingMethods?: components["schemas"]["ShippingMethod"][];
    /** Format: float */
    taxRate: number;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  TaxJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    extensions?: {
      customizedProductsOptions?: {
        data?: {
          /** @example 687cffacb8fb6b0e985310daeafaaecc */
          id?: string;
          /** @example swag_customized_products_template_option */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /tax/4b78ac8eb158840e9638a3aeb26c4a9d/customizedProductsOptions
           */
          related?: string;
        };
      };
      customizedProductsOptionValues?: {
        data?: {
          /** @example 627d98c94bb4151da667d1e9b26e9807 */
          id?: string;
          /** @example swag_customized_products_template_option_value */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /tax/4b78ac8eb158840e9638a3aeb26c4a9d/customizedProductsOptionValues
           */
          related?: string;
        };
      };
    };
    id: string;
    name: string;
    /**
     * Format: int64
     * Added since version: 6.4.0.0.
     */
    position?: number;
    relationships?: {
      products?: {
        data?: {
          /** @example 86024cad1e83101d97359d7351051156 */
          id?: string;
          /** @example product */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /tax/4b78ac8eb158840e9638a3aeb26c4a9d/products
           */
          related?: string;
        };
      };
      rules?: {
        data?: {
          /** @example a4f86f7bfc24194b276c22e0ef158197 */
          id?: string;
          /** @example tax_rule */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /tax/4b78ac8eb158840e9638a3aeb26c4a9d/rules
           */
          related?: string;
        };
      };
      shippingMethods?: {
        data?: {
          /** @example 8268b0a6c902fbde485094c2f627b854 */
          id?: string;
          /** @example shipping_method */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /tax/4b78ac8eb158840e9638a3aeb26c4a9d/shippingMethods
           */
          related?: string;
        };
      };
    };
    /** Format: float */
    taxRate: number;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  TaxProvider: {
    active?: boolean;
    app?: components["schemas"]["App"];
    appId?: string;
    availabilityRule?: components["schemas"]["Rule"];
    availabilityRuleId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    id: string;
    identifier: string;
    name: string;
    /** Format: int64 */
    priority: number;
    processUrl?: string;
    translated: {
      appId: string;
      availabilityRuleId: string;
      identifier: string;
      name: string;
      processUrl: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  TaxProviderJsonApi: components["schemas"]["resource"] & {
    active?: boolean;
    appId?: string;
    availabilityRuleId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    id: string;
    identifier: string;
    name: string;
    /** Format: int64 */
    priority: number;
    processUrl?: string;
    relationships?: {
      app?: {
        data?: {
          /** @example d2a57dc1d883fd21fb9951699df71cc7 */
          id?: string;
          /** @example app */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /tax-provider/c948e3fe09fafe2aa0da1b75ebbd211b/app
           */
          related?: string;
        };
      };
      availabilityRule?: {
        data?: {
          /** @example 9fbb7961d1cb158094924c679e1b302c */
          id?: string;
          /** @example rule */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /tax-provider/c948e3fe09fafe2aa0da1b75ebbd211b/availabilityRule
           */
          related?: string;
        };
      };
    };
    translated: {
      appId: string;
      availabilityRuleId: string;
      identifier: string;
      name: string;
      processUrl: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  TaxRule: {
    /** Format: date-time */
    activeFrom?: string;
    country?: components["schemas"]["Country"];
    countryId: string;
    /** Format: date-time */
    readonly createdAt?: string;
    data?: {
      fromZipCode?: string;
      states?: GenericRecord[];
      toZipCode?: string;
      zipCode?: string;
    };
    id: string;
    tax?: components["schemas"]["Tax"];
    taxId: string;
    /** Format: float */
    taxRate: number;
    taxRuleTypeId: string;
    type?: components["schemas"]["TaxRuleType"];
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  TaxRuleJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    activeFrom?: string;
    countryId: string;
    /** Format: date-time */
    readonly createdAt?: string;
    data?: {
      fromZipCode?: string;
      states?: GenericRecord[];
      toZipCode?: string;
      zipCode?: string;
    };
    id: string;
    relationships?: {
      country?: {
        data?: {
          /** @example e909c2d7067ea37437cf97fe11d91bd0 */
          id?: string;
          /** @example country */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /tax-rule/0c7d1b4f3382a39cbbf06af100fd4dc9/country
           */
          related?: string;
        };
      };
      tax?: {
        data?: {
          /** @example 06565e5611f23fdf8cc43e5077b92b54 */
          id?: string;
          /** @example tax */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /tax-rule/0c7d1b4f3382a39cbbf06af100fd4dc9/tax
           */
          related?: string;
        };
      };
      type?: {
        data?: {
          /** @example 599dcce2998a6b40b1e38e8c6006cb0a */
          id?: string;
          /** @example tax_rule_type */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /tax-rule/0c7d1b4f3382a39cbbf06af100fd4dc9/type
           */
          related?: string;
        };
      };
    };
    taxId: string;
    /** Format: float */
    taxRate: number;
    taxRuleTypeId: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  TaxRuleType: {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    /** Format: int64 */
    position: number;
    rules?: components["schemas"]["TaxRule"][];
    readonly technicalName: string;
    translated: {
      technicalName: string;
      typeName: string;
    };
    typeName: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  TaxRuleTypeJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    /** Format: int64 */
    position: number;
    relationships?: {
      rules?: {
        data?: {
          /** @example a4f86f7bfc24194b276c22e0ef158197 */
          id?: string;
          /** @example tax_rule */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /tax-rule-type/ebbaa02c602593b9fea23bc0256355fc/rules
           */
          related?: string;
        };
      };
    };
    readonly technicalName: string;
    translated: {
      technicalName: string;
      typeName: string;
    };
    typeName: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  Theme: {
    active: boolean;
    author: string;
    baseConfig?: GenericRecord;
    configValues?: GenericRecord;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    dependentThemes?: components["schemas"]["Theme"][];
    description?: string;
    helpTexts?: GenericRecord;
    id: string;
    labels?: GenericRecord;
    media?: components["schemas"]["Media"][];
    name: string;
    parentThemeId?: string;
    previewMedia?: components["schemas"]["Media"];
    previewMediaId?: string;
    salesChannels?: components["schemas"]["SalesChannel"][];
    technicalName?: string;
    themeJson?: GenericRecord;
    translated: {
      author: string;
      description: string;
      name: string;
      parentThemeId: string;
      previewMediaId: string;
      technicalName: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  ThemeChild: {
    childId: string;
    childTheme?: components["schemas"]["Theme"];
    id?: string;
    parentId: string;
    parentTheme?: components["schemas"]["Theme"];
  };
  ThemeJsonApi: components["schemas"]["resource"] & {
    active: boolean;
    author: string;
    baseConfig?: GenericRecord;
    configValues?: GenericRecord;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    description?: string;
    helpTexts?: GenericRecord;
    id: string;
    labels?: GenericRecord;
    name: string;
    parentThemeId?: string;
    previewMediaId?: string;
    relationships?: {
      dependentThemes?: {
        data?: {
          /** @example f0608e2d62b88d9b9da8d6d715b6439c */
          id?: string;
          /** @example theme */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /theme/d721757161f7f70c5b0949fdb6ec2c30/dependentThemes
           */
          related?: string;
        };
      };
      media?: {
        data?: {
          /** @example 62933a2951ef01f4eafd9bdf4d3cd2f0 */
          id?: string;
          /** @example media */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /theme/d721757161f7f70c5b0949fdb6ec2c30/media
           */
          related?: string;
        };
      };
      previewMedia?: {
        data?: {
          /** @example a7a817fb0e422cff87e878b8ff7ca914 */
          id?: string;
          /** @example media */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /theme/d721757161f7f70c5b0949fdb6ec2c30/previewMedia
           */
          related?: string;
        };
      };
      salesChannels?: {
        data?: {
          /** @example 986f6f891e90ab91c091ff4a1a460777 */
          id?: string;
          /** @example sales_channel */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /theme/d721757161f7f70c5b0949fdb6ec2c30/salesChannels
           */
          related?: string;
        };
      };
    };
    technicalName?: string;
    themeJson?: GenericRecord;
    translated: {
      author: string;
      description: string;
      name: string;
      parentThemeId: string;
      previewMediaId: string;
      technicalName: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  ThemeMedia: {
    id?: string;
    media?: components["schemas"]["Media"];
    mediaId: string;
    theme?: components["schemas"]["Theme"];
    themeId: string;
  };
  ThemeSalesChannel: {
    id?: string;
    salesChannel?: components["schemas"]["SalesChannel"];
    salesChannelId: string;
    theme?: components["schemas"]["Theme"];
    themeId: string;
  };
  Unit: {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    id: string;
    name: string;
    products?: components["schemas"]["Product"][];
    shortCode: string;
    translated: {
      name: string;
      shortCode: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  UnitJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    id: string;
    name: string;
    relationships?: {
      products?: {
        data?: {
          /** @example 86024cad1e83101d97359d7351051156 */
          id?: string;
          /** @example product */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /unit/19c562a36aeb455d09534f93b4f5236f/products
           */
          related?: string;
        };
      };
    };
    shortCode: string;
    translated: {
      name: string;
      shortCode: string;
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  User: {
    accessKeys?: components["schemas"]["UserAccessKey"][];
    aclRoles?: components["schemas"]["AclRole"][];
    active?: boolean;
    admin?: boolean;
    avatarId?: string;
    avatarMedia?: components["schemas"]["Media"];
    configs?: components["schemas"]["UserConfig"][];
    /** Format: date-time */
    readonly createdAt?: string;
    createdCustomers?: components["schemas"]["Customer"][];
    createdOrders?: components["schemas"]["Order"][];
    customFields?: GenericRecord;
    email: string;
    extensions?: {
      cmsPageActivities?: {
        data?: {
          /** @example aae7ba0db81d03df86e789e3f6cf8fe5 */
          id?: string;
          /** @example cms_page_activity */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /user/8f9bfe9d1345237cb3b2b205864da075/cmsPageActivities
           */
          related?: string;
        };
      };
      cmsPageDrafts?: {
        data?: {
          /** @example 93c0df75844858f2b2a9359abc152f5d */
          id?: string;
          /** @example cms_page_draft */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /user/8f9bfe9d1345237cb3b2b205864da075/cmsPageDrafts
           */
          related?: string;
        };
      };
      createdAppointments?: {
        data?: {
          /** @example 888e350c3c9a465bc4d7c8a80840b2aa */
          id?: string;
          /** @example dsr_appointment */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /user/8f9bfe9d1345237cb3b2b205864da075/createdAppointments
           */
          related?: string;
        };
      };
      createdLayouts?: {
        data?: {
          /** @example 22b76a69d00feab60733ea096895a432 */
          id?: string;
          /** @example cms_page */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /user/8f9bfe9d1345237cb3b2b205864da075/createdLayouts
           */
          related?: string;
        };
      };
      createdNotifications?: {
        data?: {
          /** @example 04f88ea12127fe03b65beffbc2c96954 */
          id?: string;
          /** @example notification */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /user/8f9bfe9d1345237cb3b2b205864da075/createdNotifications
           */
          related?: string;
        };
      };
      createdPresentations?: {
        data?: {
          /** @example d1e11035d87216918d95e78a7ac396da */
          id?: string;
          /** @example dsr_presentation */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /user/8f9bfe9d1345237cb3b2b205864da075/createdPresentations
           */
          related?: string;
        };
      };
      createdQuoteComments?: {
        data?: {
          /** @example 860bc13329c5b039ddeccbd9cced778d */
          id?: string;
          /** @example quote_comment */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /user/8f9bfe9d1345237cb3b2b205864da075/createdQuoteComments
           */
          related?: string;
        };
      };
      readonly demoToken?: {
        data?: {
          /** @example 69de4ff786578920993323df63a4439a */
          id?: string;
          /** @example saas_storefront_demo_token */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /user/8f9bfe9d1345237cb3b2b205864da075/demoToken
           */
          related?: string;
        };
      };
      dsrAppointmentGuideUser?: {
        data?: {
          /** @example e8e8e4db862bed157007764e46f5aecb */
          id?: string;
          /** @example dsr_appointment */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /user/8f9bfe9d1345237cb3b2b205864da075/dsrAppointmentGuideUser
           */
          related?: string;
        };
      };
      readonly loginToken?: {
        data?: {
          /** @example 4750140e5c1fe2a486703813ab519180 */
          id?: string;
          /** @example saas_user_login_token */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /user/8f9bfe9d1345237cb3b2b205864da075/loginToken
           */
          related?: string;
        };
      };
      orderReturnsCreated?: {
        data?: {
          /** @example 727aaaa1b237ca288bd73419446975b4 */
          id?: string;
          /** @example order_return */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /user/8f9bfe9d1345237cb3b2b205864da075/orderReturnsCreated
           */
          related?: string;
        };
      };
      orderReturnsUpdated?: {
        data?: {
          /** @example b236f1d18dddb0c2a359d93c25da5a20 */
          id?: string;
          /** @example order_return */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /user/8f9bfe9d1345237cb3b2b205864da075/orderReturnsUpdated
           */
          related?: string;
        };
      };
      quotes?: {
        data?: {
          /** @example 2150fd65034a9bcdb357943b3900a918 */
          id?: string;
          /** @example quote */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /user/8f9bfe9d1345237cb3b2b205864da075/quotes
           */
          related?: string;
        };
      };
      quotesAssignee?: {
        data?: {
          /** @example 1b848b0267abc056ed84fb16cb26f60a */
          id?: string;
          /** @example quote */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /user/8f9bfe9d1345237cb3b2b205864da075/quotesAssignee
           */
          related?: string;
        };
      };
      quotesUpdated?: {
        data?: {
          /** @example 58ff54114372ffbca7305b48fa25f8fc */
          id?: string;
          /** @example quote */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /user/8f9bfe9d1345237cb3b2b205864da075/quotesUpdated
           */
          related?: string;
        };
      };
      readonly sbpUserData?: {
        data?: {
          /** @example 7afee5a98234c94ed28df8d4f2f78b96 */
          id?: string;
          /** @example saas_sbp_user_data */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /user/8f9bfe9d1345237cb3b2b205864da075/sbpUserData
           */
          related?: string;
        };
      };
      updatedAppointments?: {
        data?: {
          /** @example b64277a1e650794e2c57924c07825014 */
          id?: string;
          /** @example dsr_appointment */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /user/8f9bfe9d1345237cb3b2b205864da075/updatedAppointments
           */
          related?: string;
        };
      };
      updatedPresentations?: {
        data?: {
          /** @example 49fb9c4fad69d4a3da998a936016c88d */
          id?: string;
          /** @example dsr_presentation */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /user/8f9bfe9d1345237cb3b2b205864da075/updatedPresentations
           */
          related?: string;
        };
      };
    };
    firstName: string;
    id: string;
    importExportLogEntries?: components["schemas"]["ImportExportLog"][];
    lastName: string;
    /** Format: date-time */
    lastUpdatedPasswordAt?: string;
    locale?: components["schemas"]["Locale"];
    localeId: string;
    media?: components["schemas"]["Media"][];
    recoveryUser?: components["schemas"]["UserRecovery"];
    stateMachineHistoryEntries?: components["schemas"]["StateMachineHistory"][];
    timeZone?: string;
    title?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    updatedCustomers?: components["schemas"]["Customer"][];
    updatedOrders?: components["schemas"]["Order"][];
    username: string;
  };
  UserAccessKey: {
    accessKey: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    id: string;
    /** Format: date-time */
    lastUsageAt?: string;
    secretAccessKey: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    user?: components["schemas"]["User"];
    userId: string;
  };
  UserAccessKeyJsonApi: components["schemas"]["resource"] & {
    accessKey: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    id: string;
    /** Format: date-time */
    lastUsageAt?: string;
    relationships?: {
      user?: {
        data?: {
          /** @example ee11cbb19052e40b07aac0ca060c23ee */
          id?: string;
          /** @example user */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /user-access-key/01614dd7e96bd79868128dca72e7eff8/user
           */
          related?: string;
        };
      };
    };
    secretAccessKey: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    userId: string;
  };
  UserConfig: {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    key: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    user?: components["schemas"]["User"];
    userId: string;
    value?: GenericRecord;
  };
  UserConfigJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    id: string;
    key: string;
    relationships?: {
      user?: {
        data?: {
          /** @example ee11cbb19052e40b07aac0ca060c23ee */
          id?: string;
          /** @example user */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /user-config/4b55408b66d30e27bb1593401072cd70/user
           */
          related?: string;
        };
      };
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    userId: string;
    value?: GenericRecord;
  };
  UserJsonApi: components["schemas"]["resource"] & {
    active?: boolean;
    admin?: boolean;
    avatarId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    email: string;
    extensions?: {
      cmsPageActivities?: {
        data?: {
          /** @example aae7ba0db81d03df86e789e3f6cf8fe5 */
          id?: string;
          /** @example cms_page_activity */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /user/8f9bfe9d1345237cb3b2b205864da075/cmsPageActivities
           */
          related?: string;
        };
      };
      cmsPageDrafts?: {
        data?: {
          /** @example 93c0df75844858f2b2a9359abc152f5d */
          id?: string;
          /** @example cms_page_draft */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /user/8f9bfe9d1345237cb3b2b205864da075/cmsPageDrafts
           */
          related?: string;
        };
      };
      createdAppointments?: {
        data?: {
          /** @example 888e350c3c9a465bc4d7c8a80840b2aa */
          id?: string;
          /** @example dsr_appointment */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /user/8f9bfe9d1345237cb3b2b205864da075/createdAppointments
           */
          related?: string;
        };
      };
      createdLayouts?: {
        data?: {
          /** @example 22b76a69d00feab60733ea096895a432 */
          id?: string;
          /** @example cms_page */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /user/8f9bfe9d1345237cb3b2b205864da075/createdLayouts
           */
          related?: string;
        };
      };
      createdNotifications?: {
        data?: {
          /** @example 04f88ea12127fe03b65beffbc2c96954 */
          id?: string;
          /** @example notification */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /user/8f9bfe9d1345237cb3b2b205864da075/createdNotifications
           */
          related?: string;
        };
      };
      createdPresentations?: {
        data?: {
          /** @example d1e11035d87216918d95e78a7ac396da */
          id?: string;
          /** @example dsr_presentation */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /user/8f9bfe9d1345237cb3b2b205864da075/createdPresentations
           */
          related?: string;
        };
      };
      createdQuoteComments?: {
        data?: {
          /** @example 860bc13329c5b039ddeccbd9cced778d */
          id?: string;
          /** @example quote_comment */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /user/8f9bfe9d1345237cb3b2b205864da075/createdQuoteComments
           */
          related?: string;
        };
      };
      readonly demoToken?: {
        data?: {
          /** @example 69de4ff786578920993323df63a4439a */
          id?: string;
          /** @example saas_storefront_demo_token */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /user/8f9bfe9d1345237cb3b2b205864da075/demoToken
           */
          related?: string;
        };
      };
      dsrAppointmentGuideUser?: {
        data?: {
          /** @example e8e8e4db862bed157007764e46f5aecb */
          id?: string;
          /** @example dsr_appointment */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /user/8f9bfe9d1345237cb3b2b205864da075/dsrAppointmentGuideUser
           */
          related?: string;
        };
      };
      readonly loginToken?: {
        data?: {
          /** @example 4750140e5c1fe2a486703813ab519180 */
          id?: string;
          /** @example saas_user_login_token */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /user/8f9bfe9d1345237cb3b2b205864da075/loginToken
           */
          related?: string;
        };
      };
      orderReturnsCreated?: {
        data?: {
          /** @example 727aaaa1b237ca288bd73419446975b4 */
          id?: string;
          /** @example order_return */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /user/8f9bfe9d1345237cb3b2b205864da075/orderReturnsCreated
           */
          related?: string;
        };
      };
      orderReturnsUpdated?: {
        data?: {
          /** @example b236f1d18dddb0c2a359d93c25da5a20 */
          id?: string;
          /** @example order_return */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /user/8f9bfe9d1345237cb3b2b205864da075/orderReturnsUpdated
           */
          related?: string;
        };
      };
      quotes?: {
        data?: {
          /** @example 2150fd65034a9bcdb357943b3900a918 */
          id?: string;
          /** @example quote */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /user/8f9bfe9d1345237cb3b2b205864da075/quotes
           */
          related?: string;
        };
      };
      quotesAssignee?: {
        data?: {
          /** @example 1b848b0267abc056ed84fb16cb26f60a */
          id?: string;
          /** @example quote */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /user/8f9bfe9d1345237cb3b2b205864da075/quotesAssignee
           */
          related?: string;
        };
      };
      quotesUpdated?: {
        data?: {
          /** @example 58ff54114372ffbca7305b48fa25f8fc */
          id?: string;
          /** @example quote */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /user/8f9bfe9d1345237cb3b2b205864da075/quotesUpdated
           */
          related?: string;
        };
      };
      readonly sbpUserData?: {
        data?: {
          /** @example 7afee5a98234c94ed28df8d4f2f78b96 */
          id?: string;
          /** @example saas_sbp_user_data */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /user/8f9bfe9d1345237cb3b2b205864da075/sbpUserData
           */
          related?: string;
        };
      };
      updatedAppointments?: {
        data?: {
          /** @example b64277a1e650794e2c57924c07825014 */
          id?: string;
          /** @example dsr_appointment */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /user/8f9bfe9d1345237cb3b2b205864da075/updatedAppointments
           */
          related?: string;
        };
      };
      updatedPresentations?: {
        data?: {
          /** @example 49fb9c4fad69d4a3da998a936016c88d */
          id?: string;
          /** @example dsr_presentation */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /user/8f9bfe9d1345237cb3b2b205864da075/updatedPresentations
           */
          related?: string;
        };
      };
    };
    firstName: string;
    id: string;
    lastName: string;
    /** Format: date-time */
    lastUpdatedPasswordAt?: string;
    localeId: string;
    relationships?: {
      accessKeys?: {
        data?: {
          /** @example d11944e47e101a4aaa8d7947faa56b16 */
          id?: string;
          /** @example user_access_key */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /user/8f9bfe9d1345237cb3b2b205864da075/accessKeys
           */
          related?: string;
        };
      };
      aclRoles?: {
        data?: {
          /** @example e050a8081a3eb1d193c23cf0ef761183 */
          id?: string;
          /** @example acl_role */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /user/8f9bfe9d1345237cb3b2b205864da075/aclRoles
           */
          related?: string;
        };
      };
      avatarMedia?: {
        data?: {
          /** @example 117ab0b986d2b792c775e3beeacca7c7 */
          id?: string;
          /** @example media */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /user/8f9bfe9d1345237cb3b2b205864da075/avatarMedia
           */
          related?: string;
        };
      };
      configs?: {
        data?: {
          /** @example c23f7ab876ac167e05468ef79f046cb7 */
          id?: string;
          /** @example user_config */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /user/8f9bfe9d1345237cb3b2b205864da075/configs
           */
          related?: string;
        };
      };
      createdCustomers?: {
        data?: {
          /** @example c0caccfe18ce8c277f15d100818139a6 */
          id?: string;
          /** @example customer */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /user/8f9bfe9d1345237cb3b2b205864da075/createdCustomers
           */
          related?: string;
        };
      };
      createdOrders?: {
        data?: {
          /** @example 20509127ddf2655eb49e3db3b1d710c0 */
          id?: string;
          /** @example order */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /user/8f9bfe9d1345237cb3b2b205864da075/createdOrders
           */
          related?: string;
        };
      };
      importExportLogEntries?: {
        data?: {
          /** @example 72ec794255f368c7a704e177fa9a4967 */
          id?: string;
          /** @example import_export_log */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /user/8f9bfe9d1345237cb3b2b205864da075/importExportLogEntries
           */
          related?: string;
        };
      };
      locale?: {
        data?: {
          /** @example fb216d9e8791e63c8d12bdc420956839 */
          id?: string;
          /** @example locale */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /user/8f9bfe9d1345237cb3b2b205864da075/locale
           */
          related?: string;
        };
      };
      media?: {
        data?: {
          /** @example 62933a2951ef01f4eafd9bdf4d3cd2f0 */
          id?: string;
          /** @example media */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /user/8f9bfe9d1345237cb3b2b205864da075/media
           */
          related?: string;
        };
      };
      recoveryUser?: {
        data?: {
          /** @example bf6cdb5c30f0f0d234b96e50f2953109 */
          id?: string;
          /** @example user_recovery */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /user/8f9bfe9d1345237cb3b2b205864da075/recoveryUser
           */
          related?: string;
        };
      };
      stateMachineHistoryEntries?: {
        data?: {
          /** @example c78c7ea361b7def0876b75bd1bd37879 */
          id?: string;
          /** @example state_machine_history */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /user/8f9bfe9d1345237cb3b2b205864da075/stateMachineHistoryEntries
           */
          related?: string;
        };
      };
      updatedCustomers?: {
        data?: {
          /** @example dddac98f88e37eb31b56e7e1d455fd75 */
          id?: string;
          /** @example customer */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /user/8f9bfe9d1345237cb3b2b205864da075/updatedCustomers
           */
          related?: string;
        };
      };
      updatedOrders?: {
        data?: {
          /** @example 9ce34a8be6d860e8bd92feaf79e9a4a2 */
          id?: string;
          /** @example order */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /user/8f9bfe9d1345237cb3b2b205864da075/updatedOrders
           */
          related?: string;
        };
      };
    };
    timeZone?: string;
    title?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    username: string;
  };
  UserRecovery: {
    /** Format: date-time */
    readonly createdAt?: string;
    hash: string;
    id: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    user?: components["schemas"]["User"];
    userId: string;
  };
  UserRecoveryJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    hash: string;
    id: string;
    relationships?: {
      user?: {
        data?: {
          /** @example ee11cbb19052e40b07aac0ca060c23ee */
          id?: string;
          /** @example user */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /user-recovery/f451cbc27abefae127822d81c5dbb338/user
           */
          related?: string;
        };
      };
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    userId: string;
  };
  VideoChatCreateStruct: {
    /** Token for the room owner (guide) to connect to the daily room */
    ownerToken?: string;
    /** Name of the video room in daily */
    roomName?: string;
    /** Url of the video room in daily */
    roomUrl?: string;
    /** @default false */
    startAsBroadcast?: boolean;
    /** Token for the end users to connect to the daily room */
    userToken?: string;
  };
  Warehouse: {
    /** Format: date-time */
    readonly createdAt?: string;
    description?: string;
    groups?: components["schemas"]["WarehouseGroup"][];
    id: string;
    name: string;
    orderProducts?: components["schemas"]["OrderProductWarehouse"][];
    productWarehouses?: components["schemas"]["ProductWarehouse"][];
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  WarehouseGroup: {
    /** Format: date-time */
    readonly createdAt?: string;
    description?: string;
    id: string;
    name: string;
    /** Format: int64 */
    priority?: number;
    products?: components["schemas"]["Product"][];
    rule?: components["schemas"]["Rule"];
    ruleId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
    warehouses?: components["schemas"]["Warehouse"][];
  };
  WarehouseGroupJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    description?: string;
    id: string;
    name: string;
    /** Format: int64 */
    priority?: number;
    relationships?: {
      products?: {
        data?: {
          /** @example 86024cad1e83101d97359d7351051156 */
          id?: string;
          /** @example product */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /warehouse-group/de0cc3be51d97f8063ce4c0cb7ba2515/products
           */
          related?: string;
        };
      };
      rule?: {
        data?: {
          /** @example 981c1e7b3795da18687613fbd66d4954 */
          id?: string;
          /** @example rule */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /warehouse-group/de0cc3be51d97f8063ce4c0cb7ba2515/rule
           */
          related?: string;
        };
      };
      warehouses?: {
        data?: {
          /** @example 544959798565126142ca2820b4f56271 */
          id?: string;
          /** @example warehouse */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /warehouse-group/de0cc3be51d97f8063ce4c0cb7ba2515/warehouses
           */
          related?: string;
        };
      };
    };
    ruleId?: string;
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  WarehouseGroupWarehouse: {
    id?: string;
    /** Format: int64 */
    priority?: number;
    warehouse?: components["schemas"]["Warehouse"];
    warehouseGroup?: components["schemas"]["WarehouseGroup"];
    warehouseGroupId: string;
    warehouseId: string;
  };
  WarehouseJsonApi: components["schemas"]["resource"] & {
    /** Format: date-time */
    readonly createdAt?: string;
    description?: string;
    id: string;
    name: string;
    relationships?: {
      groups?: {
        data?: {
          /** @example 1471e4e05a4db95d353cc867fe317314 */
          id?: string;
          /** @example warehouse_group */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /warehouse/6416e8cb5fc0a208d94fa7f5a300dbc4/groups
           */
          related?: string;
        };
      };
      orderProducts?: {
        data?: {
          /** @example 5b044c586b7768148276b8d5c4ef61b6 */
          id?: string;
          /** @example order_product_warehouse */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /warehouse/6416e8cb5fc0a208d94fa7f5a300dbc4/orderProducts
           */
          related?: string;
        };
      };
      productWarehouses?: {
        data?: {
          /** @example ff6147ec4fdd4e27441a0439366d0e4d */
          id?: string;
          /** @example product_warehouse */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /warehouse/6416e8cb5fc0a208d94fa7f5a300dbc4/productWarehouses
           */
          related?: string;
        };
      };
    };
    /** Format: date-time */
    readonly updatedAt?: string;
  };
  Webhook: {
    active?: boolean;
    app?: components["schemas"]["App"];
    appId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    /** Format: int64 */
    readonly errorCount?: number;
    eventName: string;
    id: string;
    name: string;
    onlyLiveVersion?: boolean;
    /** Format: date-time */
    readonly updatedAt?: string;
    url: string;
  };
  WebhookEventLog: {
    appName?: string;
    appVersion?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    deliveryStatus: string;
    eventName: string;
    extensions?: {
      flowSequences?: {
        data?: {
          /** @example 3a0d70b6dd3624074e5e15cd07e7fa90 */
          id?: string;
          /** @example flow_sequence */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /webhook-event-log/9a55f6ada630f9af57230d03e40bc8ee/flowSequences
           */
          related?: string;
        };
      };
    };
    id: string;
    onlyLiveVersion?: boolean;
    /** Format: int64 */
    processingTime?: number;
    requestContent?: GenericRecord;
    responseContent?: GenericRecord;
    responseReasonPhrase?: string;
    /** Format: int64 */
    responseStatusCode?: number;
    /** Format: int64 */
    timestamp?: number;
    /** Format: date-time */
    readonly updatedAt?: string;
    url: string;
    webhookName: string;
  };
  WebhookEventLogJsonApi: components["schemas"]["resource"] & {
    appName?: string;
    appVersion?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    customFields?: GenericRecord;
    deliveryStatus: string;
    eventName: string;
    extensions?: {
      flowSequences?: {
        data?: {
          /** @example 3a0d70b6dd3624074e5e15cd07e7fa90 */
          id?: string;
          /** @example flow_sequence */
          type?: string;
        }[];
        links?: {
          /**
           * Format: uri-reference
           * @example /webhook-event-log/9a55f6ada630f9af57230d03e40bc8ee/flowSequences
           */
          related?: string;
        };
      };
    };
    id: string;
    onlyLiveVersion?: boolean;
    /** Format: int64 */
    processingTime?: number;
    requestContent?: GenericRecord;
    responseContent?: GenericRecord;
    responseReasonPhrase?: string;
    /** Format: int64 */
    responseStatusCode?: number;
    /** Format: int64 */
    timestamp?: number;
    /** Format: date-time */
    readonly updatedAt?: string;
    url: string;
    webhookName: string;
  };
  WebhookJsonApi: components["schemas"]["resource"] & {
    active?: boolean;
    appId?: string;
    /** Format: date-time */
    readonly createdAt?: string;
    /** Format: int64 */
    readonly errorCount?: number;
    eventName: string;
    id: string;
    name: string;
    onlyLiveVersion?: boolean;
    relationships?: {
      app?: {
        data?: {
          /** @example d2a57dc1d883fd21fb9951699df71cc7 */
          id?: string;
          /** @example app */
          type?: string;
        };
        links?: {
          /**
           * Format: uri-reference
           * @example /webhook/150c7abfca6c489fee5cb82fbb7a9bc4/app
           */
          related?: string;
        };
      };
    };
    /** Format: date-time */
    readonly updatedAt?: string;
    url: string;
  };
  WidgetProductListing: {
    /**
     * List of extensions
     * @default []
     */
    extensions?: unknown[];
    /** The number of products per page */
    limit?: number;
    /** The current page */
    page?: number;
    /** List of last seen products */
    products?: components["schemas"]["Product"][];
    /** The total number of products */
    total?: number;
  };
  attributes: {
    [key: string]: unknown;
  };
  businessEventsResponse: {
    /** Flow builder will base on awareness to show actions */
    aware?: string[];
    /** Class name of the event */
    class?: string;
    /** Available data of event */
    data?: GenericRecord;
    /** Extensions data of event */
    extensions?: string[];
    /** Name of the event */
    name?: string;
  }[];
  data: components["schemas"]["resource"] | components["schemas"]["resource"][];
  error: {
    /** An application-specific error code, expressed as a string value. */
    code?: string;
    /** A human-readable description of the problem. */
    description?: string;
    /** A human-readable explanation specific to this occurrence of the problem. */
    detail?: string;
    /** A unique identifier for this particular occurrence of the problem. */
    id?: string;
    links?: components["schemas"]["links"];
    meta?: components["schemas"]["meta"];
    source?: {
      /** A string indicating which query parameter caused the error. */
      parameter?: string;
      /** A JSON Pointer [RFC6901] to the associated entity in the request document [e.g. "/data" for a primary data object, or "/data/attributes/title" for a specific attribute]. */
      pointer?: string;
    };
    /** The HTTP status code applicable to this problem, expressed as a string value. */
    status?: string;
    /** A short, human-readable summary of the problem. It **SHOULD NOT** change from occurrence to occurrence of the problem, except for purposes of localization. */
    title?: string;
  };
  failure: {
    errors: components["schemas"]["error"][];
    links?: components["schemas"]["links"];
    meta?: components["schemas"]["meta"];
  };
  flowBuilderActionsResponse: {
    /** Extensions data of event */
    extensions?: string[];
    /** Name of the flow action */
    name?: string;
    /** When requirement fit with aware from `events.json` actions will be shown */
    requirements?: string[];
  }[];
  info: {
    jsonapi?: components["schemas"]["jsonapi"];
    links?: components["schemas"]["links"];
    meta: components["schemas"]["meta"];
  };
  infoConfigResponse: {
    /** Information about the admin worker. */
    adminWorker?: {
      /** State of the admin worker. */
      enableAdminWorker?: boolean;
      /** Configured transports. */
      transports?: string[];
    };
    /** Asset files of active extensions */
    bundles?: {
      [key: string]: {
        css?: string[];
        js?: string[];
      };
    };
    settings?: {
      /** State of the `urlFeature` setting. */
      enableUrlFeature?: boolean;
    };
    /** The Shopware version. */
    version?: string;
    /** The Shopware version revision. */
    versionRevision?: string;
  };
  jsonapi: {
    meta?: components["schemas"]["meta"];
    version?: string;
  };
  link:
    | string
    | {
        /**
         * Format: uri-reference
         * A string containing the link's URL.
         */
        href: string;
        meta?: components["schemas"]["meta"];
      };
  linkage: {
    id: string;
    meta?: components["schemas"]["meta"];
    type: string;
  };
  links: {
    [key: string]: components["schemas"]["link"];
  };
  meta: {
    [key: string]: unknown;
  };
  pagination: {
    /**
     * Format: uri-reference
     * The first page of data
     */
    first?: string;
    /**
     * Format: uri-reference
     * The last page of data
     */
    last?: string;
    /**
     * Format: uri-reference
     * The next page of data
     */
    next?: string;
    /**
     * Format: uri-reference
     * The previous page of data
     */
    prev?: string;
  };
  relationshipLinks: {
    related?: components["schemas"]["link"];
    self?: GenericRecord[] & components["schemas"]["link"];
  } & {
    [key: string]: unknown;
  };
  relationshipToMany: components["schemas"]["linkage"][];
  relationshipToOne: unknown & components["schemas"]["linkage"];
  relationships:
    | unknown
    | unknown
    | unknown
    | {
        /** Member, whose value represents "resource linkage". */
        data?:
          | components["schemas"]["relationshipToOne"]
          | components["schemas"]["relationshipToMany"];
        links?: components["schemas"]["relationshipLinks"];
      };
  resource: {
    attributes?: components["schemas"]["attributes"];
    id: string;
    links?: components["schemas"]["links"];
    meta?: components["schemas"]["meta"];
    relationships?: components["schemas"]["relationships"];
    type: string;
  };
  success: {
    data: components["schemas"]["data"];
    /** To reduce the number of HTTP requests, servers **MAY** allow responses that include related resources along with the requested primary resources. Such responses are called "compound documents". */
    included?: components["schemas"]["resource"][];
    /** Link members related to the primary data. */
    links?: components["schemas"]["links"] &
      components["schemas"]["pagination"];
    meta?: components["schemas"]["meta"];
  };
};
type operations = {
  "clearCache delete /_action/cache": {
    contentType?: "application/json";
    accept?: "application/json";
    response: never;
    responseCode: 204;
  };
  "info get /_action/cache_info": {
    contentType?: "application/json";
    accept?: "application/json";
    response: {
      /** The active cache adapter. */
      cacheAdapter?: string;
      /** The active environment. */
      environment?: string;
      /** State of the HTTP cache. */
      httpCache?: boolean;
    };
    responseCode: 200;
  };
  "clearOldCacheFolders delete /_action/cleanup": {
    contentType?: "application/json";
    accept?: "application/json";
    response: never;
    responseCode: 204;
  };
  "clearContainerCache delete /_action/container_cache": {
    contentType?: "application/json";
    accept?: "application/json";
    response: never;
    responseCode: 204;
  };
  "createEmployee post /_action/create-employee": {
    contentType?: "application/json";
    accept?: "application/json";
    body: {
      /** Email of the new employee */
      email?: string;
      /** First name of the new employee */
      firstName?: string;
      /** Last name of the new employee */
      lastName?: string;
      /** Id of the role of the new employee */
      roleId?: string;
    };
    response: {
      /** Array of the created employee ids */
      data?: string[];
    };
    responseCode: 200;
  };
  "customPriceImport post /_action/custom-price": {
    contentType?: "application/json";
    accept?: "application/json";
    body: (
      | components["schemas"]["CustomPricingUpsertOperation"]
      | components["schemas"]["CustomPricingDeleteOperation"]
    )[];
    response: components["schemas"]["CustomPricingResponse"];
    responseCode: 200;
  };
  "downloadDocument get /_action/document/{documentId}/{deepLinkCode}": {
    contentType?: "application/json";
    accept: "application/octet-stream";
    query?: {
      /** This parameter controls the `Content-Disposition` header. If set to `true` the header will be set to `attachment` else `inline`. */
      download?: boolean;
    };
    pathParams: {
      /** A unique hash code which was generated when the document was created. */
      deepLinkCode: string;
      /** Identifier of the document to be downloaded. */
      documentId: string;
    };
    response: Blob;
    responseCode: 200;
  };
  "uploadToDocument post /_action/document/{documentId}/upload":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query: {
          /** Extension of the uploaded file. For example `pdf` */
          extension: string;
          /** Name of the uploaded file. */
          fileName: string;
        };
        pathParams: {
          /** Identifier of the document the new file should be added to. */
          documentId: string;
        };
        body: {
          /** The url of the document that will be downloaded. */
          url: string;
        };
        response: {
          /** A unique hash code which is required to open the document. */
          documentDeepLink?: string;
          /** Identifier of the document. */
          documentId?: string;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/octet-stream";
        accept?: "application/json";
        query: {
          /** Extension of the uploaded file. For example `pdf` */
          extension: string;
          /** Name of the uploaded file. */
          fileName: string;
        };
        pathParams: {
          /** Identifier of the document the new file should be added to. */
          documentId: string;
        };
        body: Blob;
        response: {
          /** A unique hash code which is required to open the document. */
          documentDeepLink?: string;
          /** Identifier of the document. */
          documentId?: string;
        };
        responseCode: 200;
      };
  "endAppointment post /_action/dsr/appointment/{appointmentId}/end": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Appointment id */
      appointmentId: string;
    };
    response: never;
    responseCode: 200;
  };
  "addInstantListing post /_action/dsr/appointment/{appointmentId}/instant-listing": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Appointment id */
      appointmentId: string;
    };
    body: {
      /** Id of the current cms page */
      currentPageGroupId?: string;
      /** The name of the instant listing page */
      pageName?: string | null;
      /** Ids of the products which should be added to the instant listing */
      productIds: string[];
    };
    response: {
      /** The current index of the instant listing which is created by this request */
      index?: number;
    };
    responseCode: 201;
  };
  "updateInstantListing patch /_action/dsr/appointment/{appointmentId}/instant-listing": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Appointment id */
      appointmentId: string;
    };
    body: {
      /** Ids of the products which should be added to the instant listing */
      addProductIds: string[];
      /** Id of the current cms page */
      currentPageGroupId: string;
      /** The name of the instant listing page */
      pageName?: string | null;
      /** Ids of the products which should be removed to the instant listing */
      removeProductIds: string[];
    };
    response: {
      /** The id of the instant listing page */
      id?: string;
      /** Ids of the products which are picked for the instant listing */
      pickedProductIds?: string[];
      /** The title of the instant listing */
      title?: string;
    };
    responseCode: 200;
  };
  "joinAppointmentAsGuide post /_action/dsr/appointment/{appointmentId}/join-as-guide": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Appointment id */
      appointmentId: string;
    };
    response: components["schemas"]["JoinAppointmentResponse"];
    responseCode: 200;
  };
  "getGuidePresentationState get /_action/dsr/appointment/{appointmentId}/presentation/state": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Appointment id */
      appointmentId: string;
    };
    response: components["schemas"]["GuidePresentationStateResponse"];
    responseCode: 200;
  };
  "startAppointment post /_action/dsr/appointment/{appointmentId}/start": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Appointment id */
      appointmentId: string;
    };
    response: never;
    responseCode: 204;
  };
  "createVideoRoom post /_action/dsr/appointment/{appointmentId}/video-room": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Appointment id */
      appointmentId: string;
    };
    response: components["schemas"]["VideoChatCreateStruct"];
    responseCode: 200;
  };
  "deleteVideoRoom delete /_action/dsr/appointment/{appointmentId}/video-room": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Appointment id */
      appointmentId: string;
    };
    response: unknown;
    responseCode: 200;
  };
  "getAttendeeInsights get /_action/dsr/appointment/{appointmentId}/widgets/attendee-insights": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Appointment id */
      appointmentId: string;
    };
    response: components["schemas"]["GetAttendeeInsightsResponse"];
    responseCode: 200;
  };
  "getCartInsights get /_action/dsr/appointment/{appointmentId}/widgets/cart-insights": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Appointment id */
      appointmentId: string;
    };
    response: components["schemas"]["GetCartInsightsResponse"];
    responseCode: 200;
  };
  "getCartStatistics get /_action/dsr/appointment/{appointmentId}/widgets/cart-statistics": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Appointment id */
      appointmentId: string;
    };
    response: components["schemas"]["Cart"];
    responseCode: 200;
  };
  "getLastSeenProductsInsights get /_action/dsr/appointment/{appointmentId}/widgets/last-seen": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Appointment id */
      appointmentId: string;
    };
    body?: {
      /** The attendee id for which the last seen products should be returned */
      attendeeId?: string;
      /**
       * The limit of the products which should be returned
       * @default 10
       */
      limit?: number;
      /**
       * The page of the products which should be returned
       * @default 1
       */
      page?: number;
    };
    response: components["schemas"]["WidgetProductListing"];
    responseCode: 200;
  };
  "getWishlistInsights get /_action/dsr/appointment/{appointmentId}/widgets/wishlist": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Appointment id */
      appointmentId: string;
    };
    response: components["schemas"]["WidgetProductListing"];
    responseCode: 200;
  };
  "getLastSeenProductIds post /_action/dsr/appointment/attendee/{attendeeId}/last-seen-product-ids": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Attendee id */
      attendeeId: string;
    };
    response: {
      collection?: {
        lastSeen?: string[];
      };
    };
    responseCode: 200;
  };
  "removeAttendee post /_action/dsr/appointment/attendee/{attendeeId}/remove": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Attendee id */
      attendeeId: string;
    };
    response: {
      /** The id of the removed attendee */
      attendeeId?: string;
      message?: string;
    };
    responseCode: 200;
  };
  "getAttendeeToken get /_action/dsr/appointment/attendee/{attendeeId}/sw-context-token": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Attendee id */
      attendeeId: string;
    };
    response: {
      "attendee-sw-context-token"?: string;
    };
    responseCode: 200;
  };
  "index post /_action/index": {
    contentType?: "application/json";
    accept?: "application/json";
    body: {
      /** Array of indexers/updaters to be skipped. */
      skip?: string[];
    };
    response: never;
    responseCode: 204;
  };
  "productIndexing post /_action/index-products": {
    contentType?: "application/json";
    accept?: "application/json";
    response: never;
    responseCode: 204;
  };
  "indexing post /_action/indexing": {
    contentType?: "application/json";
    accept?: "application/json";
    response: never;
    responseCode: 200;
  };
  "iterate post /_action/indexing/{indexer}": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Name of the indexer to iterate. */
      indexer: string;
    };
    body: {
      /** The offset for the iteration. */
      offset?: number;
    };
    response: {
      /** Indicates if the indexing process finished. */
      finish?: boolean;
      /** Offset to be used for the next iteration. */
      offset?: number;
    };
    responseCode: 200;
  };
  "inviteEmployee post /_action/invite-employee": {
    contentType?: "application/json";
    accept?: "application/json";
    body: {
      /** Id of the employee to invite */
      id: string;
      /** Id of the sales channel through which the registration will be fulfilled. */
      salesChannelId?: string;
    };
    response: never;
    responseCode: 204;
  };
  "build post /_action/mail-template/build": {
    contentType?: "application/json";
    accept?: "application/json";
    body: {
      /** The content of the mail as plain text. */
      mailTemplate: {
        /**
         * The content of mail mail template in html format.
         * @example Hello {{ order.customerName }}, this is example mail content, the current date is {{ 'now'|date('d/m/Y') }}
         */
        contentHtml?: string;
      };
      /** Only the property `templateData` is used. It provides additional variables to the templating engine. */
      mailTemplateType: {
        /**
         * An associative array that is handed over to the templating engine and can be used as variables in the mail content.
         * @example {
         *       "order": {
         *         "orderNumber": 5000,
         *         "customerName": "Example Customer"
         *       },
         *       "messageOfTheDay": "An apple a day keeps the doctor away!"
         *     }
         */
        templateData?: {
          [key: string]: unknown;
        };
      };
    };
    response: string;
    responseCode: 200;
  };
  "send post /_action/mail-template/send": {
    contentType?: "application/json";
    accept?: "application/json";
    body: {
      /** A list of binary attachments which should be added to the mail. */
      binAttachments?: {
        /** Binary content of the attachment. */
        content?: string;
        /** File name of the attachment. */
        fileName?: string;
        /** Mime type of the attachment. */
        mimeType?: string;
      }[];
      /** The content of the mail in HTML format. */
      contentHtml: string;
      /** The content of the mail as plain text. */
      contentPlain: string;
      /** List of media identifiers which should be attached to the mail. */
      mediaIds?: string[];
      /**
       * A list of recipients with name and mail address.
       * @example {
       *       "test1@example.com": "Test user 1",
       *       "test2@example.com": "Test user 2"
       *     }
       */
      recipients: {
        [key: string]: string;
      };
      /**
       * A list of recipients with name and mail address to be set in BCC.
       * @example {
       *       "test1@example.com": "Test user 1",
       *       "test2@example.com": "Test user 2"
       *     }
       */
      recipientsBcc?: {
        [key: string]: string;
      };
      /**
       * A list of recipients with name and mail address to be set in CC.
       * @example {
       *       "test1@example.com": "Test user 1",
       *       "test2@example.com": "Test user 2"
       *     }
       */
      recipientsCc?: {
        [key: string]: string;
      };
      /**
       * A list of mail addresses with name and mail address to be set in reply to.
       * @example {
       *       "test1@example.com": "Test user 1",
       *       "test2@example.com": "Test user 2"
       *     }
       */
      replyTo?: {
        [key: string]: string;
      };
      /**
       * A list of mail addresses with name and mail address to be set in return path.
       * @example {
       *       "test1@example.com": "Test user 1",
       *       "test2@example.com": "Test user 2"
       *     }
       */
      returnPath?: {
        [key: string]: string;
      };
      /** Identifier of the sales channel from which the mail should be send. */
      salesChannelId: string;
      /** Mail address of the sender. If not set, `core.basicInformation.email` or `core.mailerSettings.senderAddress` will be used from the shop configuration. */
      senderEmail?: string;
      /** Name of the sender. */
      senderName: string;
      /** Subject of the mail. */
      subject: string;
    };
    response: {
      /** Length of the email message */
      size?: number;
    };
    responseCode: 200;
  };
  "validate post /_action/mail-template/validate": {
    contentType?: "application/json";
    accept?: "application/json";
    body: {
      /** The content of the mail in HTML format. */
      contentHtml: string;
      /** The content of the mail as plain text. */
      contentPlain: string;
    };
    response: never;
    responseCode: 204;
  };
  "upload post /_action/media/{mediaId}/upload":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query: {
          /** Extension of the uploaded file. For example `png` */
          extension: string;
          /** Name of the uploaded file. If not provided the media identifier will be used as name */
          fileName?: string;
        };
        pathParams: {
          /** Identifier of the media entity. */
          mediaId: string;
        };
        body: {
          /** The url of the media file that will be downloaded. */
          url: string;
        };
        response: never;
        responseCode: 204;
      }
    | {
        contentType: "application/octet-stream";
        accept?: "application/json";
        query: {
          /** Extension of the uploaded file. For example `png` */
          extension: string;
          /** Name of the uploaded file. If not provided the media identifier will be used as name */
          fileName?: string;
        };
        pathParams: {
          /** Identifier of the media entity. */
          mediaId: string;
        };
        body: Blob;
        response: never;
        responseCode: 204;
      };
  "consumeMessages post /_action/message-queue/consume": {
    contentType?: "application/json";
    accept?: "application/json";
    body: {
      /** The name of the transport in the messenger that should be processed.
       *     See the [Symfony Messenger documentation](https://symfony.com/doc/current/messenger.html) for more information */
      receiver: string;
    };
    response: {
      /** The number of messages processed. */
      handledMessages?: number;
    };
    responseCode: 200;
  };
  "numberRangeReserve get /_action/number-range/reserve/{type}/{saleschannel}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** If this parameter has a true value, the number will not actually be incremented, but only previewed. */
      preview?: boolean;
    };
    pathParams: {
      /** Sales channel for the number range. Number ranges can be defined per sales channel, so you can pass a sales channel ID here. */
      saleschannel: string;
      /** `technicalName` of the document type (e.g. `document_invoice`). Available types can be fetched with the `/api/document-type endpoint`. */
      type: string;
    };
    response: {
      /** The generated (or previewed) document number. */
      number?: string;
    };
    responseCode: 200;
  };
  "orderDeliveryStateTransition post /_action/order_delivery/{orderDeliveryId}/state/{transition}": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Identifier of the order delivery. */
      orderDeliveryId: string;
      /** The `action_name` of the `state_machine_transition`. For example `process` if the order state should change from open to in progress.
       *
       *     Note: If you choose a transition which is not possible, you will get an error that lists possible transition for the actual state. */
      transition: string;
    };
    body?: {
      /** A list of document identifiers that should be attached */
      documentIds?: string[];
      /** A list of media identifiers that should be attached */
      mediaIds?: string[];
      /** Controls if a mail should be send to the customer. */
      sendMail?: unknown;
      /**
       * This is the state column within the order delivery database table. There should be no need to change it from the default.
       * @default stateId
       */
      stateFieldName?: string;
    };
    response: never;
    responseCode: 200;
  };
  "orderTransactionCaptureRefund post /_action/order_transaction_capture_refund/{refundId}": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Identifier of the order transaction capture refund. */
      refundId: string;
    };
    response: never;
    responseCode: 204;
  };
  "orderTransactionStateTransition post /_action/order_transaction/{orderTransactionId}/state/{transition}": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Identifier of the order transaction. */
      orderTransactionId: string;
      /** The `action_name` of the `state_machine_transition`. For example `process` if the order state should change from open to in progress.
       *
       *     Note: If you choose a transition that is not available, you will get an error that lists possible transitions for the current state. */
      transition: string;
    };
    body?: {
      /** A list of document identifiers that should be attached */
      documentIds?: string[];
      /** A list of media identifiers that should be attached */
      mediaIds?: string[];
      /** Controls if a mail should be sent to the customer. */
      sendMail?: unknown;
      /**
       * This is the state column within the order transaction database table. There should be no need to change it from the default.
       * @default stateId
       */
      stateFieldName?: string;
    };
    response: never;
    responseCode: 200;
  };
  "updateOrderAddresses post /_action/order/{orderId}/order-address": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Identifier of the order. */
      orderId: string;
    };
    body: {
      /** The mapping of order addresses */
      mapping?: {
        /** The ID of the customer address */
        customerAddressId: string;
        /** The ID of the delivery (optional) */
        deliveryId?: string | null;
        /** The type of the address */
        type: string;
      }[];
    };
    response: never;
    responseCode: 204;
  };
  "orderStateTransition post /_action/order/{orderId}/state/{transition}": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Identifier of the order. */
      orderId: string;
      /** The `action_name` of the `state_machine_transition`. For example `process` if the order state should change from open to in progress.
       *
       *     Note: If you choose a transition that is not available, you will get an error that lists possible transitions for the current state. */
      transition: string;
    };
    body?: {
      /** A list of document identifiers that should be attached */
      documentIds?: string[];
      /** A list of media identifiers that should be attached */
      mediaIds?: string[];
      /** Controls if a mail should be sent to the customer. */
      sendMail?: unknown;
      /**
       * This is the state column within the order database table. There should be no need to change it from the default.
       * @default stateId
       */
      stateFieldName?: string;
    };
    response: never;
    responseCode: 200;
  };
  "createDocuments post /_action/order/document/{documentTypeName}/create": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** The type of document to create */
      documentTypeName: string;
    };
    body: {
      /** Document specific configuration, like documentNumber, documentDate, documentComment. */
      config?: GenericRecord;
      /**
       * Type of document file to be generated.
       * @default pdf
       */
      fileType?: string;
      /** Identifier of the order. */
      orderId: string;
      /**
       * Identifier of the reverenced document.
       * @default null
       */
      referencedDocumentId?: string;
      /**
       * Indicate if the document should be static or not.
       * @default false
       */
      static?: boolean;
      /** Type of the document to be generated. */
      type: string;
    }[];
    response: never;
    responseCode: 200;
  };
  "downloadDocuments post /_action/order/document/download": {
    contentType?: "application/json";
    accept: "application/octet-stream";
    body: string[];
    response: Blob;
    responseCode: 200;
  };
  "createComment post /_action/quote/{quoteId}/comment": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Identifier of the quote to be fetched */
      quoteId: string;
    };
    body: {
      /** Message content */
      comment?: string;
      /** Current quote state */
      state?: string;
    };
    response: never;
    responseCode: 204;
  };
  "addCustomLineItemToQuote post /_action/quote/{quoteId}/lineItem": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Identifier of the quote to be fetched */
      quoteId: string;
    };
    body?: {
      /** @default null */
      description?: string;
      identifier?: string;
      /** @default null */
      label?: string;
      payload?: GenericRecord[];
      priceDefinition?: GenericRecord[];
      quantity?: number;
      /** @default true */
      removable?: boolean;
      /** @default true */
      stackable?: boolean;
      /** @default custom */
      type?: string;
    };
    response: never;
    responseCode: 204;
  };
  "addProductToQuote post /_action/quote/{quoteId}/product/{productId}": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Identifier of the product to be fetched */
      productId: string;
      /** Identifier of the quote to be fetched */
      quoteId: string;
    };
    body?: {
      quantity?: number;
    };
    response: never;
    responseCode: 204;
  };
  "recalculateQuote post /_action/quote/{quoteId}/recalculate": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Identifier of the quote to be fetched */
      quoteId: string;
    };
    response: never;
    responseCode: 204;
  };
  "getMinRunInterval get /_action/scheduled-task/min-run-interval": {
    contentType?: "application/json";
    accept?: "application/json";
    response: {
      /** Minimal interval in seconds. */
      minRunInterval?: string;
    };
    responseCode: 200;
  };
  "runScheduledTasks post /_action/scheduled-task/run": {
    contentType?: "application/json";
    accept?: "application/json";
    response: {
      /** Success message */
      message?: string;
    };
    responseCode: 200;
  };
  "sync post /_action/sync": {
    contentType?: "application/json";
    accept?: "application/json";
    headers?: {
      /** To continue upcoming actions on errors, set the `fail-on-error` header to `false`. */
      "fail-on-error"?: boolean;
      /** Controls the indexing behavior.
       *         - `disable-indexing`: Data indexing is completely disabled */
      "indexing-behavior"?: "use-queue-indexing" | "disable-indexing";
    };
    body: {
      /**
       * The action indicates what should happen with the provided payload.
       *         * `upsert`: The Sync API does not differ between create and update operations,
       *         but always performs an upsert operation. During an upsert, the system checks whether the entity already exists in the
       *         system and updates it if an identifier has been passed, otherwise a new entity is created with this identifier.
       *         * `delete`: Deletes entities with the provided identifiers
       * @enum {string}
       */
      action: "upsert" | "delete";
      /**
       * The entity that should be processed with the payload.
       * @example product
       */
      entity: string;
      /** Contains a list of changesets for an entity. If the action type is `delete`,
       *         a list of identifiers can be provided. */
      payload: GenericRecord[];
    }[];
    response: {
      /** Object with information about updated entities */
      data?: GenericRecord;
      /** Object with information about deleted entities */
      deleted?: GenericRecord;
      /** Object with information about not found entities */
      notFound?: GenericRecord;
    };
    responseCode: 200;
  };
  "textToImageGenerate post /_action/text-to-image/generate": {
    contentType?: "application/json";
    accept?: "application/json";
    body: {
      /**
       * The textual prompt to describe what image to generate
       * @example Generate a warm and inviting ambience with soft lightning and neutral tones
       */
      description?: string;
    };
    response: string;
    responseCode: 200;
  };
  "updateEmployee patch /_action/update-employee": {
    contentType?: "application/json";
    accept?: "application/json";
    body: {
      /** Email of the employee */
      email?: string;
      /** First name of the employee */
      firstName?: string;
      /** Id of the employee */
      id?: string;
      /** Last name of the employee */
      lastName?: string;
      /** Id of the role of the employee */
      roleId?: string;
    };
    response: never;
    responseCode: 204;
  };
  "config get /_info/config": {
    contentType?: "application/json";
    accept?: "application/json";
    response: components["schemas"]["infoConfigResponse"];
    responseCode: 200;
  };
  "business-events get /_info/events.json": {
    contentType?: "application/json";
    accept?: "application/json";
    response: components["schemas"]["businessEventsResponse"];
    responseCode: 200;
  };
  "flow-actions get /_info/flow-actions.json": {
    contentType?: "application/json";
    accept?: "application/json";
    response: components["schemas"]["flowBuilderActionsResponse"];
    responseCode: 200;
  };
  "healthCheck get /_info/health-check": {
    contentType?: "application/json";
    accept?: "application/json";
    response: never;
    responseCode: 200;
  };
  "api-info get /_info/openapi3.json": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Type of the api */
      type?: "jsonapi" | "json";
    };
    response: {
      components?: {
        callbacks?: GenericRecord;
        examples?: GenericRecord;
        headers?: GenericRecord;
        links?: GenericRecord;
        parameters?: GenericRecord;
        pathItems?: GenericRecord;
        requestBodies?: GenericRecord;
        responses?: GenericRecord;
        schemas?: GenericRecord;
        securitySchemes?: GenericRecord;
      };
      externalDocs?: {
        description?: string;
        /** Format: uri */
        url: string;
      };
      info: {
        contact?: {
          /** Format: email */
          email?: string;
          name?: string;
          /** Format: uri */
          url?: string;
        };
        description?: string;
        license?: {
          identifier?: string;
          name: string;
          /** Format: uri */
          url?: string;
        };
        summary?: string;
        /** Format: uri */
        termsOfService?: string;
        title: string;
        version: string;
      };
      jsonSchemaDialect?: string;
      openapi: string;
      paths?: GenericRecord;
      security?: GenericRecord[];
      servers?: {
        url: string;
      }[];
      tags?: {
        description?: string;
        externalDocs?: {
          description?: string;
          /** Format: uri */
          url: string;
        };
        name: string;
      }[];
      webhooks?: GenericRecord;
    };
    responseCode: 200;
  };
  "getRoutes get /_info/routes": {
    contentType?: "application/json";
    accept?: "application/json";
    response: {
      endpoints: {
        methods: string[];
        path: string;
      }[];
    };
    responseCode: 200;
  };
  "systemHealthCheck get /_info/system-health-check": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Include detailed information in the response */
      verbose?: boolean;
    };
    response: {
      checks?: {
        extra?: {
          [key: string]: unknown;
        }[];
        healthy?: boolean;
        message?: string;
        name?: string;
        status?: string;
      }[];
    };
    responseCode: 200;
  };
  "infoShopwareVersion get /_info/version": {
    contentType?: "application/json";
    accept?: "application/json";
    response: {
      /** The Shopware version. */
      version?: string;
    };
    responseCode: 200;
  };
  "createQuoteFromAdmin post /_proxy-quote/{salesChannelId}": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Identifier of the sales channel to be fetched */
      salesChannelId: string;
    };
    body?: {
      customerId?: string;
    };
    response: components["schemas"]["Quote"];
    responseCode: 200;
  };
  "generateImitateCustomerToken post /_proxy/generate-imitate-customer-token": {
    contentType?: "application/json";
    accept?: "application/json";
    body: {
      /** ID of the customer */
      customerId: string;
      /** ID of the sales channel */
      salesChannelId: string;
    };
    response: {
      /** The generated customer impersonation token */
      token?: string;
    };
    responseCode: 200;
  };
  "getAclRoleList get /acl-role":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["AclRole"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["AclRole"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /acl-role?limit=25 */
            first?: unknown;
            /** @example /acl-role?limit=25&page=11 */
            last?: unknown;
            /** @example /acl-role?limit=25&page=4 */
            next?: unknown;
            /** @example /acl-role?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createAclRole post /acl-role":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["AclRole"];
        response: {
          data: components["schemas"]["AclRole"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["AclRole"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AclRole"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["AclRole"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["AclRole"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["AclRole"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AclRole"];
        };
        responseCode: 200;
      };
  "getAclRole get /acl-role/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the acl_role */
          id: string;
        };
        response: {
          data: components["schemas"]["AclRole"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the acl_role */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AclRole"];
        };
        responseCode: 200;
      };
  "deleteAclRole delete /acl-role/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the acl_role */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateAclRole patch /acl-role/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the acl_role */
          id: string;
        };
        body: components["schemas"]["AclRole"];
        response: {
          data: components["schemas"]["AclRole"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the acl_role */
          id: string;
        };
        body: components["schemas"]["AclRole"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AclRole"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the acl_role */
          id: string;
        };
        body: {
          data?: components["schemas"]["AclRole"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["AclRole"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the acl_role */
          id: string;
        };
        body: {
          data?: components["schemas"]["AclRole"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AclRole"];
        };
        responseCode: 200;
      };
  "getAdvancedSearchActionList get /advanced-search-action":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["AdvancedSearchAction"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["AdvancedSearchAction"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /advanced-search-action?limit=25 */
            first?: unknown;
            /** @example /advanced-search-action?limit=25&page=11 */
            last?: unknown;
            /** @example /advanced-search-action?limit=25&page=4 */
            next?: unknown;
            /** @example /advanced-search-action?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createAdvancedSearchAction post /advanced-search-action":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["AdvancedSearchAction"];
        response: {
          data: components["schemas"]["AdvancedSearchAction"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["AdvancedSearchAction"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AdvancedSearchAction"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["AdvancedSearchAction"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["AdvancedSearchAction"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["AdvancedSearchAction"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AdvancedSearchAction"];
        };
        responseCode: 200;
      };
  "getAdvancedSearchActionSearchTermList get /advanced-search-action-search-term":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["AdvancedSearchActionSearchTerm"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["AdvancedSearchActionSearchTerm"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /advanced-search-action-search-term?limit=25 */
            first?: unknown;
            /** @example /advanced-search-action-search-term?limit=25&page=11 */
            last?: unknown;
            /** @example /advanced-search-action-search-term?limit=25&page=4 */
            next?: unknown;
            /** @example /advanced-search-action-search-term?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createAdvancedSearchActionSearchTerm post /advanced-search-action-search-term":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["AdvancedSearchActionSearchTerm"];
        response: {
          data: components["schemas"]["AdvancedSearchActionSearchTerm"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["AdvancedSearchActionSearchTerm"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AdvancedSearchActionSearchTerm"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["AdvancedSearchActionSearchTerm"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["AdvancedSearchActionSearchTerm"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["AdvancedSearchActionSearchTerm"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AdvancedSearchActionSearchTerm"];
        };
        responseCode: 200;
      };
  "getAdvancedSearchActionSearchTerm get /advanced-search-action-search-term/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the advanced_search_action_search_term */
          id: string;
        };
        response: {
          data: components["schemas"]["AdvancedSearchActionSearchTerm"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the advanced_search_action_search_term */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AdvancedSearchActionSearchTerm"];
        };
        responseCode: 200;
      };
  "deleteAdvancedSearchActionSearchTerm delete /advanced-search-action-search-term/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the advanced_search_action_search_term */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateAdvancedSearchActionSearchTerm patch /advanced-search-action-search-term/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the advanced_search_action_search_term */
          id: string;
        };
        body: components["schemas"]["AdvancedSearchActionSearchTerm"];
        response: {
          data: components["schemas"]["AdvancedSearchActionSearchTerm"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the advanced_search_action_search_term */
          id: string;
        };
        body: components["schemas"]["AdvancedSearchActionSearchTerm"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AdvancedSearchActionSearchTerm"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the advanced_search_action_search_term */
          id: string;
        };
        body: {
          data?: components["schemas"]["AdvancedSearchActionSearchTerm"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["AdvancedSearchActionSearchTerm"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the advanced_search_action_search_term */
          id: string;
        };
        body: {
          data?: components["schemas"]["AdvancedSearchActionSearchTerm"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AdvancedSearchActionSearchTerm"];
        };
        responseCode: 200;
      };
  "getAdvancedSearchAction get /advanced-search-action/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the advanced_search_action */
          id: string;
        };
        response: {
          data: components["schemas"]["AdvancedSearchAction"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the advanced_search_action */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AdvancedSearchAction"];
        };
        responseCode: 200;
      };
  "deleteAdvancedSearchAction delete /advanced-search-action/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the advanced_search_action */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateAdvancedSearchAction patch /advanced-search-action/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the advanced_search_action */
          id: string;
        };
        body: components["schemas"]["AdvancedSearchAction"];
        response: {
          data: components["schemas"]["AdvancedSearchAction"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the advanced_search_action */
          id: string;
        };
        body: components["schemas"]["AdvancedSearchAction"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AdvancedSearchAction"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the advanced_search_action */
          id: string;
        };
        body: {
          data?: components["schemas"]["AdvancedSearchAction"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["AdvancedSearchAction"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the advanced_search_action */
          id: string;
        };
        body: {
          data?: components["schemas"]["AdvancedSearchAction"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AdvancedSearchAction"];
        };
        responseCode: 200;
      };
  "getAdvancedSearchBoostingList get /advanced-search-boosting":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["AdvancedSearchBoosting"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["AdvancedSearchBoosting"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /advanced-search-boosting?limit=25 */
            first?: unknown;
            /** @example /advanced-search-boosting?limit=25&page=11 */
            last?: unknown;
            /** @example /advanced-search-boosting?limit=25&page=4 */
            next?: unknown;
            /** @example /advanced-search-boosting?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createAdvancedSearchBoosting post /advanced-search-boosting":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["AdvancedSearchBoosting"];
        response: {
          data: components["schemas"]["AdvancedSearchBoosting"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["AdvancedSearchBoosting"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AdvancedSearchBoosting"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["AdvancedSearchBoosting"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["AdvancedSearchBoosting"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["AdvancedSearchBoosting"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AdvancedSearchBoosting"];
        };
        responseCode: 200;
      };
  "getAdvancedSearchBoosting get /advanced-search-boosting/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the advanced_search_boosting */
          id: string;
        };
        response: {
          data: components["schemas"]["AdvancedSearchBoosting"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the advanced_search_boosting */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AdvancedSearchBoosting"];
        };
        responseCode: 200;
      };
  "deleteAdvancedSearchBoosting delete /advanced-search-boosting/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the advanced_search_boosting */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateAdvancedSearchBoosting patch /advanced-search-boosting/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the advanced_search_boosting */
          id: string;
        };
        body: components["schemas"]["AdvancedSearchBoosting"];
        response: {
          data: components["schemas"]["AdvancedSearchBoosting"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the advanced_search_boosting */
          id: string;
        };
        body: components["schemas"]["AdvancedSearchBoosting"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AdvancedSearchBoosting"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the advanced_search_boosting */
          id: string;
        };
        body: {
          data?: components["schemas"]["AdvancedSearchBoosting"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["AdvancedSearchBoosting"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the advanced_search_boosting */
          id: string;
        };
        body: {
          data?: components["schemas"]["AdvancedSearchBoosting"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AdvancedSearchBoosting"];
        };
        responseCode: 200;
      };
  "getAdvancedSearchConfigList get /advanced-search-config":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["AdvancedSearchConfig"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["AdvancedSearchConfig"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /advanced-search-config?limit=25 */
            first?: unknown;
            /** @example /advanced-search-config?limit=25&page=11 */
            last?: unknown;
            /** @example /advanced-search-config?limit=25&page=4 */
            next?: unknown;
            /** @example /advanced-search-config?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createAdvancedSearchConfig post /advanced-search-config":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["AdvancedSearchConfig"];
        response: {
          data: components["schemas"]["AdvancedSearchConfig"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["AdvancedSearchConfig"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AdvancedSearchConfig"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["AdvancedSearchConfig"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["AdvancedSearchConfig"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["AdvancedSearchConfig"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AdvancedSearchConfig"];
        };
        responseCode: 200;
      };
  "getAdvancedSearchConfigFieldList get /advanced-search-config-field":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["AdvancedSearchConfigField"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["AdvancedSearchConfigField"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /advanced-search-config-field?limit=25 */
            first?: unknown;
            /** @example /advanced-search-config-field?limit=25&page=11 */
            last?: unknown;
            /** @example /advanced-search-config-field?limit=25&page=4 */
            next?: unknown;
            /** @example /advanced-search-config-field?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createAdvancedSearchConfigField post /advanced-search-config-field":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["AdvancedSearchConfigField"];
        response: {
          data: components["schemas"]["AdvancedSearchConfigField"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["AdvancedSearchConfigField"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AdvancedSearchConfigField"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["AdvancedSearchConfigField"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["AdvancedSearchConfigField"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["AdvancedSearchConfigField"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AdvancedSearchConfigField"];
        };
        responseCode: 200;
      };
  "getAdvancedSearchConfigField get /advanced-search-config-field/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the advanced_search_config_field */
          id: string;
        };
        response: {
          data: components["schemas"]["AdvancedSearchConfigField"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the advanced_search_config_field */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AdvancedSearchConfigField"];
        };
        responseCode: 200;
      };
  "deleteAdvancedSearchConfigField delete /advanced-search-config-field/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the advanced_search_config_field */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateAdvancedSearchConfigField patch /advanced-search-config-field/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the advanced_search_config_field */
          id: string;
        };
        body: components["schemas"]["AdvancedSearchConfigField"];
        response: {
          data: components["schemas"]["AdvancedSearchConfigField"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the advanced_search_config_field */
          id: string;
        };
        body: components["schemas"]["AdvancedSearchConfigField"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AdvancedSearchConfigField"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the advanced_search_config_field */
          id: string;
        };
        body: {
          data?: components["schemas"]["AdvancedSearchConfigField"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["AdvancedSearchConfigField"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the advanced_search_config_field */
          id: string;
        };
        body: {
          data?: components["schemas"]["AdvancedSearchConfigField"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AdvancedSearchConfigField"];
        };
        responseCode: 200;
      };
  "getAdvancedSearchConfig get /advanced-search-config/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the advanced_search_config */
          id: string;
        };
        response: {
          data: components["schemas"]["AdvancedSearchConfig"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the advanced_search_config */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AdvancedSearchConfig"];
        };
        responseCode: 200;
      };
  "deleteAdvancedSearchConfig delete /advanced-search-config/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the advanced_search_config */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateAdvancedSearchConfig patch /advanced-search-config/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the advanced_search_config */
          id: string;
        };
        body: components["schemas"]["AdvancedSearchConfig"];
        response: {
          data: components["schemas"]["AdvancedSearchConfig"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the advanced_search_config */
          id: string;
        };
        body: components["schemas"]["AdvancedSearchConfig"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AdvancedSearchConfig"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the advanced_search_config */
          id: string;
        };
        body: {
          data?: components["schemas"]["AdvancedSearchConfig"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["AdvancedSearchConfig"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the advanced_search_config */
          id: string;
        };
        body: {
          data?: components["schemas"]["AdvancedSearchConfig"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AdvancedSearchConfig"];
        };
        responseCode: 200;
      };
  "getAdvancedSearchEntityStreamList get /advanced-search-entity-stream":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["AdvancedSearchEntityStream"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["AdvancedSearchEntityStream"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /advanced-search-entity-stream?limit=25 */
            first?: unknown;
            /** @example /advanced-search-entity-stream?limit=25&page=11 */
            last?: unknown;
            /** @example /advanced-search-entity-stream?limit=25&page=4 */
            next?: unknown;
            /** @example /advanced-search-entity-stream?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createAdvancedSearchEntityStream post /advanced-search-entity-stream":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["AdvancedSearchEntityStream"];
        response: {
          data: components["schemas"]["AdvancedSearchEntityStream"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["AdvancedSearchEntityStream"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AdvancedSearchEntityStream"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["AdvancedSearchEntityStream"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["AdvancedSearchEntityStream"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["AdvancedSearchEntityStream"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AdvancedSearchEntityStream"];
        };
        responseCode: 200;
      };
  "getAdvancedSearchEntityStreamFilterList get /advanced-search-entity-stream-filter":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["AdvancedSearchEntityStreamFilter"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["AdvancedSearchEntityStreamFilter"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /advanced-search-entity-stream-filter?limit=25 */
            first?: unknown;
            /** @example /advanced-search-entity-stream-filter?limit=25&page=11 */
            last?: unknown;
            /** @example /advanced-search-entity-stream-filter?limit=25&page=4 */
            next?: unknown;
            /** @example /advanced-search-entity-stream-filter?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createAdvancedSearchEntityStreamFilter post /advanced-search-entity-stream-filter":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["AdvancedSearchEntityStreamFilter"];
        response: {
          data: components["schemas"]["AdvancedSearchEntityStreamFilter"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["AdvancedSearchEntityStreamFilter"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AdvancedSearchEntityStreamFilter"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["AdvancedSearchEntityStreamFilter"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["AdvancedSearchEntityStreamFilter"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["AdvancedSearchEntityStreamFilter"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AdvancedSearchEntityStreamFilter"];
        };
        responseCode: 200;
      };
  "getAdvancedSearchEntityStreamFilter get /advanced-search-entity-stream-filter/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the advanced_search_entity_stream_filter */
          id: string;
        };
        response: {
          data: components["schemas"]["AdvancedSearchEntityStreamFilter"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the advanced_search_entity_stream_filter */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AdvancedSearchEntityStreamFilter"];
        };
        responseCode: 200;
      };
  "deleteAdvancedSearchEntityStreamFilter delete /advanced-search-entity-stream-filter/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the advanced_search_entity_stream_filter */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateAdvancedSearchEntityStreamFilter patch /advanced-search-entity-stream-filter/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the advanced_search_entity_stream_filter */
          id: string;
        };
        body: components["schemas"]["AdvancedSearchEntityStreamFilter"];
        response: {
          data: components["schemas"]["AdvancedSearchEntityStreamFilter"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the advanced_search_entity_stream_filter */
          id: string;
        };
        body: components["schemas"]["AdvancedSearchEntityStreamFilter"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AdvancedSearchEntityStreamFilter"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the advanced_search_entity_stream_filter */
          id: string;
        };
        body: {
          data?: components["schemas"]["AdvancedSearchEntityStreamFilter"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["AdvancedSearchEntityStreamFilter"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the advanced_search_entity_stream_filter */
          id: string;
        };
        body: {
          data?: components["schemas"]["AdvancedSearchEntityStreamFilter"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AdvancedSearchEntityStreamFilter"];
        };
        responseCode: 200;
      };
  "getAdvancedSearchEntityStream get /advanced-search-entity-stream/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the advanced_search_entity_stream */
          id: string;
        };
        response: {
          data: components["schemas"]["AdvancedSearchEntityStream"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the advanced_search_entity_stream */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AdvancedSearchEntityStream"];
        };
        responseCode: 200;
      };
  "deleteAdvancedSearchEntityStream delete /advanced-search-entity-stream/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the advanced_search_entity_stream */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateAdvancedSearchEntityStream patch /advanced-search-entity-stream/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the advanced_search_entity_stream */
          id: string;
        };
        body: components["schemas"]["AdvancedSearchEntityStream"];
        response: {
          data: components["schemas"]["AdvancedSearchEntityStream"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the advanced_search_entity_stream */
          id: string;
        };
        body: components["schemas"]["AdvancedSearchEntityStream"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AdvancedSearchEntityStream"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the advanced_search_entity_stream */
          id: string;
        };
        body: {
          data?: components["schemas"]["AdvancedSearchEntityStream"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["AdvancedSearchEntityStream"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the advanced_search_entity_stream */
          id: string;
        };
        body: {
          data?: components["schemas"]["AdvancedSearchEntityStream"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AdvancedSearchEntityStream"];
        };
        responseCode: 200;
      };
  "getAdvancedSearchSynonymList get /advanced-search-synonym":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["AdvancedSearchSynonym"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["AdvancedSearchSynonym"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /advanced-search-synonym?limit=25 */
            first?: unknown;
            /** @example /advanced-search-synonym?limit=25&page=11 */
            last?: unknown;
            /** @example /advanced-search-synonym?limit=25&page=4 */
            next?: unknown;
            /** @example /advanced-search-synonym?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createAdvancedSearchSynonym post /advanced-search-synonym":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["AdvancedSearchSynonym"];
        response: {
          data: components["schemas"]["AdvancedSearchSynonym"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["AdvancedSearchSynonym"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AdvancedSearchSynonym"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["AdvancedSearchSynonym"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["AdvancedSearchSynonym"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["AdvancedSearchSynonym"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AdvancedSearchSynonym"];
        };
        responseCode: 200;
      };
  "getAdvancedSearchSynonym get /advanced-search-synonym/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the advanced_search_synonym */
          id: string;
        };
        response: {
          data: components["schemas"]["AdvancedSearchSynonym"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the advanced_search_synonym */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AdvancedSearchSynonym"];
        };
        responseCode: 200;
      };
  "deleteAdvancedSearchSynonym delete /advanced-search-synonym/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the advanced_search_synonym */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateAdvancedSearchSynonym patch /advanced-search-synonym/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the advanced_search_synonym */
          id: string;
        };
        body: components["schemas"]["AdvancedSearchSynonym"];
        response: {
          data: components["schemas"]["AdvancedSearchSynonym"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the advanced_search_synonym */
          id: string;
        };
        body: components["schemas"]["AdvancedSearchSynonym"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AdvancedSearchSynonym"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the advanced_search_synonym */
          id: string;
        };
        body: {
          data?: components["schemas"]["AdvancedSearchSynonym"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["AdvancedSearchSynonym"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the advanced_search_synonym */
          id: string;
        };
        body: {
          data?: components["schemas"]["AdvancedSearchSynonym"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AdvancedSearchSynonym"];
        };
        responseCode: 200;
      };
  "rulePreview post /api/_admin/rule-builder-preview/{orderId}": {
    contentType?: "application/json";
    accept?: "application/json";
    pathParams: {
      /** Identifier of the order the preview should be generated for */
      orderId: string;
    };
    body: {
      /** Array of nested rule condition payloads. */
      conditions: GenericRecord[];
      /** A date and time to be mocked in the preview evaluation. */
      dateTime?: string;
    };
    response: {
      /** Evaluation of the condition */
      match?: boolean;
      /** The technical name of the condition */
      name?: string;
      /** The id of the corresponding rule_condition entity */
      ruleReferenceId?: string;
    }[];
    responseCode: 200;
  };
  "getAppList get /app":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["App"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] & components["schemas"]["App"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /app?limit=25 */
            first?: unknown;
            /** @example /app?limit=25&page=11 */
            last?: unknown;
            /** @example /app?limit=25&page=4 */
            next?: unknown;
            /** @example /app?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createApp post /app":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["App"];
        response: {
          data: components["schemas"]["App"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["App"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["App"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["App"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["App"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["App"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["App"];
        };
        responseCode: 200;
      };
  "getAppActionButtonList get /app-action-button":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["AppActionButton"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["AppActionButton"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /app-action-button?limit=25 */
            first?: unknown;
            /** @example /app-action-button?limit=25&page=11 */
            last?: unknown;
            /** @example /app-action-button?limit=25&page=4 */
            next?: unknown;
            /** @example /app-action-button?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createAppActionButton post /app-action-button":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["AppActionButton"];
        response: {
          data: components["schemas"]["AppActionButton"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["AppActionButton"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppActionButton"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["AppActionButton"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["AppActionButton"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["AppActionButton"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppActionButton"];
        };
        responseCode: 200;
      };
  "getAppActionButton get /app-action-button/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the app_action_button */
          id: string;
        };
        response: {
          data: components["schemas"]["AppActionButton"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the app_action_button */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppActionButton"];
        };
        responseCode: 200;
      };
  "deleteAppActionButton delete /app-action-button/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the app_action_button */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateAppActionButton patch /app-action-button/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the app_action_button */
          id: string;
        };
        body: components["schemas"]["AppActionButton"];
        response: {
          data: components["schemas"]["AppActionButton"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the app_action_button */
          id: string;
        };
        body: components["schemas"]["AppActionButton"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppActionButton"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the app_action_button */
          id: string;
        };
        body: {
          data?: components["schemas"]["AppActionButton"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["AppActionButton"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the app_action_button */
          id: string;
        };
        body: {
          data?: components["schemas"]["AppActionButton"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppActionButton"];
        };
        responseCode: 200;
      };
  "getAppAdministrationSnippetList get /app-administration-snippet":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["AppAdministrationSnippet"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["AppAdministrationSnippet"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /app-administration-snippet?limit=25 */
            first?: unknown;
            /** @example /app-administration-snippet?limit=25&page=11 */
            last?: unknown;
            /** @example /app-administration-snippet?limit=25&page=4 */
            next?: unknown;
            /** @example /app-administration-snippet?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createAppAdministrationSnippet post /app-administration-snippet":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["AppAdministrationSnippet"];
        response: {
          data: components["schemas"]["AppAdministrationSnippet"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["AppAdministrationSnippet"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppAdministrationSnippet"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["AppAdministrationSnippet"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["AppAdministrationSnippet"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["AppAdministrationSnippet"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppAdministrationSnippet"];
        };
        responseCode: 200;
      };
  "getAppAdministrationSnippet get /app-administration-snippet/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the app_administration_snippet */
          id: string;
        };
        response: {
          data: components["schemas"]["AppAdministrationSnippet"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the app_administration_snippet */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppAdministrationSnippet"];
        };
        responseCode: 200;
      };
  "deleteAppAdministrationSnippet delete /app-administration-snippet/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the app_administration_snippet */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateAppAdministrationSnippet patch /app-administration-snippet/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the app_administration_snippet */
          id: string;
        };
        body: components["schemas"]["AppAdministrationSnippet"];
        response: {
          data: components["schemas"]["AppAdministrationSnippet"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the app_administration_snippet */
          id: string;
        };
        body: components["schemas"]["AppAdministrationSnippet"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppAdministrationSnippet"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the app_administration_snippet */
          id: string;
        };
        body: {
          data?: components["schemas"]["AppAdministrationSnippet"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["AppAdministrationSnippet"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the app_administration_snippet */
          id: string;
        };
        body: {
          data?: components["schemas"]["AppAdministrationSnippet"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppAdministrationSnippet"];
        };
        responseCode: 200;
      };
  "getAppCmsBlockList get /app-cms-block":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["AppCmsBlock"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["AppCmsBlock"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /app-cms-block?limit=25 */
            first?: unknown;
            /** @example /app-cms-block?limit=25&page=11 */
            last?: unknown;
            /** @example /app-cms-block?limit=25&page=4 */
            next?: unknown;
            /** @example /app-cms-block?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createAppCmsBlock post /app-cms-block":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["AppCmsBlock"];
        response: {
          data: components["schemas"]["AppCmsBlock"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["AppCmsBlock"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppCmsBlock"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["AppCmsBlock"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["AppCmsBlock"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["AppCmsBlock"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppCmsBlock"];
        };
        responseCode: 200;
      };
  "getAppCmsBlock get /app-cms-block/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the app_cms_block */
          id: string;
        };
        response: {
          data: components["schemas"]["AppCmsBlock"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the app_cms_block */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppCmsBlock"];
        };
        responseCode: 200;
      };
  "deleteAppCmsBlock delete /app-cms-block/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the app_cms_block */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateAppCmsBlock patch /app-cms-block/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the app_cms_block */
          id: string;
        };
        body: components["schemas"]["AppCmsBlock"];
        response: {
          data: components["schemas"]["AppCmsBlock"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the app_cms_block */
          id: string;
        };
        body: components["schemas"]["AppCmsBlock"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppCmsBlock"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the app_cms_block */
          id: string;
        };
        body: {
          data?: components["schemas"]["AppCmsBlock"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["AppCmsBlock"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the app_cms_block */
          id: string;
        };
        body: {
          data?: components["schemas"]["AppCmsBlock"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppCmsBlock"];
        };
        responseCode: 200;
      };
  "getAppFlowActionList get /app-flow-action":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["AppFlowAction"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["AppFlowAction"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /app-flow-action?limit=25 */
            first?: unknown;
            /** @example /app-flow-action?limit=25&page=11 */
            last?: unknown;
            /** @example /app-flow-action?limit=25&page=4 */
            next?: unknown;
            /** @example /app-flow-action?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createAppFlowAction post /app-flow-action":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["AppFlowAction"];
        response: {
          data: components["schemas"]["AppFlowAction"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["AppFlowAction"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppFlowAction"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["AppFlowAction"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["AppFlowAction"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["AppFlowAction"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppFlowAction"];
        };
        responseCode: 200;
      };
  "getAppFlowAction get /app-flow-action/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the app_flow_action */
          id: string;
        };
        response: {
          data: components["schemas"]["AppFlowAction"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the app_flow_action */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppFlowAction"];
        };
        responseCode: 200;
      };
  "deleteAppFlowAction delete /app-flow-action/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the app_flow_action */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateAppFlowAction patch /app-flow-action/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the app_flow_action */
          id: string;
        };
        body: components["schemas"]["AppFlowAction"];
        response: {
          data: components["schemas"]["AppFlowAction"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the app_flow_action */
          id: string;
        };
        body: components["schemas"]["AppFlowAction"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppFlowAction"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the app_flow_action */
          id: string;
        };
        body: {
          data?: components["schemas"]["AppFlowAction"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["AppFlowAction"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the app_flow_action */
          id: string;
        };
        body: {
          data?: components["schemas"]["AppFlowAction"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppFlowAction"];
        };
        responseCode: 200;
      };
  "getAppFlowEventList get /app-flow-event":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["AppFlowEvent"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["AppFlowEvent"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /app-flow-event?limit=25 */
            first?: unknown;
            /** @example /app-flow-event?limit=25&page=11 */
            last?: unknown;
            /** @example /app-flow-event?limit=25&page=4 */
            next?: unknown;
            /** @example /app-flow-event?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createAppFlowEvent post /app-flow-event":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["AppFlowEvent"];
        response: {
          data: components["schemas"]["AppFlowEvent"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["AppFlowEvent"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppFlowEvent"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["AppFlowEvent"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["AppFlowEvent"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["AppFlowEvent"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppFlowEvent"];
        };
        responseCode: 200;
      };
  "getAppFlowEvent get /app-flow-event/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the app_flow_event */
          id: string;
        };
        response: {
          data: components["schemas"]["AppFlowEvent"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the app_flow_event */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppFlowEvent"];
        };
        responseCode: 200;
      };
  "deleteAppFlowEvent delete /app-flow-event/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the app_flow_event */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateAppFlowEvent patch /app-flow-event/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the app_flow_event */
          id: string;
        };
        body: components["schemas"]["AppFlowEvent"];
        response: {
          data: components["schemas"]["AppFlowEvent"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the app_flow_event */
          id: string;
        };
        body: components["schemas"]["AppFlowEvent"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppFlowEvent"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the app_flow_event */
          id: string;
        };
        body: {
          data?: components["schemas"]["AppFlowEvent"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["AppFlowEvent"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the app_flow_event */
          id: string;
        };
        body: {
          data?: components["schemas"]["AppFlowEvent"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppFlowEvent"];
        };
        responseCode: 200;
      };
  "getAppPaymentMethodList get /app-payment-method":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["AppPaymentMethod"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["AppPaymentMethod"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /app-payment-method?limit=25 */
            first?: unknown;
            /** @example /app-payment-method?limit=25&page=11 */
            last?: unknown;
            /** @example /app-payment-method?limit=25&page=4 */
            next?: unknown;
            /** @example /app-payment-method?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createAppPaymentMethod post /app-payment-method":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["AppPaymentMethod"];
        response: {
          data: components["schemas"]["AppPaymentMethod"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["AppPaymentMethod"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppPaymentMethod"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["AppPaymentMethod"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["AppPaymentMethod"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["AppPaymentMethod"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppPaymentMethod"];
        };
        responseCode: 200;
      };
  "getAppPaymentMethod get /app-payment-method/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the app_payment_method */
          id: string;
        };
        response: {
          data: components["schemas"]["AppPaymentMethod"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the app_payment_method */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppPaymentMethod"];
        };
        responseCode: 200;
      };
  "deleteAppPaymentMethod delete /app-payment-method/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the app_payment_method */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateAppPaymentMethod patch /app-payment-method/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the app_payment_method */
          id: string;
        };
        body: components["schemas"]["AppPaymentMethod"];
        response: {
          data: components["schemas"]["AppPaymentMethod"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the app_payment_method */
          id: string;
        };
        body: components["schemas"]["AppPaymentMethod"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppPaymentMethod"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the app_payment_method */
          id: string;
        };
        body: {
          data?: components["schemas"]["AppPaymentMethod"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["AppPaymentMethod"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the app_payment_method */
          id: string;
        };
        body: {
          data?: components["schemas"]["AppPaymentMethod"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppPaymentMethod"];
        };
        responseCode: 200;
      };
  "getAppScriptConditionList get /app-script-condition":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["AppScriptCondition"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["AppScriptCondition"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /app-script-condition?limit=25 */
            first?: unknown;
            /** @example /app-script-condition?limit=25&page=11 */
            last?: unknown;
            /** @example /app-script-condition?limit=25&page=4 */
            next?: unknown;
            /** @example /app-script-condition?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createAppScriptCondition post /app-script-condition":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["AppScriptCondition"];
        response: {
          data: components["schemas"]["AppScriptCondition"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["AppScriptCondition"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppScriptCondition"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["AppScriptCondition"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["AppScriptCondition"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["AppScriptCondition"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppScriptCondition"];
        };
        responseCode: 200;
      };
  "getAppScriptCondition get /app-script-condition/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the app_script_condition */
          id: string;
        };
        response: {
          data: components["schemas"]["AppScriptCondition"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the app_script_condition */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppScriptCondition"];
        };
        responseCode: 200;
      };
  "deleteAppScriptCondition delete /app-script-condition/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the app_script_condition */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateAppScriptCondition patch /app-script-condition/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the app_script_condition */
          id: string;
        };
        body: components["schemas"]["AppScriptCondition"];
        response: {
          data: components["schemas"]["AppScriptCondition"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the app_script_condition */
          id: string;
        };
        body: components["schemas"]["AppScriptCondition"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppScriptCondition"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the app_script_condition */
          id: string;
        };
        body: {
          data?: components["schemas"]["AppScriptCondition"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["AppScriptCondition"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the app_script_condition */
          id: string;
        };
        body: {
          data?: components["schemas"]["AppScriptCondition"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppScriptCondition"];
        };
        responseCode: 200;
      };
  "getAppShippingMethodList get /app-shipping-method":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["AppShippingMethod"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["AppShippingMethod"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /app-shipping-method?limit=25 */
            first?: unknown;
            /** @example /app-shipping-method?limit=25&page=11 */
            last?: unknown;
            /** @example /app-shipping-method?limit=25&page=4 */
            next?: unknown;
            /** @example /app-shipping-method?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createAppShippingMethod post /app-shipping-method":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["AppShippingMethod"];
        response: {
          data: components["schemas"]["AppShippingMethod"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["AppShippingMethod"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppShippingMethod"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["AppShippingMethod"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["AppShippingMethod"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["AppShippingMethod"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppShippingMethod"];
        };
        responseCode: 200;
      };
  "getAppShippingMethod get /app-shipping-method/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the app_shipping_method */
          id: string;
        };
        response: {
          data: components["schemas"]["AppShippingMethod"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the app_shipping_method */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppShippingMethod"];
        };
        responseCode: 200;
      };
  "deleteAppShippingMethod delete /app-shipping-method/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the app_shipping_method */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateAppShippingMethod patch /app-shipping-method/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the app_shipping_method */
          id: string;
        };
        body: components["schemas"]["AppShippingMethod"];
        response: {
          data: components["schemas"]["AppShippingMethod"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the app_shipping_method */
          id: string;
        };
        body: components["schemas"]["AppShippingMethod"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppShippingMethod"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the app_shipping_method */
          id: string;
        };
        body: {
          data?: components["schemas"]["AppShippingMethod"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["AppShippingMethod"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the app_shipping_method */
          id: string;
        };
        body: {
          data?: components["schemas"]["AppShippingMethod"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppShippingMethod"];
        };
        responseCode: 200;
      };
  "getAppTemplateList get /app-template":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["AppTemplate"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["AppTemplate"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /app-template?limit=25 */
            first?: unknown;
            /** @example /app-template?limit=25&page=11 */
            last?: unknown;
            /** @example /app-template?limit=25&page=4 */
            next?: unknown;
            /** @example /app-template?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createAppTemplate post /app-template":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["AppTemplate"];
        response: {
          data: components["schemas"]["AppTemplate"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["AppTemplate"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppTemplate"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["AppTemplate"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["AppTemplate"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["AppTemplate"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppTemplate"];
        };
        responseCode: 200;
      };
  "getAppTemplate get /app-template/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the app_template */
          id: string;
        };
        response: {
          data: components["schemas"]["AppTemplate"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the app_template */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppTemplate"];
        };
        responseCode: 200;
      };
  "deleteAppTemplate delete /app-template/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the app_template */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateAppTemplate patch /app-template/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the app_template */
          id: string;
        };
        body: components["schemas"]["AppTemplate"];
        response: {
          data: components["schemas"]["AppTemplate"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the app_template */
          id: string;
        };
        body: components["schemas"]["AppTemplate"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppTemplate"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the app_template */
          id: string;
        };
        body: {
          data?: components["schemas"]["AppTemplate"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["AppTemplate"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the app_template */
          id: string;
        };
        body: {
          data?: components["schemas"]["AppTemplate"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppTemplate"];
        };
        responseCode: 200;
      };
  "getApp get /app/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the app */
          id: string;
        };
        response: {
          data: components["schemas"]["App"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the app */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["App"];
        };
        responseCode: 200;
      };
  "deleteApp delete /app/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the app */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateApp patch /app/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the app */
          id: string;
        };
        body: components["schemas"]["App"];
        response: {
          data: components["schemas"]["App"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the app */
          id: string;
        };
        body: components["schemas"]["App"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["App"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the app */
          id: string;
        };
        body: {
          data?: components["schemas"]["App"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["App"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the app */
          id: string;
        };
        body: {
          data?: components["schemas"]["App"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["App"];
        };
        responseCode: 200;
      };
  "getB2bBusinessPartnerList get /b2b-business-partner":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["B2bBusinessPartner"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["B2bBusinessPartner"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /b2b-business-partner?limit=25 */
            first?: unknown;
            /** @example /b2b-business-partner?limit=25&page=11 */
            last?: unknown;
            /** @example /b2b-business-partner?limit=25&page=4 */
            next?: unknown;
            /** @example /b2b-business-partner?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createB2bBusinessPartner post /b2b-business-partner":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["B2bBusinessPartner"];
        response: {
          data: components["schemas"]["B2bBusinessPartner"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["B2bBusinessPartner"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bBusinessPartner"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["B2bBusinessPartner"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["B2bBusinessPartner"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["B2bBusinessPartner"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bBusinessPartner"];
        };
        responseCode: 200;
      };
  "getB2bBusinessPartner get /b2b-business-partner/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the b2b_business_partner */
          id: string;
        };
        response: {
          data: components["schemas"]["B2bBusinessPartner"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the b2b_business_partner */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bBusinessPartner"];
        };
        responseCode: 200;
      };
  "deleteB2bBusinessPartner delete /b2b-business-partner/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the b2b_business_partner */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateB2bBusinessPartner patch /b2b-business-partner/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the b2b_business_partner */
          id: string;
        };
        body: components["schemas"]["B2bBusinessPartner"];
        response: {
          data: components["schemas"]["B2bBusinessPartner"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the b2b_business_partner */
          id: string;
        };
        body: components["schemas"]["B2bBusinessPartner"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bBusinessPartner"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the b2b_business_partner */
          id: string;
        };
        body: {
          data?: components["schemas"]["B2bBusinessPartner"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["B2bBusinessPartner"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the b2b_business_partner */
          id: string;
        };
        body: {
          data?: components["schemas"]["B2bBusinessPartner"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bBusinessPartner"];
        };
        responseCode: 200;
      };
  "getB2bComponentsApprovalRuleList get /b2b-components-approval-rule":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["B2bComponentsApprovalRule"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["B2bComponentsApprovalRule"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /b2b-components-approval-rule?limit=25 */
            first?: unknown;
            /** @example /b2b-components-approval-rule?limit=25&page=11 */
            last?: unknown;
            /** @example /b2b-components-approval-rule?limit=25&page=4 */
            next?: unknown;
            /** @example /b2b-components-approval-rule?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createB2bComponentsApprovalRule post /b2b-components-approval-rule":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["B2bComponentsApprovalRule"];
        response: {
          data: components["schemas"]["B2bComponentsApprovalRule"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["B2bComponentsApprovalRule"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bComponentsApprovalRule"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["B2bComponentsApprovalRule"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["B2bComponentsApprovalRule"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["B2bComponentsApprovalRule"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bComponentsApprovalRule"];
        };
        responseCode: 200;
      };
  "getB2bComponentsApprovalRuleAppScriptConditionList get /b2b-components-approval-rule-app-script-condition":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["B2bComponentsApprovalRuleAppScriptCondition"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["B2bComponentsApprovalRuleAppScriptCondition"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /b2b-components-approval-rule-app-script-condition?limit=25 */
            first?: unknown;
            /** @example /b2b-components-approval-rule-app-script-condition?limit=25&page=11 */
            last?: unknown;
            /** @example /b2b-components-approval-rule-app-script-condition?limit=25&page=4 */
            next?: unknown;
            /** @example /b2b-components-approval-rule-app-script-condition?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createB2bComponentsApprovalRuleAppScriptCondition post /b2b-components-approval-rule-app-script-condition":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["B2bComponentsApprovalRuleAppScriptCondition"];
        response: {
          data: components["schemas"]["B2bComponentsApprovalRuleAppScriptCondition"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["B2bComponentsApprovalRuleAppScriptCondition"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bComponentsApprovalRuleAppScriptCondition"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["B2bComponentsApprovalRuleAppScriptCondition"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["B2bComponentsApprovalRuleAppScriptCondition"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["B2bComponentsApprovalRuleAppScriptCondition"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bComponentsApprovalRuleAppScriptCondition"];
        };
        responseCode: 200;
      };
  "getB2bComponentsApprovalRuleAppScriptCondition get /b2b-components-approval-rule-app-script-condition/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the b2b_components_approval_rule_app_script_condition */
          id: string;
        };
        response: {
          data: components["schemas"]["B2bComponentsApprovalRuleAppScriptCondition"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the b2b_components_approval_rule_app_script_condition */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bComponentsApprovalRuleAppScriptCondition"];
        };
        responseCode: 200;
      };
  "deleteB2bComponentsApprovalRuleAppScriptCondition delete /b2b-components-approval-rule-app-script-condition/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the b2b_components_approval_rule_app_script_condition */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateB2bComponentsApprovalRuleAppScriptCondition patch /b2b-components-approval-rule-app-script-condition/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the b2b_components_approval_rule_app_script_condition */
          id: string;
        };
        body: components["schemas"]["B2bComponentsApprovalRuleAppScriptCondition"];
        response: {
          data: components["schemas"]["B2bComponentsApprovalRuleAppScriptCondition"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the b2b_components_approval_rule_app_script_condition */
          id: string;
        };
        body: components["schemas"]["B2bComponentsApprovalRuleAppScriptCondition"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bComponentsApprovalRuleAppScriptCondition"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the b2b_components_approval_rule_app_script_condition */
          id: string;
        };
        body: {
          data?: components["schemas"]["B2bComponentsApprovalRuleAppScriptCondition"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["B2bComponentsApprovalRuleAppScriptCondition"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the b2b_components_approval_rule_app_script_condition */
          id: string;
        };
        body: {
          data?: components["schemas"]["B2bComponentsApprovalRuleAppScriptCondition"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bComponentsApprovalRuleAppScriptCondition"];
        };
        responseCode: 200;
      };
  "getB2bComponentsApprovalRule get /b2b-components-approval-rule/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the b2b_components_approval_rule */
          id: string;
        };
        response: {
          data: components["schemas"]["B2bComponentsApprovalRule"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the b2b_components_approval_rule */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bComponentsApprovalRule"];
        };
        responseCode: 200;
      };
  "deleteB2bComponentsApprovalRule delete /b2b-components-approval-rule/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the b2b_components_approval_rule */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateB2bComponentsApprovalRule patch /b2b-components-approval-rule/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the b2b_components_approval_rule */
          id: string;
        };
        body: components["schemas"]["B2bComponentsApprovalRule"];
        response: {
          data: components["schemas"]["B2bComponentsApprovalRule"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the b2b_components_approval_rule */
          id: string;
        };
        body: components["schemas"]["B2bComponentsApprovalRule"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bComponentsApprovalRule"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the b2b_components_approval_rule */
          id: string;
        };
        body: {
          data?: components["schemas"]["B2bComponentsApprovalRule"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["B2bComponentsApprovalRule"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the b2b_components_approval_rule */
          id: string;
        };
        body: {
          data?: components["schemas"]["B2bComponentsApprovalRule"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bComponentsApprovalRule"];
        };
        responseCode: 200;
      };
  "getB2bComponentsPendingOrderList get /b2b-components-pending-order":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["B2bComponentsPendingOrder"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["B2bComponentsPendingOrder"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /b2b-components-pending-order?limit=25 */
            first?: unknown;
            /** @example /b2b-components-pending-order?limit=25&page=11 */
            last?: unknown;
            /** @example /b2b-components-pending-order?limit=25&page=4 */
            next?: unknown;
            /** @example /b2b-components-pending-order?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createB2bComponentsPendingOrder post /b2b-components-pending-order":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["B2bComponentsPendingOrder"];
        response: {
          data: components["schemas"]["B2bComponentsPendingOrder"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["B2bComponentsPendingOrder"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bComponentsPendingOrder"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["B2bComponentsPendingOrder"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["B2bComponentsPendingOrder"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["B2bComponentsPendingOrder"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bComponentsPendingOrder"];
        };
        responseCode: 200;
      };
  "getB2bComponentsPendingOrderAddressList get /b2b-components-pending-order-address":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["B2bComponentsPendingOrderAddress"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["B2bComponentsPendingOrderAddress"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /b2b-components-pending-order-address?limit=25 */
            first?: unknown;
            /** @example /b2b-components-pending-order-address?limit=25&page=11 */
            last?: unknown;
            /** @example /b2b-components-pending-order-address?limit=25&page=4 */
            next?: unknown;
            /** @example /b2b-components-pending-order-address?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createB2bComponentsPendingOrderAddress post /b2b-components-pending-order-address":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["B2bComponentsPendingOrderAddress"];
        response: {
          data: components["schemas"]["B2bComponentsPendingOrderAddress"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["B2bComponentsPendingOrderAddress"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bComponentsPendingOrderAddress"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["B2bComponentsPendingOrderAddress"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["B2bComponentsPendingOrderAddress"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["B2bComponentsPendingOrderAddress"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bComponentsPendingOrderAddress"];
        };
        responseCode: 200;
      };
  "getB2bComponentsPendingOrderAddress get /b2b-components-pending-order-address/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the b2b_components_pending_order_address */
          id: string;
        };
        response: {
          data: components["schemas"]["B2bComponentsPendingOrderAddress"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the b2b_components_pending_order_address */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bComponentsPendingOrderAddress"];
        };
        responseCode: 200;
      };
  "deleteB2bComponentsPendingOrderAddress delete /b2b-components-pending-order-address/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the b2b_components_pending_order_address */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateB2bComponentsPendingOrderAddress patch /b2b-components-pending-order-address/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the b2b_components_pending_order_address */
          id: string;
        };
        body: components["schemas"]["B2bComponentsPendingOrderAddress"];
        response: {
          data: components["schemas"]["B2bComponentsPendingOrderAddress"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the b2b_components_pending_order_address */
          id: string;
        };
        body: components["schemas"]["B2bComponentsPendingOrderAddress"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bComponentsPendingOrderAddress"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the b2b_components_pending_order_address */
          id: string;
        };
        body: {
          data?: components["schemas"]["B2bComponentsPendingOrderAddress"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["B2bComponentsPendingOrderAddress"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the b2b_components_pending_order_address */
          id: string;
        };
        body: {
          data?: components["schemas"]["B2bComponentsPendingOrderAddress"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bComponentsPendingOrderAddress"];
        };
        responseCode: 200;
      };
  "getB2bComponentsPendingOrder get /b2b-components-pending-order/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the b2b_components_pending_order */
          id: string;
        };
        response: {
          data: components["schemas"]["B2bComponentsPendingOrder"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the b2b_components_pending_order */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bComponentsPendingOrder"];
        };
        responseCode: 200;
      };
  "deleteB2bComponentsPendingOrder delete /b2b-components-pending-order/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the b2b_components_pending_order */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateB2bComponentsPendingOrder patch /b2b-components-pending-order/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the b2b_components_pending_order */
          id: string;
        };
        body: components["schemas"]["B2bComponentsPendingOrder"];
        response: {
          data: components["schemas"]["B2bComponentsPendingOrder"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the b2b_components_pending_order */
          id: string;
        };
        body: components["schemas"]["B2bComponentsPendingOrder"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bComponentsPendingOrder"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the b2b_components_pending_order */
          id: string;
        };
        body: {
          data?: components["schemas"]["B2bComponentsPendingOrder"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["B2bComponentsPendingOrder"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the b2b_components_pending_order */
          id: string;
        };
        body: {
          data?: components["schemas"]["B2bComponentsPendingOrder"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bComponentsPendingOrder"];
        };
        responseCode: 200;
      };
  "getB2bComponentsRoleList get /b2b-components-role":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["B2bComponentsRole"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["B2bComponentsRole"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /b2b-components-role?limit=25 */
            first?: unknown;
            /** @example /b2b-components-role?limit=25&page=11 */
            last?: unknown;
            /** @example /b2b-components-role?limit=25&page=4 */
            next?: unknown;
            /** @example /b2b-components-role?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createB2bComponentsRole post /b2b-components-role":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["B2bComponentsRole"];
        response: {
          data: components["schemas"]["B2bComponentsRole"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["B2bComponentsRole"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bComponentsRole"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["B2bComponentsRole"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["B2bComponentsRole"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["B2bComponentsRole"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bComponentsRole"];
        };
        responseCode: 200;
      };
  "getB2bComponentsRole get /b2b-components-role/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the b2b_components_role */
          id: string;
        };
        response: {
          data: components["schemas"]["B2bComponentsRole"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the b2b_components_role */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bComponentsRole"];
        };
        responseCode: 200;
      };
  "deleteB2bComponentsRole delete /b2b-components-role/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the b2b_components_role */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateB2bComponentsRole patch /b2b-components-role/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the b2b_components_role */
          id: string;
        };
        body: components["schemas"]["B2bComponentsRole"];
        response: {
          data: components["schemas"]["B2bComponentsRole"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the b2b_components_role */
          id: string;
        };
        body: components["schemas"]["B2bComponentsRole"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bComponentsRole"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the b2b_components_role */
          id: string;
        };
        body: {
          data?: components["schemas"]["B2bComponentsRole"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["B2bComponentsRole"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the b2b_components_role */
          id: string;
        };
        body: {
          data?: components["schemas"]["B2bComponentsRole"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bComponentsRole"];
        };
        responseCode: 200;
      };
  "getB2bComponentsShoppingListList get /b2b-components-shopping-list":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["B2bComponentsShoppingList"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["B2bComponentsShoppingList"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /b2b-components-shopping-list?limit=25 */
            first?: unknown;
            /** @example /b2b-components-shopping-list?limit=25&page=11 */
            last?: unknown;
            /** @example /b2b-components-shopping-list?limit=25&page=4 */
            next?: unknown;
            /** @example /b2b-components-shopping-list?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createB2bComponentsShoppingList post /b2b-components-shopping-list":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["B2bComponentsShoppingList"];
        response: {
          data: components["schemas"]["B2bComponentsShoppingList"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["B2bComponentsShoppingList"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bComponentsShoppingList"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["B2bComponentsShoppingList"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["B2bComponentsShoppingList"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["B2bComponentsShoppingList"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bComponentsShoppingList"];
        };
        responseCode: 200;
      };
  "getB2bComponentsShoppingListLineItemList get /b2b-components-shopping-list-line-item":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["B2bComponentsShoppingListLineItem"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["B2bComponentsShoppingListLineItem"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /b2b-components-shopping-list-line-item?limit=25 */
            first?: unknown;
            /** @example /b2b-components-shopping-list-line-item?limit=25&page=11 */
            last?: unknown;
            /** @example /b2b-components-shopping-list-line-item?limit=25&page=4 */
            next?: unknown;
            /** @example /b2b-components-shopping-list-line-item?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createB2bComponentsShoppingListLineItem post /b2b-components-shopping-list-line-item":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["B2bComponentsShoppingListLineItem"];
        response: {
          data: components["schemas"]["B2bComponentsShoppingListLineItem"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["B2bComponentsShoppingListLineItem"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bComponentsShoppingListLineItem"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["B2bComponentsShoppingListLineItem"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["B2bComponentsShoppingListLineItem"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["B2bComponentsShoppingListLineItem"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bComponentsShoppingListLineItem"];
        };
        responseCode: 200;
      };
  "getB2bComponentsShoppingListLineItem get /b2b-components-shopping-list-line-item/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the b2b_components_shopping_list_line_item */
          id: string;
        };
        response: {
          data: components["schemas"]["B2bComponentsShoppingListLineItem"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the b2b_components_shopping_list_line_item */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bComponentsShoppingListLineItem"];
        };
        responseCode: 200;
      };
  "deleteB2bComponentsShoppingListLineItem delete /b2b-components-shopping-list-line-item/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the b2b_components_shopping_list_line_item */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateB2bComponentsShoppingListLineItem patch /b2b-components-shopping-list-line-item/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the b2b_components_shopping_list_line_item */
          id: string;
        };
        body: components["schemas"]["B2bComponentsShoppingListLineItem"];
        response: {
          data: components["schemas"]["B2bComponentsShoppingListLineItem"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the b2b_components_shopping_list_line_item */
          id: string;
        };
        body: components["schemas"]["B2bComponentsShoppingListLineItem"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bComponentsShoppingListLineItem"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the b2b_components_shopping_list_line_item */
          id: string;
        };
        body: {
          data?: components["schemas"]["B2bComponentsShoppingListLineItem"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["B2bComponentsShoppingListLineItem"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the b2b_components_shopping_list_line_item */
          id: string;
        };
        body: {
          data?: components["schemas"]["B2bComponentsShoppingListLineItem"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bComponentsShoppingListLineItem"];
        };
        responseCode: 200;
      };
  "getB2bComponentsShoppingList get /b2b-components-shopping-list/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the b2b_components_shopping_list */
          id: string;
        };
        response: {
          data: components["schemas"]["B2bComponentsShoppingList"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the b2b_components_shopping_list */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bComponentsShoppingList"];
        };
        responseCode: 200;
      };
  "deleteB2bComponentsShoppingList delete /b2b-components-shopping-list/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the b2b_components_shopping_list */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateB2bComponentsShoppingList patch /b2b-components-shopping-list/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the b2b_components_shopping_list */
          id: string;
        };
        body: components["schemas"]["B2bComponentsShoppingList"];
        response: {
          data: components["schemas"]["B2bComponentsShoppingList"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the b2b_components_shopping_list */
          id: string;
        };
        body: components["schemas"]["B2bComponentsShoppingList"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bComponentsShoppingList"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the b2b_components_shopping_list */
          id: string;
        };
        body: {
          data?: components["schemas"]["B2bComponentsShoppingList"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["B2bComponentsShoppingList"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the b2b_components_shopping_list */
          id: string;
        };
        body: {
          data?: components["schemas"]["B2bComponentsShoppingList"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bComponentsShoppingList"];
        };
        responseCode: 200;
      };
  "getB2bEmployeeList get /b2b-employee":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["B2bEmployee"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["B2bEmployee"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /b2b-employee?limit=25 */
            first?: unknown;
            /** @example /b2b-employee?limit=25&page=11 */
            last?: unknown;
            /** @example /b2b-employee?limit=25&page=4 */
            next?: unknown;
            /** @example /b2b-employee?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createB2bEmployee post /b2b-employee":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["B2bEmployee"];
        response: {
          data: components["schemas"]["B2bEmployee"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["B2bEmployee"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bEmployee"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["B2bEmployee"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["B2bEmployee"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["B2bEmployee"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bEmployee"];
        };
        responseCode: 200;
      };
  "getB2bEmployee get /b2b-employee/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the b2b_employee */
          id: string;
        };
        response: {
          data: components["schemas"]["B2bEmployee"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the b2b_employee */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bEmployee"];
        };
        responseCode: 200;
      };
  "deleteB2bEmployee delete /b2b-employee/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the b2b_employee */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateB2bEmployee patch /b2b-employee/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the b2b_employee */
          id: string;
        };
        body: components["schemas"]["B2bEmployee"];
        response: {
          data: components["schemas"]["B2bEmployee"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the b2b_employee */
          id: string;
        };
        body: components["schemas"]["B2bEmployee"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bEmployee"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the b2b_employee */
          id: string;
        };
        body: {
          data?: components["schemas"]["B2bEmployee"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["B2bEmployee"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the b2b_employee */
          id: string;
        };
        body: {
          data?: components["schemas"]["B2bEmployee"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bEmployee"];
        };
        responseCode: 200;
      };
  "getB2bOrderEmployeeList get /b2b-order-employee":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["B2bOrderEmployee"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["B2bOrderEmployee"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /b2b-order-employee?limit=25 */
            first?: unknown;
            /** @example /b2b-order-employee?limit=25&page=11 */
            last?: unknown;
            /** @example /b2b-order-employee?limit=25&page=4 */
            next?: unknown;
            /** @example /b2b-order-employee?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createB2bOrderEmployee post /b2b-order-employee":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["B2bOrderEmployee"];
        response: {
          data: components["schemas"]["B2bOrderEmployee"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["B2bOrderEmployee"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bOrderEmployee"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["B2bOrderEmployee"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["B2bOrderEmployee"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["B2bOrderEmployee"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bOrderEmployee"];
        };
        responseCode: 200;
      };
  "getB2bOrderEmployee get /b2b-order-employee/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the b2b_order_employee */
          id: string;
        };
        response: {
          data: components["schemas"]["B2bOrderEmployee"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the b2b_order_employee */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bOrderEmployee"];
        };
        responseCode: 200;
      };
  "deleteB2bOrderEmployee delete /b2b-order-employee/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the b2b_order_employee */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateB2bOrderEmployee patch /b2b-order-employee/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the b2b_order_employee */
          id: string;
        };
        body: components["schemas"]["B2bOrderEmployee"];
        response: {
          data: components["schemas"]["B2bOrderEmployee"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the b2b_order_employee */
          id: string;
        };
        body: components["schemas"]["B2bOrderEmployee"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bOrderEmployee"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the b2b_order_employee */
          id: string;
        };
        body: {
          data?: components["schemas"]["B2bOrderEmployee"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["B2bOrderEmployee"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the b2b_order_employee */
          id: string;
        };
        body: {
          data?: components["schemas"]["B2bOrderEmployee"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bOrderEmployee"];
        };
        responseCode: 200;
      };
  "getB2bPermissionList get /b2b-permission":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["B2bPermission"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["B2bPermission"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /b2b-permission?limit=25 */
            first?: unknown;
            /** @example /b2b-permission?limit=25&page=11 */
            last?: unknown;
            /** @example /b2b-permission?limit=25&page=4 */
            next?: unknown;
            /** @example /b2b-permission?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createB2bPermission post /b2b-permission":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["B2bPermission"];
        response: {
          data: components["schemas"]["B2bPermission"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["B2bPermission"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bPermission"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["B2bPermission"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["B2bPermission"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["B2bPermission"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bPermission"];
        };
        responseCode: 200;
      };
  "getB2bPermission get /b2b-permission/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the b2b_permission */
          id: string;
        };
        response: {
          data: components["schemas"]["B2bPermission"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the b2b_permission */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bPermission"];
        };
        responseCode: 200;
      };
  "deleteB2bPermission delete /b2b-permission/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the b2b_permission */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateB2bPermission patch /b2b-permission/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the b2b_permission */
          id: string;
        };
        body: components["schemas"]["B2bPermission"];
        response: {
          data: components["schemas"]["B2bPermission"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the b2b_permission */
          id: string;
        };
        body: components["schemas"]["B2bPermission"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bPermission"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the b2b_permission */
          id: string;
        };
        body: {
          data?: components["schemas"]["B2bPermission"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["B2bPermission"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the b2b_permission */
          id: string;
        };
        body: {
          data?: components["schemas"]["B2bPermission"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bPermission"];
        };
        responseCode: 200;
      };
  "getCategoryList get /category":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["Category"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["Category"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /category?limit=25 */
            first?: unknown;
            /** @example /category?limit=25&page=11 */
            last?: unknown;
            /** @example /category?limit=25&page=4 */
            next?: unknown;
            /** @example /category?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createCategory post /category":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["Category"];
        response: {
          data: components["schemas"]["Category"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["Category"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Category"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["Category"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["Category"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["Category"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Category"];
        };
        responseCode: 200;
      };
  "getCategory get /category/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the category */
          id: string;
        };
        response: {
          data: components["schemas"]["Category"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the category */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Category"];
        };
        responseCode: 200;
      };
  "deleteCategory delete /category/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the category */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateCategory patch /category/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the category */
          id: string;
        };
        body: components["schemas"]["Category"];
        response: {
          data: components["schemas"]["Category"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the category */
          id: string;
        };
        body: components["schemas"]["Category"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Category"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the category */
          id: string;
        };
        body: {
          data?: components["schemas"]["Category"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["Category"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the category */
          id: string;
        };
        body: {
          data?: components["schemas"]["Category"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Category"];
        };
        responseCode: 200;
      };
  "getCmsBlockList get /cms-block":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["CmsBlock"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["CmsBlock"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /cms-block?limit=25 */
            first?: unknown;
            /** @example /cms-block?limit=25&page=11 */
            last?: unknown;
            /** @example /cms-block?limit=25&page=4 */
            next?: unknown;
            /** @example /cms-block?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createCmsBlock post /cms-block":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["CmsBlock"];
        response: {
          data: components["schemas"]["CmsBlock"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["CmsBlock"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CmsBlock"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["CmsBlock"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["CmsBlock"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["CmsBlock"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CmsBlock"];
        };
        responseCode: 200;
      };
  "getCmsBlock get /cms-block/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the cms_block */
          id: string;
        };
        response: {
          data: components["schemas"]["CmsBlock"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the cms_block */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CmsBlock"];
        };
        responseCode: 200;
      };
  "deleteCmsBlock delete /cms-block/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the cms_block */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateCmsBlock patch /cms-block/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the cms_block */
          id: string;
        };
        body: components["schemas"]["CmsBlock"];
        response: {
          data: components["schemas"]["CmsBlock"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the cms_block */
          id: string;
        };
        body: components["schemas"]["CmsBlock"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CmsBlock"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the cms_block */
          id: string;
        };
        body: {
          data?: components["schemas"]["CmsBlock"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["CmsBlock"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the cms_block */
          id: string;
        };
        body: {
          data?: components["schemas"]["CmsBlock"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CmsBlock"];
        };
        responseCode: 200;
      };
  "getCmsPageList get /cms-page":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["CmsPage"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["CmsPage"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /cms-page?limit=25 */
            first?: unknown;
            /** @example /cms-page?limit=25&page=11 */
            last?: unknown;
            /** @example /cms-page?limit=25&page=4 */
            next?: unknown;
            /** @example /cms-page?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createCmsPage post /cms-page":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["CmsPage"];
        response: {
          data: components["schemas"]["CmsPage"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["CmsPage"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CmsPage"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["CmsPage"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["CmsPage"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["CmsPage"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CmsPage"];
        };
        responseCode: 200;
      };
  "getCmsPageActivityList get /cms-page-activity":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["CmsPageActivity"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["CmsPageActivity"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /cms-page-activity?limit=25 */
            first?: unknown;
            /** @example /cms-page-activity?limit=25&page=11 */
            last?: unknown;
            /** @example /cms-page-activity?limit=25&page=4 */
            next?: unknown;
            /** @example /cms-page-activity?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createCmsPageActivity post /cms-page-activity":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["CmsPageActivity"];
        response: {
          data: components["schemas"]["CmsPageActivity"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["CmsPageActivity"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CmsPageActivity"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["CmsPageActivity"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["CmsPageActivity"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["CmsPageActivity"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CmsPageActivity"];
        };
        responseCode: 200;
      };
  "getCmsPageActivity get /cms-page-activity/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the cms_page_activity */
          id: string;
        };
        response: {
          data: components["schemas"]["CmsPageActivity"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the cms_page_activity */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CmsPageActivity"];
        };
        responseCode: 200;
      };
  "deleteCmsPageActivity delete /cms-page-activity/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the cms_page_activity */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateCmsPageActivity patch /cms-page-activity/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the cms_page_activity */
          id: string;
        };
        body: components["schemas"]["CmsPageActivity"];
        response: {
          data: components["schemas"]["CmsPageActivity"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the cms_page_activity */
          id: string;
        };
        body: components["schemas"]["CmsPageActivity"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CmsPageActivity"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the cms_page_activity */
          id: string;
        };
        body: {
          data?: components["schemas"]["CmsPageActivity"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["CmsPageActivity"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the cms_page_activity */
          id: string;
        };
        body: {
          data?: components["schemas"]["CmsPageActivity"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CmsPageActivity"];
        };
        responseCode: 200;
      };
  "getCmsPageDraftList get /cms-page-draft":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["CmsPageDraft"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["CmsPageDraft"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /cms-page-draft?limit=25 */
            first?: unknown;
            /** @example /cms-page-draft?limit=25&page=11 */
            last?: unknown;
            /** @example /cms-page-draft?limit=25&page=4 */
            next?: unknown;
            /** @example /cms-page-draft?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createCmsPageDraft post /cms-page-draft":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["CmsPageDraft"];
        response: {
          data: components["schemas"]["CmsPageDraft"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["CmsPageDraft"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CmsPageDraft"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["CmsPageDraft"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["CmsPageDraft"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["CmsPageDraft"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CmsPageDraft"];
        };
        responseCode: 200;
      };
  "getCmsPageDraft get /cms-page-draft/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the cms_page_draft */
          id: string;
        };
        response: {
          data: components["schemas"]["CmsPageDraft"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the cms_page_draft */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CmsPageDraft"];
        };
        responseCode: 200;
      };
  "deleteCmsPageDraft delete /cms-page-draft/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the cms_page_draft */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateCmsPageDraft patch /cms-page-draft/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the cms_page_draft */
          id: string;
        };
        body: components["schemas"]["CmsPageDraft"];
        response: {
          data: components["schemas"]["CmsPageDraft"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the cms_page_draft */
          id: string;
        };
        body: components["schemas"]["CmsPageDraft"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CmsPageDraft"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the cms_page_draft */
          id: string;
        };
        body: {
          data?: components["schemas"]["CmsPageDraft"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["CmsPageDraft"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the cms_page_draft */
          id: string;
        };
        body: {
          data?: components["schemas"]["CmsPageDraft"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CmsPageDraft"];
        };
        responseCode: 200;
      };
  "getCmsPage get /cms-page/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the cms_page */
          id: string;
        };
        response: {
          data: components["schemas"]["CmsPage"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the cms_page */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CmsPage"];
        };
        responseCode: 200;
      };
  "deleteCmsPage delete /cms-page/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the cms_page */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateCmsPage patch /cms-page/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the cms_page */
          id: string;
        };
        body: components["schemas"]["CmsPage"];
        response: {
          data: components["schemas"]["CmsPage"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the cms_page */
          id: string;
        };
        body: components["schemas"]["CmsPage"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CmsPage"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the cms_page */
          id: string;
        };
        body: {
          data?: components["schemas"]["CmsPage"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["CmsPage"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the cms_page */
          id: string;
        };
        body: {
          data?: components["schemas"]["CmsPage"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CmsPage"];
        };
        responseCode: 200;
      };
  "getCmsSectionList get /cms-section":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["CmsSection"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["CmsSection"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /cms-section?limit=25 */
            first?: unknown;
            /** @example /cms-section?limit=25&page=11 */
            last?: unknown;
            /** @example /cms-section?limit=25&page=4 */
            next?: unknown;
            /** @example /cms-section?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createCmsSection post /cms-section":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["CmsSection"];
        response: {
          data: components["schemas"]["CmsSection"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["CmsSection"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CmsSection"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["CmsSection"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["CmsSection"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["CmsSection"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CmsSection"];
        };
        responseCode: 200;
      };
  "getCmsSection get /cms-section/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the cms_section */
          id: string;
        };
        response: {
          data: components["schemas"]["CmsSection"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the cms_section */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CmsSection"];
        };
        responseCode: 200;
      };
  "deleteCmsSection delete /cms-section/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the cms_section */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateCmsSection patch /cms-section/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the cms_section */
          id: string;
        };
        body: components["schemas"]["CmsSection"];
        response: {
          data: components["schemas"]["CmsSection"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the cms_section */
          id: string;
        };
        body: components["schemas"]["CmsSection"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CmsSection"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the cms_section */
          id: string;
        };
        body: {
          data?: components["schemas"]["CmsSection"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["CmsSection"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the cms_section */
          id: string;
        };
        body: {
          data?: components["schemas"]["CmsSection"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CmsSection"];
        };
        responseCode: 200;
      };
  "getCmsSlotList get /cms-slot":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["CmsSlot"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["CmsSlot"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /cms-slot?limit=25 */
            first?: unknown;
            /** @example /cms-slot?limit=25&page=11 */
            last?: unknown;
            /** @example /cms-slot?limit=25&page=4 */
            next?: unknown;
            /** @example /cms-slot?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createCmsSlot post /cms-slot":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["CmsSlot"];
        response: {
          data: components["schemas"]["CmsSlot"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["CmsSlot"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CmsSlot"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["CmsSlot"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["CmsSlot"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["CmsSlot"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CmsSlot"];
        };
        responseCode: 200;
      };
  "getCmsSlot get /cms-slot/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the cms_slot */
          id: string;
        };
        response: {
          data: components["schemas"]["CmsSlot"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the cms_slot */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CmsSlot"];
        };
        responseCode: 200;
      };
  "deleteCmsSlot delete /cms-slot/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the cms_slot */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateCmsSlot patch /cms-slot/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the cms_slot */
          id: string;
        };
        body: components["schemas"]["CmsSlot"];
        response: {
          data: components["schemas"]["CmsSlot"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the cms_slot */
          id: string;
        };
        body: components["schemas"]["CmsSlot"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CmsSlot"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the cms_slot */
          id: string;
        };
        body: {
          data?: components["schemas"]["CmsSlot"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["CmsSlot"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the cms_slot */
          id: string;
        };
        body: {
          data?: components["schemas"]["CmsSlot"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CmsSlot"];
        };
        responseCode: 200;
      };
  "getCountryList get /country":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["Country"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["Country"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /country?limit=25 */
            first?: unknown;
            /** @example /country?limit=25&page=11 */
            last?: unknown;
            /** @example /country?limit=25&page=4 */
            next?: unknown;
            /** @example /country?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createCountry post /country":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["Country"];
        response: {
          data: components["schemas"]["Country"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["Country"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Country"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["Country"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["Country"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["Country"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Country"];
        };
        responseCode: 200;
      };
  "getCountryStateList get /country-state":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["CountryState"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["CountryState"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /country-state?limit=25 */
            first?: unknown;
            /** @example /country-state?limit=25&page=11 */
            last?: unknown;
            /** @example /country-state?limit=25&page=4 */
            next?: unknown;
            /** @example /country-state?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createCountryState post /country-state":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["CountryState"];
        response: {
          data: components["schemas"]["CountryState"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["CountryState"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CountryState"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["CountryState"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["CountryState"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["CountryState"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CountryState"];
        };
        responseCode: 200;
      };
  "getCountryState get /country-state/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the country_state */
          id: string;
        };
        response: {
          data: components["schemas"]["CountryState"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the country_state */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CountryState"];
        };
        responseCode: 200;
      };
  "deleteCountryState delete /country-state/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the country_state */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateCountryState patch /country-state/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the country_state */
          id: string;
        };
        body: components["schemas"]["CountryState"];
        response: {
          data: components["schemas"]["CountryState"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the country_state */
          id: string;
        };
        body: components["schemas"]["CountryState"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CountryState"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the country_state */
          id: string;
        };
        body: {
          data?: components["schemas"]["CountryState"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["CountryState"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the country_state */
          id: string;
        };
        body: {
          data?: components["schemas"]["CountryState"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CountryState"];
        };
        responseCode: 200;
      };
  "getCountry get /country/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the country */
          id: string;
        };
        response: {
          data: components["schemas"]["Country"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the country */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Country"];
        };
        responseCode: 200;
      };
  "deleteCountry delete /country/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the country */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateCountry patch /country/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the country */
          id: string;
        };
        body: components["schemas"]["Country"];
        response: {
          data: components["schemas"]["Country"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the country */
          id: string;
        };
        body: components["schemas"]["Country"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Country"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the country */
          id: string;
        };
        body: {
          data?: components["schemas"]["Country"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["Country"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the country */
          id: string;
        };
        body: {
          data?: components["schemas"]["Country"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Country"];
        };
        responseCode: 200;
      };
  "getCurrencyList get /currency":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["Currency"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["Currency"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /currency?limit=25 */
            first?: unknown;
            /** @example /currency?limit=25&page=11 */
            last?: unknown;
            /** @example /currency?limit=25&page=4 */
            next?: unknown;
            /** @example /currency?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createCurrency post /currency":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["Currency"];
        response: {
          data: components["schemas"]["Currency"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["Currency"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Currency"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["Currency"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["Currency"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["Currency"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Currency"];
        };
        responseCode: 200;
      };
  "getCurrencyCountryRoundingList get /currency-country-rounding":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["CurrencyCountryRounding"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["CurrencyCountryRounding"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /currency-country-rounding?limit=25 */
            first?: unknown;
            /** @example /currency-country-rounding?limit=25&page=11 */
            last?: unknown;
            /** @example /currency-country-rounding?limit=25&page=4 */
            next?: unknown;
            /** @example /currency-country-rounding?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createCurrencyCountryRounding post /currency-country-rounding":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["CurrencyCountryRounding"];
        response: {
          data: components["schemas"]["CurrencyCountryRounding"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["CurrencyCountryRounding"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CurrencyCountryRounding"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["CurrencyCountryRounding"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["CurrencyCountryRounding"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["CurrencyCountryRounding"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CurrencyCountryRounding"];
        };
        responseCode: 200;
      };
  "getCurrencyCountryRounding get /currency-country-rounding/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the currency_country_rounding */
          id: string;
        };
        response: {
          data: components["schemas"]["CurrencyCountryRounding"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the currency_country_rounding */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CurrencyCountryRounding"];
        };
        responseCode: 200;
      };
  "deleteCurrencyCountryRounding delete /currency-country-rounding/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the currency_country_rounding */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateCurrencyCountryRounding patch /currency-country-rounding/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the currency_country_rounding */
          id: string;
        };
        body: components["schemas"]["CurrencyCountryRounding"];
        response: {
          data: components["schemas"]["CurrencyCountryRounding"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the currency_country_rounding */
          id: string;
        };
        body: components["schemas"]["CurrencyCountryRounding"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CurrencyCountryRounding"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the currency_country_rounding */
          id: string;
        };
        body: {
          data?: components["schemas"]["CurrencyCountryRounding"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["CurrencyCountryRounding"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the currency_country_rounding */
          id: string;
        };
        body: {
          data?: components["schemas"]["CurrencyCountryRounding"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CurrencyCountryRounding"];
        };
        responseCode: 200;
      };
  "getCurrency get /currency/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the currency */
          id: string;
        };
        response: {
          data: components["schemas"]["Currency"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the currency */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Currency"];
        };
        responseCode: 200;
      };
  "deleteCurrency delete /currency/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the currency */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateCurrency patch /currency/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the currency */
          id: string;
        };
        body: components["schemas"]["Currency"];
        response: {
          data: components["schemas"]["Currency"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the currency */
          id: string;
        };
        body: components["schemas"]["Currency"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Currency"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the currency */
          id: string;
        };
        body: {
          data?: components["schemas"]["Currency"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["Currency"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the currency */
          id: string;
        };
        body: {
          data?: components["schemas"]["Currency"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Currency"];
        };
        responseCode: 200;
      };
  "getCustomEntityList get /custom-entity":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["CustomEntity"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["CustomEntity"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /custom-entity?limit=25 */
            first?: unknown;
            /** @example /custom-entity?limit=25&page=11 */
            last?: unknown;
            /** @example /custom-entity?limit=25&page=4 */
            next?: unknown;
            /** @example /custom-entity?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createCustomEntity post /custom-entity":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["CustomEntity"];
        response: {
          data: components["schemas"]["CustomEntity"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["CustomEntity"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomEntity"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["CustomEntity"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["CustomEntity"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["CustomEntity"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomEntity"];
        };
        responseCode: 200;
      };
  "getCustomEntity get /custom-entity/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the custom_entity */
          id: string;
        };
        response: {
          data: components["schemas"]["CustomEntity"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the custom_entity */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomEntity"];
        };
        responseCode: 200;
      };
  "deleteCustomEntity delete /custom-entity/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the custom_entity */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateCustomEntity patch /custom-entity/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the custom_entity */
          id: string;
        };
        body: components["schemas"]["CustomEntity"];
        response: {
          data: components["schemas"]["CustomEntity"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the custom_entity */
          id: string;
        };
        body: components["schemas"]["CustomEntity"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomEntity"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the custom_entity */
          id: string;
        };
        body: {
          data?: components["schemas"]["CustomEntity"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["CustomEntity"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the custom_entity */
          id: string;
        };
        body: {
          data?: components["schemas"]["CustomEntity"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomEntity"];
        };
        responseCode: 200;
      };
  "getCustomFieldList get /custom-field":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["CustomField"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["CustomField"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /custom-field?limit=25 */
            first?: unknown;
            /** @example /custom-field?limit=25&page=11 */
            last?: unknown;
            /** @example /custom-field?limit=25&page=4 */
            next?: unknown;
            /** @example /custom-field?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createCustomField post /custom-field":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["CustomField"];
        response: {
          data: components["schemas"]["CustomField"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["CustomField"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomField"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["CustomField"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["CustomField"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["CustomField"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomField"];
        };
        responseCode: 200;
      };
  "getCustomFieldSetList get /custom-field-set":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["CustomFieldSet"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["CustomFieldSet"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /custom-field-set?limit=25 */
            first?: unknown;
            /** @example /custom-field-set?limit=25&page=11 */
            last?: unknown;
            /** @example /custom-field-set?limit=25&page=4 */
            next?: unknown;
            /** @example /custom-field-set?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createCustomFieldSet post /custom-field-set":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["CustomFieldSet"];
        response: {
          data: components["schemas"]["CustomFieldSet"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["CustomFieldSet"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomFieldSet"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["CustomFieldSet"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["CustomFieldSet"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["CustomFieldSet"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomFieldSet"];
        };
        responseCode: 200;
      };
  "getCustomFieldSetRelationList get /custom-field-set-relation":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["CustomFieldSetRelation"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["CustomFieldSetRelation"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /custom-field-set-relation?limit=25 */
            first?: unknown;
            /** @example /custom-field-set-relation?limit=25&page=11 */
            last?: unknown;
            /** @example /custom-field-set-relation?limit=25&page=4 */
            next?: unknown;
            /** @example /custom-field-set-relation?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createCustomFieldSetRelation post /custom-field-set-relation":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["CustomFieldSetRelation"];
        response: {
          data: components["schemas"]["CustomFieldSetRelation"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["CustomFieldSetRelation"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomFieldSetRelation"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["CustomFieldSetRelation"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["CustomFieldSetRelation"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["CustomFieldSetRelation"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomFieldSetRelation"];
        };
        responseCode: 200;
      };
  "getCustomFieldSetRelation get /custom-field-set-relation/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the custom_field_set_relation */
          id: string;
        };
        response: {
          data: components["schemas"]["CustomFieldSetRelation"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the custom_field_set_relation */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomFieldSetRelation"];
        };
        responseCode: 200;
      };
  "deleteCustomFieldSetRelation delete /custom-field-set-relation/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the custom_field_set_relation */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateCustomFieldSetRelation patch /custom-field-set-relation/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the custom_field_set_relation */
          id: string;
        };
        body: components["schemas"]["CustomFieldSetRelation"];
        response: {
          data: components["schemas"]["CustomFieldSetRelation"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the custom_field_set_relation */
          id: string;
        };
        body: components["schemas"]["CustomFieldSetRelation"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomFieldSetRelation"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the custom_field_set_relation */
          id: string;
        };
        body: {
          data?: components["schemas"]["CustomFieldSetRelation"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["CustomFieldSetRelation"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the custom_field_set_relation */
          id: string;
        };
        body: {
          data?: components["schemas"]["CustomFieldSetRelation"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomFieldSetRelation"];
        };
        responseCode: 200;
      };
  "getCustomFieldSet get /custom-field-set/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the custom_field_set */
          id: string;
        };
        response: {
          data: components["schemas"]["CustomFieldSet"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the custom_field_set */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomFieldSet"];
        };
        responseCode: 200;
      };
  "deleteCustomFieldSet delete /custom-field-set/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the custom_field_set */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateCustomFieldSet patch /custom-field-set/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the custom_field_set */
          id: string;
        };
        body: components["schemas"]["CustomFieldSet"];
        response: {
          data: components["schemas"]["CustomFieldSet"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the custom_field_set */
          id: string;
        };
        body: components["schemas"]["CustomFieldSet"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomFieldSet"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the custom_field_set */
          id: string;
        };
        body: {
          data?: components["schemas"]["CustomFieldSet"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["CustomFieldSet"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the custom_field_set */
          id: string;
        };
        body: {
          data?: components["schemas"]["CustomFieldSet"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomFieldSet"];
        };
        responseCode: 200;
      };
  "getCustomField get /custom-field/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the custom_field */
          id: string;
        };
        response: {
          data: components["schemas"]["CustomField"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the custom_field */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomField"];
        };
        responseCode: 200;
      };
  "deleteCustomField delete /custom-field/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the custom_field */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateCustomField patch /custom-field/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the custom_field */
          id: string;
        };
        body: components["schemas"]["CustomField"];
        response: {
          data: components["schemas"]["CustomField"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the custom_field */
          id: string;
        };
        body: components["schemas"]["CustomField"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomField"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the custom_field */
          id: string;
        };
        body: {
          data?: components["schemas"]["CustomField"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["CustomField"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the custom_field */
          id: string;
        };
        body: {
          data?: components["schemas"]["CustomField"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomField"];
        };
        responseCode: 200;
      };
  "getCustomPriceList get /custom-price":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["CustomPrice"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["CustomPrice"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /custom-price?limit=25 */
            first?: unknown;
            /** @example /custom-price?limit=25&page=11 */
            last?: unknown;
            /** @example /custom-price?limit=25&page=4 */
            next?: unknown;
            /** @example /custom-price?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createCustomPrice post /custom-price":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["CustomPrice"];
        response: {
          data: components["schemas"]["CustomPrice"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["CustomPrice"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomPrice"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["CustomPrice"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["CustomPrice"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["CustomPrice"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomPrice"];
        };
        responseCode: 200;
      };
  "getCustomPrice get /custom-price/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the custom_price */
          id: string;
        };
        response: {
          data: components["schemas"]["CustomPrice"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the custom_price */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomPrice"];
        };
        responseCode: 200;
      };
  "deleteCustomPrice delete /custom-price/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the custom_price */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateCustomPrice patch /custom-price/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the custom_price */
          id: string;
        };
        body: components["schemas"]["CustomPrice"];
        response: {
          data: components["schemas"]["CustomPrice"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the custom_price */
          id: string;
        };
        body: components["schemas"]["CustomPrice"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomPrice"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the custom_price */
          id: string;
        };
        body: {
          data?: components["schemas"]["CustomPrice"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["CustomPrice"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the custom_price */
          id: string;
        };
        body: {
          data?: components["schemas"]["CustomPrice"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomPrice"];
        };
        responseCode: 200;
      };
  "getCustomerList get /customer":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["Customer"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["Customer"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /customer?limit=25 */
            first?: unknown;
            /** @example /customer?limit=25&page=11 */
            last?: unknown;
            /** @example /customer?limit=25&page=4 */
            next?: unknown;
            /** @example /customer?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createCustomer post /customer":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["Customer"];
        response: {
          data: components["schemas"]["Customer"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["Customer"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Customer"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["Customer"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["Customer"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["Customer"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Customer"];
        };
        responseCode: 200;
      };
  "getCustomerAddressList get /customer-address":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["CustomerAddress"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["CustomerAddress"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /customer-address?limit=25 */
            first?: unknown;
            /** @example /customer-address?limit=25&page=11 */
            last?: unknown;
            /** @example /customer-address?limit=25&page=4 */
            next?: unknown;
            /** @example /customer-address?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createCustomerAddress post /customer-address":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["CustomerAddress"];
        response: {
          data: components["schemas"]["CustomerAddress"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["CustomerAddress"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomerAddress"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["CustomerAddress"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["CustomerAddress"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["CustomerAddress"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomerAddress"];
        };
        responseCode: 200;
      };
  "getCustomerAddress get /customer-address/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the customer_address */
          id: string;
        };
        response: {
          data: components["schemas"]["CustomerAddress"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the customer_address */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomerAddress"];
        };
        responseCode: 200;
      };
  "deleteCustomerAddress delete /customer-address/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the customer_address */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateCustomerAddress patch /customer-address/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the customer_address */
          id: string;
        };
        body: components["schemas"]["CustomerAddress"];
        response: {
          data: components["schemas"]["CustomerAddress"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the customer_address */
          id: string;
        };
        body: components["schemas"]["CustomerAddress"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomerAddress"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the customer_address */
          id: string;
        };
        body: {
          data?: components["schemas"]["CustomerAddress"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["CustomerAddress"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the customer_address */
          id: string;
        };
        body: {
          data?: components["schemas"]["CustomerAddress"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomerAddress"];
        };
        responseCode: 200;
      };
  "getCustomerGroupList get /customer-group":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["CustomerGroup"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["CustomerGroup"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /customer-group?limit=25 */
            first?: unknown;
            /** @example /customer-group?limit=25&page=11 */
            last?: unknown;
            /** @example /customer-group?limit=25&page=4 */
            next?: unknown;
            /** @example /customer-group?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createCustomerGroup post /customer-group":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["CustomerGroup"];
        response: {
          data: components["schemas"]["CustomerGroup"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["CustomerGroup"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomerGroup"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["CustomerGroup"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["CustomerGroup"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["CustomerGroup"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomerGroup"];
        };
        responseCode: 200;
      };
  "getCustomerGroup get /customer-group/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the customer_group */
          id: string;
        };
        response: {
          data: components["schemas"]["CustomerGroup"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the customer_group */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomerGroup"];
        };
        responseCode: 200;
      };
  "deleteCustomerGroup delete /customer-group/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the customer_group */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateCustomerGroup patch /customer-group/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the customer_group */
          id: string;
        };
        body: components["schemas"]["CustomerGroup"];
        response: {
          data: components["schemas"]["CustomerGroup"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the customer_group */
          id: string;
        };
        body: components["schemas"]["CustomerGroup"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomerGroup"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the customer_group */
          id: string;
        };
        body: {
          data?: components["schemas"]["CustomerGroup"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["CustomerGroup"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the customer_group */
          id: string;
        };
        body: {
          data?: components["schemas"]["CustomerGroup"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomerGroup"];
        };
        responseCode: 200;
      };
  "getCustomerRecoveryList get /customer-recovery":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["CustomerRecovery"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["CustomerRecovery"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /customer-recovery?limit=25 */
            first?: unknown;
            /** @example /customer-recovery?limit=25&page=11 */
            last?: unknown;
            /** @example /customer-recovery?limit=25&page=4 */
            next?: unknown;
            /** @example /customer-recovery?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createCustomerRecovery post /customer-recovery":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["CustomerRecovery"];
        response: {
          data: components["schemas"]["CustomerRecovery"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["CustomerRecovery"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomerRecovery"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["CustomerRecovery"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["CustomerRecovery"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["CustomerRecovery"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomerRecovery"];
        };
        responseCode: 200;
      };
  "getCustomerRecovery get /customer-recovery/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the customer_recovery */
          id: string;
        };
        response: {
          data: components["schemas"]["CustomerRecovery"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the customer_recovery */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomerRecovery"];
        };
        responseCode: 200;
      };
  "deleteCustomerRecovery delete /customer-recovery/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the customer_recovery */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateCustomerRecovery patch /customer-recovery/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the customer_recovery */
          id: string;
        };
        body: components["schemas"]["CustomerRecovery"];
        response: {
          data: components["schemas"]["CustomerRecovery"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the customer_recovery */
          id: string;
        };
        body: components["schemas"]["CustomerRecovery"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomerRecovery"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the customer_recovery */
          id: string;
        };
        body: {
          data?: components["schemas"]["CustomerRecovery"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["CustomerRecovery"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the customer_recovery */
          id: string;
        };
        body: {
          data?: components["schemas"]["CustomerRecovery"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomerRecovery"];
        };
        responseCode: 200;
      };
  "getCustomerSpecificFeaturesList get /customer-specific-features":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["CustomerSpecificFeatures"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["CustomerSpecificFeatures"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /customer-specific-features?limit=25 */
            first?: unknown;
            /** @example /customer-specific-features?limit=25&page=11 */
            last?: unknown;
            /** @example /customer-specific-features?limit=25&page=4 */
            next?: unknown;
            /** @example /customer-specific-features?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createCustomerSpecificFeatures post /customer-specific-features":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["CustomerSpecificFeatures"];
        response: {
          data: components["schemas"]["CustomerSpecificFeatures"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["CustomerSpecificFeatures"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomerSpecificFeatures"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["CustomerSpecificFeatures"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["CustomerSpecificFeatures"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["CustomerSpecificFeatures"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomerSpecificFeatures"];
        };
        responseCode: 200;
      };
  "getCustomerSpecificFeatures get /customer-specific-features/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the customer_specific_features */
          id: string;
        };
        response: {
          data: components["schemas"]["CustomerSpecificFeatures"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the customer_specific_features */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomerSpecificFeatures"];
        };
        responseCode: 200;
      };
  "deleteCustomerSpecificFeatures delete /customer-specific-features/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the customer_specific_features */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateCustomerSpecificFeatures patch /customer-specific-features/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the customer_specific_features */
          id: string;
        };
        body: components["schemas"]["CustomerSpecificFeatures"];
        response: {
          data: components["schemas"]["CustomerSpecificFeatures"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the customer_specific_features */
          id: string;
        };
        body: components["schemas"]["CustomerSpecificFeatures"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomerSpecificFeatures"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the customer_specific_features */
          id: string;
        };
        body: {
          data?: components["schemas"]["CustomerSpecificFeatures"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["CustomerSpecificFeatures"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the customer_specific_features */
          id: string;
        };
        body: {
          data?: components["schemas"]["CustomerSpecificFeatures"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomerSpecificFeatures"];
        };
        responseCode: 200;
      };
  "getCustomerWishlistList get /customer-wishlist":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["CustomerWishlist"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["CustomerWishlist"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /customer-wishlist?limit=25 */
            first?: unknown;
            /** @example /customer-wishlist?limit=25&page=11 */
            last?: unknown;
            /** @example /customer-wishlist?limit=25&page=4 */
            next?: unknown;
            /** @example /customer-wishlist?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createCustomerWishlist post /customer-wishlist":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["CustomerWishlist"];
        response: {
          data: components["schemas"]["CustomerWishlist"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["CustomerWishlist"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomerWishlist"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["CustomerWishlist"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["CustomerWishlist"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["CustomerWishlist"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomerWishlist"];
        };
        responseCode: 200;
      };
  "getCustomerWishlistProductList get /customer-wishlist-product":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["CustomerWishlistProduct"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["CustomerWishlistProduct"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /customer-wishlist-product?limit=25 */
            first?: unknown;
            /** @example /customer-wishlist-product?limit=25&page=11 */
            last?: unknown;
            /** @example /customer-wishlist-product?limit=25&page=4 */
            next?: unknown;
            /** @example /customer-wishlist-product?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createCustomerWishlistProduct post /customer-wishlist-product":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["CustomerWishlistProduct"];
        response: {
          data: components["schemas"]["CustomerWishlistProduct"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["CustomerWishlistProduct"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomerWishlistProduct"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["CustomerWishlistProduct"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["CustomerWishlistProduct"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["CustomerWishlistProduct"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomerWishlistProduct"];
        };
        responseCode: 200;
      };
  "getCustomerWishlistProduct get /customer-wishlist-product/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the customer_wishlist_product */
          id: string;
        };
        response: {
          data: components["schemas"]["CustomerWishlistProduct"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the customer_wishlist_product */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomerWishlistProduct"];
        };
        responseCode: 200;
      };
  "deleteCustomerWishlistProduct delete /customer-wishlist-product/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the customer_wishlist_product */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateCustomerWishlistProduct patch /customer-wishlist-product/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the customer_wishlist_product */
          id: string;
        };
        body: components["schemas"]["CustomerWishlistProduct"];
        response: {
          data: components["schemas"]["CustomerWishlistProduct"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the customer_wishlist_product */
          id: string;
        };
        body: components["schemas"]["CustomerWishlistProduct"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomerWishlistProduct"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the customer_wishlist_product */
          id: string;
        };
        body: {
          data?: components["schemas"]["CustomerWishlistProduct"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["CustomerWishlistProduct"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the customer_wishlist_product */
          id: string;
        };
        body: {
          data?: components["schemas"]["CustomerWishlistProduct"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomerWishlistProduct"];
        };
        responseCode: 200;
      };
  "getCustomerWishlist get /customer-wishlist/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the customer_wishlist */
          id: string;
        };
        response: {
          data: components["schemas"]["CustomerWishlist"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the customer_wishlist */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomerWishlist"];
        };
        responseCode: 200;
      };
  "deleteCustomerWishlist delete /customer-wishlist/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the customer_wishlist */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateCustomerWishlist patch /customer-wishlist/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the customer_wishlist */
          id: string;
        };
        body: components["schemas"]["CustomerWishlist"];
        response: {
          data: components["schemas"]["CustomerWishlist"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the customer_wishlist */
          id: string;
        };
        body: components["schemas"]["CustomerWishlist"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomerWishlist"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the customer_wishlist */
          id: string;
        };
        body: {
          data?: components["schemas"]["CustomerWishlist"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["CustomerWishlist"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the customer_wishlist */
          id: string;
        };
        body: {
          data?: components["schemas"]["CustomerWishlist"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomerWishlist"];
        };
        responseCode: 200;
      };
  "getCustomer get /customer/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the customer */
          id: string;
        };
        response: {
          data: components["schemas"]["Customer"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the customer */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Customer"];
        };
        responseCode: 200;
      };
  "deleteCustomer delete /customer/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the customer */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateCustomer patch /customer/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the customer */
          id: string;
        };
        body: components["schemas"]["Customer"];
        response: {
          data: components["schemas"]["Customer"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the customer */
          id: string;
        };
        body: components["schemas"]["Customer"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Customer"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the customer */
          id: string;
        };
        body: {
          data?: components["schemas"]["Customer"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["Customer"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the customer */
          id: string;
        };
        body: {
          data?: components["schemas"]["Customer"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Customer"];
        };
        responseCode: 200;
      };
  "getDeliveryTimeList get /delivery-time":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["DeliveryTime"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["DeliveryTime"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /delivery-time?limit=25 */
            first?: unknown;
            /** @example /delivery-time?limit=25&page=11 */
            last?: unknown;
            /** @example /delivery-time?limit=25&page=4 */
            next?: unknown;
            /** @example /delivery-time?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createDeliveryTime post /delivery-time":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["DeliveryTime"];
        response: {
          data: components["schemas"]["DeliveryTime"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["DeliveryTime"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DeliveryTime"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["DeliveryTime"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["DeliveryTime"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["DeliveryTime"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DeliveryTime"];
        };
        responseCode: 200;
      };
  "getDeliveryTime get /delivery-time/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the delivery_time */
          id: string;
        };
        response: {
          data: components["schemas"]["DeliveryTime"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the delivery_time */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DeliveryTime"];
        };
        responseCode: 200;
      };
  "deleteDeliveryTime delete /delivery-time/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the delivery_time */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateDeliveryTime patch /delivery-time/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the delivery_time */
          id: string;
        };
        body: components["schemas"]["DeliveryTime"];
        response: {
          data: components["schemas"]["DeliveryTime"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the delivery_time */
          id: string;
        };
        body: components["schemas"]["DeliveryTime"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DeliveryTime"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the delivery_time */
          id: string;
        };
        body: {
          data?: components["schemas"]["DeliveryTime"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["DeliveryTime"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the delivery_time */
          id: string;
        };
        body: {
          data?: components["schemas"]["DeliveryTime"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DeliveryTime"];
        };
        responseCode: 200;
      };
  "getDocumentList get /document":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["Document"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["Document"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /document?limit=25 */
            first?: unknown;
            /** @example /document?limit=25&page=11 */
            last?: unknown;
            /** @example /document?limit=25&page=4 */
            next?: unknown;
            /** @example /document?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createDocument post /document":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["Document"];
        response: {
          data: components["schemas"]["Document"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["Document"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Document"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["Document"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["Document"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["Document"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Document"];
        };
        responseCode: 200;
      };
  "getDocumentBaseConfigList get /document-base-config":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["DocumentBaseConfig"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["DocumentBaseConfig"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /document-base-config?limit=25 */
            first?: unknown;
            /** @example /document-base-config?limit=25&page=11 */
            last?: unknown;
            /** @example /document-base-config?limit=25&page=4 */
            next?: unknown;
            /** @example /document-base-config?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createDocumentBaseConfig post /document-base-config":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["DocumentBaseConfig"];
        response: {
          data: components["schemas"]["DocumentBaseConfig"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["DocumentBaseConfig"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DocumentBaseConfig"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["DocumentBaseConfig"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["DocumentBaseConfig"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["DocumentBaseConfig"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DocumentBaseConfig"];
        };
        responseCode: 200;
      };
  "getDocumentBaseConfigSalesChannelList get /document-base-config-sales-channel":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["DocumentBaseConfigSalesChannel"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["DocumentBaseConfigSalesChannel"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /document-base-config-sales-channel?limit=25 */
            first?: unknown;
            /** @example /document-base-config-sales-channel?limit=25&page=11 */
            last?: unknown;
            /** @example /document-base-config-sales-channel?limit=25&page=4 */
            next?: unknown;
            /** @example /document-base-config-sales-channel?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createDocumentBaseConfigSalesChannel post /document-base-config-sales-channel":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["DocumentBaseConfigSalesChannel"];
        response: {
          data: components["schemas"]["DocumentBaseConfigSalesChannel"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["DocumentBaseConfigSalesChannel"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DocumentBaseConfigSalesChannel"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["DocumentBaseConfigSalesChannel"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["DocumentBaseConfigSalesChannel"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["DocumentBaseConfigSalesChannel"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DocumentBaseConfigSalesChannel"];
        };
        responseCode: 200;
      };
  "getDocumentBaseConfigSalesChannel get /document-base-config-sales-channel/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the document_base_config_sales_channel */
          id: string;
        };
        response: {
          data: components["schemas"]["DocumentBaseConfigSalesChannel"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the document_base_config_sales_channel */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DocumentBaseConfigSalesChannel"];
        };
        responseCode: 200;
      };
  "deleteDocumentBaseConfigSalesChannel delete /document-base-config-sales-channel/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the document_base_config_sales_channel */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateDocumentBaseConfigSalesChannel patch /document-base-config-sales-channel/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the document_base_config_sales_channel */
          id: string;
        };
        body: components["schemas"]["DocumentBaseConfigSalesChannel"];
        response: {
          data: components["schemas"]["DocumentBaseConfigSalesChannel"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the document_base_config_sales_channel */
          id: string;
        };
        body: components["schemas"]["DocumentBaseConfigSalesChannel"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DocumentBaseConfigSalesChannel"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the document_base_config_sales_channel */
          id: string;
        };
        body: {
          data?: components["schemas"]["DocumentBaseConfigSalesChannel"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["DocumentBaseConfigSalesChannel"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the document_base_config_sales_channel */
          id: string;
        };
        body: {
          data?: components["schemas"]["DocumentBaseConfigSalesChannel"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DocumentBaseConfigSalesChannel"];
        };
        responseCode: 200;
      };
  "getDocumentBaseConfig get /document-base-config/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the document_base_config */
          id: string;
        };
        response: {
          data: components["schemas"]["DocumentBaseConfig"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the document_base_config */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DocumentBaseConfig"];
        };
        responseCode: 200;
      };
  "deleteDocumentBaseConfig delete /document-base-config/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the document_base_config */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateDocumentBaseConfig patch /document-base-config/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the document_base_config */
          id: string;
        };
        body: components["schemas"]["DocumentBaseConfig"];
        response: {
          data: components["schemas"]["DocumentBaseConfig"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the document_base_config */
          id: string;
        };
        body: components["schemas"]["DocumentBaseConfig"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DocumentBaseConfig"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the document_base_config */
          id: string;
        };
        body: {
          data?: components["schemas"]["DocumentBaseConfig"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["DocumentBaseConfig"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the document_base_config */
          id: string;
        };
        body: {
          data?: components["schemas"]["DocumentBaseConfig"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DocumentBaseConfig"];
        };
        responseCode: 200;
      };
  "getDocumentTypeList get /document-type":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["DocumentType"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["DocumentType"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /document-type?limit=25 */
            first?: unknown;
            /** @example /document-type?limit=25&page=11 */
            last?: unknown;
            /** @example /document-type?limit=25&page=4 */
            next?: unknown;
            /** @example /document-type?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createDocumentType post /document-type":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["DocumentType"];
        response: {
          data: components["schemas"]["DocumentType"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["DocumentType"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DocumentType"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["DocumentType"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["DocumentType"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["DocumentType"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DocumentType"];
        };
        responseCode: 200;
      };
  "getDocumentType get /document-type/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the document_type */
          id: string;
        };
        response: {
          data: components["schemas"]["DocumentType"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the document_type */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DocumentType"];
        };
        responseCode: 200;
      };
  "deleteDocumentType delete /document-type/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the document_type */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateDocumentType patch /document-type/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the document_type */
          id: string;
        };
        body: components["schemas"]["DocumentType"];
        response: {
          data: components["schemas"]["DocumentType"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the document_type */
          id: string;
        };
        body: components["schemas"]["DocumentType"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DocumentType"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the document_type */
          id: string;
        };
        body: {
          data?: components["schemas"]["DocumentType"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["DocumentType"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the document_type */
          id: string;
        };
        body: {
          data?: components["schemas"]["DocumentType"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DocumentType"];
        };
        responseCode: 200;
      };
  "getDocument get /document/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the document */
          id: string;
        };
        response: {
          data: components["schemas"]["Document"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the document */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Document"];
        };
        responseCode: 200;
      };
  "deleteDocument delete /document/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the document */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateDocument patch /document/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the document */
          id: string;
        };
        body: components["schemas"]["Document"];
        response: {
          data: components["schemas"]["Document"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the document */
          id: string;
        };
        body: components["schemas"]["Document"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Document"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the document */
          id: string;
        };
        body: {
          data?: components["schemas"]["Document"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["Document"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the document */
          id: string;
        };
        body: {
          data?: components["schemas"]["Document"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Document"];
        };
        responseCode: 200;
      };
  "getDsrAppointmentList get /dsr-appointment":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["DsrAppointment"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["DsrAppointment"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /dsr-appointment?limit=25 */
            first?: unknown;
            /** @example /dsr-appointment?limit=25&page=11 */
            last?: unknown;
            /** @example /dsr-appointment?limit=25&page=4 */
            next?: unknown;
            /** @example /dsr-appointment?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createDsrAppointment post /dsr-appointment":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["DsrAppointment"];
        response: {
          data: components["schemas"]["DsrAppointment"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["DsrAppointment"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DsrAppointment"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["DsrAppointment"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["DsrAppointment"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["DsrAppointment"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DsrAppointment"];
        };
        responseCode: 200;
      };
  "getDsrAppointmentAttendeeList get /dsr-appointment-attendee":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["DsrAppointmentAttendee"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["DsrAppointmentAttendee"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /dsr-appointment-attendee?limit=25 */
            first?: unknown;
            /** @example /dsr-appointment-attendee?limit=25&page=11 */
            last?: unknown;
            /** @example /dsr-appointment-attendee?limit=25&page=4 */
            next?: unknown;
            /** @example /dsr-appointment-attendee?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createDsrAppointmentAttendee post /dsr-appointment-attendee":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["DsrAppointmentAttendee"];
        response: {
          data: components["schemas"]["DsrAppointmentAttendee"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["DsrAppointmentAttendee"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DsrAppointmentAttendee"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["DsrAppointmentAttendee"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["DsrAppointmentAttendee"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["DsrAppointmentAttendee"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DsrAppointmentAttendee"];
        };
        responseCode: 200;
      };
  "getDsrAppointmentAttendee get /dsr-appointment-attendee/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the dsr_appointment_attendee */
          id: string;
        };
        response: {
          data: components["schemas"]["DsrAppointmentAttendee"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the dsr_appointment_attendee */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DsrAppointmentAttendee"];
        };
        responseCode: 200;
      };
  "deleteDsrAppointmentAttendee delete /dsr-appointment-attendee/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the dsr_appointment_attendee */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateDsrAppointmentAttendee patch /dsr-appointment-attendee/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the dsr_appointment_attendee */
          id: string;
        };
        body: components["schemas"]["DsrAppointmentAttendee"];
        response: {
          data: components["schemas"]["DsrAppointmentAttendee"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the dsr_appointment_attendee */
          id: string;
        };
        body: components["schemas"]["DsrAppointmentAttendee"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DsrAppointmentAttendee"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the dsr_appointment_attendee */
          id: string;
        };
        body: {
          data?: components["schemas"]["DsrAppointmentAttendee"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["DsrAppointmentAttendee"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the dsr_appointment_attendee */
          id: string;
        };
        body: {
          data?: components["schemas"]["DsrAppointmentAttendee"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DsrAppointmentAttendee"];
        };
        responseCode: 200;
      };
  "getDsrAppointmentRequestList get /dsr-appointment-request":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["DsrAppointmentRequest"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["DsrAppointmentRequest"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /dsr-appointment-request?limit=25 */
            first?: unknown;
            /** @example /dsr-appointment-request?limit=25&page=11 */
            last?: unknown;
            /** @example /dsr-appointment-request?limit=25&page=4 */
            next?: unknown;
            /** @example /dsr-appointment-request?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createDsrAppointmentRequest post /dsr-appointment-request":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["DsrAppointmentRequest"];
        response: {
          data: components["schemas"]["DsrAppointmentRequest"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["DsrAppointmentRequest"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DsrAppointmentRequest"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["DsrAppointmentRequest"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["DsrAppointmentRequest"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["DsrAppointmentRequest"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DsrAppointmentRequest"];
        };
        responseCode: 200;
      };
  "getDsrAppointmentRequest get /dsr-appointment-request/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the dsr_appointment_request */
          id: string;
        };
        response: {
          data: components["schemas"]["DsrAppointmentRequest"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the dsr_appointment_request */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DsrAppointmentRequest"];
        };
        responseCode: 200;
      };
  "deleteDsrAppointmentRequest delete /dsr-appointment-request/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the dsr_appointment_request */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateDsrAppointmentRequest patch /dsr-appointment-request/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the dsr_appointment_request */
          id: string;
        };
        body: components["schemas"]["DsrAppointmentRequest"];
        response: {
          data: components["schemas"]["DsrAppointmentRequest"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the dsr_appointment_request */
          id: string;
        };
        body: components["schemas"]["DsrAppointmentRequest"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DsrAppointmentRequest"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the dsr_appointment_request */
          id: string;
        };
        body: {
          data?: components["schemas"]["DsrAppointmentRequest"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["DsrAppointmentRequest"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the dsr_appointment_request */
          id: string;
        };
        body: {
          data?: components["schemas"]["DsrAppointmentRequest"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DsrAppointmentRequest"];
        };
        responseCode: 200;
      };
  "getDsrAppointmentVideoChatList get /dsr-appointment-video-chat":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["DsrAppointmentVideoChat"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["DsrAppointmentVideoChat"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /dsr-appointment-video-chat?limit=25 */
            first?: unknown;
            /** @example /dsr-appointment-video-chat?limit=25&page=11 */
            last?: unknown;
            /** @example /dsr-appointment-video-chat?limit=25&page=4 */
            next?: unknown;
            /** @example /dsr-appointment-video-chat?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createDsrAppointmentVideoChat post /dsr-appointment-video-chat":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["DsrAppointmentVideoChat"];
        response: {
          data: components["schemas"]["DsrAppointmentVideoChat"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["DsrAppointmentVideoChat"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DsrAppointmentVideoChat"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["DsrAppointmentVideoChat"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["DsrAppointmentVideoChat"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["DsrAppointmentVideoChat"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DsrAppointmentVideoChat"];
        };
        responseCode: 200;
      };
  "getDsrAppointmentVideoChat get /dsr-appointment-video-chat/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the dsr_appointment_video_chat */
          id: string;
        };
        response: {
          data: components["schemas"]["DsrAppointmentVideoChat"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the dsr_appointment_video_chat */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DsrAppointmentVideoChat"];
        };
        responseCode: 200;
      };
  "deleteDsrAppointmentVideoChat delete /dsr-appointment-video-chat/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the dsr_appointment_video_chat */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateDsrAppointmentVideoChat patch /dsr-appointment-video-chat/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the dsr_appointment_video_chat */
          id: string;
        };
        body: components["schemas"]["DsrAppointmentVideoChat"];
        response: {
          data: components["schemas"]["DsrAppointmentVideoChat"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the dsr_appointment_video_chat */
          id: string;
        };
        body: components["schemas"]["DsrAppointmentVideoChat"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DsrAppointmentVideoChat"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the dsr_appointment_video_chat */
          id: string;
        };
        body: {
          data?: components["schemas"]["DsrAppointmentVideoChat"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["DsrAppointmentVideoChat"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the dsr_appointment_video_chat */
          id: string;
        };
        body: {
          data?: components["schemas"]["DsrAppointmentVideoChat"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DsrAppointmentVideoChat"];
        };
        responseCode: 200;
      };
  "getDsrAppointment get /dsr-appointment/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the dsr_appointment */
          id: string;
        };
        response: {
          data: components["schemas"]["DsrAppointment"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the dsr_appointment */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DsrAppointment"];
        };
        responseCode: 200;
      };
  "deleteDsrAppointment delete /dsr-appointment/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the dsr_appointment */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateDsrAppointment patch /dsr-appointment/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the dsr_appointment */
          id: string;
        };
        body: components["schemas"]["DsrAppointment"];
        response: {
          data: components["schemas"]["DsrAppointment"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the dsr_appointment */
          id: string;
        };
        body: components["schemas"]["DsrAppointment"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DsrAppointment"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the dsr_appointment */
          id: string;
        };
        body: {
          data?: components["schemas"]["DsrAppointment"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["DsrAppointment"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the dsr_appointment */
          id: string;
        };
        body: {
          data?: components["schemas"]["DsrAppointment"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DsrAppointment"];
        };
        responseCode: 200;
      };
  "getDsrAttendeeProductCollectionList get /dsr-attendee-product-collection":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["DsrAttendeeProductCollection"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["DsrAttendeeProductCollection"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /dsr-attendee-product-collection?limit=25 */
            first?: unknown;
            /** @example /dsr-attendee-product-collection?limit=25&page=11 */
            last?: unknown;
            /** @example /dsr-attendee-product-collection?limit=25&page=4 */
            next?: unknown;
            /** @example /dsr-attendee-product-collection?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createDsrAttendeeProductCollection post /dsr-attendee-product-collection":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["DsrAttendeeProductCollection"];
        response: {
          data: components["schemas"]["DsrAttendeeProductCollection"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["DsrAttendeeProductCollection"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DsrAttendeeProductCollection"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["DsrAttendeeProductCollection"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["DsrAttendeeProductCollection"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["DsrAttendeeProductCollection"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DsrAttendeeProductCollection"];
        };
        responseCode: 200;
      };
  "getDsrAttendeeProductCollection get /dsr-attendee-product-collection/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the dsr_attendee_product_collection */
          id: string;
        };
        response: {
          data: components["schemas"]["DsrAttendeeProductCollection"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the dsr_attendee_product_collection */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DsrAttendeeProductCollection"];
        };
        responseCode: 200;
      };
  "deleteDsrAttendeeProductCollection delete /dsr-attendee-product-collection/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the dsr_attendee_product_collection */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateDsrAttendeeProductCollection patch /dsr-attendee-product-collection/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the dsr_attendee_product_collection */
          id: string;
        };
        body: components["schemas"]["DsrAttendeeProductCollection"];
        response: {
          data: components["schemas"]["DsrAttendeeProductCollection"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the dsr_attendee_product_collection */
          id: string;
        };
        body: components["schemas"]["DsrAttendeeProductCollection"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DsrAttendeeProductCollection"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the dsr_attendee_product_collection */
          id: string;
        };
        body: {
          data?: components["schemas"]["DsrAttendeeProductCollection"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["DsrAttendeeProductCollection"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the dsr_attendee_product_collection */
          id: string;
        };
        body: {
          data?: components["schemas"]["DsrAttendeeProductCollection"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DsrAttendeeProductCollection"];
        };
        responseCode: 200;
      };
  "getDsrInteractionList get /dsr-interaction":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["DsrInteraction"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["DsrInteraction"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /dsr-interaction?limit=25 */
            first?: unknown;
            /** @example /dsr-interaction?limit=25&page=11 */
            last?: unknown;
            /** @example /dsr-interaction?limit=25&page=4 */
            next?: unknown;
            /** @example /dsr-interaction?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createDsrInteraction post /dsr-interaction":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["DsrInteraction"];
        response: {
          data: components["schemas"]["DsrInteraction"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["DsrInteraction"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DsrInteraction"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["DsrInteraction"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["DsrInteraction"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["DsrInteraction"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DsrInteraction"];
        };
        responseCode: 200;
      };
  "getDsrInteraction get /dsr-interaction/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the dsr_interaction */
          id: string;
        };
        response: {
          data: components["schemas"]["DsrInteraction"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the dsr_interaction */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DsrInteraction"];
        };
        responseCode: 200;
      };
  "deleteDsrInteraction delete /dsr-interaction/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the dsr_interaction */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateDsrInteraction patch /dsr-interaction/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the dsr_interaction */
          id: string;
        };
        body: components["schemas"]["DsrInteraction"];
        response: {
          data: components["schemas"]["DsrInteraction"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the dsr_interaction */
          id: string;
        };
        body: components["schemas"]["DsrInteraction"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DsrInteraction"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the dsr_interaction */
          id: string;
        };
        body: {
          data?: components["schemas"]["DsrInteraction"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["DsrInteraction"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the dsr_interaction */
          id: string;
        };
        body: {
          data?: components["schemas"]["DsrInteraction"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DsrInteraction"];
        };
        responseCode: 200;
      };
  "getDsrPresentationList get /dsr-presentation":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["DsrPresentation"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["DsrPresentation"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /dsr-presentation?limit=25 */
            first?: unknown;
            /** @example /dsr-presentation?limit=25&page=11 */
            last?: unknown;
            /** @example /dsr-presentation?limit=25&page=4 */
            next?: unknown;
            /** @example /dsr-presentation?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createDsrPresentation post /dsr-presentation":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["DsrPresentation"];
        response: {
          data: components["schemas"]["DsrPresentation"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["DsrPresentation"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DsrPresentation"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["DsrPresentation"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["DsrPresentation"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["DsrPresentation"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DsrPresentation"];
        };
        responseCode: 200;
      };
  "getDsrPresentationCmsPageList get /dsr-presentation-cms-page":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["DsrPresentationCmsPage"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["DsrPresentationCmsPage"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /dsr-presentation-cms-page?limit=25 */
            first?: unknown;
            /** @example /dsr-presentation-cms-page?limit=25&page=11 */
            last?: unknown;
            /** @example /dsr-presentation-cms-page?limit=25&page=4 */
            next?: unknown;
            /** @example /dsr-presentation-cms-page?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createDsrPresentationCmsPage post /dsr-presentation-cms-page":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["DsrPresentationCmsPage"];
        response: {
          data: components["schemas"]["DsrPresentationCmsPage"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["DsrPresentationCmsPage"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DsrPresentationCmsPage"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["DsrPresentationCmsPage"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["DsrPresentationCmsPage"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["DsrPresentationCmsPage"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DsrPresentationCmsPage"];
        };
        responseCode: 200;
      };
  "getDsrPresentationCmsPage get /dsr-presentation-cms-page/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the dsr_presentation_cms_page */
          id: string;
        };
        response: {
          data: components["schemas"]["DsrPresentationCmsPage"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the dsr_presentation_cms_page */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DsrPresentationCmsPage"];
        };
        responseCode: 200;
      };
  "deleteDsrPresentationCmsPage delete /dsr-presentation-cms-page/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the dsr_presentation_cms_page */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateDsrPresentationCmsPage patch /dsr-presentation-cms-page/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the dsr_presentation_cms_page */
          id: string;
        };
        body: components["schemas"]["DsrPresentationCmsPage"];
        response: {
          data: components["schemas"]["DsrPresentationCmsPage"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the dsr_presentation_cms_page */
          id: string;
        };
        body: components["schemas"]["DsrPresentationCmsPage"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DsrPresentationCmsPage"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the dsr_presentation_cms_page */
          id: string;
        };
        body: {
          data?: components["schemas"]["DsrPresentationCmsPage"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["DsrPresentationCmsPage"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the dsr_presentation_cms_page */
          id: string;
        };
        body: {
          data?: components["schemas"]["DsrPresentationCmsPage"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DsrPresentationCmsPage"];
        };
        responseCode: 200;
      };
  "getDsrPresentation get /dsr-presentation/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the dsr_presentation */
          id: string;
        };
        response: {
          data: components["schemas"]["DsrPresentation"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the dsr_presentation */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DsrPresentation"];
        };
        responseCode: 200;
      };
  "deleteDsrPresentation delete /dsr-presentation/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the dsr_presentation */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateDsrPresentation patch /dsr-presentation/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the dsr_presentation */
          id: string;
        };
        body: components["schemas"]["DsrPresentation"];
        response: {
          data: components["schemas"]["DsrPresentation"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the dsr_presentation */
          id: string;
        };
        body: components["schemas"]["DsrPresentation"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DsrPresentation"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the dsr_presentation */
          id: string;
        };
        body: {
          data?: components["schemas"]["DsrPresentation"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["DsrPresentation"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the dsr_presentation */
          id: string;
        };
        body: {
          data?: components["schemas"]["DsrPresentation"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DsrPresentation"];
        };
        responseCode: 200;
      };
  "getFlowList get /flow":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["Flow"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["Flow"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /flow?limit=25 */
            first?: unknown;
            /** @example /flow?limit=25&page=11 */
            last?: unknown;
            /** @example /flow?limit=25&page=4 */
            next?: unknown;
            /** @example /flow?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createFlow post /flow":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["Flow"];
        response: {
          data: components["schemas"]["Flow"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["Flow"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Flow"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["Flow"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["Flow"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["Flow"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Flow"];
        };
        responseCode: 200;
      };
  "getFlowSequenceList get /flow-sequence":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["FlowSequence"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["FlowSequence"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /flow-sequence?limit=25 */
            first?: unknown;
            /** @example /flow-sequence?limit=25&page=11 */
            last?: unknown;
            /** @example /flow-sequence?limit=25&page=4 */
            next?: unknown;
            /** @example /flow-sequence?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createFlowSequence post /flow-sequence":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["FlowSequence"];
        response: {
          data: components["schemas"]["FlowSequence"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["FlowSequence"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["FlowSequence"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["FlowSequence"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["FlowSequence"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["FlowSequence"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["FlowSequence"];
        };
        responseCode: 200;
      };
  "getFlowSequence get /flow-sequence/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the flow_sequence */
          id: string;
        };
        response: {
          data: components["schemas"]["FlowSequence"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the flow_sequence */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["FlowSequence"];
        };
        responseCode: 200;
      };
  "deleteFlowSequence delete /flow-sequence/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the flow_sequence */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateFlowSequence patch /flow-sequence/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the flow_sequence */
          id: string;
        };
        body: components["schemas"]["FlowSequence"];
        response: {
          data: components["schemas"]["FlowSequence"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the flow_sequence */
          id: string;
        };
        body: components["schemas"]["FlowSequence"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["FlowSequence"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the flow_sequence */
          id: string;
        };
        body: {
          data?: components["schemas"]["FlowSequence"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["FlowSequence"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the flow_sequence */
          id: string;
        };
        body: {
          data?: components["schemas"]["FlowSequence"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["FlowSequence"];
        };
        responseCode: 200;
      };
  "getFlowTemplateList get /flow-template":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["FlowTemplate"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["FlowTemplate"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /flow-template?limit=25 */
            first?: unknown;
            /** @example /flow-template?limit=25&page=11 */
            last?: unknown;
            /** @example /flow-template?limit=25&page=4 */
            next?: unknown;
            /** @example /flow-template?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createFlowTemplate post /flow-template":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["FlowTemplate"];
        response: {
          data: components["schemas"]["FlowTemplate"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["FlowTemplate"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["FlowTemplate"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["FlowTemplate"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["FlowTemplate"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["FlowTemplate"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["FlowTemplate"];
        };
        responseCode: 200;
      };
  "getFlowTemplate get /flow-template/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the flow_template */
          id: string;
        };
        response: {
          data: components["schemas"]["FlowTemplate"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the flow_template */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["FlowTemplate"];
        };
        responseCode: 200;
      };
  "deleteFlowTemplate delete /flow-template/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the flow_template */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateFlowTemplate patch /flow-template/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the flow_template */
          id: string;
        };
        body: components["schemas"]["FlowTemplate"];
        response: {
          data: components["schemas"]["FlowTemplate"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the flow_template */
          id: string;
        };
        body: components["schemas"]["FlowTemplate"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["FlowTemplate"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the flow_template */
          id: string;
        };
        body: {
          data?: components["schemas"]["FlowTemplate"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["FlowTemplate"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the flow_template */
          id: string;
        };
        body: {
          data?: components["schemas"]["FlowTemplate"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["FlowTemplate"];
        };
        responseCode: 200;
      };
  "getFlow get /flow/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the flow */
          id: string;
        };
        response: {
          data: components["schemas"]["Flow"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the flow */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Flow"];
        };
        responseCode: 200;
      };
  "deleteFlow delete /flow/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the flow */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateFlow patch /flow/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the flow */
          id: string;
        };
        body: components["schemas"]["Flow"];
        response: {
          data: components["schemas"]["Flow"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the flow */
          id: string;
        };
        body: components["schemas"]["Flow"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Flow"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the flow */
          id: string;
        };
        body: {
          data?: components["schemas"]["Flow"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["Flow"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the flow */
          id: string;
        };
        body: {
          data?: components["schemas"]["Flow"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Flow"];
        };
        responseCode: 200;
      };
  "getImportExportFileList get /import-export-file":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["ImportExportFile"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["ImportExportFile"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /import-export-file?limit=25 */
            first?: unknown;
            /** @example /import-export-file?limit=25&page=11 */
            last?: unknown;
            /** @example /import-export-file?limit=25&page=4 */
            next?: unknown;
            /** @example /import-export-file?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createImportExportFile post /import-export-file":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["ImportExportFile"];
        response: {
          data: components["schemas"]["ImportExportFile"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["ImportExportFile"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ImportExportFile"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["ImportExportFile"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["ImportExportFile"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["ImportExportFile"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ImportExportFile"];
        };
        responseCode: 200;
      };
  "getImportExportFile get /import-export-file/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the import_export_file */
          id: string;
        };
        response: {
          data: components["schemas"]["ImportExportFile"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the import_export_file */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ImportExportFile"];
        };
        responseCode: 200;
      };
  "deleteImportExportFile delete /import-export-file/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the import_export_file */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateImportExportFile patch /import-export-file/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the import_export_file */
          id: string;
        };
        body: components["schemas"]["ImportExportFile"];
        response: {
          data: components["schemas"]["ImportExportFile"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the import_export_file */
          id: string;
        };
        body: components["schemas"]["ImportExportFile"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ImportExportFile"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the import_export_file */
          id: string;
        };
        body: {
          data?: components["schemas"]["ImportExportFile"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["ImportExportFile"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the import_export_file */
          id: string;
        };
        body: {
          data?: components["schemas"]["ImportExportFile"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ImportExportFile"];
        };
        responseCode: 200;
      };
  "getImportExportLogList get /import-export-log":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["ImportExportLog"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["ImportExportLog"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /import-export-log?limit=25 */
            first?: unknown;
            /** @example /import-export-log?limit=25&page=11 */
            last?: unknown;
            /** @example /import-export-log?limit=25&page=4 */
            next?: unknown;
            /** @example /import-export-log?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createImportExportLog post /import-export-log":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["ImportExportLog"];
        response: {
          data: components["schemas"]["ImportExportLog"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["ImportExportLog"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ImportExportLog"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["ImportExportLog"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["ImportExportLog"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["ImportExportLog"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ImportExportLog"];
        };
        responseCode: 200;
      };
  "getImportExportLog get /import-export-log/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the import_export_log */
          id: string;
        };
        response: {
          data: components["schemas"]["ImportExportLog"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the import_export_log */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ImportExportLog"];
        };
        responseCode: 200;
      };
  "deleteImportExportLog delete /import-export-log/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the import_export_log */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateImportExportLog patch /import-export-log/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the import_export_log */
          id: string;
        };
        body: components["schemas"]["ImportExportLog"];
        response: {
          data: components["schemas"]["ImportExportLog"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the import_export_log */
          id: string;
        };
        body: components["schemas"]["ImportExportLog"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ImportExportLog"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the import_export_log */
          id: string;
        };
        body: {
          data?: components["schemas"]["ImportExportLog"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["ImportExportLog"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the import_export_log */
          id: string;
        };
        body: {
          data?: components["schemas"]["ImportExportLog"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ImportExportLog"];
        };
        responseCode: 200;
      };
  "getImportExportProfileList get /import-export-profile":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["ImportExportProfile"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["ImportExportProfile"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /import-export-profile?limit=25 */
            first?: unknown;
            /** @example /import-export-profile?limit=25&page=11 */
            last?: unknown;
            /** @example /import-export-profile?limit=25&page=4 */
            next?: unknown;
            /** @example /import-export-profile?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createImportExportProfile post /import-export-profile":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["ImportExportProfile"];
        response: {
          data: components["schemas"]["ImportExportProfile"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["ImportExportProfile"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ImportExportProfile"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["ImportExportProfile"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["ImportExportProfile"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["ImportExportProfile"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ImportExportProfile"];
        };
        responseCode: 200;
      };
  "getImportExportProfile get /import-export-profile/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the import_export_profile */
          id: string;
        };
        response: {
          data: components["schemas"]["ImportExportProfile"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the import_export_profile */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ImportExportProfile"];
        };
        responseCode: 200;
      };
  "deleteImportExportProfile delete /import-export-profile/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the import_export_profile */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateImportExportProfile patch /import-export-profile/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the import_export_profile */
          id: string;
        };
        body: components["schemas"]["ImportExportProfile"];
        response: {
          data: components["schemas"]["ImportExportProfile"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the import_export_profile */
          id: string;
        };
        body: components["schemas"]["ImportExportProfile"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ImportExportProfile"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the import_export_profile */
          id: string;
        };
        body: {
          data?: components["schemas"]["ImportExportProfile"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["ImportExportProfile"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the import_export_profile */
          id: string;
        };
        body: {
          data?: components["schemas"]["ImportExportProfile"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ImportExportProfile"];
        };
        responseCode: 200;
      };
  "getIntegrationList get /integration":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["Integration"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["Integration"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /integration?limit=25 */
            first?: unknown;
            /** @example /integration?limit=25&page=11 */
            last?: unknown;
            /** @example /integration?limit=25&page=4 */
            next?: unknown;
            /** @example /integration?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createIntegration post /integration":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["Integration"];
        response: {
          data: components["schemas"]["Integration"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["Integration"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Integration"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["Integration"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["Integration"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["Integration"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Integration"];
        };
        responseCode: 200;
      };
  "getIntegration get /integration/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the integration */
          id: string;
        };
        response: {
          data: components["schemas"]["Integration"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the integration */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Integration"];
        };
        responseCode: 200;
      };
  "deleteIntegration delete /integration/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the integration */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateIntegration patch /integration/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the integration */
          id: string;
        };
        body: components["schemas"]["Integration"];
        response: {
          data: components["schemas"]["Integration"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the integration */
          id: string;
        };
        body: components["schemas"]["Integration"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Integration"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the integration */
          id: string;
        };
        body: {
          data?: components["schemas"]["Integration"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["Integration"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the integration */
          id: string;
        };
        body: {
          data?: components["schemas"]["Integration"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Integration"];
        };
        responseCode: 200;
      };
  "getLandingPageList get /landing-page":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["LandingPage"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["LandingPage"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /landing-page?limit=25 */
            first?: unknown;
            /** @example /landing-page?limit=25&page=11 */
            last?: unknown;
            /** @example /landing-page?limit=25&page=4 */
            next?: unknown;
            /** @example /landing-page?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createLandingPage post /landing-page":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["LandingPage"];
        response: {
          data: components["schemas"]["LandingPage"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["LandingPage"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["LandingPage"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["LandingPage"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["LandingPage"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["LandingPage"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["LandingPage"];
        };
        responseCode: 200;
      };
  "getLandingPage get /landing-page/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the landing_page */
          id: string;
        };
        response: {
          data: components["schemas"]["LandingPage"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the landing_page */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["LandingPage"];
        };
        responseCode: 200;
      };
  "deleteLandingPage delete /landing-page/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the landing_page */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateLandingPage patch /landing-page/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the landing_page */
          id: string;
        };
        body: components["schemas"]["LandingPage"];
        response: {
          data: components["schemas"]["LandingPage"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the landing_page */
          id: string;
        };
        body: components["schemas"]["LandingPage"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["LandingPage"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the landing_page */
          id: string;
        };
        body: {
          data?: components["schemas"]["LandingPage"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["LandingPage"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the landing_page */
          id: string;
        };
        body: {
          data?: components["schemas"]["LandingPage"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["LandingPage"];
        };
        responseCode: 200;
      };
  "getLanguageList get /language":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["Language"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["Language"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /language?limit=25 */
            first?: unknown;
            /** @example /language?limit=25&page=11 */
            last?: unknown;
            /** @example /language?limit=25&page=4 */
            next?: unknown;
            /** @example /language?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createLanguage post /language":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["Language"];
        response: {
          data: components["schemas"]["Language"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["Language"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Language"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["Language"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["Language"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["Language"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Language"];
        };
        responseCode: 200;
      };
  "getLanguage get /language/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the language */
          id: string;
        };
        response: {
          data: components["schemas"]["Language"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the language */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Language"];
        };
        responseCode: 200;
      };
  "deleteLanguage delete /language/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the language */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateLanguage patch /language/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the language */
          id: string;
        };
        body: components["schemas"]["Language"];
        response: {
          data: components["schemas"]["Language"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the language */
          id: string;
        };
        body: components["schemas"]["Language"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Language"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the language */
          id: string;
        };
        body: {
          data?: components["schemas"]["Language"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["Language"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the language */
          id: string;
        };
        body: {
          data?: components["schemas"]["Language"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Language"];
        };
        responseCode: 200;
      };
  "getLocaleList get /locale":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["Locale"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["Locale"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /locale?limit=25 */
            first?: unknown;
            /** @example /locale?limit=25&page=11 */
            last?: unknown;
            /** @example /locale?limit=25&page=4 */
            next?: unknown;
            /** @example /locale?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createLocale post /locale":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["Locale"];
        response: {
          data: components["schemas"]["Locale"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["Locale"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Locale"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["Locale"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["Locale"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["Locale"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Locale"];
        };
        responseCode: 200;
      };
  "getLocale get /locale/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the locale */
          id: string;
        };
        response: {
          data: components["schemas"]["Locale"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the locale */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Locale"];
        };
        responseCode: 200;
      };
  "deleteLocale delete /locale/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the locale */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateLocale patch /locale/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the locale */
          id: string;
        };
        body: components["schemas"]["Locale"];
        response: {
          data: components["schemas"]["Locale"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the locale */
          id: string;
        };
        body: components["schemas"]["Locale"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Locale"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the locale */
          id: string;
        };
        body: {
          data?: components["schemas"]["Locale"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["Locale"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the locale */
          id: string;
        };
        body: {
          data?: components["schemas"]["Locale"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Locale"];
        };
        responseCode: 200;
      };
  "getLogEntryList get /log-entry":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["LogEntry"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["LogEntry"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /log-entry?limit=25 */
            first?: unknown;
            /** @example /log-entry?limit=25&page=11 */
            last?: unknown;
            /** @example /log-entry?limit=25&page=4 */
            next?: unknown;
            /** @example /log-entry?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createLogEntry post /log-entry":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["LogEntry"];
        response: {
          data: components["schemas"]["LogEntry"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["LogEntry"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["LogEntry"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["LogEntry"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["LogEntry"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["LogEntry"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["LogEntry"];
        };
        responseCode: 200;
      };
  "getLogEntry get /log-entry/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the log_entry */
          id: string;
        };
        response: {
          data: components["schemas"]["LogEntry"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the log_entry */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["LogEntry"];
        };
        responseCode: 200;
      };
  "deleteLogEntry delete /log-entry/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the log_entry */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateLogEntry patch /log-entry/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the log_entry */
          id: string;
        };
        body: components["schemas"]["LogEntry"];
        response: {
          data: components["schemas"]["LogEntry"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the log_entry */
          id: string;
        };
        body: components["schemas"]["LogEntry"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["LogEntry"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the log_entry */
          id: string;
        };
        body: {
          data?: components["schemas"]["LogEntry"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["LogEntry"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the log_entry */
          id: string;
        };
        body: {
          data?: components["schemas"]["LogEntry"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["LogEntry"];
        };
        responseCode: 200;
      };
  "getMailHeaderFooterList get /mail-header-footer":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["MailHeaderFooter"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["MailHeaderFooter"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /mail-header-footer?limit=25 */
            first?: unknown;
            /** @example /mail-header-footer?limit=25&page=11 */
            last?: unknown;
            /** @example /mail-header-footer?limit=25&page=4 */
            next?: unknown;
            /** @example /mail-header-footer?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createMailHeaderFooter post /mail-header-footer":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["MailHeaderFooter"];
        response: {
          data: components["schemas"]["MailHeaderFooter"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["MailHeaderFooter"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MailHeaderFooter"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["MailHeaderFooter"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["MailHeaderFooter"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["MailHeaderFooter"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MailHeaderFooter"];
        };
        responseCode: 200;
      };
  "getMailHeaderFooter get /mail-header-footer/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the mail_header_footer */
          id: string;
        };
        response: {
          data: components["schemas"]["MailHeaderFooter"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the mail_header_footer */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MailHeaderFooter"];
        };
        responseCode: 200;
      };
  "deleteMailHeaderFooter delete /mail-header-footer/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the mail_header_footer */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateMailHeaderFooter patch /mail-header-footer/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the mail_header_footer */
          id: string;
        };
        body: components["schemas"]["MailHeaderFooter"];
        response: {
          data: components["schemas"]["MailHeaderFooter"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the mail_header_footer */
          id: string;
        };
        body: components["schemas"]["MailHeaderFooter"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MailHeaderFooter"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the mail_header_footer */
          id: string;
        };
        body: {
          data?: components["schemas"]["MailHeaderFooter"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["MailHeaderFooter"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the mail_header_footer */
          id: string;
        };
        body: {
          data?: components["schemas"]["MailHeaderFooter"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MailHeaderFooter"];
        };
        responseCode: 200;
      };
  "getMailTemplateList get /mail-template":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["MailTemplate"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["MailTemplate"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /mail-template?limit=25 */
            first?: unknown;
            /** @example /mail-template?limit=25&page=11 */
            last?: unknown;
            /** @example /mail-template?limit=25&page=4 */
            next?: unknown;
            /** @example /mail-template?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createMailTemplate post /mail-template":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["MailTemplate"];
        response: {
          data: components["schemas"]["MailTemplate"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["MailTemplate"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MailTemplate"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["MailTemplate"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["MailTemplate"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["MailTemplate"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MailTemplate"];
        };
        responseCode: 200;
      };
  "getMailTemplateTypeList get /mail-template-type":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["MailTemplateType"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["MailTemplateType"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /mail-template-type?limit=25 */
            first?: unknown;
            /** @example /mail-template-type?limit=25&page=11 */
            last?: unknown;
            /** @example /mail-template-type?limit=25&page=4 */
            next?: unknown;
            /** @example /mail-template-type?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createMailTemplateType post /mail-template-type":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["MailTemplateType"];
        response: {
          data: components["schemas"]["MailTemplateType"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["MailTemplateType"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MailTemplateType"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["MailTemplateType"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["MailTemplateType"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["MailTemplateType"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MailTemplateType"];
        };
        responseCode: 200;
      };
  "getMailTemplateType get /mail-template-type/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the mail_template_type */
          id: string;
        };
        response: {
          data: components["schemas"]["MailTemplateType"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the mail_template_type */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MailTemplateType"];
        };
        responseCode: 200;
      };
  "deleteMailTemplateType delete /mail-template-type/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the mail_template_type */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateMailTemplateType patch /mail-template-type/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the mail_template_type */
          id: string;
        };
        body: components["schemas"]["MailTemplateType"];
        response: {
          data: components["schemas"]["MailTemplateType"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the mail_template_type */
          id: string;
        };
        body: components["schemas"]["MailTemplateType"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MailTemplateType"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the mail_template_type */
          id: string;
        };
        body: {
          data?: components["schemas"]["MailTemplateType"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["MailTemplateType"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the mail_template_type */
          id: string;
        };
        body: {
          data?: components["schemas"]["MailTemplateType"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MailTemplateType"];
        };
        responseCode: 200;
      };
  "getMailTemplate get /mail-template/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the mail_template */
          id: string;
        };
        response: {
          data: components["schemas"]["MailTemplate"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the mail_template */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MailTemplate"];
        };
        responseCode: 200;
      };
  "deleteMailTemplate delete /mail-template/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the mail_template */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateMailTemplate patch /mail-template/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the mail_template */
          id: string;
        };
        body: components["schemas"]["MailTemplate"];
        response: {
          data: components["schemas"]["MailTemplate"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the mail_template */
          id: string;
        };
        body: components["schemas"]["MailTemplate"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MailTemplate"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the mail_template */
          id: string;
        };
        body: {
          data?: components["schemas"]["MailTemplate"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["MailTemplate"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the mail_template */
          id: string;
        };
        body: {
          data?: components["schemas"]["MailTemplate"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MailTemplate"];
        };
        responseCode: 200;
      };
  "getMainCategoryList get /main-category":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["MainCategory"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["MainCategory"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /main-category?limit=25 */
            first?: unknown;
            /** @example /main-category?limit=25&page=11 */
            last?: unknown;
            /** @example /main-category?limit=25&page=4 */
            next?: unknown;
            /** @example /main-category?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createMainCategory post /main-category":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["MainCategory"];
        response: {
          data: components["schemas"]["MainCategory"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["MainCategory"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MainCategory"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["MainCategory"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["MainCategory"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["MainCategory"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MainCategory"];
        };
        responseCode: 200;
      };
  "getMainCategory get /main-category/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the main_category */
          id: string;
        };
        response: {
          data: components["schemas"]["MainCategory"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the main_category */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MainCategory"];
        };
        responseCode: 200;
      };
  "deleteMainCategory delete /main-category/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the main_category */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateMainCategory patch /main-category/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the main_category */
          id: string;
        };
        body: components["schemas"]["MainCategory"];
        response: {
          data: components["schemas"]["MainCategory"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the main_category */
          id: string;
        };
        body: components["schemas"]["MainCategory"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MainCategory"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the main_category */
          id: string;
        };
        body: {
          data?: components["schemas"]["MainCategory"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["MainCategory"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the main_category */
          id: string;
        };
        body: {
          data?: components["schemas"]["MainCategory"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MainCategory"];
        };
        responseCode: 200;
      };
  "getMediaList get /media":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["Media"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["Media"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /media?limit=25 */
            first?: unknown;
            /** @example /media?limit=25&page=11 */
            last?: unknown;
            /** @example /media?limit=25&page=4 */
            next?: unknown;
            /** @example /media?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createMedia post /media":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["Media"];
        response: {
          data: components["schemas"]["Media"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["Media"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Media"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["Media"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["Media"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["Media"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Media"];
        };
        responseCode: 200;
      };
  "getMediaAiTagList get /media-ai-tag":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["MediaAiTag"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["MediaAiTag"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /media-ai-tag?limit=25 */
            first?: unknown;
            /** @example /media-ai-tag?limit=25&page=11 */
            last?: unknown;
            /** @example /media-ai-tag?limit=25&page=4 */
            next?: unknown;
            /** @example /media-ai-tag?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createMediaAiTag post /media-ai-tag":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["MediaAiTag"];
        response: {
          data: components["schemas"]["MediaAiTag"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["MediaAiTag"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MediaAiTag"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["MediaAiTag"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["MediaAiTag"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["MediaAiTag"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MediaAiTag"];
        };
        responseCode: 200;
      };
  "getMediaAiTag get /media-ai-tag/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the media_ai_tag */
          id: string;
        };
        response: {
          data: components["schemas"]["MediaAiTag"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the media_ai_tag */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MediaAiTag"];
        };
        responseCode: 200;
      };
  "deleteMediaAiTag delete /media-ai-tag/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the media_ai_tag */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateMediaAiTag patch /media-ai-tag/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the media_ai_tag */
          id: string;
        };
        body: components["schemas"]["MediaAiTag"];
        response: {
          data: components["schemas"]["MediaAiTag"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the media_ai_tag */
          id: string;
        };
        body: components["schemas"]["MediaAiTag"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MediaAiTag"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the media_ai_tag */
          id: string;
        };
        body: {
          data?: components["schemas"]["MediaAiTag"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["MediaAiTag"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the media_ai_tag */
          id: string;
        };
        body: {
          data?: components["schemas"]["MediaAiTag"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MediaAiTag"];
        };
        responseCode: 200;
      };
  "getMediaDefaultFolderList get /media-default-folder":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["MediaDefaultFolder"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["MediaDefaultFolder"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /media-default-folder?limit=25 */
            first?: unknown;
            /** @example /media-default-folder?limit=25&page=11 */
            last?: unknown;
            /** @example /media-default-folder?limit=25&page=4 */
            next?: unknown;
            /** @example /media-default-folder?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createMediaDefaultFolder post /media-default-folder":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["MediaDefaultFolder"];
        response: {
          data: components["schemas"]["MediaDefaultFolder"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["MediaDefaultFolder"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MediaDefaultFolder"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["MediaDefaultFolder"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["MediaDefaultFolder"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["MediaDefaultFolder"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MediaDefaultFolder"];
        };
        responseCode: 200;
      };
  "getMediaDefaultFolder get /media-default-folder/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the media_default_folder */
          id: string;
        };
        response: {
          data: components["schemas"]["MediaDefaultFolder"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the media_default_folder */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MediaDefaultFolder"];
        };
        responseCode: 200;
      };
  "deleteMediaDefaultFolder delete /media-default-folder/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the media_default_folder */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateMediaDefaultFolder patch /media-default-folder/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the media_default_folder */
          id: string;
        };
        body: components["schemas"]["MediaDefaultFolder"];
        response: {
          data: components["schemas"]["MediaDefaultFolder"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the media_default_folder */
          id: string;
        };
        body: components["schemas"]["MediaDefaultFolder"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MediaDefaultFolder"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the media_default_folder */
          id: string;
        };
        body: {
          data?: components["schemas"]["MediaDefaultFolder"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["MediaDefaultFolder"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the media_default_folder */
          id: string;
        };
        body: {
          data?: components["schemas"]["MediaDefaultFolder"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MediaDefaultFolder"];
        };
        responseCode: 200;
      };
  "getMediaFolderList get /media-folder":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["MediaFolder"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["MediaFolder"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /media-folder?limit=25 */
            first?: unknown;
            /** @example /media-folder?limit=25&page=11 */
            last?: unknown;
            /** @example /media-folder?limit=25&page=4 */
            next?: unknown;
            /** @example /media-folder?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createMediaFolder post /media-folder":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["MediaFolder"];
        response: {
          data: components["schemas"]["MediaFolder"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["MediaFolder"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MediaFolder"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["MediaFolder"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["MediaFolder"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["MediaFolder"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MediaFolder"];
        };
        responseCode: 200;
      };
  "getMediaFolderConfigurationList get /media-folder-configuration":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["MediaFolderConfiguration"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["MediaFolderConfiguration"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /media-folder-configuration?limit=25 */
            first?: unknown;
            /** @example /media-folder-configuration?limit=25&page=11 */
            last?: unknown;
            /** @example /media-folder-configuration?limit=25&page=4 */
            next?: unknown;
            /** @example /media-folder-configuration?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createMediaFolderConfiguration post /media-folder-configuration":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["MediaFolderConfiguration"];
        response: {
          data: components["schemas"]["MediaFolderConfiguration"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["MediaFolderConfiguration"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MediaFolderConfiguration"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["MediaFolderConfiguration"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["MediaFolderConfiguration"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["MediaFolderConfiguration"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MediaFolderConfiguration"];
        };
        responseCode: 200;
      };
  "getMediaFolderConfiguration get /media-folder-configuration/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the media_folder_configuration */
          id: string;
        };
        response: {
          data: components["schemas"]["MediaFolderConfiguration"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the media_folder_configuration */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MediaFolderConfiguration"];
        };
        responseCode: 200;
      };
  "deleteMediaFolderConfiguration delete /media-folder-configuration/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the media_folder_configuration */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateMediaFolderConfiguration patch /media-folder-configuration/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the media_folder_configuration */
          id: string;
        };
        body: components["schemas"]["MediaFolderConfiguration"];
        response: {
          data: components["schemas"]["MediaFolderConfiguration"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the media_folder_configuration */
          id: string;
        };
        body: components["schemas"]["MediaFolderConfiguration"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MediaFolderConfiguration"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the media_folder_configuration */
          id: string;
        };
        body: {
          data?: components["schemas"]["MediaFolderConfiguration"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["MediaFolderConfiguration"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the media_folder_configuration */
          id: string;
        };
        body: {
          data?: components["schemas"]["MediaFolderConfiguration"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MediaFolderConfiguration"];
        };
        responseCode: 200;
      };
  "getMediaFolder get /media-folder/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the media_folder */
          id: string;
        };
        response: {
          data: components["schemas"]["MediaFolder"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the media_folder */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MediaFolder"];
        };
        responseCode: 200;
      };
  "deleteMediaFolder delete /media-folder/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the media_folder */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateMediaFolder patch /media-folder/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the media_folder */
          id: string;
        };
        body: components["schemas"]["MediaFolder"];
        response: {
          data: components["schemas"]["MediaFolder"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the media_folder */
          id: string;
        };
        body: components["schemas"]["MediaFolder"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MediaFolder"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the media_folder */
          id: string;
        };
        body: {
          data?: components["schemas"]["MediaFolder"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["MediaFolder"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the media_folder */
          id: string;
        };
        body: {
          data?: components["schemas"]["MediaFolder"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MediaFolder"];
        };
        responseCode: 200;
      };
  "getMediaThumbnailList get /media-thumbnail":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["MediaThumbnail"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["MediaThumbnail"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /media-thumbnail?limit=25 */
            first?: unknown;
            /** @example /media-thumbnail?limit=25&page=11 */
            last?: unknown;
            /** @example /media-thumbnail?limit=25&page=4 */
            next?: unknown;
            /** @example /media-thumbnail?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createMediaThumbnail post /media-thumbnail":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["MediaThumbnail"];
        response: {
          data: components["schemas"]["MediaThumbnail"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["MediaThumbnail"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MediaThumbnail"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["MediaThumbnail"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["MediaThumbnail"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["MediaThumbnail"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MediaThumbnail"];
        };
        responseCode: 200;
      };
  "getMediaThumbnailSizeList get /media-thumbnail-size":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["MediaThumbnailSize"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["MediaThumbnailSize"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /media-thumbnail-size?limit=25 */
            first?: unknown;
            /** @example /media-thumbnail-size?limit=25&page=11 */
            last?: unknown;
            /** @example /media-thumbnail-size?limit=25&page=4 */
            next?: unknown;
            /** @example /media-thumbnail-size?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createMediaThumbnailSize post /media-thumbnail-size":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["MediaThumbnailSize"];
        response: {
          data: components["schemas"]["MediaThumbnailSize"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["MediaThumbnailSize"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MediaThumbnailSize"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["MediaThumbnailSize"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["MediaThumbnailSize"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["MediaThumbnailSize"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MediaThumbnailSize"];
        };
        responseCode: 200;
      };
  "getMediaThumbnailSize get /media-thumbnail-size/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the media_thumbnail_size */
          id: string;
        };
        response: {
          data: components["schemas"]["MediaThumbnailSize"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the media_thumbnail_size */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MediaThumbnailSize"];
        };
        responseCode: 200;
      };
  "deleteMediaThumbnailSize delete /media-thumbnail-size/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the media_thumbnail_size */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateMediaThumbnailSize patch /media-thumbnail-size/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the media_thumbnail_size */
          id: string;
        };
        body: components["schemas"]["MediaThumbnailSize"];
        response: {
          data: components["schemas"]["MediaThumbnailSize"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the media_thumbnail_size */
          id: string;
        };
        body: components["schemas"]["MediaThumbnailSize"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MediaThumbnailSize"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the media_thumbnail_size */
          id: string;
        };
        body: {
          data?: components["schemas"]["MediaThumbnailSize"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["MediaThumbnailSize"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the media_thumbnail_size */
          id: string;
        };
        body: {
          data?: components["schemas"]["MediaThumbnailSize"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MediaThumbnailSize"];
        };
        responseCode: 200;
      };
  "getMediaThumbnail get /media-thumbnail/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the media_thumbnail */
          id: string;
        };
        response: {
          data: components["schemas"]["MediaThumbnail"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the media_thumbnail */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MediaThumbnail"];
        };
        responseCode: 200;
      };
  "deleteMediaThumbnail delete /media-thumbnail/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the media_thumbnail */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateMediaThumbnail patch /media-thumbnail/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the media_thumbnail */
          id: string;
        };
        body: components["schemas"]["MediaThumbnail"];
        response: {
          data: components["schemas"]["MediaThumbnail"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the media_thumbnail */
          id: string;
        };
        body: components["schemas"]["MediaThumbnail"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MediaThumbnail"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the media_thumbnail */
          id: string;
        };
        body: {
          data?: components["schemas"]["MediaThumbnail"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["MediaThumbnail"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the media_thumbnail */
          id: string;
        };
        body: {
          data?: components["schemas"]["MediaThumbnail"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MediaThumbnail"];
        };
        responseCode: 200;
      };
  "getMedia get /media/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the media */
          id: string;
        };
        response: {
          data: components["schemas"]["Media"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the media */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Media"];
        };
        responseCode: 200;
      };
  "deleteMedia delete /media/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the media */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateMedia patch /media/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the media */
          id: string;
        };
        body: components["schemas"]["Media"];
        response: {
          data: components["schemas"]["Media"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the media */
          id: string;
        };
        body: components["schemas"]["Media"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Media"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the media */
          id: string;
        };
        body: {
          data?: components["schemas"]["Media"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["Media"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the media */
          id: string;
        };
        body: {
          data?: components["schemas"]["Media"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Media"];
        };
        responseCode: 200;
      };
  "getNewsletterRecipientList get /newsletter-recipient":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["NewsletterRecipient"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["NewsletterRecipient"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /newsletter-recipient?limit=25 */
            first?: unknown;
            /** @example /newsletter-recipient?limit=25&page=11 */
            last?: unknown;
            /** @example /newsletter-recipient?limit=25&page=4 */
            next?: unknown;
            /** @example /newsletter-recipient?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createNewsletterRecipient post /newsletter-recipient":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["NewsletterRecipient"];
        response: {
          data: components["schemas"]["NewsletterRecipient"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["NewsletterRecipient"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["NewsletterRecipient"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["NewsletterRecipient"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["NewsletterRecipient"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["NewsletterRecipient"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["NewsletterRecipient"];
        };
        responseCode: 200;
      };
  "getNewsletterRecipient get /newsletter-recipient/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the newsletter_recipient */
          id: string;
        };
        response: {
          data: components["schemas"]["NewsletterRecipient"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the newsletter_recipient */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["NewsletterRecipient"];
        };
        responseCode: 200;
      };
  "deleteNewsletterRecipient delete /newsletter-recipient/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the newsletter_recipient */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateNewsletterRecipient patch /newsletter-recipient/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the newsletter_recipient */
          id: string;
        };
        body: components["schemas"]["NewsletterRecipient"];
        response: {
          data: components["schemas"]["NewsletterRecipient"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the newsletter_recipient */
          id: string;
        };
        body: components["schemas"]["NewsletterRecipient"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["NewsletterRecipient"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the newsletter_recipient */
          id: string;
        };
        body: {
          data?: components["schemas"]["NewsletterRecipient"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["NewsletterRecipient"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the newsletter_recipient */
          id: string;
        };
        body: {
          data?: components["schemas"]["NewsletterRecipient"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["NewsletterRecipient"];
        };
        responseCode: 200;
      };
  "getNotificationList get /notification":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["Notification"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["Notification"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /notification?limit=25 */
            first?: unknown;
            /** @example /notification?limit=25&page=11 */
            last?: unknown;
            /** @example /notification?limit=25&page=4 */
            next?: unknown;
            /** @example /notification?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createNotification post /notification":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["Notification"];
        response: {
          data: components["schemas"]["Notification"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["Notification"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Notification"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["Notification"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["Notification"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["Notification"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Notification"];
        };
        responseCode: 200;
      };
  "getNotification get /notification/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the notification */
          id: string;
        };
        response: {
          data: components["schemas"]["Notification"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the notification */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Notification"];
        };
        responseCode: 200;
      };
  "deleteNotification delete /notification/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the notification */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateNotification patch /notification/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the notification */
          id: string;
        };
        body: components["schemas"]["Notification"];
        response: {
          data: components["schemas"]["Notification"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the notification */
          id: string;
        };
        body: components["schemas"]["Notification"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Notification"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the notification */
          id: string;
        };
        body: {
          data?: components["schemas"]["Notification"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["Notification"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the notification */
          id: string;
        };
        body: {
          data?: components["schemas"]["Notification"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Notification"];
        };
        responseCode: 200;
      };
  "getNumberRangeList get /number-range":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["NumberRange"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["NumberRange"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /number-range?limit=25 */
            first?: unknown;
            /** @example /number-range?limit=25&page=11 */
            last?: unknown;
            /** @example /number-range?limit=25&page=4 */
            next?: unknown;
            /** @example /number-range?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createNumberRange post /number-range":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["NumberRange"];
        response: {
          data: components["schemas"]["NumberRange"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["NumberRange"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["NumberRange"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["NumberRange"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["NumberRange"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["NumberRange"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["NumberRange"];
        };
        responseCode: 200;
      };
  "getNumberRangeSalesChannelList get /number-range-sales-channel":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["NumberRangeSalesChannel"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["NumberRangeSalesChannel"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /number-range-sales-channel?limit=25 */
            first?: unknown;
            /** @example /number-range-sales-channel?limit=25&page=11 */
            last?: unknown;
            /** @example /number-range-sales-channel?limit=25&page=4 */
            next?: unknown;
            /** @example /number-range-sales-channel?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createNumberRangeSalesChannel post /number-range-sales-channel":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["NumberRangeSalesChannel"];
        response: {
          data: components["schemas"]["NumberRangeSalesChannel"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["NumberRangeSalesChannel"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["NumberRangeSalesChannel"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["NumberRangeSalesChannel"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["NumberRangeSalesChannel"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["NumberRangeSalesChannel"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["NumberRangeSalesChannel"];
        };
        responseCode: 200;
      };
  "getNumberRangeSalesChannel get /number-range-sales-channel/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the number_range_sales_channel */
          id: string;
        };
        response: {
          data: components["schemas"]["NumberRangeSalesChannel"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the number_range_sales_channel */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["NumberRangeSalesChannel"];
        };
        responseCode: 200;
      };
  "deleteNumberRangeSalesChannel delete /number-range-sales-channel/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the number_range_sales_channel */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateNumberRangeSalesChannel patch /number-range-sales-channel/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the number_range_sales_channel */
          id: string;
        };
        body: components["schemas"]["NumberRangeSalesChannel"];
        response: {
          data: components["schemas"]["NumberRangeSalesChannel"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the number_range_sales_channel */
          id: string;
        };
        body: components["schemas"]["NumberRangeSalesChannel"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["NumberRangeSalesChannel"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the number_range_sales_channel */
          id: string;
        };
        body: {
          data?: components["schemas"]["NumberRangeSalesChannel"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["NumberRangeSalesChannel"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the number_range_sales_channel */
          id: string;
        };
        body: {
          data?: components["schemas"]["NumberRangeSalesChannel"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["NumberRangeSalesChannel"];
        };
        responseCode: 200;
      };
  "getNumberRangeStateList get /number-range-state":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["NumberRangeState"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["NumberRangeState"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /number-range-state?limit=25 */
            first?: unknown;
            /** @example /number-range-state?limit=25&page=11 */
            last?: unknown;
            /** @example /number-range-state?limit=25&page=4 */
            next?: unknown;
            /** @example /number-range-state?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createNumberRangeState post /number-range-state":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["NumberRangeState"];
        response: {
          data: components["schemas"]["NumberRangeState"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["NumberRangeState"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["NumberRangeState"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["NumberRangeState"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["NumberRangeState"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["NumberRangeState"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["NumberRangeState"];
        };
        responseCode: 200;
      };
  "getNumberRangeState get /number-range-state/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the number_range_state */
          id: string;
        };
        response: {
          data: components["schemas"]["NumberRangeState"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the number_range_state */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["NumberRangeState"];
        };
        responseCode: 200;
      };
  "deleteNumberRangeState delete /number-range-state/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the number_range_state */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateNumberRangeState patch /number-range-state/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the number_range_state */
          id: string;
        };
        body: components["schemas"]["NumberRangeState"];
        response: {
          data: components["schemas"]["NumberRangeState"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the number_range_state */
          id: string;
        };
        body: components["schemas"]["NumberRangeState"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["NumberRangeState"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the number_range_state */
          id: string;
        };
        body: {
          data?: components["schemas"]["NumberRangeState"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["NumberRangeState"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the number_range_state */
          id: string;
        };
        body: {
          data?: components["schemas"]["NumberRangeState"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["NumberRangeState"];
        };
        responseCode: 200;
      };
  "getNumberRangeTypeList get /number-range-type":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["NumberRangeType"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["NumberRangeType"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /number-range-type?limit=25 */
            first?: unknown;
            /** @example /number-range-type?limit=25&page=11 */
            last?: unknown;
            /** @example /number-range-type?limit=25&page=4 */
            next?: unknown;
            /** @example /number-range-type?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createNumberRangeType post /number-range-type":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["NumberRangeType"];
        response: {
          data: components["schemas"]["NumberRangeType"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["NumberRangeType"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["NumberRangeType"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["NumberRangeType"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["NumberRangeType"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["NumberRangeType"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["NumberRangeType"];
        };
        responseCode: 200;
      };
  "getNumberRangeType get /number-range-type/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the number_range_type */
          id: string;
        };
        response: {
          data: components["schemas"]["NumberRangeType"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the number_range_type */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["NumberRangeType"];
        };
        responseCode: 200;
      };
  "deleteNumberRangeType delete /number-range-type/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the number_range_type */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateNumberRangeType patch /number-range-type/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the number_range_type */
          id: string;
        };
        body: components["schemas"]["NumberRangeType"];
        response: {
          data: components["schemas"]["NumberRangeType"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the number_range_type */
          id: string;
        };
        body: components["schemas"]["NumberRangeType"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["NumberRangeType"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the number_range_type */
          id: string;
        };
        body: {
          data?: components["schemas"]["NumberRangeType"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["NumberRangeType"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the number_range_type */
          id: string;
        };
        body: {
          data?: components["schemas"]["NumberRangeType"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["NumberRangeType"];
        };
        responseCode: 200;
      };
  "getNumberRange get /number-range/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the number_range */
          id: string;
        };
        response: {
          data: components["schemas"]["NumberRange"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the number_range */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["NumberRange"];
        };
        responseCode: 200;
      };
  "deleteNumberRange delete /number-range/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the number_range */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateNumberRange patch /number-range/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the number_range */
          id: string;
        };
        body: components["schemas"]["NumberRange"];
        response: {
          data: components["schemas"]["NumberRange"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the number_range */
          id: string;
        };
        body: components["schemas"]["NumberRange"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["NumberRange"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the number_range */
          id: string;
        };
        body: {
          data?: components["schemas"]["NumberRange"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["NumberRange"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the number_range */
          id: string;
        };
        body: {
          data?: components["schemas"]["NumberRange"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["NumberRange"];
        };
        responseCode: 200;
      };
  "token post /oauth/token": {
    contentType?: "application/json";
    accept?: "application/json";
    body:
      | components["schemas"]["OAuthPasswordGrant"]
      | components["schemas"]["OAuthRefreshTokenGrant"]
      | components["schemas"]["OAuthClientCredentialsGrant"];
    response: {
      /** The access token that can be used for subsequent requests */
      access_token: string;
      /** Token lifetime in seconds. */
      expires_in: number;
      /** The refresh token that can be used to refresh the access token. This field is not returned on grant type `refresh_token`. */
      refresh_token?: string;
      /** Type of the token. */
      token_type: string;
    };
    responseCode: 200;
  };
  "getOrderList get /order":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["Order"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["Order"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /order?limit=25 */
            first?: unknown;
            /** @example /order?limit=25&page=11 */
            last?: unknown;
            /** @example /order?limit=25&page=4 */
            next?: unknown;
            /** @example /order?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createOrder post /order":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["Order"];
        response: {
          data: components["schemas"]["Order"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["Order"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Order"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["Order"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["Order"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["Order"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Order"];
        };
        responseCode: 200;
      };
  "getOrderAddressList get /order-address":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["OrderAddress"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["OrderAddress"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /order-address?limit=25 */
            first?: unknown;
            /** @example /order-address?limit=25&page=11 */
            last?: unknown;
            /** @example /order-address?limit=25&page=4 */
            next?: unknown;
            /** @example /order-address?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createOrderAddress post /order-address":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["OrderAddress"];
        response: {
          data: components["schemas"]["OrderAddress"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["OrderAddress"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderAddress"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["OrderAddress"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["OrderAddress"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["OrderAddress"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderAddress"];
        };
        responseCode: 200;
      };
  "getOrderAddress get /order-address/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the order_address */
          id: string;
        };
        response: {
          data: components["schemas"]["OrderAddress"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the order_address */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderAddress"];
        };
        responseCode: 200;
      };
  "deleteOrderAddress delete /order-address/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the order_address */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateOrderAddress patch /order-address/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order_address */
          id: string;
        };
        body: components["schemas"]["OrderAddress"];
        response: {
          data: components["schemas"]["OrderAddress"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order_address */
          id: string;
        };
        body: components["schemas"]["OrderAddress"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderAddress"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order_address */
          id: string;
        };
        body: {
          data?: components["schemas"]["OrderAddress"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["OrderAddress"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order_address */
          id: string;
        };
        body: {
          data?: components["schemas"]["OrderAddress"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderAddress"];
        };
        responseCode: 200;
      };
  "getOrderCustomerList get /order-customer":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["OrderCustomer"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["OrderCustomer"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /order-customer?limit=25 */
            first?: unknown;
            /** @example /order-customer?limit=25&page=11 */
            last?: unknown;
            /** @example /order-customer?limit=25&page=4 */
            next?: unknown;
            /** @example /order-customer?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createOrderCustomer post /order-customer":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["OrderCustomer"];
        response: {
          data: components["schemas"]["OrderCustomer"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["OrderCustomer"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderCustomer"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["OrderCustomer"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["OrderCustomer"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["OrderCustomer"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderCustomer"];
        };
        responseCode: 200;
      };
  "getOrderCustomer get /order-customer/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the order_customer */
          id: string;
        };
        response: {
          data: components["schemas"]["OrderCustomer"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the order_customer */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderCustomer"];
        };
        responseCode: 200;
      };
  "deleteOrderCustomer delete /order-customer/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the order_customer */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateOrderCustomer patch /order-customer/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order_customer */
          id: string;
        };
        body: components["schemas"]["OrderCustomer"];
        response: {
          data: components["schemas"]["OrderCustomer"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order_customer */
          id: string;
        };
        body: components["schemas"]["OrderCustomer"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderCustomer"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order_customer */
          id: string;
        };
        body: {
          data?: components["schemas"]["OrderCustomer"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["OrderCustomer"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order_customer */
          id: string;
        };
        body: {
          data?: components["schemas"]["OrderCustomer"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderCustomer"];
        };
        responseCode: 200;
      };
  "getOrderDeliveryList get /order-delivery":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["OrderDelivery"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["OrderDelivery"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /order-delivery?limit=25 */
            first?: unknown;
            /** @example /order-delivery?limit=25&page=11 */
            last?: unknown;
            /** @example /order-delivery?limit=25&page=4 */
            next?: unknown;
            /** @example /order-delivery?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createOrderDelivery post /order-delivery":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["OrderDelivery"];
        response: {
          data: components["schemas"]["OrderDelivery"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["OrderDelivery"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderDelivery"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["OrderDelivery"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["OrderDelivery"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["OrderDelivery"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderDelivery"];
        };
        responseCode: 200;
      };
  "getOrderDeliveryPositionList get /order-delivery-position":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["OrderDeliveryPosition"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["OrderDeliveryPosition"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /order-delivery-position?limit=25 */
            first?: unknown;
            /** @example /order-delivery-position?limit=25&page=11 */
            last?: unknown;
            /** @example /order-delivery-position?limit=25&page=4 */
            next?: unknown;
            /** @example /order-delivery-position?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createOrderDeliveryPosition post /order-delivery-position":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["OrderDeliveryPosition"];
        response: {
          data: components["schemas"]["OrderDeliveryPosition"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["OrderDeliveryPosition"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderDeliveryPosition"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["OrderDeliveryPosition"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["OrderDeliveryPosition"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["OrderDeliveryPosition"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderDeliveryPosition"];
        };
        responseCode: 200;
      };
  "getOrderDeliveryPosition get /order-delivery-position/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the order_delivery_position */
          id: string;
        };
        response: {
          data: components["schemas"]["OrderDeliveryPosition"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the order_delivery_position */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderDeliveryPosition"];
        };
        responseCode: 200;
      };
  "deleteOrderDeliveryPosition delete /order-delivery-position/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the order_delivery_position */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateOrderDeliveryPosition patch /order-delivery-position/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order_delivery_position */
          id: string;
        };
        body: components["schemas"]["OrderDeliveryPosition"];
        response: {
          data: components["schemas"]["OrderDeliveryPosition"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order_delivery_position */
          id: string;
        };
        body: components["schemas"]["OrderDeliveryPosition"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderDeliveryPosition"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order_delivery_position */
          id: string;
        };
        body: {
          data?: components["schemas"]["OrderDeliveryPosition"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["OrderDeliveryPosition"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order_delivery_position */
          id: string;
        };
        body: {
          data?: components["schemas"]["OrderDeliveryPosition"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderDeliveryPosition"];
        };
        responseCode: 200;
      };
  "getOrderDelivery get /order-delivery/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the order_delivery */
          id: string;
        };
        response: {
          data: components["schemas"]["OrderDelivery"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the order_delivery */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderDelivery"];
        };
        responseCode: 200;
      };
  "deleteOrderDelivery delete /order-delivery/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the order_delivery */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateOrderDelivery patch /order-delivery/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order_delivery */
          id: string;
        };
        body: components["schemas"]["OrderDelivery"];
        response: {
          data: components["schemas"]["OrderDelivery"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order_delivery */
          id: string;
        };
        body: components["schemas"]["OrderDelivery"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderDelivery"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order_delivery */
          id: string;
        };
        body: {
          data?: components["schemas"]["OrderDelivery"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["OrderDelivery"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order_delivery */
          id: string;
        };
        body: {
          data?: components["schemas"]["OrderDelivery"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderDelivery"];
        };
        responseCode: 200;
      };
  "getOrderLineItemList get /order-line-item":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["OrderLineItem"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["OrderLineItem"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /order-line-item?limit=25 */
            first?: unknown;
            /** @example /order-line-item?limit=25&page=11 */
            last?: unknown;
            /** @example /order-line-item?limit=25&page=4 */
            next?: unknown;
            /** @example /order-line-item?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createOrderLineItem post /order-line-item":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["OrderLineItem"];
        response: {
          data: components["schemas"]["OrderLineItem"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["OrderLineItem"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderLineItem"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["OrderLineItem"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["OrderLineItem"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["OrderLineItem"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderLineItem"];
        };
        responseCode: 200;
      };
  "getOrderLineItemDownloadList get /order-line-item-download":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["OrderLineItemDownload"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["OrderLineItemDownload"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /order-line-item-download?limit=25 */
            first?: unknown;
            /** @example /order-line-item-download?limit=25&page=11 */
            last?: unknown;
            /** @example /order-line-item-download?limit=25&page=4 */
            next?: unknown;
            /** @example /order-line-item-download?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createOrderLineItemDownload post /order-line-item-download":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["OrderLineItemDownload"];
        response: {
          data: components["schemas"]["OrderLineItemDownload"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["OrderLineItemDownload"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderLineItemDownload"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["OrderLineItemDownload"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["OrderLineItemDownload"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["OrderLineItemDownload"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderLineItemDownload"];
        };
        responseCode: 200;
      };
  "getOrderLineItemDownload get /order-line-item-download/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the order_line_item_download */
          id: string;
        };
        response: {
          data: components["schemas"]["OrderLineItemDownload"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the order_line_item_download */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderLineItemDownload"];
        };
        responseCode: 200;
      };
  "deleteOrderLineItemDownload delete /order-line-item-download/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the order_line_item_download */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateOrderLineItemDownload patch /order-line-item-download/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order_line_item_download */
          id: string;
        };
        body: components["schemas"]["OrderLineItemDownload"];
        response: {
          data: components["schemas"]["OrderLineItemDownload"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order_line_item_download */
          id: string;
        };
        body: components["schemas"]["OrderLineItemDownload"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderLineItemDownload"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order_line_item_download */
          id: string;
        };
        body: {
          data?: components["schemas"]["OrderLineItemDownload"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["OrderLineItemDownload"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order_line_item_download */
          id: string;
        };
        body: {
          data?: components["schemas"]["OrderLineItemDownload"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderLineItemDownload"];
        };
        responseCode: 200;
      };
  "getOrderLineItem get /order-line-item/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the order_line_item */
          id: string;
        };
        response: {
          data: components["schemas"]["OrderLineItem"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the order_line_item */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderLineItem"];
        };
        responseCode: 200;
      };
  "deleteOrderLineItem delete /order-line-item/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the order_line_item */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateOrderLineItem patch /order-line-item/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order_line_item */
          id: string;
        };
        body: components["schemas"]["OrderLineItem"];
        response: {
          data: components["schemas"]["OrderLineItem"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order_line_item */
          id: string;
        };
        body: components["schemas"]["OrderLineItem"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderLineItem"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order_line_item */
          id: string;
        };
        body: {
          data?: components["schemas"]["OrderLineItem"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["OrderLineItem"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order_line_item */
          id: string;
        };
        body: {
          data?: components["schemas"]["OrderLineItem"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderLineItem"];
        };
        responseCode: 200;
      };
  "getOrderProductWarehouseList get /order-product-warehouse":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["OrderProductWarehouse"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["OrderProductWarehouse"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /order-product-warehouse?limit=25 */
            first?: unknown;
            /** @example /order-product-warehouse?limit=25&page=11 */
            last?: unknown;
            /** @example /order-product-warehouse?limit=25&page=4 */
            next?: unknown;
            /** @example /order-product-warehouse?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createOrderProductWarehouse post /order-product-warehouse":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["OrderProductWarehouse"];
        response: {
          data: components["schemas"]["OrderProductWarehouse"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["OrderProductWarehouse"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderProductWarehouse"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["OrderProductWarehouse"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["OrderProductWarehouse"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["OrderProductWarehouse"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderProductWarehouse"];
        };
        responseCode: 200;
      };
  "getOrderProductWarehouse get /order-product-warehouse/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the order_product_warehouse */
          id: string;
        };
        response: {
          data: components["schemas"]["OrderProductWarehouse"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the order_product_warehouse */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderProductWarehouse"];
        };
        responseCode: 200;
      };
  "deleteOrderProductWarehouse delete /order-product-warehouse/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the order_product_warehouse */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateOrderProductWarehouse patch /order-product-warehouse/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order_product_warehouse */
          id: string;
        };
        body: components["schemas"]["OrderProductWarehouse"];
        response: {
          data: components["schemas"]["OrderProductWarehouse"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order_product_warehouse */
          id: string;
        };
        body: components["schemas"]["OrderProductWarehouse"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderProductWarehouse"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order_product_warehouse */
          id: string;
        };
        body: {
          data?: components["schemas"]["OrderProductWarehouse"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["OrderProductWarehouse"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order_product_warehouse */
          id: string;
        };
        body: {
          data?: components["schemas"]["OrderProductWarehouse"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderProductWarehouse"];
        };
        responseCode: 200;
      };
  "getOrderReturnList get /order-return":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["OrderReturn"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["OrderReturn"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /order-return?limit=25 */
            first?: unknown;
            /** @example /order-return?limit=25&page=11 */
            last?: unknown;
            /** @example /order-return?limit=25&page=4 */
            next?: unknown;
            /** @example /order-return?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createOrderReturn post /order-return":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["OrderReturn"];
        response: {
          data: components["schemas"]["OrderReturn"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["OrderReturn"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderReturn"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["OrderReturn"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["OrderReturn"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["OrderReturn"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderReturn"];
        };
        responseCode: 200;
      };
  "getOrderReturnLineItemList get /order-return-line-item":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["OrderReturnLineItem"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["OrderReturnLineItem"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /order-return-line-item?limit=25 */
            first?: unknown;
            /** @example /order-return-line-item?limit=25&page=11 */
            last?: unknown;
            /** @example /order-return-line-item?limit=25&page=4 */
            next?: unknown;
            /** @example /order-return-line-item?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createOrderReturnLineItem post /order-return-line-item":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["OrderReturnLineItem"];
        response: {
          data: components["schemas"]["OrderReturnLineItem"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["OrderReturnLineItem"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderReturnLineItem"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["OrderReturnLineItem"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["OrderReturnLineItem"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["OrderReturnLineItem"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderReturnLineItem"];
        };
        responseCode: 200;
      };
  "getOrderReturnLineItemReasonList get /order-return-line-item-reason":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["OrderReturnLineItemReason"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["OrderReturnLineItemReason"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /order-return-line-item-reason?limit=25 */
            first?: unknown;
            /** @example /order-return-line-item-reason?limit=25&page=11 */
            last?: unknown;
            /** @example /order-return-line-item-reason?limit=25&page=4 */
            next?: unknown;
            /** @example /order-return-line-item-reason?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createOrderReturnLineItemReason post /order-return-line-item-reason":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["OrderReturnLineItemReason"];
        response: {
          data: components["schemas"]["OrderReturnLineItemReason"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["OrderReturnLineItemReason"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderReturnLineItemReason"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["OrderReturnLineItemReason"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["OrderReturnLineItemReason"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["OrderReturnLineItemReason"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderReturnLineItemReason"];
        };
        responseCode: 200;
      };
  "getOrderReturnLineItemReason get /order-return-line-item-reason/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the order_return_line_item_reason */
          id: string;
        };
        response: {
          data: components["schemas"]["OrderReturnLineItemReason"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the order_return_line_item_reason */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderReturnLineItemReason"];
        };
        responseCode: 200;
      };
  "deleteOrderReturnLineItemReason delete /order-return-line-item-reason/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the order_return_line_item_reason */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateOrderReturnLineItemReason patch /order-return-line-item-reason/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order_return_line_item_reason */
          id: string;
        };
        body: components["schemas"]["OrderReturnLineItemReason"];
        response: {
          data: components["schemas"]["OrderReturnLineItemReason"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order_return_line_item_reason */
          id: string;
        };
        body: components["schemas"]["OrderReturnLineItemReason"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderReturnLineItemReason"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order_return_line_item_reason */
          id: string;
        };
        body: {
          data?: components["schemas"]["OrderReturnLineItemReason"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["OrderReturnLineItemReason"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order_return_line_item_reason */
          id: string;
        };
        body: {
          data?: components["schemas"]["OrderReturnLineItemReason"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderReturnLineItemReason"];
        };
        responseCode: 200;
      };
  "getOrderReturnLineItem get /order-return-line-item/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the order_return_line_item */
          id: string;
        };
        response: {
          data: components["schemas"]["OrderReturnLineItem"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the order_return_line_item */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderReturnLineItem"];
        };
        responseCode: 200;
      };
  "deleteOrderReturnLineItem delete /order-return-line-item/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the order_return_line_item */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateOrderReturnLineItem patch /order-return-line-item/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order_return_line_item */
          id: string;
        };
        body: components["schemas"]["OrderReturnLineItem"];
        response: {
          data: components["schemas"]["OrderReturnLineItem"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order_return_line_item */
          id: string;
        };
        body: components["schemas"]["OrderReturnLineItem"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderReturnLineItem"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order_return_line_item */
          id: string;
        };
        body: {
          data?: components["schemas"]["OrderReturnLineItem"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["OrderReturnLineItem"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order_return_line_item */
          id: string;
        };
        body: {
          data?: components["schemas"]["OrderReturnLineItem"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderReturnLineItem"];
        };
        responseCode: 200;
      };
  "getOrderReturn get /order-return/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the order_return */
          id: string;
        };
        response: {
          data: components["schemas"]["OrderReturn"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the order_return */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderReturn"];
        };
        responseCode: 200;
      };
  "deleteOrderReturn delete /order-return/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the order_return */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateOrderReturn patch /order-return/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order_return */
          id: string;
        };
        body: components["schemas"]["OrderReturn"];
        response: {
          data: components["schemas"]["OrderReturn"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order_return */
          id: string;
        };
        body: components["schemas"]["OrderReturn"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderReturn"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order_return */
          id: string;
        };
        body: {
          data?: components["schemas"]["OrderReturn"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["OrderReturn"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order_return */
          id: string;
        };
        body: {
          data?: components["schemas"]["OrderReturn"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderReturn"];
        };
        responseCode: 200;
      };
  "getOrderTransactionList get /order-transaction":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["OrderTransaction"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["OrderTransaction"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /order-transaction?limit=25 */
            first?: unknown;
            /** @example /order-transaction?limit=25&page=11 */
            last?: unknown;
            /** @example /order-transaction?limit=25&page=4 */
            next?: unknown;
            /** @example /order-transaction?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createOrderTransaction post /order-transaction":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["OrderTransaction"];
        response: {
          data: components["schemas"]["OrderTransaction"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["OrderTransaction"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderTransaction"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["OrderTransaction"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["OrderTransaction"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["OrderTransaction"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderTransaction"];
        };
        responseCode: 200;
      };
  "getOrderTransactionCaptureList get /order-transaction-capture":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["OrderTransactionCapture"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["OrderTransactionCapture"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /order-transaction-capture?limit=25 */
            first?: unknown;
            /** @example /order-transaction-capture?limit=25&page=11 */
            last?: unknown;
            /** @example /order-transaction-capture?limit=25&page=4 */
            next?: unknown;
            /** @example /order-transaction-capture?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createOrderTransactionCapture post /order-transaction-capture":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["OrderTransactionCapture"];
        response: {
          data: components["schemas"]["OrderTransactionCapture"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["OrderTransactionCapture"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderTransactionCapture"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["OrderTransactionCapture"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["OrderTransactionCapture"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["OrderTransactionCapture"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderTransactionCapture"];
        };
        responseCode: 200;
      };
  "getOrderTransactionCaptureRefundList get /order-transaction-capture-refund":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["OrderTransactionCaptureRefund"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["OrderTransactionCaptureRefund"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /order-transaction-capture-refund?limit=25 */
            first?: unknown;
            /** @example /order-transaction-capture-refund?limit=25&page=11 */
            last?: unknown;
            /** @example /order-transaction-capture-refund?limit=25&page=4 */
            next?: unknown;
            /** @example /order-transaction-capture-refund?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createOrderTransactionCaptureRefund post /order-transaction-capture-refund":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["OrderTransactionCaptureRefund"];
        response: {
          data: components["schemas"]["OrderTransactionCaptureRefund"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["OrderTransactionCaptureRefund"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderTransactionCaptureRefund"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["OrderTransactionCaptureRefund"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["OrderTransactionCaptureRefund"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["OrderTransactionCaptureRefund"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderTransactionCaptureRefund"];
        };
        responseCode: 200;
      };
  "getOrderTransactionCaptureRefundPositionList get /order-transaction-capture-refund-position":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["OrderTransactionCaptureRefundPosition"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["OrderTransactionCaptureRefundPosition"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /order-transaction-capture-refund-position?limit=25 */
            first?: unknown;
            /** @example /order-transaction-capture-refund-position?limit=25&page=11 */
            last?: unknown;
            /** @example /order-transaction-capture-refund-position?limit=25&page=4 */
            next?: unknown;
            /** @example /order-transaction-capture-refund-position?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createOrderTransactionCaptureRefundPosition post /order-transaction-capture-refund-position":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["OrderTransactionCaptureRefundPosition"];
        response: {
          data: components["schemas"]["OrderTransactionCaptureRefundPosition"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["OrderTransactionCaptureRefundPosition"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderTransactionCaptureRefundPosition"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["OrderTransactionCaptureRefundPosition"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["OrderTransactionCaptureRefundPosition"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["OrderTransactionCaptureRefundPosition"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderTransactionCaptureRefundPosition"];
        };
        responseCode: 200;
      };
  "getOrderTransactionCaptureRefundPosition get /order-transaction-capture-refund-position/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the order_transaction_capture_refund_position */
          id: string;
        };
        response: {
          data: components["schemas"]["OrderTransactionCaptureRefundPosition"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the order_transaction_capture_refund_position */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderTransactionCaptureRefundPosition"];
        };
        responseCode: 200;
      };
  "deleteOrderTransactionCaptureRefundPosition delete /order-transaction-capture-refund-position/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the order_transaction_capture_refund_position */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateOrderTransactionCaptureRefundPosition patch /order-transaction-capture-refund-position/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order_transaction_capture_refund_position */
          id: string;
        };
        body: components["schemas"]["OrderTransactionCaptureRefundPosition"];
        response: {
          data: components["schemas"]["OrderTransactionCaptureRefundPosition"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order_transaction_capture_refund_position */
          id: string;
        };
        body: components["schemas"]["OrderTransactionCaptureRefundPosition"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderTransactionCaptureRefundPosition"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order_transaction_capture_refund_position */
          id: string;
        };
        body: {
          data?: components["schemas"]["OrderTransactionCaptureRefundPosition"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["OrderTransactionCaptureRefundPosition"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order_transaction_capture_refund_position */
          id: string;
        };
        body: {
          data?: components["schemas"]["OrderTransactionCaptureRefundPosition"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderTransactionCaptureRefundPosition"];
        };
        responseCode: 200;
      };
  "getOrderTransactionCaptureRefund get /order-transaction-capture-refund/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the order_transaction_capture_refund */
          id: string;
        };
        response: {
          data: components["schemas"]["OrderTransactionCaptureRefund"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the order_transaction_capture_refund */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderTransactionCaptureRefund"];
        };
        responseCode: 200;
      };
  "deleteOrderTransactionCaptureRefund delete /order-transaction-capture-refund/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the order_transaction_capture_refund */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateOrderTransactionCaptureRefund patch /order-transaction-capture-refund/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order_transaction_capture_refund */
          id: string;
        };
        body: components["schemas"]["OrderTransactionCaptureRefund"];
        response: {
          data: components["schemas"]["OrderTransactionCaptureRefund"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order_transaction_capture_refund */
          id: string;
        };
        body: components["schemas"]["OrderTransactionCaptureRefund"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderTransactionCaptureRefund"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order_transaction_capture_refund */
          id: string;
        };
        body: {
          data?: components["schemas"]["OrderTransactionCaptureRefund"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["OrderTransactionCaptureRefund"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order_transaction_capture_refund */
          id: string;
        };
        body: {
          data?: components["schemas"]["OrderTransactionCaptureRefund"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderTransactionCaptureRefund"];
        };
        responseCode: 200;
      };
  "getOrderTransactionCapture get /order-transaction-capture/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the order_transaction_capture */
          id: string;
        };
        response: {
          data: components["schemas"]["OrderTransactionCapture"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the order_transaction_capture */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderTransactionCapture"];
        };
        responseCode: 200;
      };
  "deleteOrderTransactionCapture delete /order-transaction-capture/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the order_transaction_capture */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateOrderTransactionCapture patch /order-transaction-capture/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order_transaction_capture */
          id: string;
        };
        body: components["schemas"]["OrderTransactionCapture"];
        response: {
          data: components["schemas"]["OrderTransactionCapture"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order_transaction_capture */
          id: string;
        };
        body: components["schemas"]["OrderTransactionCapture"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderTransactionCapture"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order_transaction_capture */
          id: string;
        };
        body: {
          data?: components["schemas"]["OrderTransactionCapture"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["OrderTransactionCapture"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order_transaction_capture */
          id: string;
        };
        body: {
          data?: components["schemas"]["OrderTransactionCapture"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderTransactionCapture"];
        };
        responseCode: 200;
      };
  "getOrderTransaction get /order-transaction/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the order_transaction */
          id: string;
        };
        response: {
          data: components["schemas"]["OrderTransaction"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the order_transaction */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderTransaction"];
        };
        responseCode: 200;
      };
  "deleteOrderTransaction delete /order-transaction/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the order_transaction */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateOrderTransaction patch /order-transaction/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order_transaction */
          id: string;
        };
        body: components["schemas"]["OrderTransaction"];
        response: {
          data: components["schemas"]["OrderTransaction"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order_transaction */
          id: string;
        };
        body: components["schemas"]["OrderTransaction"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderTransaction"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order_transaction */
          id: string;
        };
        body: {
          data?: components["schemas"]["OrderTransaction"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["OrderTransaction"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order_transaction */
          id: string;
        };
        body: {
          data?: components["schemas"]["OrderTransaction"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderTransaction"];
        };
        responseCode: 200;
      };
  "getOrderWarehouseGroupList get /order-warehouse-group":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["OrderWarehouseGroup"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["OrderWarehouseGroup"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /order-warehouse-group?limit=25 */
            first?: unknown;
            /** @example /order-warehouse-group?limit=25&page=11 */
            last?: unknown;
            /** @example /order-warehouse-group?limit=25&page=4 */
            next?: unknown;
            /** @example /order-warehouse-group?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createOrderWarehouseGroup post /order-warehouse-group":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["OrderWarehouseGroup"];
        response: {
          data: components["schemas"]["OrderWarehouseGroup"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["OrderWarehouseGroup"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderWarehouseGroup"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["OrderWarehouseGroup"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["OrderWarehouseGroup"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["OrderWarehouseGroup"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderWarehouseGroup"];
        };
        responseCode: 200;
      };
  "getOrderWarehouseGroup get /order-warehouse-group/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the order_warehouse_group */
          id: string;
        };
        response: {
          data: components["schemas"]["OrderWarehouseGroup"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the order_warehouse_group */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderWarehouseGroup"];
        };
        responseCode: 200;
      };
  "deleteOrderWarehouseGroup delete /order-warehouse-group/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the order_warehouse_group */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateOrderWarehouseGroup patch /order-warehouse-group/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order_warehouse_group */
          id: string;
        };
        body: components["schemas"]["OrderWarehouseGroup"];
        response: {
          data: components["schemas"]["OrderWarehouseGroup"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order_warehouse_group */
          id: string;
        };
        body: components["schemas"]["OrderWarehouseGroup"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderWarehouseGroup"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order_warehouse_group */
          id: string;
        };
        body: {
          data?: components["schemas"]["OrderWarehouseGroup"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["OrderWarehouseGroup"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order_warehouse_group */
          id: string;
        };
        body: {
          data?: components["schemas"]["OrderWarehouseGroup"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderWarehouseGroup"];
        };
        responseCode: 200;
      };
  "getOrder get /order/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the order */
          id: string;
        };
        response: {
          data: components["schemas"]["Order"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the order */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Order"];
        };
        responseCode: 200;
      };
  "deleteOrder delete /order/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the order */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateOrder patch /order/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order */
          id: string;
        };
        body: components["schemas"]["Order"];
        response: {
          data: components["schemas"]["Order"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order */
          id: string;
        };
        body: components["schemas"]["Order"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Order"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order */
          id: string;
        };
        body: {
          data?: components["schemas"]["Order"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["Order"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the order */
          id: string;
        };
        body: {
          data?: components["schemas"]["Order"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Order"];
        };
        responseCode: 200;
      };
  "getPaymentMethodList get /payment-method":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["PaymentMethod"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["PaymentMethod"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /payment-method?limit=25 */
            first?: unknown;
            /** @example /payment-method?limit=25&page=11 */
            last?: unknown;
            /** @example /payment-method?limit=25&page=4 */
            next?: unknown;
            /** @example /payment-method?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createPaymentMethod post /payment-method":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["PaymentMethod"];
        response: {
          data: components["schemas"]["PaymentMethod"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["PaymentMethod"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["PaymentMethod"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["PaymentMethod"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["PaymentMethod"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["PaymentMethod"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["PaymentMethod"];
        };
        responseCode: 200;
      };
  "getPaymentMethod get /payment-method/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the payment_method */
          id: string;
        };
        response: {
          data: components["schemas"]["PaymentMethod"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the payment_method */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["PaymentMethod"];
        };
        responseCode: 200;
      };
  "deletePaymentMethod delete /payment-method/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the payment_method */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updatePaymentMethod patch /payment-method/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the payment_method */
          id: string;
        };
        body: components["schemas"]["PaymentMethod"];
        response: {
          data: components["schemas"]["PaymentMethod"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the payment_method */
          id: string;
        };
        body: components["schemas"]["PaymentMethod"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["PaymentMethod"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the payment_method */
          id: string;
        };
        body: {
          data?: components["schemas"]["PaymentMethod"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["PaymentMethod"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the payment_method */
          id: string;
        };
        body: {
          data?: components["schemas"]["PaymentMethod"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["PaymentMethod"];
        };
        responseCode: 200;
      };
  "getPluginList get /plugin":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["Plugin"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["Plugin"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /plugin?limit=25 */
            first?: unknown;
            /** @example /plugin?limit=25&page=11 */
            last?: unknown;
            /** @example /plugin?limit=25&page=4 */
            next?: unknown;
            /** @example /plugin?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createPlugin post /plugin":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["Plugin"];
        response: {
          data: components["schemas"]["Plugin"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["Plugin"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Plugin"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["Plugin"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["Plugin"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["Plugin"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Plugin"];
        };
        responseCode: 200;
      };
  "getPlugin get /plugin/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the plugin */
          id: string;
        };
        response: {
          data: components["schemas"]["Plugin"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the plugin */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Plugin"];
        };
        responseCode: 200;
      };
  "deletePlugin delete /plugin/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the plugin */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updatePlugin patch /plugin/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the plugin */
          id: string;
        };
        body: components["schemas"]["Plugin"];
        response: {
          data: components["schemas"]["Plugin"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the plugin */
          id: string;
        };
        body: components["schemas"]["Plugin"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Plugin"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the plugin */
          id: string;
        };
        body: {
          data?: components["schemas"]["Plugin"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["Plugin"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the plugin */
          id: string;
        };
        body: {
          data?: components["schemas"]["Plugin"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Plugin"];
        };
        responseCode: 200;
      };
  "getProductList get /product":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["Product"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["Product"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /product?limit=25 */
            first?: unknown;
            /** @example /product?limit=25&page=11 */
            last?: unknown;
            /** @example /product?limit=25&page=4 */
            next?: unknown;
            /** @example /product?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createProduct post /product":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["Product"];
        response: {
          data: components["schemas"]["Product"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["Product"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Product"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["Product"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["Product"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["Product"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Product"];
        };
        responseCode: 200;
      };
  "getProductConfiguratorSettingList get /product-configurator-setting":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["ProductConfiguratorSetting"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["ProductConfiguratorSetting"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /product-configurator-setting?limit=25 */
            first?: unknown;
            /** @example /product-configurator-setting?limit=25&page=11 */
            last?: unknown;
            /** @example /product-configurator-setting?limit=25&page=4 */
            next?: unknown;
            /** @example /product-configurator-setting?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createProductConfiguratorSetting post /product-configurator-setting":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["ProductConfiguratorSetting"];
        response: {
          data: components["schemas"]["ProductConfiguratorSetting"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["ProductConfiguratorSetting"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductConfiguratorSetting"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["ProductConfiguratorSetting"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["ProductConfiguratorSetting"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["ProductConfiguratorSetting"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductConfiguratorSetting"];
        };
        responseCode: 200;
      };
  "getProductConfiguratorSetting get /product-configurator-setting/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the product_configurator_setting */
          id: string;
        };
        response: {
          data: components["schemas"]["ProductConfiguratorSetting"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the product_configurator_setting */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductConfiguratorSetting"];
        };
        responseCode: 200;
      };
  "deleteProductConfiguratorSetting delete /product-configurator-setting/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the product_configurator_setting */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateProductConfiguratorSetting patch /product-configurator-setting/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_configurator_setting */
          id: string;
        };
        body: components["schemas"]["ProductConfiguratorSetting"];
        response: {
          data: components["schemas"]["ProductConfiguratorSetting"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_configurator_setting */
          id: string;
        };
        body: components["schemas"]["ProductConfiguratorSetting"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductConfiguratorSetting"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_configurator_setting */
          id: string;
        };
        body: {
          data?: components["schemas"]["ProductConfiguratorSetting"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["ProductConfiguratorSetting"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_configurator_setting */
          id: string;
        };
        body: {
          data?: components["schemas"]["ProductConfiguratorSetting"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductConfiguratorSetting"];
        };
        responseCode: 200;
      };
  "getProductCrossSellingList get /product-cross-selling":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["ProductCrossSelling"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["ProductCrossSelling"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /product-cross-selling?limit=25 */
            first?: unknown;
            /** @example /product-cross-selling?limit=25&page=11 */
            last?: unknown;
            /** @example /product-cross-selling?limit=25&page=4 */
            next?: unknown;
            /** @example /product-cross-selling?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createProductCrossSelling post /product-cross-selling":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["ProductCrossSelling"];
        response: {
          data: components["schemas"]["ProductCrossSelling"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["ProductCrossSelling"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductCrossSelling"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["ProductCrossSelling"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["ProductCrossSelling"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["ProductCrossSelling"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductCrossSelling"];
        };
        responseCode: 200;
      };
  "getProductCrossSellingAssignedProductsList get /product-cross-selling-assigned-products":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["ProductCrossSellingAssignedProducts"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["ProductCrossSellingAssignedProducts"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /product-cross-selling-assigned-products?limit=25 */
            first?: unknown;
            /** @example /product-cross-selling-assigned-products?limit=25&page=11 */
            last?: unknown;
            /** @example /product-cross-selling-assigned-products?limit=25&page=4 */
            next?: unknown;
            /** @example /product-cross-selling-assigned-products?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createProductCrossSellingAssignedProducts post /product-cross-selling-assigned-products":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["ProductCrossSellingAssignedProducts"];
        response: {
          data: components["schemas"]["ProductCrossSellingAssignedProducts"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["ProductCrossSellingAssignedProducts"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductCrossSellingAssignedProducts"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["ProductCrossSellingAssignedProducts"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["ProductCrossSellingAssignedProducts"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["ProductCrossSellingAssignedProducts"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductCrossSellingAssignedProducts"];
        };
        responseCode: 200;
      };
  "getProductCrossSellingAssignedProducts get /product-cross-selling-assigned-products/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the product_cross_selling_assigned_products */
          id: string;
        };
        response: {
          data: components["schemas"]["ProductCrossSellingAssignedProducts"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the product_cross_selling_assigned_products */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductCrossSellingAssignedProducts"];
        };
        responseCode: 200;
      };
  "deleteProductCrossSellingAssignedProducts delete /product-cross-selling-assigned-products/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the product_cross_selling_assigned_products */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateProductCrossSellingAssignedProducts patch /product-cross-selling-assigned-products/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_cross_selling_assigned_products */
          id: string;
        };
        body: components["schemas"]["ProductCrossSellingAssignedProducts"];
        response: {
          data: components["schemas"]["ProductCrossSellingAssignedProducts"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_cross_selling_assigned_products */
          id: string;
        };
        body: components["schemas"]["ProductCrossSellingAssignedProducts"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductCrossSellingAssignedProducts"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_cross_selling_assigned_products */
          id: string;
        };
        body: {
          data?: components["schemas"]["ProductCrossSellingAssignedProducts"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["ProductCrossSellingAssignedProducts"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_cross_selling_assigned_products */
          id: string;
        };
        body: {
          data?: components["schemas"]["ProductCrossSellingAssignedProducts"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductCrossSellingAssignedProducts"];
        };
        responseCode: 200;
      };
  "getProductCrossSelling get /product-cross-selling/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the product_cross_selling */
          id: string;
        };
        response: {
          data: components["schemas"]["ProductCrossSelling"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the product_cross_selling */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductCrossSelling"];
        };
        responseCode: 200;
      };
  "deleteProductCrossSelling delete /product-cross-selling/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the product_cross_selling */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateProductCrossSelling patch /product-cross-selling/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_cross_selling */
          id: string;
        };
        body: components["schemas"]["ProductCrossSelling"];
        response: {
          data: components["schemas"]["ProductCrossSelling"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_cross_selling */
          id: string;
        };
        body: components["schemas"]["ProductCrossSelling"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductCrossSelling"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_cross_selling */
          id: string;
        };
        body: {
          data?: components["schemas"]["ProductCrossSelling"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["ProductCrossSelling"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_cross_selling */
          id: string;
        };
        body: {
          data?: components["schemas"]["ProductCrossSelling"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductCrossSelling"];
        };
        responseCode: 200;
      };
  "getProductDownloadList get /product-download":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["ProductDownload"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["ProductDownload"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /product-download?limit=25 */
            first?: unknown;
            /** @example /product-download?limit=25&page=11 */
            last?: unknown;
            /** @example /product-download?limit=25&page=4 */
            next?: unknown;
            /** @example /product-download?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createProductDownload post /product-download":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["ProductDownload"];
        response: {
          data: components["schemas"]["ProductDownload"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["ProductDownload"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductDownload"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["ProductDownload"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["ProductDownload"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["ProductDownload"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductDownload"];
        };
        responseCode: 200;
      };
  "getProductDownload get /product-download/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the product_download */
          id: string;
        };
        response: {
          data: components["schemas"]["ProductDownload"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the product_download */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductDownload"];
        };
        responseCode: 200;
      };
  "deleteProductDownload delete /product-download/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the product_download */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateProductDownload patch /product-download/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_download */
          id: string;
        };
        body: components["schemas"]["ProductDownload"];
        response: {
          data: components["schemas"]["ProductDownload"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_download */
          id: string;
        };
        body: components["schemas"]["ProductDownload"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductDownload"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_download */
          id: string;
        };
        body: {
          data?: components["schemas"]["ProductDownload"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["ProductDownload"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_download */
          id: string;
        };
        body: {
          data?: components["schemas"]["ProductDownload"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductDownload"];
        };
        responseCode: 200;
      };
  "getProductExportList get /product-export":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["ProductExport"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["ProductExport"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /product-export?limit=25 */
            first?: unknown;
            /** @example /product-export?limit=25&page=11 */
            last?: unknown;
            /** @example /product-export?limit=25&page=4 */
            next?: unknown;
            /** @example /product-export?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createProductExport post /product-export":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["ProductExport"];
        response: {
          data: components["schemas"]["ProductExport"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["ProductExport"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductExport"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["ProductExport"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["ProductExport"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["ProductExport"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductExport"];
        };
        responseCode: 200;
      };
  "getProductExport get /product-export/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the product_export */
          id: string;
        };
        response: {
          data: components["schemas"]["ProductExport"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the product_export */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductExport"];
        };
        responseCode: 200;
      };
  "deleteProductExport delete /product-export/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the product_export */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateProductExport patch /product-export/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_export */
          id: string;
        };
        body: components["schemas"]["ProductExport"];
        response: {
          data: components["schemas"]["ProductExport"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_export */
          id: string;
        };
        body: components["schemas"]["ProductExport"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductExport"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_export */
          id: string;
        };
        body: {
          data?: components["schemas"]["ProductExport"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["ProductExport"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_export */
          id: string;
        };
        body: {
          data?: components["schemas"]["ProductExport"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductExport"];
        };
        responseCode: 200;
      };
  "getProductFeatureSetList get /product-feature-set":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["ProductFeatureSet"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["ProductFeatureSet"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /product-feature-set?limit=25 */
            first?: unknown;
            /** @example /product-feature-set?limit=25&page=11 */
            last?: unknown;
            /** @example /product-feature-set?limit=25&page=4 */
            next?: unknown;
            /** @example /product-feature-set?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createProductFeatureSet post /product-feature-set":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["ProductFeatureSet"];
        response: {
          data: components["schemas"]["ProductFeatureSet"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["ProductFeatureSet"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductFeatureSet"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["ProductFeatureSet"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["ProductFeatureSet"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["ProductFeatureSet"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductFeatureSet"];
        };
        responseCode: 200;
      };
  "getProductFeatureSet get /product-feature-set/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the product_feature_set */
          id: string;
        };
        response: {
          data: components["schemas"]["ProductFeatureSet"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the product_feature_set */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductFeatureSet"];
        };
        responseCode: 200;
      };
  "deleteProductFeatureSet delete /product-feature-set/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the product_feature_set */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateProductFeatureSet patch /product-feature-set/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_feature_set */
          id: string;
        };
        body: components["schemas"]["ProductFeatureSet"];
        response: {
          data: components["schemas"]["ProductFeatureSet"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_feature_set */
          id: string;
        };
        body: components["schemas"]["ProductFeatureSet"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductFeatureSet"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_feature_set */
          id: string;
        };
        body: {
          data?: components["schemas"]["ProductFeatureSet"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["ProductFeatureSet"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_feature_set */
          id: string;
        };
        body: {
          data?: components["schemas"]["ProductFeatureSet"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductFeatureSet"];
        };
        responseCode: 200;
      };
  "getProductKeywordDictionaryList get /product-keyword-dictionary":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["ProductKeywordDictionary"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["ProductKeywordDictionary"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /product-keyword-dictionary?limit=25 */
            first?: unknown;
            /** @example /product-keyword-dictionary?limit=25&page=11 */
            last?: unknown;
            /** @example /product-keyword-dictionary?limit=25&page=4 */
            next?: unknown;
            /** @example /product-keyword-dictionary?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createProductKeywordDictionary post /product-keyword-dictionary":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["ProductKeywordDictionary"];
        response: {
          data: components["schemas"]["ProductKeywordDictionary"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["ProductKeywordDictionary"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductKeywordDictionary"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["ProductKeywordDictionary"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["ProductKeywordDictionary"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["ProductKeywordDictionary"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductKeywordDictionary"];
        };
        responseCode: 200;
      };
  "getProductKeywordDictionary get /product-keyword-dictionary/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the product_keyword_dictionary */
          id: string;
        };
        response: {
          data: components["schemas"]["ProductKeywordDictionary"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the product_keyword_dictionary */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductKeywordDictionary"];
        };
        responseCode: 200;
      };
  "deleteProductKeywordDictionary delete /product-keyword-dictionary/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the product_keyword_dictionary */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateProductKeywordDictionary patch /product-keyword-dictionary/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_keyword_dictionary */
          id: string;
        };
        body: components["schemas"]["ProductKeywordDictionary"];
        response: {
          data: components["schemas"]["ProductKeywordDictionary"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_keyword_dictionary */
          id: string;
        };
        body: components["schemas"]["ProductKeywordDictionary"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductKeywordDictionary"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_keyword_dictionary */
          id: string;
        };
        body: {
          data?: components["schemas"]["ProductKeywordDictionary"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["ProductKeywordDictionary"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_keyword_dictionary */
          id: string;
        };
        body: {
          data?: components["schemas"]["ProductKeywordDictionary"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductKeywordDictionary"];
        };
        responseCode: 200;
      };
  "getProductManufacturerList get /product-manufacturer":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["ProductManufacturer"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["ProductManufacturer"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /product-manufacturer?limit=25 */
            first?: unknown;
            /** @example /product-manufacturer?limit=25&page=11 */
            last?: unknown;
            /** @example /product-manufacturer?limit=25&page=4 */
            next?: unknown;
            /** @example /product-manufacturer?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createProductManufacturer post /product-manufacturer":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["ProductManufacturer"];
        response: {
          data: components["schemas"]["ProductManufacturer"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["ProductManufacturer"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductManufacturer"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["ProductManufacturer"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["ProductManufacturer"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["ProductManufacturer"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductManufacturer"];
        };
        responseCode: 200;
      };
  "getProductManufacturer get /product-manufacturer/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the product_manufacturer */
          id: string;
        };
        response: {
          data: components["schemas"]["ProductManufacturer"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the product_manufacturer */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductManufacturer"];
        };
        responseCode: 200;
      };
  "deleteProductManufacturer delete /product-manufacturer/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the product_manufacturer */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateProductManufacturer patch /product-manufacturer/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_manufacturer */
          id: string;
        };
        body: components["schemas"]["ProductManufacturer"];
        response: {
          data: components["schemas"]["ProductManufacturer"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_manufacturer */
          id: string;
        };
        body: components["schemas"]["ProductManufacturer"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductManufacturer"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_manufacturer */
          id: string;
        };
        body: {
          data?: components["schemas"]["ProductManufacturer"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["ProductManufacturer"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_manufacturer */
          id: string;
        };
        body: {
          data?: components["schemas"]["ProductManufacturer"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductManufacturer"];
        };
        responseCode: 200;
      };
  "getProductMediaList get /product-media":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["ProductMedia"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["ProductMedia"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /product-media?limit=25 */
            first?: unknown;
            /** @example /product-media?limit=25&page=11 */
            last?: unknown;
            /** @example /product-media?limit=25&page=4 */
            next?: unknown;
            /** @example /product-media?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createProductMedia post /product-media":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["ProductMedia"];
        response: {
          data: components["schemas"]["ProductMedia"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["ProductMedia"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductMedia"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["ProductMedia"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["ProductMedia"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["ProductMedia"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductMedia"];
        };
        responseCode: 200;
      };
  "getProductMedia get /product-media/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the product_media */
          id: string;
        };
        response: {
          data: components["schemas"]["ProductMedia"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the product_media */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductMedia"];
        };
        responseCode: 200;
      };
  "deleteProductMedia delete /product-media/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the product_media */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateProductMedia patch /product-media/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_media */
          id: string;
        };
        body: components["schemas"]["ProductMedia"];
        response: {
          data: components["schemas"]["ProductMedia"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_media */
          id: string;
        };
        body: components["schemas"]["ProductMedia"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductMedia"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_media */
          id: string;
        };
        body: {
          data?: components["schemas"]["ProductMedia"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["ProductMedia"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_media */
          id: string;
        };
        body: {
          data?: components["schemas"]["ProductMedia"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductMedia"];
        };
        responseCode: 200;
      };
  "getProductPriceList get /product-price":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["ProductPrice"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["ProductPrice"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /product-price?limit=25 */
            first?: unknown;
            /** @example /product-price?limit=25&page=11 */
            last?: unknown;
            /** @example /product-price?limit=25&page=4 */
            next?: unknown;
            /** @example /product-price?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createProductPrice post /product-price":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["ProductPrice"];
        response: {
          data: components["schemas"]["ProductPrice"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["ProductPrice"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductPrice"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["ProductPrice"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["ProductPrice"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["ProductPrice"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductPrice"];
        };
        responseCode: 200;
      };
  "getProductPrice get /product-price/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the product_price */
          id: string;
        };
        response: {
          data: components["schemas"]["ProductPrice"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the product_price */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductPrice"];
        };
        responseCode: 200;
      };
  "deleteProductPrice delete /product-price/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the product_price */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateProductPrice patch /product-price/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_price */
          id: string;
        };
        body: components["schemas"]["ProductPrice"];
        response: {
          data: components["schemas"]["ProductPrice"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_price */
          id: string;
        };
        body: components["schemas"]["ProductPrice"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductPrice"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_price */
          id: string;
        };
        body: {
          data?: components["schemas"]["ProductPrice"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["ProductPrice"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_price */
          id: string;
        };
        body: {
          data?: components["schemas"]["ProductPrice"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductPrice"];
        };
        responseCode: 200;
      };
  "getProductReviewList get /product-review":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["ProductReview"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["ProductReview"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /product-review?limit=25 */
            first?: unknown;
            /** @example /product-review?limit=25&page=11 */
            last?: unknown;
            /** @example /product-review?limit=25&page=4 */
            next?: unknown;
            /** @example /product-review?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createProductReview post /product-review":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["ProductReview"];
        response: {
          data: components["schemas"]["ProductReview"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["ProductReview"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductReview"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["ProductReview"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["ProductReview"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["ProductReview"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductReview"];
        };
        responseCode: 200;
      };
  "getProductReviewSummaryList get /product-review-summary":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["ProductReviewSummary"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["ProductReviewSummary"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /product-review-summary?limit=25 */
            first?: unknown;
            /** @example /product-review-summary?limit=25&page=11 */
            last?: unknown;
            /** @example /product-review-summary?limit=25&page=4 */
            next?: unknown;
            /** @example /product-review-summary?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createProductReviewSummary post /product-review-summary":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["ProductReviewSummary"];
        response: {
          data: components["schemas"]["ProductReviewSummary"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["ProductReviewSummary"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductReviewSummary"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["ProductReviewSummary"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["ProductReviewSummary"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["ProductReviewSummary"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductReviewSummary"];
        };
        responseCode: 200;
      };
  "getProductReviewSummary get /product-review-summary/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the product_review_summary */
          id: string;
        };
        response: {
          data: components["schemas"]["ProductReviewSummary"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the product_review_summary */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductReviewSummary"];
        };
        responseCode: 200;
      };
  "deleteProductReviewSummary delete /product-review-summary/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the product_review_summary */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateProductReviewSummary patch /product-review-summary/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_review_summary */
          id: string;
        };
        body: components["schemas"]["ProductReviewSummary"];
        response: {
          data: components["schemas"]["ProductReviewSummary"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_review_summary */
          id: string;
        };
        body: components["schemas"]["ProductReviewSummary"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductReviewSummary"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_review_summary */
          id: string;
        };
        body: {
          data?: components["schemas"]["ProductReviewSummary"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["ProductReviewSummary"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_review_summary */
          id: string;
        };
        body: {
          data?: components["schemas"]["ProductReviewSummary"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductReviewSummary"];
        };
        responseCode: 200;
      };
  "getProductReview get /product-review/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the product_review */
          id: string;
        };
        response: {
          data: components["schemas"]["ProductReview"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the product_review */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductReview"];
        };
        responseCode: 200;
      };
  "deleteProductReview delete /product-review/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the product_review */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateProductReview patch /product-review/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_review */
          id: string;
        };
        body: components["schemas"]["ProductReview"];
        response: {
          data: components["schemas"]["ProductReview"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_review */
          id: string;
        };
        body: components["schemas"]["ProductReview"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductReview"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_review */
          id: string;
        };
        body: {
          data?: components["schemas"]["ProductReview"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["ProductReview"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_review */
          id: string;
        };
        body: {
          data?: components["schemas"]["ProductReview"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductReview"];
        };
        responseCode: 200;
      };
  "getProductSearchConfigList get /product-search-config":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["ProductSearchConfig"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["ProductSearchConfig"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /product-search-config?limit=25 */
            first?: unknown;
            /** @example /product-search-config?limit=25&page=11 */
            last?: unknown;
            /** @example /product-search-config?limit=25&page=4 */
            next?: unknown;
            /** @example /product-search-config?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createProductSearchConfig post /product-search-config":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["ProductSearchConfig"];
        response: {
          data: components["schemas"]["ProductSearchConfig"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["ProductSearchConfig"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductSearchConfig"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["ProductSearchConfig"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["ProductSearchConfig"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["ProductSearchConfig"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductSearchConfig"];
        };
        responseCode: 200;
      };
  "getProductSearchConfigFieldList get /product-search-config-field":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["ProductSearchConfigField"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["ProductSearchConfigField"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /product-search-config-field?limit=25 */
            first?: unknown;
            /** @example /product-search-config-field?limit=25&page=11 */
            last?: unknown;
            /** @example /product-search-config-field?limit=25&page=4 */
            next?: unknown;
            /** @example /product-search-config-field?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createProductSearchConfigField post /product-search-config-field":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["ProductSearchConfigField"];
        response: {
          data: components["schemas"]["ProductSearchConfigField"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["ProductSearchConfigField"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductSearchConfigField"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["ProductSearchConfigField"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["ProductSearchConfigField"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["ProductSearchConfigField"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductSearchConfigField"];
        };
        responseCode: 200;
      };
  "getProductSearchConfigField get /product-search-config-field/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the product_search_config_field */
          id: string;
        };
        response: {
          data: components["schemas"]["ProductSearchConfigField"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the product_search_config_field */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductSearchConfigField"];
        };
        responseCode: 200;
      };
  "deleteProductSearchConfigField delete /product-search-config-field/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the product_search_config_field */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateProductSearchConfigField patch /product-search-config-field/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_search_config_field */
          id: string;
        };
        body: components["schemas"]["ProductSearchConfigField"];
        response: {
          data: components["schemas"]["ProductSearchConfigField"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_search_config_field */
          id: string;
        };
        body: components["schemas"]["ProductSearchConfigField"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductSearchConfigField"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_search_config_field */
          id: string;
        };
        body: {
          data?: components["schemas"]["ProductSearchConfigField"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["ProductSearchConfigField"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_search_config_field */
          id: string;
        };
        body: {
          data?: components["schemas"]["ProductSearchConfigField"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductSearchConfigField"];
        };
        responseCode: 200;
      };
  "getProductSearchConfig get /product-search-config/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the product_search_config */
          id: string;
        };
        response: {
          data: components["schemas"]["ProductSearchConfig"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the product_search_config */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductSearchConfig"];
        };
        responseCode: 200;
      };
  "deleteProductSearchConfig delete /product-search-config/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the product_search_config */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateProductSearchConfig patch /product-search-config/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_search_config */
          id: string;
        };
        body: components["schemas"]["ProductSearchConfig"];
        response: {
          data: components["schemas"]["ProductSearchConfig"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_search_config */
          id: string;
        };
        body: components["schemas"]["ProductSearchConfig"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductSearchConfig"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_search_config */
          id: string;
        };
        body: {
          data?: components["schemas"]["ProductSearchConfig"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["ProductSearchConfig"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_search_config */
          id: string;
        };
        body: {
          data?: components["schemas"]["ProductSearchConfig"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductSearchConfig"];
        };
        responseCode: 200;
      };
  "getProductSearchKeywordList get /product-search-keyword":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["ProductSearchKeyword"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["ProductSearchKeyword"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /product-search-keyword?limit=25 */
            first?: unknown;
            /** @example /product-search-keyword?limit=25&page=11 */
            last?: unknown;
            /** @example /product-search-keyword?limit=25&page=4 */
            next?: unknown;
            /** @example /product-search-keyword?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createProductSearchKeyword post /product-search-keyword":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["ProductSearchKeyword"];
        response: {
          data: components["schemas"]["ProductSearchKeyword"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["ProductSearchKeyword"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductSearchKeyword"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["ProductSearchKeyword"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["ProductSearchKeyword"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["ProductSearchKeyword"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductSearchKeyword"];
        };
        responseCode: 200;
      };
  "getProductSearchKeyword get /product-search-keyword/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the product_search_keyword */
          id: string;
        };
        response: {
          data: components["schemas"]["ProductSearchKeyword"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the product_search_keyword */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductSearchKeyword"];
        };
        responseCode: 200;
      };
  "deleteProductSearchKeyword delete /product-search-keyword/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the product_search_keyword */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateProductSearchKeyword patch /product-search-keyword/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_search_keyword */
          id: string;
        };
        body: components["schemas"]["ProductSearchKeyword"];
        response: {
          data: components["schemas"]["ProductSearchKeyword"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_search_keyword */
          id: string;
        };
        body: components["schemas"]["ProductSearchKeyword"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductSearchKeyword"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_search_keyword */
          id: string;
        };
        body: {
          data?: components["schemas"]["ProductSearchKeyword"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["ProductSearchKeyword"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_search_keyword */
          id: string;
        };
        body: {
          data?: components["schemas"]["ProductSearchKeyword"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductSearchKeyword"];
        };
        responseCode: 200;
      };
  "getProductSortingList get /product-sorting":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["ProductSorting"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["ProductSorting"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /product-sorting?limit=25 */
            first?: unknown;
            /** @example /product-sorting?limit=25&page=11 */
            last?: unknown;
            /** @example /product-sorting?limit=25&page=4 */
            next?: unknown;
            /** @example /product-sorting?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createProductSorting post /product-sorting":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["ProductSorting"];
        response: {
          data: components["schemas"]["ProductSorting"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["ProductSorting"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductSorting"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["ProductSorting"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["ProductSorting"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["ProductSorting"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductSorting"];
        };
        responseCode: 200;
      };
  "getProductSorting get /product-sorting/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the product_sorting */
          id: string;
        };
        response: {
          data: components["schemas"]["ProductSorting"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the product_sorting */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductSorting"];
        };
        responseCode: 200;
      };
  "deleteProductSorting delete /product-sorting/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the product_sorting */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateProductSorting patch /product-sorting/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_sorting */
          id: string;
        };
        body: components["schemas"]["ProductSorting"];
        response: {
          data: components["schemas"]["ProductSorting"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_sorting */
          id: string;
        };
        body: components["schemas"]["ProductSorting"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductSorting"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_sorting */
          id: string;
        };
        body: {
          data?: components["schemas"]["ProductSorting"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["ProductSorting"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_sorting */
          id: string;
        };
        body: {
          data?: components["schemas"]["ProductSorting"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductSorting"];
        };
        responseCode: 200;
      };
  "getProductStreamList get /product-stream":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["ProductStream"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["ProductStream"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /product-stream?limit=25 */
            first?: unknown;
            /** @example /product-stream?limit=25&page=11 */
            last?: unknown;
            /** @example /product-stream?limit=25&page=4 */
            next?: unknown;
            /** @example /product-stream?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createProductStream post /product-stream":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["ProductStream"];
        response: {
          data: components["schemas"]["ProductStream"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["ProductStream"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductStream"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["ProductStream"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["ProductStream"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["ProductStream"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductStream"];
        };
        responseCode: 200;
      };
  "getProductStreamFilterList get /product-stream-filter":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["ProductStreamFilter"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["ProductStreamFilter"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /product-stream-filter?limit=25 */
            first?: unknown;
            /** @example /product-stream-filter?limit=25&page=11 */
            last?: unknown;
            /** @example /product-stream-filter?limit=25&page=4 */
            next?: unknown;
            /** @example /product-stream-filter?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createProductStreamFilter post /product-stream-filter":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["ProductStreamFilter"];
        response: {
          data: components["schemas"]["ProductStreamFilter"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["ProductStreamFilter"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductStreamFilter"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["ProductStreamFilter"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["ProductStreamFilter"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["ProductStreamFilter"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductStreamFilter"];
        };
        responseCode: 200;
      };
  "getProductStreamFilter get /product-stream-filter/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the product_stream_filter */
          id: string;
        };
        response: {
          data: components["schemas"]["ProductStreamFilter"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the product_stream_filter */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductStreamFilter"];
        };
        responseCode: 200;
      };
  "deleteProductStreamFilter delete /product-stream-filter/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the product_stream_filter */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateProductStreamFilter patch /product-stream-filter/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_stream_filter */
          id: string;
        };
        body: components["schemas"]["ProductStreamFilter"];
        response: {
          data: components["schemas"]["ProductStreamFilter"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_stream_filter */
          id: string;
        };
        body: components["schemas"]["ProductStreamFilter"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductStreamFilter"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_stream_filter */
          id: string;
        };
        body: {
          data?: components["schemas"]["ProductStreamFilter"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["ProductStreamFilter"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_stream_filter */
          id: string;
        };
        body: {
          data?: components["schemas"]["ProductStreamFilter"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductStreamFilter"];
        };
        responseCode: 200;
      };
  "getProductStream get /product-stream/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the product_stream */
          id: string;
        };
        response: {
          data: components["schemas"]["ProductStream"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the product_stream */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductStream"];
        };
        responseCode: 200;
      };
  "deleteProductStream delete /product-stream/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the product_stream */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateProductStream patch /product-stream/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_stream */
          id: string;
        };
        body: components["schemas"]["ProductStream"];
        response: {
          data: components["schemas"]["ProductStream"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_stream */
          id: string;
        };
        body: components["schemas"]["ProductStream"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductStream"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_stream */
          id: string;
        };
        body: {
          data?: components["schemas"]["ProductStream"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["ProductStream"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_stream */
          id: string;
        };
        body: {
          data?: components["schemas"]["ProductStream"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductStream"];
        };
        responseCode: 200;
      };
  "getProductVisibilityList get /product-visibility":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["ProductVisibility"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["ProductVisibility"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /product-visibility?limit=25 */
            first?: unknown;
            /** @example /product-visibility?limit=25&page=11 */
            last?: unknown;
            /** @example /product-visibility?limit=25&page=4 */
            next?: unknown;
            /** @example /product-visibility?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createProductVisibility post /product-visibility":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["ProductVisibility"];
        response: {
          data: components["schemas"]["ProductVisibility"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["ProductVisibility"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductVisibility"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["ProductVisibility"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["ProductVisibility"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["ProductVisibility"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductVisibility"];
        };
        responseCode: 200;
      };
  "getProductVisibility get /product-visibility/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the product_visibility */
          id: string;
        };
        response: {
          data: components["schemas"]["ProductVisibility"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the product_visibility */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductVisibility"];
        };
        responseCode: 200;
      };
  "deleteProductVisibility delete /product-visibility/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the product_visibility */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateProductVisibility patch /product-visibility/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_visibility */
          id: string;
        };
        body: components["schemas"]["ProductVisibility"];
        response: {
          data: components["schemas"]["ProductVisibility"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_visibility */
          id: string;
        };
        body: components["schemas"]["ProductVisibility"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductVisibility"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_visibility */
          id: string;
        };
        body: {
          data?: components["schemas"]["ProductVisibility"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["ProductVisibility"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_visibility */
          id: string;
        };
        body: {
          data?: components["schemas"]["ProductVisibility"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductVisibility"];
        };
        responseCode: 200;
      };
  "getProductWarehouseList get /product-warehouse":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["ProductWarehouse"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["ProductWarehouse"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /product-warehouse?limit=25 */
            first?: unknown;
            /** @example /product-warehouse?limit=25&page=11 */
            last?: unknown;
            /** @example /product-warehouse?limit=25&page=4 */
            next?: unknown;
            /** @example /product-warehouse?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createProductWarehouse post /product-warehouse":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["ProductWarehouse"];
        response: {
          data: components["schemas"]["ProductWarehouse"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["ProductWarehouse"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductWarehouse"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["ProductWarehouse"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["ProductWarehouse"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["ProductWarehouse"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductWarehouse"];
        };
        responseCode: 200;
      };
  "getProductWarehouse get /product-warehouse/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the product_warehouse */
          id: string;
        };
        response: {
          data: components["schemas"]["ProductWarehouse"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the product_warehouse */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductWarehouse"];
        };
        responseCode: 200;
      };
  "deleteProductWarehouse delete /product-warehouse/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the product_warehouse */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateProductWarehouse patch /product-warehouse/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_warehouse */
          id: string;
        };
        body: components["schemas"]["ProductWarehouse"];
        response: {
          data: components["schemas"]["ProductWarehouse"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_warehouse */
          id: string;
        };
        body: components["schemas"]["ProductWarehouse"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductWarehouse"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_warehouse */
          id: string;
        };
        body: {
          data?: components["schemas"]["ProductWarehouse"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["ProductWarehouse"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product_warehouse */
          id: string;
        };
        body: {
          data?: components["schemas"]["ProductWarehouse"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductWarehouse"];
        };
        responseCode: 200;
      };
  "getProduct get /product/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the product */
          id: string;
        };
        response: {
          data: components["schemas"]["Product"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the product */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Product"];
        };
        responseCode: 200;
      };
  "deleteProduct delete /product/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the product */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateProduct patch /product/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product */
          id: string;
        };
        body: components["schemas"]["Product"];
        response: {
          data: components["schemas"]["Product"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product */
          id: string;
        };
        body: components["schemas"]["Product"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Product"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product */
          id: string;
        };
        body: {
          data?: components["schemas"]["Product"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["Product"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the product */
          id: string;
        };
        body: {
          data?: components["schemas"]["Product"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Product"];
        };
        responseCode: 200;
      };
  "getPromotionList get /promotion":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["Promotion"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["Promotion"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /promotion?limit=25 */
            first?: unknown;
            /** @example /promotion?limit=25&page=11 */
            last?: unknown;
            /** @example /promotion?limit=25&page=4 */
            next?: unknown;
            /** @example /promotion?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createPromotion post /promotion":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["Promotion"];
        response: {
          data: components["schemas"]["Promotion"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["Promotion"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Promotion"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["Promotion"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["Promotion"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["Promotion"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Promotion"];
        };
        responseCode: 200;
      };
  "getPromotionDiscountList get /promotion-discount":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["PromotionDiscount"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["PromotionDiscount"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /promotion-discount?limit=25 */
            first?: unknown;
            /** @example /promotion-discount?limit=25&page=11 */
            last?: unknown;
            /** @example /promotion-discount?limit=25&page=4 */
            next?: unknown;
            /** @example /promotion-discount?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createPromotionDiscount post /promotion-discount":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["PromotionDiscount"];
        response: {
          data: components["schemas"]["PromotionDiscount"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["PromotionDiscount"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["PromotionDiscount"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["PromotionDiscount"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["PromotionDiscount"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["PromotionDiscount"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["PromotionDiscount"];
        };
        responseCode: 200;
      };
  "getPromotionDiscountPricesList get /promotion-discount-prices":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["PromotionDiscountPrices"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["PromotionDiscountPrices"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /promotion-discount-prices?limit=25 */
            first?: unknown;
            /** @example /promotion-discount-prices?limit=25&page=11 */
            last?: unknown;
            /** @example /promotion-discount-prices?limit=25&page=4 */
            next?: unknown;
            /** @example /promotion-discount-prices?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createPromotionDiscountPrices post /promotion-discount-prices":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["PromotionDiscountPrices"];
        response: {
          data: components["schemas"]["PromotionDiscountPrices"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["PromotionDiscountPrices"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["PromotionDiscountPrices"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["PromotionDiscountPrices"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["PromotionDiscountPrices"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["PromotionDiscountPrices"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["PromotionDiscountPrices"];
        };
        responseCode: 200;
      };
  "getPromotionDiscountPrices get /promotion-discount-prices/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the promotion_discount_prices */
          id: string;
        };
        response: {
          data: components["schemas"]["PromotionDiscountPrices"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the promotion_discount_prices */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["PromotionDiscountPrices"];
        };
        responseCode: 200;
      };
  "deletePromotionDiscountPrices delete /promotion-discount-prices/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the promotion_discount_prices */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updatePromotionDiscountPrices patch /promotion-discount-prices/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the promotion_discount_prices */
          id: string;
        };
        body: components["schemas"]["PromotionDiscountPrices"];
        response: {
          data: components["schemas"]["PromotionDiscountPrices"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the promotion_discount_prices */
          id: string;
        };
        body: components["schemas"]["PromotionDiscountPrices"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["PromotionDiscountPrices"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the promotion_discount_prices */
          id: string;
        };
        body: {
          data?: components["schemas"]["PromotionDiscountPrices"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["PromotionDiscountPrices"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the promotion_discount_prices */
          id: string;
        };
        body: {
          data?: components["schemas"]["PromotionDiscountPrices"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["PromotionDiscountPrices"];
        };
        responseCode: 200;
      };
  "getPromotionDiscount get /promotion-discount/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the promotion_discount */
          id: string;
        };
        response: {
          data: components["schemas"]["PromotionDiscount"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the promotion_discount */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["PromotionDiscount"];
        };
        responseCode: 200;
      };
  "deletePromotionDiscount delete /promotion-discount/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the promotion_discount */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updatePromotionDiscount patch /promotion-discount/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the promotion_discount */
          id: string;
        };
        body: components["schemas"]["PromotionDiscount"];
        response: {
          data: components["schemas"]["PromotionDiscount"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the promotion_discount */
          id: string;
        };
        body: components["schemas"]["PromotionDiscount"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["PromotionDiscount"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the promotion_discount */
          id: string;
        };
        body: {
          data?: components["schemas"]["PromotionDiscount"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["PromotionDiscount"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the promotion_discount */
          id: string;
        };
        body: {
          data?: components["schemas"]["PromotionDiscount"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["PromotionDiscount"];
        };
        responseCode: 200;
      };
  "getPromotionIndividualCodeList get /promotion-individual-code":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["PromotionIndividualCode"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["PromotionIndividualCode"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /promotion-individual-code?limit=25 */
            first?: unknown;
            /** @example /promotion-individual-code?limit=25&page=11 */
            last?: unknown;
            /** @example /promotion-individual-code?limit=25&page=4 */
            next?: unknown;
            /** @example /promotion-individual-code?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createPromotionIndividualCode post /promotion-individual-code":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["PromotionIndividualCode"];
        response: {
          data: components["schemas"]["PromotionIndividualCode"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["PromotionIndividualCode"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["PromotionIndividualCode"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["PromotionIndividualCode"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["PromotionIndividualCode"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["PromotionIndividualCode"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["PromotionIndividualCode"];
        };
        responseCode: 200;
      };
  "getPromotionIndividualCode get /promotion-individual-code/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the promotion_individual_code */
          id: string;
        };
        response: {
          data: components["schemas"]["PromotionIndividualCode"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the promotion_individual_code */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["PromotionIndividualCode"];
        };
        responseCode: 200;
      };
  "deletePromotionIndividualCode delete /promotion-individual-code/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the promotion_individual_code */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updatePromotionIndividualCode patch /promotion-individual-code/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the promotion_individual_code */
          id: string;
        };
        body: components["schemas"]["PromotionIndividualCode"];
        response: {
          data: components["schemas"]["PromotionIndividualCode"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the promotion_individual_code */
          id: string;
        };
        body: components["schemas"]["PromotionIndividualCode"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["PromotionIndividualCode"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the promotion_individual_code */
          id: string;
        };
        body: {
          data?: components["schemas"]["PromotionIndividualCode"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["PromotionIndividualCode"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the promotion_individual_code */
          id: string;
        };
        body: {
          data?: components["schemas"]["PromotionIndividualCode"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["PromotionIndividualCode"];
        };
        responseCode: 200;
      };
  "getPromotionSalesChannelList get /promotion-sales-channel":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["PromotionSalesChannel"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["PromotionSalesChannel"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /promotion-sales-channel?limit=25 */
            first?: unknown;
            /** @example /promotion-sales-channel?limit=25&page=11 */
            last?: unknown;
            /** @example /promotion-sales-channel?limit=25&page=4 */
            next?: unknown;
            /** @example /promotion-sales-channel?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createPromotionSalesChannel post /promotion-sales-channel":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["PromotionSalesChannel"];
        response: {
          data: components["schemas"]["PromotionSalesChannel"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["PromotionSalesChannel"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["PromotionSalesChannel"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["PromotionSalesChannel"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["PromotionSalesChannel"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["PromotionSalesChannel"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["PromotionSalesChannel"];
        };
        responseCode: 200;
      };
  "getPromotionSalesChannel get /promotion-sales-channel/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the promotion_sales_channel */
          id: string;
        };
        response: {
          data: components["schemas"]["PromotionSalesChannel"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the promotion_sales_channel */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["PromotionSalesChannel"];
        };
        responseCode: 200;
      };
  "deletePromotionSalesChannel delete /promotion-sales-channel/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the promotion_sales_channel */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updatePromotionSalesChannel patch /promotion-sales-channel/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the promotion_sales_channel */
          id: string;
        };
        body: components["schemas"]["PromotionSalesChannel"];
        response: {
          data: components["schemas"]["PromotionSalesChannel"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the promotion_sales_channel */
          id: string;
        };
        body: components["schemas"]["PromotionSalesChannel"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["PromotionSalesChannel"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the promotion_sales_channel */
          id: string;
        };
        body: {
          data?: components["schemas"]["PromotionSalesChannel"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["PromotionSalesChannel"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the promotion_sales_channel */
          id: string;
        };
        body: {
          data?: components["schemas"]["PromotionSalesChannel"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["PromotionSalesChannel"];
        };
        responseCode: 200;
      };
  "getPromotionSetgroupList get /promotion-setgroup":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["PromotionSetgroup"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["PromotionSetgroup"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /promotion-setgroup?limit=25 */
            first?: unknown;
            /** @example /promotion-setgroup?limit=25&page=11 */
            last?: unknown;
            /** @example /promotion-setgroup?limit=25&page=4 */
            next?: unknown;
            /** @example /promotion-setgroup?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createPromotionSetgroup post /promotion-setgroup":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["PromotionSetgroup"];
        response: {
          data: components["schemas"]["PromotionSetgroup"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["PromotionSetgroup"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["PromotionSetgroup"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["PromotionSetgroup"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["PromotionSetgroup"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["PromotionSetgroup"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["PromotionSetgroup"];
        };
        responseCode: 200;
      };
  "getPromotionSetgroup get /promotion-setgroup/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the promotion_setgroup */
          id: string;
        };
        response: {
          data: components["schemas"]["PromotionSetgroup"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the promotion_setgroup */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["PromotionSetgroup"];
        };
        responseCode: 200;
      };
  "deletePromotionSetgroup delete /promotion-setgroup/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the promotion_setgroup */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updatePromotionSetgroup patch /promotion-setgroup/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the promotion_setgroup */
          id: string;
        };
        body: components["schemas"]["PromotionSetgroup"];
        response: {
          data: components["schemas"]["PromotionSetgroup"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the promotion_setgroup */
          id: string;
        };
        body: components["schemas"]["PromotionSetgroup"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["PromotionSetgroup"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the promotion_setgroup */
          id: string;
        };
        body: {
          data?: components["schemas"]["PromotionSetgroup"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["PromotionSetgroup"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the promotion_setgroup */
          id: string;
        };
        body: {
          data?: components["schemas"]["PromotionSetgroup"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["PromotionSetgroup"];
        };
        responseCode: 200;
      };
  "getPromotion get /promotion/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the promotion */
          id: string;
        };
        response: {
          data: components["schemas"]["Promotion"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the promotion */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Promotion"];
        };
        responseCode: 200;
      };
  "deletePromotion delete /promotion/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the promotion */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updatePromotion patch /promotion/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the promotion */
          id: string;
        };
        body: components["schemas"]["Promotion"];
        response: {
          data: components["schemas"]["Promotion"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the promotion */
          id: string;
        };
        body: components["schemas"]["Promotion"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Promotion"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the promotion */
          id: string;
        };
        body: {
          data?: components["schemas"]["Promotion"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["Promotion"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the promotion */
          id: string;
        };
        body: {
          data?: components["schemas"]["Promotion"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Promotion"];
        };
        responseCode: 200;
      };
  "getPropertyGroupList get /property-group":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["PropertyGroup"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["PropertyGroup"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /property-group?limit=25 */
            first?: unknown;
            /** @example /property-group?limit=25&page=11 */
            last?: unknown;
            /** @example /property-group?limit=25&page=4 */
            next?: unknown;
            /** @example /property-group?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createPropertyGroup post /property-group":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["PropertyGroup"];
        response: {
          data: components["schemas"]["PropertyGroup"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["PropertyGroup"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["PropertyGroup"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["PropertyGroup"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["PropertyGroup"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["PropertyGroup"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["PropertyGroup"];
        };
        responseCode: 200;
      };
  "getPropertyGroupOptionList get /property-group-option":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["PropertyGroupOption"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["PropertyGroupOption"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /property-group-option?limit=25 */
            first?: unknown;
            /** @example /property-group-option?limit=25&page=11 */
            last?: unknown;
            /** @example /property-group-option?limit=25&page=4 */
            next?: unknown;
            /** @example /property-group-option?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createPropertyGroupOption post /property-group-option":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["PropertyGroupOption"];
        response: {
          data: components["schemas"]["PropertyGroupOption"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["PropertyGroupOption"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["PropertyGroupOption"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["PropertyGroupOption"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["PropertyGroupOption"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["PropertyGroupOption"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["PropertyGroupOption"];
        };
        responseCode: 200;
      };
  "getPropertyGroupOption get /property-group-option/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the property_group_option */
          id: string;
        };
        response: {
          data: components["schemas"]["PropertyGroupOption"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the property_group_option */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["PropertyGroupOption"];
        };
        responseCode: 200;
      };
  "deletePropertyGroupOption delete /property-group-option/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the property_group_option */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updatePropertyGroupOption patch /property-group-option/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the property_group_option */
          id: string;
        };
        body: components["schemas"]["PropertyGroupOption"];
        response: {
          data: components["schemas"]["PropertyGroupOption"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the property_group_option */
          id: string;
        };
        body: components["schemas"]["PropertyGroupOption"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["PropertyGroupOption"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the property_group_option */
          id: string;
        };
        body: {
          data?: components["schemas"]["PropertyGroupOption"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["PropertyGroupOption"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the property_group_option */
          id: string;
        };
        body: {
          data?: components["schemas"]["PropertyGroupOption"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["PropertyGroupOption"];
        };
        responseCode: 200;
      };
  "getPropertyGroup get /property-group/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the property_group */
          id: string;
        };
        response: {
          data: components["schemas"]["PropertyGroup"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the property_group */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["PropertyGroup"];
        };
        responseCode: 200;
      };
  "deletePropertyGroup delete /property-group/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the property_group */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updatePropertyGroup patch /property-group/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the property_group */
          id: string;
        };
        body: components["schemas"]["PropertyGroup"];
        response: {
          data: components["schemas"]["PropertyGroup"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the property_group */
          id: string;
        };
        body: components["schemas"]["PropertyGroup"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["PropertyGroup"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the property_group */
          id: string;
        };
        body: {
          data?: components["schemas"]["PropertyGroup"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["PropertyGroup"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the property_group */
          id: string;
        };
        body: {
          data?: components["schemas"]["PropertyGroup"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["PropertyGroup"];
        };
        responseCode: 200;
      };
  "getQuoteList get /quote":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["Quote"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["Quote"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /quote?limit=25 */
            first?: unknown;
            /** @example /quote?limit=25&page=11 */
            last?: unknown;
            /** @example /quote?limit=25&page=4 */
            next?: unknown;
            /** @example /quote?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createQuote post /quote":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["Quote"];
        response: {
          data: components["schemas"]["Quote"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["Quote"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Quote"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["Quote"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["Quote"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["Quote"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Quote"];
        };
        responseCode: 200;
      };
  "getQuoteCommentList get /quote-comment":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["QuoteComment"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["QuoteComment"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /quote-comment?limit=25 */
            first?: unknown;
            /** @example /quote-comment?limit=25&page=11 */
            last?: unknown;
            /** @example /quote-comment?limit=25&page=4 */
            next?: unknown;
            /** @example /quote-comment?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createQuoteComment post /quote-comment":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["QuoteComment"];
        response: {
          data: components["schemas"]["QuoteComment"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["QuoteComment"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["QuoteComment"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["QuoteComment"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["QuoteComment"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["QuoteComment"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["QuoteComment"];
        };
        responseCode: 200;
      };
  "getQuoteComment get /quote-comment/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the quote_comment */
          id: string;
        };
        response: {
          data: components["schemas"]["QuoteComment"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the quote_comment */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["QuoteComment"];
        };
        responseCode: 200;
      };
  "deleteQuoteComment delete /quote-comment/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the quote_comment */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateQuoteComment patch /quote-comment/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the quote_comment */
          id: string;
        };
        body: components["schemas"]["QuoteComment"];
        response: {
          data: components["schemas"]["QuoteComment"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the quote_comment */
          id: string;
        };
        body: components["schemas"]["QuoteComment"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["QuoteComment"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the quote_comment */
          id: string;
        };
        body: {
          data?: components["schemas"]["QuoteComment"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["QuoteComment"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the quote_comment */
          id: string;
        };
        body: {
          data?: components["schemas"]["QuoteComment"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["QuoteComment"];
        };
        responseCode: 200;
      };
  "getQuoteDeliveryList get /quote-delivery":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["QuoteDelivery"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["QuoteDelivery"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /quote-delivery?limit=25 */
            first?: unknown;
            /** @example /quote-delivery?limit=25&page=11 */
            last?: unknown;
            /** @example /quote-delivery?limit=25&page=4 */
            next?: unknown;
            /** @example /quote-delivery?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createQuoteDelivery post /quote-delivery":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["QuoteDelivery"];
        response: {
          data: components["schemas"]["QuoteDelivery"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["QuoteDelivery"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["QuoteDelivery"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["QuoteDelivery"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["QuoteDelivery"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["QuoteDelivery"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["QuoteDelivery"];
        };
        responseCode: 200;
      };
  "getQuoteDeliveryPositionList get /quote-delivery-position":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["QuoteDeliveryPosition"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["QuoteDeliveryPosition"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /quote-delivery-position?limit=25 */
            first?: unknown;
            /** @example /quote-delivery-position?limit=25&page=11 */
            last?: unknown;
            /** @example /quote-delivery-position?limit=25&page=4 */
            next?: unknown;
            /** @example /quote-delivery-position?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createQuoteDeliveryPosition post /quote-delivery-position":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["QuoteDeliveryPosition"];
        response: {
          data: components["schemas"]["QuoteDeliveryPosition"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["QuoteDeliveryPosition"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["QuoteDeliveryPosition"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["QuoteDeliveryPosition"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["QuoteDeliveryPosition"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["QuoteDeliveryPosition"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["QuoteDeliveryPosition"];
        };
        responseCode: 200;
      };
  "getQuoteDeliveryPosition get /quote-delivery-position/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the quote_delivery_position */
          id: string;
        };
        response: {
          data: components["schemas"]["QuoteDeliveryPosition"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the quote_delivery_position */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["QuoteDeliveryPosition"];
        };
        responseCode: 200;
      };
  "deleteQuoteDeliveryPosition delete /quote-delivery-position/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the quote_delivery_position */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateQuoteDeliveryPosition patch /quote-delivery-position/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the quote_delivery_position */
          id: string;
        };
        body: components["schemas"]["QuoteDeliveryPosition"];
        response: {
          data: components["schemas"]["QuoteDeliveryPosition"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the quote_delivery_position */
          id: string;
        };
        body: components["schemas"]["QuoteDeliveryPosition"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["QuoteDeliveryPosition"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the quote_delivery_position */
          id: string;
        };
        body: {
          data?: components["schemas"]["QuoteDeliveryPosition"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["QuoteDeliveryPosition"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the quote_delivery_position */
          id: string;
        };
        body: {
          data?: components["schemas"]["QuoteDeliveryPosition"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["QuoteDeliveryPosition"];
        };
        responseCode: 200;
      };
  "getQuoteDelivery get /quote-delivery/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the quote_delivery */
          id: string;
        };
        response: {
          data: components["schemas"]["QuoteDelivery"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the quote_delivery */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["QuoteDelivery"];
        };
        responseCode: 200;
      };
  "deleteQuoteDelivery delete /quote-delivery/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the quote_delivery */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateQuoteDelivery patch /quote-delivery/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the quote_delivery */
          id: string;
        };
        body: components["schemas"]["QuoteDelivery"];
        response: {
          data: components["schemas"]["QuoteDelivery"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the quote_delivery */
          id: string;
        };
        body: components["schemas"]["QuoteDelivery"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["QuoteDelivery"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the quote_delivery */
          id: string;
        };
        body: {
          data?: components["schemas"]["QuoteDelivery"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["QuoteDelivery"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the quote_delivery */
          id: string;
        };
        body: {
          data?: components["schemas"]["QuoteDelivery"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["QuoteDelivery"];
        };
        responseCode: 200;
      };
  "getQuoteDocumentList get /quote-document":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["QuoteDocument"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["QuoteDocument"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /quote-document?limit=25 */
            first?: unknown;
            /** @example /quote-document?limit=25&page=11 */
            last?: unknown;
            /** @example /quote-document?limit=25&page=4 */
            next?: unknown;
            /** @example /quote-document?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createQuoteDocument post /quote-document":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["QuoteDocument"];
        response: {
          data: components["schemas"]["QuoteDocument"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["QuoteDocument"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["QuoteDocument"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["QuoteDocument"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["QuoteDocument"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["QuoteDocument"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["QuoteDocument"];
        };
        responseCode: 200;
      };
  "getQuoteDocument get /quote-document/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the quote_document */
          id: string;
        };
        response: {
          data: components["schemas"]["QuoteDocument"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the quote_document */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["QuoteDocument"];
        };
        responseCode: 200;
      };
  "deleteQuoteDocument delete /quote-document/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the quote_document */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateQuoteDocument patch /quote-document/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the quote_document */
          id: string;
        };
        body: components["schemas"]["QuoteDocument"];
        response: {
          data: components["schemas"]["QuoteDocument"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the quote_document */
          id: string;
        };
        body: components["schemas"]["QuoteDocument"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["QuoteDocument"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the quote_document */
          id: string;
        };
        body: {
          data?: components["schemas"]["QuoteDocument"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["QuoteDocument"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the quote_document */
          id: string;
        };
        body: {
          data?: components["schemas"]["QuoteDocument"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["QuoteDocument"];
        };
        responseCode: 200;
      };
  "getQuoteEmployeeList get /quote-employee":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["QuoteEmployee"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["QuoteEmployee"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /quote-employee?limit=25 */
            first?: unknown;
            /** @example /quote-employee?limit=25&page=11 */
            last?: unknown;
            /** @example /quote-employee?limit=25&page=4 */
            next?: unknown;
            /** @example /quote-employee?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createQuoteEmployee post /quote-employee":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["QuoteEmployee"];
        response: {
          data: components["schemas"]["QuoteEmployee"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["QuoteEmployee"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["QuoteEmployee"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["QuoteEmployee"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["QuoteEmployee"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["QuoteEmployee"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["QuoteEmployee"];
        };
        responseCode: 200;
      };
  "getQuoteEmployee get /quote-employee/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the quote_employee */
          id: string;
        };
        response: {
          data: components["schemas"]["QuoteEmployee"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the quote_employee */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["QuoteEmployee"];
        };
        responseCode: 200;
      };
  "deleteQuoteEmployee delete /quote-employee/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the quote_employee */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateQuoteEmployee patch /quote-employee/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the quote_employee */
          id: string;
        };
        body: components["schemas"]["QuoteEmployee"];
        response: {
          data: components["schemas"]["QuoteEmployee"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the quote_employee */
          id: string;
        };
        body: components["schemas"]["QuoteEmployee"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["QuoteEmployee"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the quote_employee */
          id: string;
        };
        body: {
          data?: components["schemas"]["QuoteEmployee"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["QuoteEmployee"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the quote_employee */
          id: string;
        };
        body: {
          data?: components["schemas"]["QuoteEmployee"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["QuoteEmployee"];
        };
        responseCode: 200;
      };
  "getQuoteLineItemList get /quote-line-item":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["QuoteLineItem"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["QuoteLineItem"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /quote-line-item?limit=25 */
            first?: unknown;
            /** @example /quote-line-item?limit=25&page=11 */
            last?: unknown;
            /** @example /quote-line-item?limit=25&page=4 */
            next?: unknown;
            /** @example /quote-line-item?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createQuoteLineItem post /quote-line-item":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["QuoteLineItem"];
        response: {
          data: components["schemas"]["QuoteLineItem"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["QuoteLineItem"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["QuoteLineItem"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["QuoteLineItem"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["QuoteLineItem"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["QuoteLineItem"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["QuoteLineItem"];
        };
        responseCode: 200;
      };
  "getQuoteLineItem get /quote-line-item/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the quote_line_item */
          id: string;
        };
        response: {
          data: components["schemas"]["QuoteLineItem"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the quote_line_item */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["QuoteLineItem"];
        };
        responseCode: 200;
      };
  "deleteQuoteLineItem delete /quote-line-item/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the quote_line_item */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateQuoteLineItem patch /quote-line-item/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the quote_line_item */
          id: string;
        };
        body: components["schemas"]["QuoteLineItem"];
        response: {
          data: components["schemas"]["QuoteLineItem"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the quote_line_item */
          id: string;
        };
        body: components["schemas"]["QuoteLineItem"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["QuoteLineItem"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the quote_line_item */
          id: string;
        };
        body: {
          data?: components["schemas"]["QuoteLineItem"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["QuoteLineItem"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the quote_line_item */
          id: string;
        };
        body: {
          data?: components["schemas"]["QuoteLineItem"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["QuoteLineItem"];
        };
        responseCode: 200;
      };
  "getQuoteTransactionList get /quote-transaction":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["QuoteTransaction"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["QuoteTransaction"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /quote-transaction?limit=25 */
            first?: unknown;
            /** @example /quote-transaction?limit=25&page=11 */
            last?: unknown;
            /** @example /quote-transaction?limit=25&page=4 */
            next?: unknown;
            /** @example /quote-transaction?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createQuoteTransaction post /quote-transaction":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["QuoteTransaction"];
        response: {
          data: components["schemas"]["QuoteTransaction"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["QuoteTransaction"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["QuoteTransaction"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["QuoteTransaction"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["QuoteTransaction"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["QuoteTransaction"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["QuoteTransaction"];
        };
        responseCode: 200;
      };
  "getQuoteTransaction get /quote-transaction/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the quote_transaction */
          id: string;
        };
        response: {
          data: components["schemas"]["QuoteTransaction"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the quote_transaction */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["QuoteTransaction"];
        };
        responseCode: 200;
      };
  "deleteQuoteTransaction delete /quote-transaction/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the quote_transaction */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateQuoteTransaction patch /quote-transaction/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the quote_transaction */
          id: string;
        };
        body: components["schemas"]["QuoteTransaction"];
        response: {
          data: components["schemas"]["QuoteTransaction"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the quote_transaction */
          id: string;
        };
        body: components["schemas"]["QuoteTransaction"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["QuoteTransaction"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the quote_transaction */
          id: string;
        };
        body: {
          data?: components["schemas"]["QuoteTransaction"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["QuoteTransaction"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the quote_transaction */
          id: string;
        };
        body: {
          data?: components["schemas"]["QuoteTransaction"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["QuoteTransaction"];
        };
        responseCode: 200;
      };
  "getQuote get /quote/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the quote */
          id: string;
        };
        response: {
          data: components["schemas"]["Quote"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the quote */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Quote"];
        };
        responseCode: 200;
      };
  "deleteQuote delete /quote/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the quote */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateQuote patch /quote/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the quote */
          id: string;
        };
        body: components["schemas"]["Quote"];
        response: {
          data: components["schemas"]["Quote"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the quote */
          id: string;
        };
        body: components["schemas"]["Quote"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Quote"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the quote */
          id: string;
        };
        body: {
          data?: components["schemas"]["Quote"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["Quote"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the quote */
          id: string;
        };
        body: {
          data?: components["schemas"]["Quote"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Quote"];
        };
        responseCode: 200;
      };
  "getRuleList get /rule":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["Rule"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["Rule"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /rule?limit=25 */
            first?: unknown;
            /** @example /rule?limit=25&page=11 */
            last?: unknown;
            /** @example /rule?limit=25&page=4 */
            next?: unknown;
            /** @example /rule?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createRule post /rule":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["Rule"];
        response: {
          data: components["schemas"]["Rule"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["Rule"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Rule"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["Rule"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["Rule"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["Rule"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Rule"];
        };
        responseCode: 200;
      };
  "getRuleConditionList get /rule-condition":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["RuleCondition"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["RuleCondition"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /rule-condition?limit=25 */
            first?: unknown;
            /** @example /rule-condition?limit=25&page=11 */
            last?: unknown;
            /** @example /rule-condition?limit=25&page=4 */
            next?: unknown;
            /** @example /rule-condition?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createRuleCondition post /rule-condition":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["RuleCondition"];
        response: {
          data: components["schemas"]["RuleCondition"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["RuleCondition"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["RuleCondition"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["RuleCondition"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["RuleCondition"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["RuleCondition"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["RuleCondition"];
        };
        responseCode: 200;
      };
  "getRuleCondition get /rule-condition/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the rule_condition */
          id: string;
        };
        response: {
          data: components["schemas"]["RuleCondition"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the rule_condition */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["RuleCondition"];
        };
        responseCode: 200;
      };
  "deleteRuleCondition delete /rule-condition/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the rule_condition */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateRuleCondition patch /rule-condition/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the rule_condition */
          id: string;
        };
        body: components["schemas"]["RuleCondition"];
        response: {
          data: components["schemas"]["RuleCondition"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the rule_condition */
          id: string;
        };
        body: components["schemas"]["RuleCondition"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["RuleCondition"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the rule_condition */
          id: string;
        };
        body: {
          data?: components["schemas"]["RuleCondition"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["RuleCondition"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the rule_condition */
          id: string;
        };
        body: {
          data?: components["schemas"]["RuleCondition"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["RuleCondition"];
        };
        responseCode: 200;
      };
  "getRule get /rule/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the rule */
          id: string;
        };
        response: {
          data: components["schemas"]["Rule"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the rule */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Rule"];
        };
        responseCode: 200;
      };
  "deleteRule delete /rule/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the rule */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateRule patch /rule/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the rule */
          id: string;
        };
        body: components["schemas"]["Rule"];
        response: {
          data: components["schemas"]["Rule"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the rule */
          id: string;
        };
        body: components["schemas"]["Rule"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Rule"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the rule */
          id: string;
        };
        body: {
          data?: components["schemas"]["Rule"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["Rule"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the rule */
          id: string;
        };
        body: {
          data?: components["schemas"]["Rule"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Rule"];
        };
        responseCode: 200;
      };
  "getSaasAppStorefrontConfigList get /saas-app-storefront-config":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["SaasAppStorefrontConfig"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["SaasAppStorefrontConfig"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /saas-app-storefront-config?limit=25 */
            first?: unknown;
            /** @example /saas-app-storefront-config?limit=25&page=11 */
            last?: unknown;
            /** @example /saas-app-storefront-config?limit=25&page=4 */
            next?: unknown;
            /** @example /saas-app-storefront-config?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createSaasAppStorefrontConfig post /saas-app-storefront-config":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SaasAppStorefrontConfig"];
        response: {
          data: components["schemas"]["SaasAppStorefrontConfig"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SaasAppStorefrontConfig"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SaasAppStorefrontConfig"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SaasAppStorefrontConfig"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SaasAppStorefrontConfig"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SaasAppStorefrontConfig"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SaasAppStorefrontConfig"];
        };
        responseCode: 200;
      };
  "getSaasAppStorefrontConfig get /saas-app-storefront-config/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the saas_app_storefront_config */
          id: string;
        };
        response: {
          data: components["schemas"]["SaasAppStorefrontConfig"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the saas_app_storefront_config */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SaasAppStorefrontConfig"];
        };
        responseCode: 200;
      };
  "deleteSaasAppStorefrontConfig delete /saas-app-storefront-config/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the saas_app_storefront_config */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateSaasAppStorefrontConfig patch /saas-app-storefront-config/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the saas_app_storefront_config */
          id: string;
        };
        body: components["schemas"]["SaasAppStorefrontConfig"];
        response: {
          data: components["schemas"]["SaasAppStorefrontConfig"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the saas_app_storefront_config */
          id: string;
        };
        body: components["schemas"]["SaasAppStorefrontConfig"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SaasAppStorefrontConfig"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the saas_app_storefront_config */
          id: string;
        };
        body: {
          data?: components["schemas"]["SaasAppStorefrontConfig"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SaasAppStorefrontConfig"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the saas_app_storefront_config */
          id: string;
        };
        body: {
          data?: components["schemas"]["SaasAppStorefrontConfig"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SaasAppStorefrontConfig"];
        };
        responseCode: 200;
      };
  "getSaasSbpUserDataList get /saas-sbp-user-data":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["SaasSbpUserData"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["SaasSbpUserData"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /saas-sbp-user-data?limit=25 */
            first?: unknown;
            /** @example /saas-sbp-user-data?limit=25&page=11 */
            last?: unknown;
            /** @example /saas-sbp-user-data?limit=25&page=4 */
            next?: unknown;
            /** @example /saas-sbp-user-data?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createSaasSbpUserData post /saas-sbp-user-data":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SaasSbpUserData"];
        response: {
          data: components["schemas"]["SaasSbpUserData"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SaasSbpUserData"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SaasSbpUserData"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SaasSbpUserData"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SaasSbpUserData"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SaasSbpUserData"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SaasSbpUserData"];
        };
        responseCode: 200;
      };
  "getSaasSbpUserData get /saas-sbp-user-data/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the saas_sbp_user_data */
          id: string;
        };
        response: {
          data: components["schemas"]["SaasSbpUserData"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the saas_sbp_user_data */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SaasSbpUserData"];
        };
        responseCode: 200;
      };
  "deleteSaasSbpUserData delete /saas-sbp-user-data/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the saas_sbp_user_data */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateSaasSbpUserData patch /saas-sbp-user-data/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the saas_sbp_user_data */
          id: string;
        };
        body: components["schemas"]["SaasSbpUserData"];
        response: {
          data: components["schemas"]["SaasSbpUserData"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the saas_sbp_user_data */
          id: string;
        };
        body: components["schemas"]["SaasSbpUserData"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SaasSbpUserData"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the saas_sbp_user_data */
          id: string;
        };
        body: {
          data?: components["schemas"]["SaasSbpUserData"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SaasSbpUserData"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the saas_sbp_user_data */
          id: string;
        };
        body: {
          data?: components["schemas"]["SaasSbpUserData"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SaasSbpUserData"];
        };
        responseCode: 200;
      };
  "getSaasStorefrontDemoTokenList get /saas-storefront-demo-token":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["SaasStorefrontDemoToken"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["SaasStorefrontDemoToken"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /saas-storefront-demo-token?limit=25 */
            first?: unknown;
            /** @example /saas-storefront-demo-token?limit=25&page=11 */
            last?: unknown;
            /** @example /saas-storefront-demo-token?limit=25&page=4 */
            next?: unknown;
            /** @example /saas-storefront-demo-token?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createSaasStorefrontDemoToken post /saas-storefront-demo-token":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SaasStorefrontDemoToken"];
        response: {
          data: components["schemas"]["SaasStorefrontDemoToken"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SaasStorefrontDemoToken"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SaasStorefrontDemoToken"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SaasStorefrontDemoToken"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SaasStorefrontDemoToken"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SaasStorefrontDemoToken"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SaasStorefrontDemoToken"];
        };
        responseCode: 200;
      };
  "getSaasStorefrontDemoToken get /saas-storefront-demo-token/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the saas_storefront_demo_token */
          id: string;
        };
        response: {
          data: components["schemas"]["SaasStorefrontDemoToken"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the saas_storefront_demo_token */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SaasStorefrontDemoToken"];
        };
        responseCode: 200;
      };
  "deleteSaasStorefrontDemoToken delete /saas-storefront-demo-token/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the saas_storefront_demo_token */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateSaasStorefrontDemoToken patch /saas-storefront-demo-token/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the saas_storefront_demo_token */
          id: string;
        };
        body: components["schemas"]["SaasStorefrontDemoToken"];
        response: {
          data: components["schemas"]["SaasStorefrontDemoToken"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the saas_storefront_demo_token */
          id: string;
        };
        body: components["schemas"]["SaasStorefrontDemoToken"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SaasStorefrontDemoToken"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the saas_storefront_demo_token */
          id: string;
        };
        body: {
          data?: components["schemas"]["SaasStorefrontDemoToken"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SaasStorefrontDemoToken"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the saas_storefront_demo_token */
          id: string;
        };
        body: {
          data?: components["schemas"]["SaasStorefrontDemoToken"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SaasStorefrontDemoToken"];
        };
        responseCode: 200;
      };
  "getSaasUserLoginTokenList get /saas-user-login-token":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["SaasUserLoginToken"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["SaasUserLoginToken"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /saas-user-login-token?limit=25 */
            first?: unknown;
            /** @example /saas-user-login-token?limit=25&page=11 */
            last?: unknown;
            /** @example /saas-user-login-token?limit=25&page=4 */
            next?: unknown;
            /** @example /saas-user-login-token?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createSaasUserLoginToken post /saas-user-login-token":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SaasUserLoginToken"];
        response: {
          data: components["schemas"]["SaasUserLoginToken"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SaasUserLoginToken"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SaasUserLoginToken"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SaasUserLoginToken"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SaasUserLoginToken"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SaasUserLoginToken"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SaasUserLoginToken"];
        };
        responseCode: 200;
      };
  "getSaasUserLoginToken get /saas-user-login-token/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the saas_user_login_token */
          id: string;
        };
        response: {
          data: components["schemas"]["SaasUserLoginToken"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the saas_user_login_token */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SaasUserLoginToken"];
        };
        responseCode: 200;
      };
  "deleteSaasUserLoginToken delete /saas-user-login-token/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the saas_user_login_token */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateSaasUserLoginToken patch /saas-user-login-token/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the saas_user_login_token */
          id: string;
        };
        body: components["schemas"]["SaasUserLoginToken"];
        response: {
          data: components["schemas"]["SaasUserLoginToken"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the saas_user_login_token */
          id: string;
        };
        body: components["schemas"]["SaasUserLoginToken"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SaasUserLoginToken"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the saas_user_login_token */
          id: string;
        };
        body: {
          data?: components["schemas"]["SaasUserLoginToken"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SaasUserLoginToken"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the saas_user_login_token */
          id: string;
        };
        body: {
          data?: components["schemas"]["SaasUserLoginToken"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SaasUserLoginToken"];
        };
        responseCode: 200;
      };
  "getSalesChannelList get /sales-channel":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["SalesChannel"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["SalesChannel"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /sales-channel?limit=25 */
            first?: unknown;
            /** @example /sales-channel?limit=25&page=11 */
            last?: unknown;
            /** @example /sales-channel?limit=25&page=4 */
            next?: unknown;
            /** @example /sales-channel?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createSalesChannel post /sales-channel":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SalesChannel"];
        response: {
          data: components["schemas"]["SalesChannel"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SalesChannel"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SalesChannel"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SalesChannel"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SalesChannel"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SalesChannel"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SalesChannel"];
        };
        responseCode: 200;
      };
  "getSalesChannelAnalyticsList get /sales-channel-analytics":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["SalesChannelAnalytics"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["SalesChannelAnalytics"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /sales-channel-analytics?limit=25 */
            first?: unknown;
            /** @example /sales-channel-analytics?limit=25&page=11 */
            last?: unknown;
            /** @example /sales-channel-analytics?limit=25&page=4 */
            next?: unknown;
            /** @example /sales-channel-analytics?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createSalesChannelAnalytics post /sales-channel-analytics":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SalesChannelAnalytics"];
        response: {
          data: components["schemas"]["SalesChannelAnalytics"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SalesChannelAnalytics"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SalesChannelAnalytics"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SalesChannelAnalytics"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SalesChannelAnalytics"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SalesChannelAnalytics"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SalesChannelAnalytics"];
        };
        responseCode: 200;
      };
  "getSalesChannelAnalytics get /sales-channel-analytics/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the sales_channel_analytics */
          id: string;
        };
        response: {
          data: components["schemas"]["SalesChannelAnalytics"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the sales_channel_analytics */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SalesChannelAnalytics"];
        };
        responseCode: 200;
      };
  "deleteSalesChannelAnalytics delete /sales-channel-analytics/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the sales_channel_analytics */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateSalesChannelAnalytics patch /sales-channel-analytics/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the sales_channel_analytics */
          id: string;
        };
        body: components["schemas"]["SalesChannelAnalytics"];
        response: {
          data: components["schemas"]["SalesChannelAnalytics"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the sales_channel_analytics */
          id: string;
        };
        body: components["schemas"]["SalesChannelAnalytics"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SalesChannelAnalytics"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the sales_channel_analytics */
          id: string;
        };
        body: {
          data?: components["schemas"]["SalesChannelAnalytics"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SalesChannelAnalytics"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the sales_channel_analytics */
          id: string;
        };
        body: {
          data?: components["schemas"]["SalesChannelAnalytics"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SalesChannelAnalytics"];
        };
        responseCode: 200;
      };
  "getSalesChannelDomainList get /sales-channel-domain":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["SalesChannelDomain"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["SalesChannelDomain"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /sales-channel-domain?limit=25 */
            first?: unknown;
            /** @example /sales-channel-domain?limit=25&page=11 */
            last?: unknown;
            /** @example /sales-channel-domain?limit=25&page=4 */
            next?: unknown;
            /** @example /sales-channel-domain?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createSalesChannelDomain post /sales-channel-domain":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SalesChannelDomain"];
        response: {
          data: components["schemas"]["SalesChannelDomain"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SalesChannelDomain"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SalesChannelDomain"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SalesChannelDomain"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SalesChannelDomain"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SalesChannelDomain"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SalesChannelDomain"];
        };
        responseCode: 200;
      };
  "getSalesChannelDomain get /sales-channel-domain/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the sales_channel_domain */
          id: string;
        };
        response: {
          data: components["schemas"]["SalesChannelDomain"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the sales_channel_domain */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SalesChannelDomain"];
        };
        responseCode: 200;
      };
  "deleteSalesChannelDomain delete /sales-channel-domain/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the sales_channel_domain */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateSalesChannelDomain patch /sales-channel-domain/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the sales_channel_domain */
          id: string;
        };
        body: components["schemas"]["SalesChannelDomain"];
        response: {
          data: components["schemas"]["SalesChannelDomain"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the sales_channel_domain */
          id: string;
        };
        body: components["schemas"]["SalesChannelDomain"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SalesChannelDomain"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the sales_channel_domain */
          id: string;
        };
        body: {
          data?: components["schemas"]["SalesChannelDomain"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SalesChannelDomain"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the sales_channel_domain */
          id: string;
        };
        body: {
          data?: components["schemas"]["SalesChannelDomain"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SalesChannelDomain"];
        };
        responseCode: 200;
      };
  "getSalesChannelTypeList get /sales-channel-type":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["SalesChannelType"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["SalesChannelType"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /sales-channel-type?limit=25 */
            first?: unknown;
            /** @example /sales-channel-type?limit=25&page=11 */
            last?: unknown;
            /** @example /sales-channel-type?limit=25&page=4 */
            next?: unknown;
            /** @example /sales-channel-type?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createSalesChannelType post /sales-channel-type":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SalesChannelType"];
        response: {
          data: components["schemas"]["SalesChannelType"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SalesChannelType"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SalesChannelType"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SalesChannelType"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SalesChannelType"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SalesChannelType"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SalesChannelType"];
        };
        responseCode: 200;
      };
  "getSalesChannelType get /sales-channel-type/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the sales_channel_type */
          id: string;
        };
        response: {
          data: components["schemas"]["SalesChannelType"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the sales_channel_type */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SalesChannelType"];
        };
        responseCode: 200;
      };
  "deleteSalesChannelType delete /sales-channel-type/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the sales_channel_type */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateSalesChannelType patch /sales-channel-type/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the sales_channel_type */
          id: string;
        };
        body: components["schemas"]["SalesChannelType"];
        response: {
          data: components["schemas"]["SalesChannelType"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the sales_channel_type */
          id: string;
        };
        body: components["schemas"]["SalesChannelType"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SalesChannelType"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the sales_channel_type */
          id: string;
        };
        body: {
          data?: components["schemas"]["SalesChannelType"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SalesChannelType"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the sales_channel_type */
          id: string;
        };
        body: {
          data?: components["schemas"]["SalesChannelType"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SalesChannelType"];
        };
        responseCode: 200;
      };
  "getSalesChannel get /sales-channel/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the sales_channel */
          id: string;
        };
        response: {
          data: components["schemas"]["SalesChannel"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the sales_channel */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SalesChannel"];
        };
        responseCode: 200;
      };
  "deleteSalesChannel delete /sales-channel/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the sales_channel */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateSalesChannel patch /sales-channel/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the sales_channel */
          id: string;
        };
        body: components["schemas"]["SalesChannel"];
        response: {
          data: components["schemas"]["SalesChannel"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the sales_channel */
          id: string;
        };
        body: components["schemas"]["SalesChannel"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SalesChannel"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the sales_channel */
          id: string;
        };
        body: {
          data?: components["schemas"]["SalesChannel"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SalesChannel"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the sales_channel */
          id: string;
        };
        body: {
          data?: components["schemas"]["SalesChannel"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SalesChannel"];
        };
        responseCode: 200;
      };
  "getSalutationList get /salutation":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["Salutation"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["Salutation"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /salutation?limit=25 */
            first?: unknown;
            /** @example /salutation?limit=25&page=11 */
            last?: unknown;
            /** @example /salutation?limit=25&page=4 */
            next?: unknown;
            /** @example /salutation?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createSalutation post /salutation":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["Salutation"];
        response: {
          data: components["schemas"]["Salutation"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["Salutation"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Salutation"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["Salutation"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["Salutation"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["Salutation"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Salutation"];
        };
        responseCode: 200;
      };
  "getSalutation get /salutation/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the salutation */
          id: string;
        };
        response: {
          data: components["schemas"]["Salutation"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the salutation */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Salutation"];
        };
        responseCode: 200;
      };
  "deleteSalutation delete /salutation/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the salutation */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateSalutation patch /salutation/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the salutation */
          id: string;
        };
        body: components["schemas"]["Salutation"];
        response: {
          data: components["schemas"]["Salutation"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the salutation */
          id: string;
        };
        body: components["schemas"]["Salutation"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Salutation"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the salutation */
          id: string;
        };
        body: {
          data?: components["schemas"]["Salutation"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["Salutation"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the salutation */
          id: string;
        };
        body: {
          data?: components["schemas"]["Salutation"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Salutation"];
        };
        responseCode: 200;
      };
  "getScheduledTaskList get /scheduled-task":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["ScheduledTask"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["ScheduledTask"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /scheduled-task?limit=25 */
            first?: unknown;
            /** @example /scheduled-task?limit=25&page=11 */
            last?: unknown;
            /** @example /scheduled-task?limit=25&page=4 */
            next?: unknown;
            /** @example /scheduled-task?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createScheduledTask post /scheduled-task":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["ScheduledTask"];
        response: {
          data: components["schemas"]["ScheduledTask"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["ScheduledTask"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ScheduledTask"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["ScheduledTask"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["ScheduledTask"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["ScheduledTask"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ScheduledTask"];
        };
        responseCode: 200;
      };
  "getScheduledTask get /scheduled-task/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the scheduled_task */
          id: string;
        };
        response: {
          data: components["schemas"]["ScheduledTask"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the scheduled_task */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ScheduledTask"];
        };
        responseCode: 200;
      };
  "deleteScheduledTask delete /scheduled-task/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the scheduled_task */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateScheduledTask patch /scheduled-task/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the scheduled_task */
          id: string;
        };
        body: components["schemas"]["ScheduledTask"];
        response: {
          data: components["schemas"]["ScheduledTask"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the scheduled_task */
          id: string;
        };
        body: components["schemas"]["ScheduledTask"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ScheduledTask"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the scheduled_task */
          id: string;
        };
        body: {
          data?: components["schemas"]["ScheduledTask"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["ScheduledTask"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the scheduled_task */
          id: string;
        };
        body: {
          data?: components["schemas"]["ScheduledTask"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ScheduledTask"];
        };
        responseCode: 200;
      };
  "getScriptList get /script":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["Script"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["Script"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /script?limit=25 */
            first?: unknown;
            /** @example /script?limit=25&page=11 */
            last?: unknown;
            /** @example /script?limit=25&page=4 */
            next?: unknown;
            /** @example /script?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createScript post /script":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["Script"];
        response: {
          data: components["schemas"]["Script"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["Script"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Script"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["Script"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["Script"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["Script"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Script"];
        };
        responseCode: 200;
      };
  "getScript get /script/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the script */
          id: string;
        };
        response: {
          data: components["schemas"]["Script"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the script */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Script"];
        };
        responseCode: 200;
      };
  "deleteScript delete /script/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the script */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateScript patch /script/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the script */
          id: string;
        };
        body: components["schemas"]["Script"];
        response: {
          data: components["schemas"]["Script"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the script */
          id: string;
        };
        body: components["schemas"]["Script"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Script"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the script */
          id: string;
        };
        body: {
          data?: components["schemas"]["Script"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["Script"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the script */
          id: string;
        };
        body: {
          data?: components["schemas"]["Script"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Script"];
        };
        responseCode: 200;
      };
  "searchAclRole post /search/acl-role":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["AclRole"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AclRole"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["AclRole"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AclRole"][];
        };
        responseCode: 200;
      };
  "searchAdvancedSearchAction post /search/advanced-search-action":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["AdvancedSearchAction"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AdvancedSearchAction"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["AdvancedSearchAction"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AdvancedSearchAction"][];
        };
        responseCode: 200;
      };
  "searchAdvancedSearchActionSearchTerm post /search/advanced-search-action-search-term":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["AdvancedSearchActionSearchTerm"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AdvancedSearchActionSearchTerm"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["AdvancedSearchActionSearchTerm"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AdvancedSearchActionSearchTerm"][];
        };
        responseCode: 200;
      };
  "searchAdvancedSearchBoosting post /search/advanced-search-boosting":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["AdvancedSearchBoosting"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AdvancedSearchBoosting"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["AdvancedSearchBoosting"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AdvancedSearchBoosting"][];
        };
        responseCode: 200;
      };
  "searchAdvancedSearchConfig post /search/advanced-search-config":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["AdvancedSearchConfig"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AdvancedSearchConfig"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["AdvancedSearchConfig"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AdvancedSearchConfig"][];
        };
        responseCode: 200;
      };
  "searchAdvancedSearchConfigField post /search/advanced-search-config-field":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["AdvancedSearchConfigField"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AdvancedSearchConfigField"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["AdvancedSearchConfigField"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AdvancedSearchConfigField"][];
        };
        responseCode: 200;
      };
  "searchAdvancedSearchEntityStream post /search/advanced-search-entity-stream":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["AdvancedSearchEntityStream"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AdvancedSearchEntityStream"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["AdvancedSearchEntityStream"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AdvancedSearchEntityStream"][];
        };
        responseCode: 200;
      };
  "searchAdvancedSearchEntityStreamFilter post /search/advanced-search-entity-stream-filter":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["AdvancedSearchEntityStreamFilter"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AdvancedSearchEntityStreamFilter"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["AdvancedSearchEntityStreamFilter"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AdvancedSearchEntityStreamFilter"][];
        };
        responseCode: 200;
      };
  "searchAdvancedSearchSynonym post /search/advanced-search-synonym":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["AdvancedSearchSynonym"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AdvancedSearchSynonym"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["AdvancedSearchSynonym"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AdvancedSearchSynonym"][];
        };
        responseCode: 200;
      };
  "searchApp post /search/app":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["App"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["App"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["App"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["App"][];
        };
        responseCode: 200;
      };
  "searchAppActionButton post /search/app-action-button":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["AppActionButton"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppActionButton"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["AppActionButton"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppActionButton"][];
        };
        responseCode: 200;
      };
  "searchAppAdministrationSnippet post /search/app-administration-snippet":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["AppAdministrationSnippet"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppAdministrationSnippet"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["AppAdministrationSnippet"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppAdministrationSnippet"][];
        };
        responseCode: 200;
      };
  "searchAppCmsBlock post /search/app-cms-block":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["AppCmsBlock"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppCmsBlock"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["AppCmsBlock"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppCmsBlock"][];
        };
        responseCode: 200;
      };
  "searchAppFlowAction post /search/app-flow-action":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["AppFlowAction"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppFlowAction"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["AppFlowAction"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppFlowAction"][];
        };
        responseCode: 200;
      };
  "searchAppFlowEvent post /search/app-flow-event":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["AppFlowEvent"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppFlowEvent"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["AppFlowEvent"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppFlowEvent"][];
        };
        responseCode: 200;
      };
  "searchAppPaymentMethod post /search/app-payment-method":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["AppPaymentMethod"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppPaymentMethod"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["AppPaymentMethod"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppPaymentMethod"][];
        };
        responseCode: 200;
      };
  "searchAppScriptCondition post /search/app-script-condition":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["AppScriptCondition"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppScriptCondition"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["AppScriptCondition"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppScriptCondition"][];
        };
        responseCode: 200;
      };
  "searchAppShippingMethod post /search/app-shipping-method":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["AppShippingMethod"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppShippingMethod"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["AppShippingMethod"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppShippingMethod"][];
        };
        responseCode: 200;
      };
  "searchAppTemplate post /search/app-template":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["AppTemplate"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppTemplate"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["AppTemplate"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["AppTemplate"][];
        };
        responseCode: 200;
      };
  "searchB2bBusinessPartner post /search/b2b-business-partner":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["B2bBusinessPartner"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bBusinessPartner"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["B2bBusinessPartner"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bBusinessPartner"][];
        };
        responseCode: 200;
      };
  "searchB2bComponentsApprovalRule post /search/b2b-components-approval-rule":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["B2bComponentsApprovalRule"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bComponentsApprovalRule"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["B2bComponentsApprovalRule"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bComponentsApprovalRule"][];
        };
        responseCode: 200;
      };
  "searchB2bComponentsApprovalRuleAppScriptCondition post /search/b2b-components-approval-rule-app-script-condition":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["B2bComponentsApprovalRuleAppScriptCondition"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bComponentsApprovalRuleAppScriptCondition"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["B2bComponentsApprovalRuleAppScriptCondition"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bComponentsApprovalRuleAppScriptCondition"][];
        };
        responseCode: 200;
      };
  "searchB2bComponentsPendingOrder post /search/b2b-components-pending-order":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["B2bComponentsPendingOrder"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bComponentsPendingOrder"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["B2bComponentsPendingOrder"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bComponentsPendingOrder"][];
        };
        responseCode: 200;
      };
  "searchB2bComponentsPendingOrderAddress post /search/b2b-components-pending-order-address":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["B2bComponentsPendingOrderAddress"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bComponentsPendingOrderAddress"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["B2bComponentsPendingOrderAddress"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bComponentsPendingOrderAddress"][];
        };
        responseCode: 200;
      };
  "searchB2bComponentsRole post /search/b2b-components-role":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["B2bComponentsRole"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bComponentsRole"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["B2bComponentsRole"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bComponentsRole"][];
        };
        responseCode: 200;
      };
  "searchB2bComponentsShoppingList post /search/b2b-components-shopping-list":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["B2bComponentsShoppingList"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bComponentsShoppingList"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["B2bComponentsShoppingList"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bComponentsShoppingList"][];
        };
        responseCode: 200;
      };
  "searchB2bComponentsShoppingListLineItem post /search/b2b-components-shopping-list-line-item":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["B2bComponentsShoppingListLineItem"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bComponentsShoppingListLineItem"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["B2bComponentsShoppingListLineItem"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bComponentsShoppingListLineItem"][];
        };
        responseCode: 200;
      };
  "searchB2bEmployee post /search/b2b-employee":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["B2bEmployee"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bEmployee"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["B2bEmployee"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bEmployee"][];
        };
        responseCode: 200;
      };
  "searchB2bOrderEmployee post /search/b2b-order-employee":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["B2bOrderEmployee"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bOrderEmployee"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["B2bOrderEmployee"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bOrderEmployee"][];
        };
        responseCode: 200;
      };
  "searchB2bPermission post /search/b2b-permission":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["B2bPermission"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bPermission"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["B2bPermission"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["B2bPermission"][];
        };
        responseCode: 200;
      };
  "searchCategory post /search/category":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["Category"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Category"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["Category"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Category"][];
        };
        responseCode: 200;
      };
  "searchCmsBlock post /search/cms-block":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["CmsBlock"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CmsBlock"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["CmsBlock"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CmsBlock"][];
        };
        responseCode: 200;
      };
  "searchCmsPage post /search/cms-page":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["CmsPage"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CmsPage"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["CmsPage"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CmsPage"][];
        };
        responseCode: 200;
      };
  "searchCmsPageActivity post /search/cms-page-activity":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["CmsPageActivity"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CmsPageActivity"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["CmsPageActivity"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CmsPageActivity"][];
        };
        responseCode: 200;
      };
  "searchCmsPageDraft post /search/cms-page-draft":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["CmsPageDraft"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CmsPageDraft"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["CmsPageDraft"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CmsPageDraft"][];
        };
        responseCode: 200;
      };
  "searchCmsSection post /search/cms-section":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["CmsSection"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CmsSection"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["CmsSection"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CmsSection"][];
        };
        responseCode: 200;
      };
  "searchCmsSlot post /search/cms-slot":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["CmsSlot"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CmsSlot"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["CmsSlot"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CmsSlot"][];
        };
        responseCode: 200;
      };
  "searchCountry post /search/country":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["Country"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Country"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["Country"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Country"][];
        };
        responseCode: 200;
      };
  "searchCountryState post /search/country-state":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["CountryState"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CountryState"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["CountryState"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CountryState"][];
        };
        responseCode: 200;
      };
  "searchCurrency post /search/currency":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["Currency"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Currency"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["Currency"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Currency"][];
        };
        responseCode: 200;
      };
  "searchCurrencyCountryRounding post /search/currency-country-rounding":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["CurrencyCountryRounding"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CurrencyCountryRounding"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["CurrencyCountryRounding"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CurrencyCountryRounding"][];
        };
        responseCode: 200;
      };
  "searchCustomEntity post /search/custom-entity":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["CustomEntity"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomEntity"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["CustomEntity"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomEntity"][];
        };
        responseCode: 200;
      };
  "searchCustomField post /search/custom-field":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["CustomField"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomField"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["CustomField"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomField"][];
        };
        responseCode: 200;
      };
  "searchCustomFieldSet post /search/custom-field-set":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["CustomFieldSet"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomFieldSet"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["CustomFieldSet"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomFieldSet"][];
        };
        responseCode: 200;
      };
  "searchCustomFieldSetRelation post /search/custom-field-set-relation":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["CustomFieldSetRelation"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomFieldSetRelation"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["CustomFieldSetRelation"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomFieldSetRelation"][];
        };
        responseCode: 200;
      };
  "searchCustomPrice post /search/custom-price":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["CustomPrice"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomPrice"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["CustomPrice"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomPrice"][];
        };
        responseCode: 200;
      };
  "searchCustomer post /search/customer":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["Customer"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Customer"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["Customer"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Customer"][];
        };
        responseCode: 200;
      };
  "searchCustomerAddress post /search/customer-address":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["CustomerAddress"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomerAddress"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["CustomerAddress"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomerAddress"][];
        };
        responseCode: 200;
      };
  "searchCustomerGroup post /search/customer-group":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["CustomerGroup"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomerGroup"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["CustomerGroup"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomerGroup"][];
        };
        responseCode: 200;
      };
  "searchCustomerRecovery post /search/customer-recovery":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["CustomerRecovery"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomerRecovery"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["CustomerRecovery"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomerRecovery"][];
        };
        responseCode: 200;
      };
  "searchCustomerSpecificFeatures post /search/customer-specific-features":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["CustomerSpecificFeatures"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomerSpecificFeatures"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["CustomerSpecificFeatures"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomerSpecificFeatures"][];
        };
        responseCode: 200;
      };
  "searchCustomerWishlist post /search/customer-wishlist":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["CustomerWishlist"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomerWishlist"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["CustomerWishlist"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomerWishlist"][];
        };
        responseCode: 200;
      };
  "searchCustomerWishlistProduct post /search/customer-wishlist-product":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["CustomerWishlistProduct"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomerWishlistProduct"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["CustomerWishlistProduct"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["CustomerWishlistProduct"][];
        };
        responseCode: 200;
      };
  "searchDeliveryTime post /search/delivery-time":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["DeliveryTime"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DeliveryTime"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["DeliveryTime"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DeliveryTime"][];
        };
        responseCode: 200;
      };
  "searchDocument post /search/document":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["Document"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Document"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["Document"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Document"][];
        };
        responseCode: 200;
      };
  "searchDocumentBaseConfig post /search/document-base-config":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["DocumentBaseConfig"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DocumentBaseConfig"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["DocumentBaseConfig"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DocumentBaseConfig"][];
        };
        responseCode: 200;
      };
  "searchDocumentBaseConfigSalesChannel post /search/document-base-config-sales-channel":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["DocumentBaseConfigSalesChannel"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DocumentBaseConfigSalesChannel"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["DocumentBaseConfigSalesChannel"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DocumentBaseConfigSalesChannel"][];
        };
        responseCode: 200;
      };
  "searchDocumentType post /search/document-type":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["DocumentType"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DocumentType"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["DocumentType"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DocumentType"][];
        };
        responseCode: 200;
      };
  "searchDsrAppointment post /search/dsr-appointment":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["DsrAppointment"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DsrAppointment"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["DsrAppointment"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DsrAppointment"][];
        };
        responseCode: 200;
      };
  "searchDsrAppointmentAttendee post /search/dsr-appointment-attendee":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["DsrAppointmentAttendee"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DsrAppointmentAttendee"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["DsrAppointmentAttendee"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DsrAppointmentAttendee"][];
        };
        responseCode: 200;
      };
  "searchDsrAppointmentRequest post /search/dsr-appointment-request":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["DsrAppointmentRequest"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DsrAppointmentRequest"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["DsrAppointmentRequest"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DsrAppointmentRequest"][];
        };
        responseCode: 200;
      };
  "searchDsrAppointmentVideoChat post /search/dsr-appointment-video-chat":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["DsrAppointmentVideoChat"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DsrAppointmentVideoChat"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["DsrAppointmentVideoChat"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DsrAppointmentVideoChat"][];
        };
        responseCode: 200;
      };
  "searchDsrAttendeeProductCollection post /search/dsr-attendee-product-collection":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["DsrAttendeeProductCollection"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DsrAttendeeProductCollection"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["DsrAttendeeProductCollection"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DsrAttendeeProductCollection"][];
        };
        responseCode: 200;
      };
  "searchDsrInteraction post /search/dsr-interaction":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["DsrInteraction"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DsrInteraction"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["DsrInteraction"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DsrInteraction"][];
        };
        responseCode: 200;
      };
  "searchDsrPresentation post /search/dsr-presentation":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["DsrPresentation"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DsrPresentation"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["DsrPresentation"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DsrPresentation"][];
        };
        responseCode: 200;
      };
  "searchDsrPresentationCmsPage post /search/dsr-presentation-cms-page":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["DsrPresentationCmsPage"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DsrPresentationCmsPage"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["DsrPresentationCmsPage"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["DsrPresentationCmsPage"][];
        };
        responseCode: 200;
      };
  "searchFlow post /search/flow":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["Flow"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Flow"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["Flow"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Flow"][];
        };
        responseCode: 200;
      };
  "searchFlowSequence post /search/flow-sequence":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["FlowSequence"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["FlowSequence"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["FlowSequence"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["FlowSequence"][];
        };
        responseCode: 200;
      };
  "searchFlowTemplate post /search/flow-template":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["FlowTemplate"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["FlowTemplate"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["FlowTemplate"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["FlowTemplate"][];
        };
        responseCode: 200;
      };
  "searchImportExportFile post /search/import-export-file":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["ImportExportFile"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ImportExportFile"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["ImportExportFile"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ImportExportFile"][];
        };
        responseCode: 200;
      };
  "searchImportExportLog post /search/import-export-log":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["ImportExportLog"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ImportExportLog"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["ImportExportLog"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ImportExportLog"][];
        };
        responseCode: 200;
      };
  "searchImportExportProfile post /search/import-export-profile":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["ImportExportProfile"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ImportExportProfile"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["ImportExportProfile"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ImportExportProfile"][];
        };
        responseCode: 200;
      };
  "searchIntegration post /search/integration":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["Integration"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Integration"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["Integration"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Integration"][];
        };
        responseCode: 200;
      };
  "searchLandingPage post /search/landing-page":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["LandingPage"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["LandingPage"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["LandingPage"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["LandingPage"][];
        };
        responseCode: 200;
      };
  "searchLanguage post /search/language":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["Language"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Language"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["Language"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Language"][];
        };
        responseCode: 200;
      };
  "searchLocale post /search/locale":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["Locale"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Locale"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["Locale"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Locale"][];
        };
        responseCode: 200;
      };
  "searchLogEntry post /search/log-entry":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["LogEntry"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["LogEntry"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["LogEntry"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["LogEntry"][];
        };
        responseCode: 200;
      };
  "searchMailHeaderFooter post /search/mail-header-footer":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["MailHeaderFooter"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MailHeaderFooter"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["MailHeaderFooter"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MailHeaderFooter"][];
        };
        responseCode: 200;
      };
  "searchMailTemplate post /search/mail-template":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["MailTemplate"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MailTemplate"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["MailTemplate"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MailTemplate"][];
        };
        responseCode: 200;
      };
  "searchMailTemplateType post /search/mail-template-type":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["MailTemplateType"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MailTemplateType"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["MailTemplateType"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MailTemplateType"][];
        };
        responseCode: 200;
      };
  "searchMainCategory post /search/main-category":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["MainCategory"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MainCategory"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["MainCategory"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MainCategory"][];
        };
        responseCode: 200;
      };
  "searchMedia post /search/media":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["Media"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Media"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["Media"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Media"][];
        };
        responseCode: 200;
      };
  "searchMediaAiTag post /search/media-ai-tag":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["MediaAiTag"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MediaAiTag"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["MediaAiTag"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MediaAiTag"][];
        };
        responseCode: 200;
      };
  "searchMediaDefaultFolder post /search/media-default-folder":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["MediaDefaultFolder"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MediaDefaultFolder"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["MediaDefaultFolder"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MediaDefaultFolder"][];
        };
        responseCode: 200;
      };
  "searchMediaFolder post /search/media-folder":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["MediaFolder"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MediaFolder"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["MediaFolder"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MediaFolder"][];
        };
        responseCode: 200;
      };
  "searchMediaFolderConfiguration post /search/media-folder-configuration":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["MediaFolderConfiguration"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MediaFolderConfiguration"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["MediaFolderConfiguration"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MediaFolderConfiguration"][];
        };
        responseCode: 200;
      };
  "searchMediaThumbnail post /search/media-thumbnail":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["MediaThumbnail"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MediaThumbnail"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["MediaThumbnail"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MediaThumbnail"][];
        };
        responseCode: 200;
      };
  "searchMediaThumbnailSize post /search/media-thumbnail-size":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["MediaThumbnailSize"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MediaThumbnailSize"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["MediaThumbnailSize"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["MediaThumbnailSize"][];
        };
        responseCode: 200;
      };
  "searchNewsletterRecipient post /search/newsletter-recipient":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["NewsletterRecipient"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["NewsletterRecipient"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["NewsletterRecipient"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["NewsletterRecipient"][];
        };
        responseCode: 200;
      };
  "searchNotification post /search/notification":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["Notification"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Notification"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["Notification"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Notification"][];
        };
        responseCode: 200;
      };
  "searchNumberRange post /search/number-range":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["NumberRange"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["NumberRange"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["NumberRange"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["NumberRange"][];
        };
        responseCode: 200;
      };
  "searchNumberRangeSalesChannel post /search/number-range-sales-channel":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["NumberRangeSalesChannel"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["NumberRangeSalesChannel"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["NumberRangeSalesChannel"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["NumberRangeSalesChannel"][];
        };
        responseCode: 200;
      };
  "searchNumberRangeState post /search/number-range-state":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["NumberRangeState"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["NumberRangeState"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["NumberRangeState"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["NumberRangeState"][];
        };
        responseCode: 200;
      };
  "searchNumberRangeType post /search/number-range-type":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["NumberRangeType"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["NumberRangeType"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["NumberRangeType"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["NumberRangeType"][];
        };
        responseCode: 200;
      };
  "searchOrder post /search/order":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["Order"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Order"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["Order"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Order"][];
        };
        responseCode: 200;
      };
  "searchOrderAddress post /search/order-address":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["OrderAddress"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderAddress"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["OrderAddress"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderAddress"][];
        };
        responseCode: 200;
      };
  "searchOrderCustomer post /search/order-customer":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["OrderCustomer"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderCustomer"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["OrderCustomer"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderCustomer"][];
        };
        responseCode: 200;
      };
  "searchOrderDelivery post /search/order-delivery":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["OrderDelivery"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderDelivery"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["OrderDelivery"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderDelivery"][];
        };
        responseCode: 200;
      };
  "searchOrderDeliveryPosition post /search/order-delivery-position":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["OrderDeliveryPosition"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderDeliveryPosition"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["OrderDeliveryPosition"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderDeliveryPosition"][];
        };
        responseCode: 200;
      };
  "searchOrderLineItem post /search/order-line-item":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["OrderLineItem"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderLineItem"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["OrderLineItem"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderLineItem"][];
        };
        responseCode: 200;
      };
  "searchOrderLineItemDownload post /search/order-line-item-download":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["OrderLineItemDownload"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderLineItemDownload"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["OrderLineItemDownload"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderLineItemDownload"][];
        };
        responseCode: 200;
      };
  "searchOrderProductWarehouse post /search/order-product-warehouse":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["OrderProductWarehouse"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderProductWarehouse"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["OrderProductWarehouse"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderProductWarehouse"][];
        };
        responseCode: 200;
      };
  "searchOrderReturn post /search/order-return":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["OrderReturn"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderReturn"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["OrderReturn"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderReturn"][];
        };
        responseCode: 200;
      };
  "searchOrderReturnLineItem post /search/order-return-line-item":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["OrderReturnLineItem"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderReturnLineItem"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["OrderReturnLineItem"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderReturnLineItem"][];
        };
        responseCode: 200;
      };
  "searchOrderReturnLineItemReason post /search/order-return-line-item-reason":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["OrderReturnLineItemReason"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderReturnLineItemReason"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["OrderReturnLineItemReason"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderReturnLineItemReason"][];
        };
        responseCode: 200;
      };
  "searchOrderTransaction post /search/order-transaction":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["OrderTransaction"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderTransaction"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["OrderTransaction"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderTransaction"][];
        };
        responseCode: 200;
      };
  "searchOrderTransactionCapture post /search/order-transaction-capture":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["OrderTransactionCapture"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderTransactionCapture"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["OrderTransactionCapture"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderTransactionCapture"][];
        };
        responseCode: 200;
      };
  "searchOrderTransactionCaptureRefund post /search/order-transaction-capture-refund":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["OrderTransactionCaptureRefund"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderTransactionCaptureRefund"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["OrderTransactionCaptureRefund"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderTransactionCaptureRefund"][];
        };
        responseCode: 200;
      };
  "searchOrderTransactionCaptureRefundPosition post /search/order-transaction-capture-refund-position":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["OrderTransactionCaptureRefundPosition"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderTransactionCaptureRefundPosition"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["OrderTransactionCaptureRefundPosition"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderTransactionCaptureRefundPosition"][];
        };
        responseCode: 200;
      };
  "searchOrderWarehouseGroup post /search/order-warehouse-group":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["OrderWarehouseGroup"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderWarehouseGroup"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["OrderWarehouseGroup"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["OrderWarehouseGroup"][];
        };
        responseCode: 200;
      };
  "searchPaymentMethod post /search/payment-method":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["PaymentMethod"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["PaymentMethod"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["PaymentMethod"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["PaymentMethod"][];
        };
        responseCode: 200;
      };
  "searchPlugin post /search/plugin":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["Plugin"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Plugin"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["Plugin"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Plugin"][];
        };
        responseCode: 200;
      };
  "searchProduct post /search/product":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["Product"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Product"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["Product"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Product"][];
        };
        responseCode: 200;
      };
  "searchProductConfiguratorSetting post /search/product-configurator-setting":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["ProductConfiguratorSetting"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductConfiguratorSetting"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["ProductConfiguratorSetting"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductConfiguratorSetting"][];
        };
        responseCode: 200;
      };
  "searchProductCrossSelling post /search/product-cross-selling":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["ProductCrossSelling"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductCrossSelling"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["ProductCrossSelling"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductCrossSelling"][];
        };
        responseCode: 200;
      };
  "searchProductCrossSellingAssignedProducts post /search/product-cross-selling-assigned-products":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["ProductCrossSellingAssignedProducts"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductCrossSellingAssignedProducts"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["ProductCrossSellingAssignedProducts"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductCrossSellingAssignedProducts"][];
        };
        responseCode: 200;
      };
  "searchProductDownload post /search/product-download":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["ProductDownload"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductDownload"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["ProductDownload"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductDownload"][];
        };
        responseCode: 200;
      };
  "searchProductExport post /search/product-export":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["ProductExport"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductExport"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["ProductExport"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductExport"][];
        };
        responseCode: 200;
      };
  "searchProductFeatureSet post /search/product-feature-set":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["ProductFeatureSet"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductFeatureSet"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["ProductFeatureSet"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductFeatureSet"][];
        };
        responseCode: 200;
      };
  "searchProductKeywordDictionary post /search/product-keyword-dictionary":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["ProductKeywordDictionary"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductKeywordDictionary"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["ProductKeywordDictionary"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductKeywordDictionary"][];
        };
        responseCode: 200;
      };
  "searchProductManufacturer post /search/product-manufacturer":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["ProductManufacturer"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductManufacturer"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["ProductManufacturer"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductManufacturer"][];
        };
        responseCode: 200;
      };
  "searchProductMedia post /search/product-media":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["ProductMedia"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductMedia"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["ProductMedia"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductMedia"][];
        };
        responseCode: 200;
      };
  "searchProductPrice post /search/product-price":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["ProductPrice"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductPrice"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["ProductPrice"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductPrice"][];
        };
        responseCode: 200;
      };
  "searchProductReview post /search/product-review":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["ProductReview"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductReview"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["ProductReview"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductReview"][];
        };
        responseCode: 200;
      };
  "searchProductReviewSummary post /search/product-review-summary":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["ProductReviewSummary"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductReviewSummary"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["ProductReviewSummary"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductReviewSummary"][];
        };
        responseCode: 200;
      };
  "searchProductSearchConfig post /search/product-search-config":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["ProductSearchConfig"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductSearchConfig"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["ProductSearchConfig"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductSearchConfig"][];
        };
        responseCode: 200;
      };
  "searchProductSearchConfigField post /search/product-search-config-field":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["ProductSearchConfigField"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductSearchConfigField"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["ProductSearchConfigField"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductSearchConfigField"][];
        };
        responseCode: 200;
      };
  "searchProductSearchKeyword post /search/product-search-keyword":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["ProductSearchKeyword"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductSearchKeyword"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["ProductSearchKeyword"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductSearchKeyword"][];
        };
        responseCode: 200;
      };
  "searchProductSorting post /search/product-sorting":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["ProductSorting"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductSorting"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["ProductSorting"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductSorting"][];
        };
        responseCode: 200;
      };
  "searchProductStream post /search/product-stream":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["ProductStream"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductStream"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["ProductStream"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductStream"][];
        };
        responseCode: 200;
      };
  "searchProductStreamFilter post /search/product-stream-filter":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["ProductStreamFilter"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductStreamFilter"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["ProductStreamFilter"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductStreamFilter"][];
        };
        responseCode: 200;
      };
  "searchProductVisibility post /search/product-visibility":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["ProductVisibility"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductVisibility"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["ProductVisibility"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductVisibility"][];
        };
        responseCode: 200;
      };
  "searchProductWarehouse post /search/product-warehouse":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["ProductWarehouse"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductWarehouse"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["ProductWarehouse"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ProductWarehouse"][];
        };
        responseCode: 200;
      };
  "searchPromotion post /search/promotion":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["Promotion"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Promotion"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["Promotion"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Promotion"][];
        };
        responseCode: 200;
      };
  "searchPromotionDiscount post /search/promotion-discount":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["PromotionDiscount"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["PromotionDiscount"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["PromotionDiscount"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["PromotionDiscount"][];
        };
        responseCode: 200;
      };
  "searchPromotionDiscountPrices post /search/promotion-discount-prices":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["PromotionDiscountPrices"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["PromotionDiscountPrices"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["PromotionDiscountPrices"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["PromotionDiscountPrices"][];
        };
        responseCode: 200;
      };
  "searchPromotionIndividualCode post /search/promotion-individual-code":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["PromotionIndividualCode"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["PromotionIndividualCode"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["PromotionIndividualCode"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["PromotionIndividualCode"][];
        };
        responseCode: 200;
      };
  "searchPromotionSalesChannel post /search/promotion-sales-channel":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["PromotionSalesChannel"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["PromotionSalesChannel"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["PromotionSalesChannel"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["PromotionSalesChannel"][];
        };
        responseCode: 200;
      };
  "searchPromotionSetgroup post /search/promotion-setgroup":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["PromotionSetgroup"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["PromotionSetgroup"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["PromotionSetgroup"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["PromotionSetgroup"][];
        };
        responseCode: 200;
      };
  "searchPropertyGroup post /search/property-group":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["PropertyGroup"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["PropertyGroup"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["PropertyGroup"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["PropertyGroup"][];
        };
        responseCode: 200;
      };
  "searchPropertyGroupOption post /search/property-group-option":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["PropertyGroupOption"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["PropertyGroupOption"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["PropertyGroupOption"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["PropertyGroupOption"][];
        };
        responseCode: 200;
      };
  "searchQuote post /search/quote":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["Quote"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Quote"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["Quote"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Quote"][];
        };
        responseCode: 200;
      };
  "searchQuoteComment post /search/quote-comment":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["QuoteComment"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["QuoteComment"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["QuoteComment"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["QuoteComment"][];
        };
        responseCode: 200;
      };
  "searchQuoteDelivery post /search/quote-delivery":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["QuoteDelivery"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["QuoteDelivery"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["QuoteDelivery"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["QuoteDelivery"][];
        };
        responseCode: 200;
      };
  "searchQuoteDeliveryPosition post /search/quote-delivery-position":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["QuoteDeliveryPosition"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["QuoteDeliveryPosition"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["QuoteDeliveryPosition"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["QuoteDeliveryPosition"][];
        };
        responseCode: 200;
      };
  "searchQuoteDocument post /search/quote-document":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["QuoteDocument"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["QuoteDocument"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["QuoteDocument"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["QuoteDocument"][];
        };
        responseCode: 200;
      };
  "searchQuoteEmployee post /search/quote-employee":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["QuoteEmployee"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["QuoteEmployee"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["QuoteEmployee"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["QuoteEmployee"][];
        };
        responseCode: 200;
      };
  "searchQuoteLineItem post /search/quote-line-item":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["QuoteLineItem"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["QuoteLineItem"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["QuoteLineItem"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["QuoteLineItem"][];
        };
        responseCode: 200;
      };
  "searchQuoteTransaction post /search/quote-transaction":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["QuoteTransaction"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["QuoteTransaction"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["QuoteTransaction"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["QuoteTransaction"][];
        };
        responseCode: 200;
      };
  "searchRule post /search/rule":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["Rule"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Rule"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["Rule"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Rule"][];
        };
        responseCode: 200;
      };
  "searchRuleCondition post /search/rule-condition":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["RuleCondition"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["RuleCondition"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["RuleCondition"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["RuleCondition"][];
        };
        responseCode: 200;
      };
  "searchSaasAppStorefrontConfig post /search/saas-app-storefront-config":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SaasAppStorefrontConfig"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SaasAppStorefrontConfig"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SaasAppStorefrontConfig"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SaasAppStorefrontConfig"][];
        };
        responseCode: 200;
      };
  "searchSaasSbpUserData post /search/saas-sbp-user-data":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SaasSbpUserData"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SaasSbpUserData"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SaasSbpUserData"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SaasSbpUserData"][];
        };
        responseCode: 200;
      };
  "searchSaasStorefrontDemoToken post /search/saas-storefront-demo-token":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SaasStorefrontDemoToken"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SaasStorefrontDemoToken"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SaasStorefrontDemoToken"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SaasStorefrontDemoToken"][];
        };
        responseCode: 200;
      };
  "searchSaasUserLoginToken post /search/saas-user-login-token":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SaasUserLoginToken"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SaasUserLoginToken"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SaasUserLoginToken"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SaasUserLoginToken"][];
        };
        responseCode: 200;
      };
  "searchSalesChannel post /search/sales-channel":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SalesChannel"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SalesChannel"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SalesChannel"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SalesChannel"][];
        };
        responseCode: 200;
      };
  "searchSalesChannelAnalytics post /search/sales-channel-analytics":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SalesChannelAnalytics"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SalesChannelAnalytics"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SalesChannelAnalytics"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SalesChannelAnalytics"][];
        };
        responseCode: 200;
      };
  "searchSalesChannelDomain post /search/sales-channel-domain":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SalesChannelDomain"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SalesChannelDomain"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SalesChannelDomain"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SalesChannelDomain"][];
        };
        responseCode: 200;
      };
  "searchSalesChannelType post /search/sales-channel-type":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SalesChannelType"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SalesChannelType"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SalesChannelType"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SalesChannelType"][];
        };
        responseCode: 200;
      };
  "searchSalutation post /search/salutation":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["Salutation"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Salutation"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["Salutation"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Salutation"][];
        };
        responseCode: 200;
      };
  "searchScheduledTask post /search/scheduled-task":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["ScheduledTask"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ScheduledTask"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["ScheduledTask"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ScheduledTask"][];
        };
        responseCode: 200;
      };
  "searchScript post /search/script":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["Script"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Script"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["Script"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Script"][];
        };
        responseCode: 200;
      };
  "searchSeoUrl post /search/seo-url":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SeoUrl"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SeoUrl"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SeoUrl"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SeoUrl"][];
        };
        responseCode: 200;
      };
  "searchSeoUrlTemplate post /search/seo-url-template":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SeoUrlTemplate"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SeoUrlTemplate"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SeoUrlTemplate"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SeoUrlTemplate"][];
        };
        responseCode: 200;
      };
  "searchShippingMethod post /search/shipping-method":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["ShippingMethod"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ShippingMethod"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["ShippingMethod"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ShippingMethod"][];
        };
        responseCode: 200;
      };
  "searchShippingMethodPrice post /search/shipping-method-price":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["ShippingMethodPrice"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ShippingMethodPrice"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["ShippingMethodPrice"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ShippingMethodPrice"][];
        };
        responseCode: 200;
      };
  "searchSnippet post /search/snippet":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["Snippet"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Snippet"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["Snippet"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Snippet"][];
        };
        responseCode: 200;
      };
  "searchSnippetSet post /search/snippet-set":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SnippetSet"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SnippetSet"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SnippetSet"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SnippetSet"][];
        };
        responseCode: 200;
      };
  "searchSpatialRenderConfigSize post /search/spatial-render-config-size":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SpatialRenderConfigSize"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SpatialRenderConfigSize"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SpatialRenderConfigSize"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SpatialRenderConfigSize"][];
        };
        responseCode: 200;
      };
  "searchSpatialScene post /search/spatial-scene":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SpatialScene"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SpatialScene"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SpatialScene"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SpatialScene"][];
        };
        responseCode: 200;
      };
  "searchSpatialSceneCamera post /search/spatial-scene-camera":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SpatialSceneCamera"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SpatialSceneCamera"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SpatialSceneCamera"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SpatialSceneCamera"][];
        };
        responseCode: 200;
      };
  "searchSpatialSceneLight post /search/spatial-scene-light":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SpatialSceneLight"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SpatialSceneLight"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SpatialSceneLight"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SpatialSceneLight"][];
        };
        responseCode: 200;
      };
  "searchSpatialSceneObject post /search/spatial-scene-object":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SpatialSceneObject"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SpatialSceneObject"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SpatialSceneObject"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SpatialSceneObject"][];
        };
        responseCode: 200;
      };
  "searchSsoProvider post /search/sso-provider":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SsoProvider"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SsoProvider"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SsoProvider"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SsoProvider"][];
        };
        responseCode: 200;
      };
  "searchSsoProviderCustomer post /search/sso-provider-customer":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SsoProviderCustomer"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SsoProviderCustomer"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SsoProviderCustomer"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SsoProviderCustomer"][];
        };
        responseCode: 200;
      };
  "searchStateMachine post /search/state-machine":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["StateMachine"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["StateMachine"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["StateMachine"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["StateMachine"][];
        };
        responseCode: 200;
      };
  "searchStateMachineHistory post /search/state-machine-history":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["StateMachineHistory"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["StateMachineHistory"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["StateMachineHistory"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["StateMachineHistory"][];
        };
        responseCode: 200;
      };
  "searchStateMachineState post /search/state-machine-state":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["StateMachineState"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["StateMachineState"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["StateMachineState"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["StateMachineState"][];
        };
        responseCode: 200;
      };
  "searchStateMachineTransition post /search/state-machine-transition":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["StateMachineTransition"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["StateMachineTransition"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["StateMachineTransition"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["StateMachineTransition"][];
        };
        responseCode: 200;
      };
  "searchSubscription post /search/subscription":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["Subscription"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Subscription"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["Subscription"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Subscription"][];
        };
        responseCode: 200;
      };
  "searchSubscriptionAddress post /search/subscription-address":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SubscriptionAddress"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SubscriptionAddress"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SubscriptionAddress"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SubscriptionAddress"][];
        };
        responseCode: 200;
      };
  "searchSubscriptionCustomer post /search/subscription-customer":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SubscriptionCustomer"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SubscriptionCustomer"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SubscriptionCustomer"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SubscriptionCustomer"][];
        };
        responseCode: 200;
      };
  "searchSubscriptionInterval post /search/subscription-interval":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SubscriptionInterval"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SubscriptionInterval"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SubscriptionInterval"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SubscriptionInterval"][];
        };
        responseCode: 200;
      };
  "searchSubscriptionPlan post /search/subscription-plan":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SubscriptionPlan"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SubscriptionPlan"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SubscriptionPlan"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SubscriptionPlan"][];
        };
        responseCode: 200;
      };
  "searchSwagCmsExtensionsBlockRule post /search/swag-cms-extensions-block-rule":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagCmsExtensionsBlockRule"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCmsExtensionsBlockRule"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagCmsExtensionsBlockRule"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCmsExtensionsBlockRule"][];
        };
        responseCode: 200;
      };
  "searchSwagCmsExtensionsForm post /search/swag-cms-extensions-form":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagCmsExtensionsForm"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCmsExtensionsForm"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagCmsExtensionsForm"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCmsExtensionsForm"][];
        };
        responseCode: 200;
      };
  "searchSwagCmsExtensionsFormGroup post /search/swag-cms-extensions-form-group":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagCmsExtensionsFormGroup"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCmsExtensionsFormGroup"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagCmsExtensionsFormGroup"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCmsExtensionsFormGroup"][];
        };
        responseCode: 200;
      };
  "searchSwagCmsExtensionsFormGroupField post /search/swag-cms-extensions-form-group-field":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagCmsExtensionsFormGroupField"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCmsExtensionsFormGroupField"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagCmsExtensionsFormGroupField"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCmsExtensionsFormGroupField"][];
        };
        responseCode: 200;
      };
  "searchSwagCmsExtensionsQuickview post /search/swag-cms-extensions-quickview":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagCmsExtensionsQuickview"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCmsExtensionsQuickview"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagCmsExtensionsQuickview"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCmsExtensionsQuickview"][];
        };
        responseCode: 200;
      };
  "searchSwagCmsExtensionsScrollNavigation post /search/swag-cms-extensions-scroll-navigation":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagCmsExtensionsScrollNavigation"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCmsExtensionsScrollNavigation"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagCmsExtensionsScrollNavigation"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCmsExtensionsScrollNavigation"][];
        };
        responseCode: 200;
      };
  "searchSwagCmsExtensionsScrollNavigationPageSettings post /search/swag-cms-extensions-scroll-navigation-page-settings":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagCmsExtensionsScrollNavigationPageSettings"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCmsExtensionsScrollNavigationPageSettings"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagCmsExtensionsScrollNavigationPageSettings"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCmsExtensionsScrollNavigationPageSettings"][];
        };
        responseCode: 200;
      };
  "searchSwagCustomizedProductsTemplate post /search/swag-customized-products-template":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagCustomizedProductsTemplate"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplate"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagCustomizedProductsTemplate"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplate"][];
        };
        responseCode: 200;
      };
  "searchSwagCustomizedProductsTemplateConfiguration post /search/swag-customized-products-template-configuration":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateConfiguration"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateConfiguration"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateConfiguration"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateConfiguration"][];
        };
        responseCode: 200;
      };
  "searchSwagCustomizedProductsTemplateConfigurationShare post /search/swag-customized-products-template-configuration-share":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateConfigurationShare"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateConfigurationShare"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateConfigurationShare"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateConfigurationShare"][];
        };
        responseCode: 200;
      };
  "searchSwagCustomizedProductsTemplateExclusion post /search/swag-customized-products-template-exclusion":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateExclusion"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateExclusion"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateExclusion"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateExclusion"][];
        };
        responseCode: 200;
      };
  "searchSwagCustomizedProductsTemplateExclusionCondition post /search/swag-customized-products-template-exclusion-condition":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateExclusionCondition"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateExclusionCondition"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateExclusionCondition"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateExclusionCondition"][];
        };
        responseCode: 200;
      };
  "searchSwagCustomizedProductsTemplateExclusionOperator post /search/swag-customized-products-template-exclusion-operator":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateExclusionOperator"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateExclusionOperator"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateExclusionOperator"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateExclusionOperator"][];
        };
        responseCode: 200;
      };
  "searchSwagCustomizedProductsTemplateOption post /search/swag-customized-products-template-option":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateOption"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateOption"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateOption"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateOption"][];
        };
        responseCode: 200;
      };
  "searchSwagCustomizedProductsTemplateOptionPrice post /search/swag-customized-products-template-option-price":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateOptionPrice"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateOptionPrice"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateOptionPrice"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateOptionPrice"][];
        };
        responseCode: 200;
      };
  "searchSwagCustomizedProductsTemplateOptionValue post /search/swag-customized-products-template-option-value":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateOptionValue"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateOptionValue"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateOptionValue"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateOptionValue"][];
        };
        responseCode: 200;
      };
  "searchSwagCustomizedProductsTemplateOptionValuePrice post /search/swag-customized-products-template-option-value-price":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateOptionValuePrice"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateOptionValuePrice"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateOptionValuePrice"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateOptionValuePrice"][];
        };
        responseCode: 200;
      };
  "searchSwagDelayAction post /search/swag-delay-action":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagDelayAction"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagDelayAction"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagDelayAction"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagDelayAction"][];
        };
        responseCode: 200;
      };
  "searchSwagLanguagePackLanguage post /search/swag-language-pack-language":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagLanguagePackLanguage"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagLanguagePackLanguage"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagLanguagePackLanguage"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagLanguagePackLanguage"][];
        };
        responseCode: 200;
      };
  "searchSwagMigrationConnection post /search/swag-migration-connection":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagMigrationConnection"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagMigrationConnection"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagMigrationConnection"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagMigrationConnection"][];
        };
        responseCode: 200;
      };
  "searchSwagMigrationData post /search/swag-migration-data":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagMigrationData"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagMigrationData"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagMigrationData"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagMigrationData"][];
        };
        responseCode: 200;
      };
  "searchSwagMigrationGeneralSetting post /search/swag-migration-general-setting":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagMigrationGeneralSetting"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagMigrationGeneralSetting"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagMigrationGeneralSetting"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagMigrationGeneralSetting"][];
        };
        responseCode: 200;
      };
  "searchSwagMigrationLogging post /search/swag-migration-logging":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagMigrationLogging"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagMigrationLogging"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagMigrationLogging"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagMigrationLogging"][];
        };
        responseCode: 200;
      };
  "searchSwagMigrationMapping post /search/swag-migration-mapping":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagMigrationMapping"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagMigrationMapping"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagMigrationMapping"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagMigrationMapping"][];
        };
        responseCode: 200;
      };
  "searchSwagMigrationMediaFile post /search/swag-migration-media-file":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagMigrationMediaFile"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagMigrationMediaFile"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagMigrationMediaFile"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagMigrationMediaFile"][];
        };
        responseCode: 200;
      };
  "searchSwagMigrationRun post /search/swag-migration-run":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagMigrationRun"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagMigrationRun"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagMigrationRun"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagMigrationRun"][];
        };
        responseCode: 200;
      };
  "searchSwagPaypalPosSalesChannel post /search/swag-paypal-pos-sales-channel":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagPaypalPosSalesChannel"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagPaypalPosSalesChannel"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagPaypalPosSalesChannel"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagPaypalPosSalesChannel"][];
        };
        responseCode: 200;
      };
  "searchSwagPaypalPosSalesChannelRun post /search/swag-paypal-pos-sales-channel-run":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagPaypalPosSalesChannelRun"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagPaypalPosSalesChannelRun"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagPaypalPosSalesChannelRun"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagPaypalPosSalesChannelRun"][];
        };
        responseCode: 200;
      };
  "searchSwagPaypalPosSalesChannelRunLog post /search/swag-paypal-pos-sales-channel-run-log":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagPaypalPosSalesChannelRunLog"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagPaypalPosSalesChannelRunLog"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagPaypalPosSalesChannelRunLog"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagPaypalPosSalesChannelRunLog"][];
        };
        responseCode: 200;
      };
  "searchSwagPaypalTransactionReport post /search/swag-paypal-transaction-report":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagPaypalTransactionReport"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagPaypalTransactionReport"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagPaypalTransactionReport"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagPaypalTransactionReport"][];
        };
        responseCode: 200;
      };
  "searchSwagPaypalVaultToken post /search/swag-paypal-vault-token":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagPaypalVaultToken"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagPaypalVaultToken"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagPaypalVaultToken"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagPaypalVaultToken"][];
        };
        responseCode: 200;
      };
  "searchSwagPaypalVaultTokenMapping post /search/swag-paypal-vault-token-mapping":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagPaypalVaultTokenMapping"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagPaypalVaultTokenMapping"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagPaypalVaultTokenMapping"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagPaypalVaultTokenMapping"][];
        };
        responseCode: 200;
      };
  "searchSwagSocialShoppingCustomer post /search/swag-social-shopping-customer":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagSocialShoppingCustomer"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagSocialShoppingCustomer"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagSocialShoppingCustomer"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagSocialShoppingCustomer"][];
        };
        responseCode: 200;
      };
  "searchSwagSocialShoppingOrder post /search/swag-social-shopping-order":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagSocialShoppingOrder"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagSocialShoppingOrder"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagSocialShoppingOrder"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagSocialShoppingOrder"][];
        };
        responseCode: 200;
      };
  "searchSwagSocialShoppingProductError post /search/swag-social-shopping-product-error":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagSocialShoppingProductError"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagSocialShoppingProductError"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagSocialShoppingProductError"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagSocialShoppingProductError"][];
        };
        responseCode: 200;
      };
  "searchSwagSocialShoppingSalesChannel post /search/swag-social-shopping-sales-channel":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagSocialShoppingSalesChannel"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagSocialShoppingSalesChannel"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SwagSocialShoppingSalesChannel"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagSocialShoppingSalesChannel"][];
        };
        responseCode: 200;
      };
  "searchSystemConfig post /search/system-config":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SystemConfig"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SystemConfig"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["SystemConfig"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SystemConfig"][];
        };
        responseCode: 200;
      };
  "searchTag post /search/tag":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["Tag"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Tag"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["Tag"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Tag"][];
        };
        responseCode: 200;
      };
  "searchTax post /search/tax":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["Tax"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Tax"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["Tax"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Tax"][];
        };
        responseCode: 200;
      };
  "searchTaxProvider post /search/tax-provider":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["TaxProvider"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["TaxProvider"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["TaxProvider"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["TaxProvider"][];
        };
        responseCode: 200;
      };
  "searchTaxRule post /search/tax-rule":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["TaxRule"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["TaxRule"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["TaxRule"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["TaxRule"][];
        };
        responseCode: 200;
      };
  "searchTaxRuleType post /search/tax-rule-type":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["TaxRuleType"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["TaxRuleType"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["TaxRuleType"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["TaxRuleType"][];
        };
        responseCode: 200;
      };
  "searchTheme post /search/theme":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["Theme"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Theme"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["Theme"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Theme"][];
        };
        responseCode: 200;
      };
  "searchUnit post /search/unit":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["Unit"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Unit"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["Unit"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Unit"][];
        };
        responseCode: 200;
      };
  "searchUser post /search/user":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["User"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["User"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["User"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["User"][];
        };
        responseCode: 200;
      };
  "searchUserAccessKey post /search/user-access-key":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["UserAccessKey"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["UserAccessKey"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["UserAccessKey"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["UserAccessKey"][];
        };
        responseCode: 200;
      };
  "searchUserConfig post /search/user-config":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["UserConfig"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["UserConfig"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["UserConfig"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["UserConfig"][];
        };
        responseCode: 200;
      };
  "searchUserRecovery post /search/user-recovery":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["UserRecovery"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["UserRecovery"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["UserRecovery"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["UserRecovery"][];
        };
        responseCode: 200;
      };
  "searchWarehouse post /search/warehouse":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["Warehouse"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Warehouse"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["Warehouse"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Warehouse"][];
        };
        responseCode: 200;
      };
  "searchWarehouseGroup post /search/warehouse-group":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["WarehouseGroup"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["WarehouseGroup"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["WarehouseGroup"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["WarehouseGroup"][];
        };
        responseCode: 200;
      };
  "searchWebhook post /search/webhook":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["Webhook"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Webhook"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["Webhook"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Webhook"][];
        };
        responseCode: 200;
      };
  "searchWebhookEventLog post /search/webhook-event-log":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["WebhookEventLog"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["WebhookEventLog"][];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        body: components["schemas"]["Criteria"];
        response: {
          data?: components["schemas"]["WebhookEventLog"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        body: components["schemas"]["Criteria"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["WebhookEventLog"][];
        };
        responseCode: 200;
      };
  "getSeoUrlList get /seo-url":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["SeoUrl"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["SeoUrl"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /seo-url?limit=25 */
            first?: unknown;
            /** @example /seo-url?limit=25&page=11 */
            last?: unknown;
            /** @example /seo-url?limit=25&page=4 */
            next?: unknown;
            /** @example /seo-url?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createSeoUrl post /seo-url":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SeoUrl"];
        response: {
          data: components["schemas"]["SeoUrl"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SeoUrl"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SeoUrl"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SeoUrl"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SeoUrl"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SeoUrl"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SeoUrl"];
        };
        responseCode: 200;
      };
  "getSeoUrlTemplateList get /seo-url-template":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["SeoUrlTemplate"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["SeoUrlTemplate"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /seo-url-template?limit=25 */
            first?: unknown;
            /** @example /seo-url-template?limit=25&page=11 */
            last?: unknown;
            /** @example /seo-url-template?limit=25&page=4 */
            next?: unknown;
            /** @example /seo-url-template?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createSeoUrlTemplate post /seo-url-template":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SeoUrlTemplate"];
        response: {
          data: components["schemas"]["SeoUrlTemplate"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SeoUrlTemplate"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SeoUrlTemplate"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SeoUrlTemplate"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SeoUrlTemplate"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SeoUrlTemplate"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SeoUrlTemplate"];
        };
        responseCode: 200;
      };
  "getSeoUrlTemplate get /seo-url-template/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the seo_url_template */
          id: string;
        };
        response: {
          data: components["schemas"]["SeoUrlTemplate"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the seo_url_template */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SeoUrlTemplate"];
        };
        responseCode: 200;
      };
  "deleteSeoUrlTemplate delete /seo-url-template/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the seo_url_template */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateSeoUrlTemplate patch /seo-url-template/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the seo_url_template */
          id: string;
        };
        body: components["schemas"]["SeoUrlTemplate"];
        response: {
          data: components["schemas"]["SeoUrlTemplate"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the seo_url_template */
          id: string;
        };
        body: components["schemas"]["SeoUrlTemplate"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SeoUrlTemplate"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the seo_url_template */
          id: string;
        };
        body: {
          data?: components["schemas"]["SeoUrlTemplate"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SeoUrlTemplate"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the seo_url_template */
          id: string;
        };
        body: {
          data?: components["schemas"]["SeoUrlTemplate"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SeoUrlTemplate"];
        };
        responseCode: 200;
      };
  "getSeoUrl get /seo-url/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the seo_url */
          id: string;
        };
        response: {
          data: components["schemas"]["SeoUrl"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the seo_url */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SeoUrl"];
        };
        responseCode: 200;
      };
  "deleteSeoUrl delete /seo-url/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the seo_url */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateSeoUrl patch /seo-url/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the seo_url */
          id: string;
        };
        body: components["schemas"]["SeoUrl"];
        response: {
          data: components["schemas"]["SeoUrl"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the seo_url */
          id: string;
        };
        body: components["schemas"]["SeoUrl"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SeoUrl"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the seo_url */
          id: string;
        };
        body: {
          data?: components["schemas"]["SeoUrl"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SeoUrl"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the seo_url */
          id: string;
        };
        body: {
          data?: components["schemas"]["SeoUrl"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SeoUrl"];
        };
        responseCode: 200;
      };
  "getShippingMethodList get /shipping-method":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["ShippingMethod"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["ShippingMethod"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /shipping-method?limit=25 */
            first?: unknown;
            /** @example /shipping-method?limit=25&page=11 */
            last?: unknown;
            /** @example /shipping-method?limit=25&page=4 */
            next?: unknown;
            /** @example /shipping-method?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createShippingMethod post /shipping-method":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["ShippingMethod"];
        response: {
          data: components["schemas"]["ShippingMethod"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["ShippingMethod"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ShippingMethod"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["ShippingMethod"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["ShippingMethod"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["ShippingMethod"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ShippingMethod"];
        };
        responseCode: 200;
      };
  "getShippingMethodPriceList get /shipping-method-price":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["ShippingMethodPrice"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["ShippingMethodPrice"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /shipping-method-price?limit=25 */
            first?: unknown;
            /** @example /shipping-method-price?limit=25&page=11 */
            last?: unknown;
            /** @example /shipping-method-price?limit=25&page=4 */
            next?: unknown;
            /** @example /shipping-method-price?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createShippingMethodPrice post /shipping-method-price":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["ShippingMethodPrice"];
        response: {
          data: components["schemas"]["ShippingMethodPrice"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["ShippingMethodPrice"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ShippingMethodPrice"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["ShippingMethodPrice"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["ShippingMethodPrice"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["ShippingMethodPrice"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ShippingMethodPrice"];
        };
        responseCode: 200;
      };
  "getShippingMethodPrice get /shipping-method-price/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the shipping_method_price */
          id: string;
        };
        response: {
          data: components["schemas"]["ShippingMethodPrice"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the shipping_method_price */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ShippingMethodPrice"];
        };
        responseCode: 200;
      };
  "deleteShippingMethodPrice delete /shipping-method-price/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the shipping_method_price */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateShippingMethodPrice patch /shipping-method-price/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the shipping_method_price */
          id: string;
        };
        body: components["schemas"]["ShippingMethodPrice"];
        response: {
          data: components["schemas"]["ShippingMethodPrice"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the shipping_method_price */
          id: string;
        };
        body: components["schemas"]["ShippingMethodPrice"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ShippingMethodPrice"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the shipping_method_price */
          id: string;
        };
        body: {
          data?: components["schemas"]["ShippingMethodPrice"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["ShippingMethodPrice"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the shipping_method_price */
          id: string;
        };
        body: {
          data?: components["schemas"]["ShippingMethodPrice"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ShippingMethodPrice"];
        };
        responseCode: 200;
      };
  "getShippingMethod get /shipping-method/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the shipping_method */
          id: string;
        };
        response: {
          data: components["schemas"]["ShippingMethod"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the shipping_method */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ShippingMethod"];
        };
        responseCode: 200;
      };
  "deleteShippingMethod delete /shipping-method/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the shipping_method */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateShippingMethod patch /shipping-method/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the shipping_method */
          id: string;
        };
        body: components["schemas"]["ShippingMethod"];
        response: {
          data: components["schemas"]["ShippingMethod"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the shipping_method */
          id: string;
        };
        body: components["schemas"]["ShippingMethod"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ShippingMethod"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the shipping_method */
          id: string;
        };
        body: {
          data?: components["schemas"]["ShippingMethod"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["ShippingMethod"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the shipping_method */
          id: string;
        };
        body: {
          data?: components["schemas"]["ShippingMethod"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["ShippingMethod"];
        };
        responseCode: 200;
      };
  "getSnippetList get /snippet":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["Snippet"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["Snippet"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /snippet?limit=25 */
            first?: unknown;
            /** @example /snippet?limit=25&page=11 */
            last?: unknown;
            /** @example /snippet?limit=25&page=4 */
            next?: unknown;
            /** @example /snippet?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createSnippet post /snippet":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["Snippet"];
        response: {
          data: components["schemas"]["Snippet"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["Snippet"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Snippet"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["Snippet"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["Snippet"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["Snippet"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Snippet"];
        };
        responseCode: 200;
      };
  "getSnippetSetList get /snippet-set":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["SnippetSet"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["SnippetSet"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /snippet-set?limit=25 */
            first?: unknown;
            /** @example /snippet-set?limit=25&page=11 */
            last?: unknown;
            /** @example /snippet-set?limit=25&page=4 */
            next?: unknown;
            /** @example /snippet-set?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createSnippetSet post /snippet-set":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SnippetSet"];
        response: {
          data: components["schemas"]["SnippetSet"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SnippetSet"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SnippetSet"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SnippetSet"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SnippetSet"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SnippetSet"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SnippetSet"];
        };
        responseCode: 200;
      };
  "getSnippetSet get /snippet-set/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the snippet_set */
          id: string;
        };
        response: {
          data: components["schemas"]["SnippetSet"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the snippet_set */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SnippetSet"];
        };
        responseCode: 200;
      };
  "deleteSnippetSet delete /snippet-set/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the snippet_set */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateSnippetSet patch /snippet-set/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the snippet_set */
          id: string;
        };
        body: components["schemas"]["SnippetSet"];
        response: {
          data: components["schemas"]["SnippetSet"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the snippet_set */
          id: string;
        };
        body: components["schemas"]["SnippetSet"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SnippetSet"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the snippet_set */
          id: string;
        };
        body: {
          data?: components["schemas"]["SnippetSet"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SnippetSet"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the snippet_set */
          id: string;
        };
        body: {
          data?: components["schemas"]["SnippetSet"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SnippetSet"];
        };
        responseCode: 200;
      };
  "getSnippet get /snippet/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the snippet */
          id: string;
        };
        response: {
          data: components["schemas"]["Snippet"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the snippet */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Snippet"];
        };
        responseCode: 200;
      };
  "deleteSnippet delete /snippet/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the snippet */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateSnippet patch /snippet/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the snippet */
          id: string;
        };
        body: components["schemas"]["Snippet"];
        response: {
          data: components["schemas"]["Snippet"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the snippet */
          id: string;
        };
        body: components["schemas"]["Snippet"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Snippet"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the snippet */
          id: string;
        };
        body: {
          data?: components["schemas"]["Snippet"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["Snippet"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the snippet */
          id: string;
        };
        body: {
          data?: components["schemas"]["Snippet"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Snippet"];
        };
        responseCode: 200;
      };
  "getSpatialRenderConfigSizeList get /spatial-render-config-size":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["SpatialRenderConfigSize"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["SpatialRenderConfigSize"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /spatial-render-config-size?limit=25 */
            first?: unknown;
            /** @example /spatial-render-config-size?limit=25&page=11 */
            last?: unknown;
            /** @example /spatial-render-config-size?limit=25&page=4 */
            next?: unknown;
            /** @example /spatial-render-config-size?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createSpatialRenderConfigSize post /spatial-render-config-size":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SpatialRenderConfigSize"];
        response: {
          data: components["schemas"]["SpatialRenderConfigSize"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SpatialRenderConfigSize"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SpatialRenderConfigSize"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SpatialRenderConfigSize"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SpatialRenderConfigSize"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SpatialRenderConfigSize"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SpatialRenderConfigSize"];
        };
        responseCode: 200;
      };
  "getSpatialRenderConfigSize get /spatial-render-config-size/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the spatial_render_config_size */
          id: string;
        };
        response: {
          data: components["schemas"]["SpatialRenderConfigSize"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the spatial_render_config_size */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SpatialRenderConfigSize"];
        };
        responseCode: 200;
      };
  "deleteSpatialRenderConfigSize delete /spatial-render-config-size/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the spatial_render_config_size */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateSpatialRenderConfigSize patch /spatial-render-config-size/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the spatial_render_config_size */
          id: string;
        };
        body: components["schemas"]["SpatialRenderConfigSize"];
        response: {
          data: components["schemas"]["SpatialRenderConfigSize"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the spatial_render_config_size */
          id: string;
        };
        body: components["schemas"]["SpatialRenderConfigSize"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SpatialRenderConfigSize"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the spatial_render_config_size */
          id: string;
        };
        body: {
          data?: components["schemas"]["SpatialRenderConfigSize"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SpatialRenderConfigSize"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the spatial_render_config_size */
          id: string;
        };
        body: {
          data?: components["schemas"]["SpatialRenderConfigSize"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SpatialRenderConfigSize"];
        };
        responseCode: 200;
      };
  "getSpatialSceneList get /spatial-scene":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["SpatialScene"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["SpatialScene"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /spatial-scene?limit=25 */
            first?: unknown;
            /** @example /spatial-scene?limit=25&page=11 */
            last?: unknown;
            /** @example /spatial-scene?limit=25&page=4 */
            next?: unknown;
            /** @example /spatial-scene?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createSpatialScene post /spatial-scene":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SpatialScene"];
        response: {
          data: components["schemas"]["SpatialScene"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SpatialScene"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SpatialScene"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SpatialScene"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SpatialScene"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SpatialScene"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SpatialScene"];
        };
        responseCode: 200;
      };
  "getSpatialSceneCameraList get /spatial-scene-camera":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["SpatialSceneCamera"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["SpatialSceneCamera"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /spatial-scene-camera?limit=25 */
            first?: unknown;
            /** @example /spatial-scene-camera?limit=25&page=11 */
            last?: unknown;
            /** @example /spatial-scene-camera?limit=25&page=4 */
            next?: unknown;
            /** @example /spatial-scene-camera?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createSpatialSceneCamera post /spatial-scene-camera":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SpatialSceneCamera"];
        response: {
          data: components["schemas"]["SpatialSceneCamera"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SpatialSceneCamera"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SpatialSceneCamera"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SpatialSceneCamera"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SpatialSceneCamera"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SpatialSceneCamera"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SpatialSceneCamera"];
        };
        responseCode: 200;
      };
  "getSpatialSceneCamera get /spatial-scene-camera/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the spatial_scene_camera */
          id: string;
        };
        response: {
          data: components["schemas"]["SpatialSceneCamera"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the spatial_scene_camera */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SpatialSceneCamera"];
        };
        responseCode: 200;
      };
  "deleteSpatialSceneCamera delete /spatial-scene-camera/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the spatial_scene_camera */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateSpatialSceneCamera patch /spatial-scene-camera/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the spatial_scene_camera */
          id: string;
        };
        body: components["schemas"]["SpatialSceneCamera"];
        response: {
          data: components["schemas"]["SpatialSceneCamera"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the spatial_scene_camera */
          id: string;
        };
        body: components["schemas"]["SpatialSceneCamera"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SpatialSceneCamera"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the spatial_scene_camera */
          id: string;
        };
        body: {
          data?: components["schemas"]["SpatialSceneCamera"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SpatialSceneCamera"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the spatial_scene_camera */
          id: string;
        };
        body: {
          data?: components["schemas"]["SpatialSceneCamera"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SpatialSceneCamera"];
        };
        responseCode: 200;
      };
  "getSpatialSceneLightList get /spatial-scene-light":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["SpatialSceneLight"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["SpatialSceneLight"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /spatial-scene-light?limit=25 */
            first?: unknown;
            /** @example /spatial-scene-light?limit=25&page=11 */
            last?: unknown;
            /** @example /spatial-scene-light?limit=25&page=4 */
            next?: unknown;
            /** @example /spatial-scene-light?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createSpatialSceneLight post /spatial-scene-light":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SpatialSceneLight"];
        response: {
          data: components["schemas"]["SpatialSceneLight"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SpatialSceneLight"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SpatialSceneLight"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SpatialSceneLight"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SpatialSceneLight"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SpatialSceneLight"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SpatialSceneLight"];
        };
        responseCode: 200;
      };
  "getSpatialSceneLight get /spatial-scene-light/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the spatial_scene_light */
          id: string;
        };
        response: {
          data: components["schemas"]["SpatialSceneLight"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the spatial_scene_light */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SpatialSceneLight"];
        };
        responseCode: 200;
      };
  "deleteSpatialSceneLight delete /spatial-scene-light/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the spatial_scene_light */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateSpatialSceneLight patch /spatial-scene-light/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the spatial_scene_light */
          id: string;
        };
        body: components["schemas"]["SpatialSceneLight"];
        response: {
          data: components["schemas"]["SpatialSceneLight"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the spatial_scene_light */
          id: string;
        };
        body: components["schemas"]["SpatialSceneLight"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SpatialSceneLight"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the spatial_scene_light */
          id: string;
        };
        body: {
          data?: components["schemas"]["SpatialSceneLight"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SpatialSceneLight"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the spatial_scene_light */
          id: string;
        };
        body: {
          data?: components["schemas"]["SpatialSceneLight"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SpatialSceneLight"];
        };
        responseCode: 200;
      };
  "getSpatialSceneObjectList get /spatial-scene-object":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["SpatialSceneObject"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["SpatialSceneObject"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /spatial-scene-object?limit=25 */
            first?: unknown;
            /** @example /spatial-scene-object?limit=25&page=11 */
            last?: unknown;
            /** @example /spatial-scene-object?limit=25&page=4 */
            next?: unknown;
            /** @example /spatial-scene-object?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createSpatialSceneObject post /spatial-scene-object":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SpatialSceneObject"];
        response: {
          data: components["schemas"]["SpatialSceneObject"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SpatialSceneObject"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SpatialSceneObject"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SpatialSceneObject"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SpatialSceneObject"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SpatialSceneObject"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SpatialSceneObject"];
        };
        responseCode: 200;
      };
  "getSpatialSceneObject get /spatial-scene-object/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the spatial_scene_object */
          id: string;
        };
        response: {
          data: components["schemas"]["SpatialSceneObject"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the spatial_scene_object */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SpatialSceneObject"];
        };
        responseCode: 200;
      };
  "deleteSpatialSceneObject delete /spatial-scene-object/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the spatial_scene_object */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateSpatialSceneObject patch /spatial-scene-object/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the spatial_scene_object */
          id: string;
        };
        body: components["schemas"]["SpatialSceneObject"];
        response: {
          data: components["schemas"]["SpatialSceneObject"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the spatial_scene_object */
          id: string;
        };
        body: components["schemas"]["SpatialSceneObject"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SpatialSceneObject"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the spatial_scene_object */
          id: string;
        };
        body: {
          data?: components["schemas"]["SpatialSceneObject"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SpatialSceneObject"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the spatial_scene_object */
          id: string;
        };
        body: {
          data?: components["schemas"]["SpatialSceneObject"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SpatialSceneObject"];
        };
        responseCode: 200;
      };
  "getSpatialScene get /spatial-scene/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the spatial_scene */
          id: string;
        };
        response: {
          data: components["schemas"]["SpatialScene"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the spatial_scene */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SpatialScene"];
        };
        responseCode: 200;
      };
  "deleteSpatialScene delete /spatial-scene/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the spatial_scene */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateSpatialScene patch /spatial-scene/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the spatial_scene */
          id: string;
        };
        body: components["schemas"]["SpatialScene"];
        response: {
          data: components["schemas"]["SpatialScene"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the spatial_scene */
          id: string;
        };
        body: components["schemas"]["SpatialScene"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SpatialScene"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the spatial_scene */
          id: string;
        };
        body: {
          data?: components["schemas"]["SpatialScene"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SpatialScene"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the spatial_scene */
          id: string;
        };
        body: {
          data?: components["schemas"]["SpatialScene"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SpatialScene"];
        };
        responseCode: 200;
      };
  "getSsoProviderList get /sso-provider":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["SsoProvider"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["SsoProvider"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /sso-provider?limit=25 */
            first?: unknown;
            /** @example /sso-provider?limit=25&page=11 */
            last?: unknown;
            /** @example /sso-provider?limit=25&page=4 */
            next?: unknown;
            /** @example /sso-provider?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createSsoProvider post /sso-provider":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SsoProvider"];
        response: {
          data: components["schemas"]["SsoProvider"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SsoProvider"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SsoProvider"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SsoProvider"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SsoProvider"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SsoProvider"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SsoProvider"];
        };
        responseCode: 200;
      };
  "getSsoProviderCustomerList get /sso-provider-customer":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["SsoProviderCustomer"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["SsoProviderCustomer"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /sso-provider-customer?limit=25 */
            first?: unknown;
            /** @example /sso-provider-customer?limit=25&page=11 */
            last?: unknown;
            /** @example /sso-provider-customer?limit=25&page=4 */
            next?: unknown;
            /** @example /sso-provider-customer?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createSsoProviderCustomer post /sso-provider-customer":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SsoProviderCustomer"];
        response: {
          data: components["schemas"]["SsoProviderCustomer"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SsoProviderCustomer"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SsoProviderCustomer"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SsoProviderCustomer"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SsoProviderCustomer"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SsoProviderCustomer"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SsoProviderCustomer"];
        };
        responseCode: 200;
      };
  "getSsoProviderCustomer get /sso-provider-customer/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the sso_provider_customer */
          id: string;
        };
        response: {
          data: components["schemas"]["SsoProviderCustomer"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the sso_provider_customer */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SsoProviderCustomer"];
        };
        responseCode: 200;
      };
  "deleteSsoProviderCustomer delete /sso-provider-customer/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the sso_provider_customer */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateSsoProviderCustomer patch /sso-provider-customer/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the sso_provider_customer */
          id: string;
        };
        body: components["schemas"]["SsoProviderCustomer"];
        response: {
          data: components["schemas"]["SsoProviderCustomer"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the sso_provider_customer */
          id: string;
        };
        body: components["schemas"]["SsoProviderCustomer"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SsoProviderCustomer"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the sso_provider_customer */
          id: string;
        };
        body: {
          data?: components["schemas"]["SsoProviderCustomer"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SsoProviderCustomer"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the sso_provider_customer */
          id: string;
        };
        body: {
          data?: components["schemas"]["SsoProviderCustomer"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SsoProviderCustomer"];
        };
        responseCode: 200;
      };
  "getSsoProvider get /sso-provider/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the sso_provider */
          id: string;
        };
        response: {
          data: components["schemas"]["SsoProvider"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the sso_provider */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SsoProvider"];
        };
        responseCode: 200;
      };
  "deleteSsoProvider delete /sso-provider/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the sso_provider */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateSsoProvider patch /sso-provider/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the sso_provider */
          id: string;
        };
        body: components["schemas"]["SsoProvider"];
        response: {
          data: components["schemas"]["SsoProvider"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the sso_provider */
          id: string;
        };
        body: components["schemas"]["SsoProvider"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SsoProvider"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the sso_provider */
          id: string;
        };
        body: {
          data?: components["schemas"]["SsoProvider"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SsoProvider"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the sso_provider */
          id: string;
        };
        body: {
          data?: components["schemas"]["SsoProvider"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SsoProvider"];
        };
        responseCode: 200;
      };
  "getStateMachineList get /state-machine":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["StateMachine"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["StateMachine"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /state-machine?limit=25 */
            first?: unknown;
            /** @example /state-machine?limit=25&page=11 */
            last?: unknown;
            /** @example /state-machine?limit=25&page=4 */
            next?: unknown;
            /** @example /state-machine?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createStateMachine post /state-machine":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["StateMachine"];
        response: {
          data: components["schemas"]["StateMachine"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["StateMachine"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["StateMachine"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["StateMachine"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["StateMachine"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["StateMachine"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["StateMachine"];
        };
        responseCode: 200;
      };
  "getStateMachineHistoryList get /state-machine-history":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["StateMachineHistory"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["StateMachineHistory"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /state-machine-history?limit=25 */
            first?: unknown;
            /** @example /state-machine-history?limit=25&page=11 */
            last?: unknown;
            /** @example /state-machine-history?limit=25&page=4 */
            next?: unknown;
            /** @example /state-machine-history?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createStateMachineHistory post /state-machine-history":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["StateMachineHistory"];
        response: {
          data: components["schemas"]["StateMachineHistory"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["StateMachineHistory"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["StateMachineHistory"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["StateMachineHistory"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["StateMachineHistory"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["StateMachineHistory"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["StateMachineHistory"];
        };
        responseCode: 200;
      };
  "getStateMachineHistory get /state-machine-history/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the state_machine_history */
          id: string;
        };
        response: {
          data: components["schemas"]["StateMachineHistory"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the state_machine_history */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["StateMachineHistory"];
        };
        responseCode: 200;
      };
  "deleteStateMachineHistory delete /state-machine-history/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the state_machine_history */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateStateMachineHistory patch /state-machine-history/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the state_machine_history */
          id: string;
        };
        body: components["schemas"]["StateMachineHistory"];
        response: {
          data: components["schemas"]["StateMachineHistory"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the state_machine_history */
          id: string;
        };
        body: components["schemas"]["StateMachineHistory"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["StateMachineHistory"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the state_machine_history */
          id: string;
        };
        body: {
          data?: components["schemas"]["StateMachineHistory"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["StateMachineHistory"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the state_machine_history */
          id: string;
        };
        body: {
          data?: components["schemas"]["StateMachineHistory"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["StateMachineHistory"];
        };
        responseCode: 200;
      };
  "getStateMachineStateList get /state-machine-state":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["StateMachineState"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["StateMachineState"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /state-machine-state?limit=25 */
            first?: unknown;
            /** @example /state-machine-state?limit=25&page=11 */
            last?: unknown;
            /** @example /state-machine-state?limit=25&page=4 */
            next?: unknown;
            /** @example /state-machine-state?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createStateMachineState post /state-machine-state":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["StateMachineState"];
        response: {
          data: components["schemas"]["StateMachineState"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["StateMachineState"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["StateMachineState"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["StateMachineState"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["StateMachineState"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["StateMachineState"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["StateMachineState"];
        };
        responseCode: 200;
      };
  "getStateMachineState get /state-machine-state/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the state_machine_state */
          id: string;
        };
        response: {
          data: components["schemas"]["StateMachineState"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the state_machine_state */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["StateMachineState"];
        };
        responseCode: 200;
      };
  "deleteStateMachineState delete /state-machine-state/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the state_machine_state */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateStateMachineState patch /state-machine-state/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the state_machine_state */
          id: string;
        };
        body: components["schemas"]["StateMachineState"];
        response: {
          data: components["schemas"]["StateMachineState"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the state_machine_state */
          id: string;
        };
        body: components["schemas"]["StateMachineState"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["StateMachineState"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the state_machine_state */
          id: string;
        };
        body: {
          data?: components["schemas"]["StateMachineState"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["StateMachineState"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the state_machine_state */
          id: string;
        };
        body: {
          data?: components["schemas"]["StateMachineState"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["StateMachineState"];
        };
        responseCode: 200;
      };
  "getStateMachineTransitionList get /state-machine-transition":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["StateMachineTransition"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["StateMachineTransition"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /state-machine-transition?limit=25 */
            first?: unknown;
            /** @example /state-machine-transition?limit=25&page=11 */
            last?: unknown;
            /** @example /state-machine-transition?limit=25&page=4 */
            next?: unknown;
            /** @example /state-machine-transition?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createStateMachineTransition post /state-machine-transition":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["StateMachineTransition"];
        response: {
          data: components["schemas"]["StateMachineTransition"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["StateMachineTransition"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["StateMachineTransition"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["StateMachineTransition"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["StateMachineTransition"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["StateMachineTransition"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["StateMachineTransition"];
        };
        responseCode: 200;
      };
  "getStateMachineTransition get /state-machine-transition/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the state_machine_transition */
          id: string;
        };
        response: {
          data: components["schemas"]["StateMachineTransition"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the state_machine_transition */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["StateMachineTransition"];
        };
        responseCode: 200;
      };
  "deleteStateMachineTransition delete /state-machine-transition/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the state_machine_transition */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateStateMachineTransition patch /state-machine-transition/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the state_machine_transition */
          id: string;
        };
        body: components["schemas"]["StateMachineTransition"];
        response: {
          data: components["schemas"]["StateMachineTransition"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the state_machine_transition */
          id: string;
        };
        body: components["schemas"]["StateMachineTransition"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["StateMachineTransition"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the state_machine_transition */
          id: string;
        };
        body: {
          data?: components["schemas"]["StateMachineTransition"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["StateMachineTransition"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the state_machine_transition */
          id: string;
        };
        body: {
          data?: components["schemas"]["StateMachineTransition"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["StateMachineTransition"];
        };
        responseCode: 200;
      };
  "getStateMachine get /state-machine/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the state_machine */
          id: string;
        };
        response: {
          data: components["schemas"]["StateMachine"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the state_machine */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["StateMachine"];
        };
        responseCode: 200;
      };
  "deleteStateMachine delete /state-machine/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the state_machine */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateStateMachine patch /state-machine/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the state_machine */
          id: string;
        };
        body: components["schemas"]["StateMachine"];
        response: {
          data: components["schemas"]["StateMachine"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the state_machine */
          id: string;
        };
        body: components["schemas"]["StateMachine"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["StateMachine"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the state_machine */
          id: string;
        };
        body: {
          data?: components["schemas"]["StateMachine"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["StateMachine"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the state_machine */
          id: string;
        };
        body: {
          data?: components["schemas"]["StateMachine"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["StateMachine"];
        };
        responseCode: 200;
      };
  "getSubscriptionList get /subscription":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["Subscription"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["Subscription"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /subscription?limit=25 */
            first?: unknown;
            /** @example /subscription?limit=25&page=11 */
            last?: unknown;
            /** @example /subscription?limit=25&page=4 */
            next?: unknown;
            /** @example /subscription?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createSubscription post /subscription":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["Subscription"];
        response: {
          data: components["schemas"]["Subscription"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["Subscription"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Subscription"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["Subscription"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["Subscription"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["Subscription"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Subscription"];
        };
        responseCode: 200;
      };
  "getSubscriptionAddressList get /subscription-address":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["SubscriptionAddress"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["SubscriptionAddress"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /subscription-address?limit=25 */
            first?: unknown;
            /** @example /subscription-address?limit=25&page=11 */
            last?: unknown;
            /** @example /subscription-address?limit=25&page=4 */
            next?: unknown;
            /** @example /subscription-address?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createSubscriptionAddress post /subscription-address":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SubscriptionAddress"];
        response: {
          data: components["schemas"]["SubscriptionAddress"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SubscriptionAddress"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SubscriptionAddress"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SubscriptionAddress"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SubscriptionAddress"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SubscriptionAddress"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SubscriptionAddress"];
        };
        responseCode: 200;
      };
  "getSubscriptionAddress get /subscription-address/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the subscription_address */
          id: string;
        };
        response: {
          data: components["schemas"]["SubscriptionAddress"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the subscription_address */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SubscriptionAddress"];
        };
        responseCode: 200;
      };
  "deleteSubscriptionAddress delete /subscription-address/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the subscription_address */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateSubscriptionAddress patch /subscription-address/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the subscription_address */
          id: string;
        };
        body: components["schemas"]["SubscriptionAddress"];
        response: {
          data: components["schemas"]["SubscriptionAddress"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the subscription_address */
          id: string;
        };
        body: components["schemas"]["SubscriptionAddress"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SubscriptionAddress"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the subscription_address */
          id: string;
        };
        body: {
          data?: components["schemas"]["SubscriptionAddress"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SubscriptionAddress"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the subscription_address */
          id: string;
        };
        body: {
          data?: components["schemas"]["SubscriptionAddress"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SubscriptionAddress"];
        };
        responseCode: 200;
      };
  "getSubscriptionCustomerList get /subscription-customer":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["SubscriptionCustomer"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["SubscriptionCustomer"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /subscription-customer?limit=25 */
            first?: unknown;
            /** @example /subscription-customer?limit=25&page=11 */
            last?: unknown;
            /** @example /subscription-customer?limit=25&page=4 */
            next?: unknown;
            /** @example /subscription-customer?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createSubscriptionCustomer post /subscription-customer":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SubscriptionCustomer"];
        response: {
          data: components["schemas"]["SubscriptionCustomer"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SubscriptionCustomer"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SubscriptionCustomer"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SubscriptionCustomer"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SubscriptionCustomer"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SubscriptionCustomer"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SubscriptionCustomer"];
        };
        responseCode: 200;
      };
  "getSubscriptionCustomer get /subscription-customer/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the subscription_customer */
          id: string;
        };
        response: {
          data: components["schemas"]["SubscriptionCustomer"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the subscription_customer */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SubscriptionCustomer"];
        };
        responseCode: 200;
      };
  "deleteSubscriptionCustomer delete /subscription-customer/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the subscription_customer */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateSubscriptionCustomer patch /subscription-customer/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the subscription_customer */
          id: string;
        };
        body: components["schemas"]["SubscriptionCustomer"];
        response: {
          data: components["schemas"]["SubscriptionCustomer"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the subscription_customer */
          id: string;
        };
        body: components["schemas"]["SubscriptionCustomer"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SubscriptionCustomer"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the subscription_customer */
          id: string;
        };
        body: {
          data?: components["schemas"]["SubscriptionCustomer"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SubscriptionCustomer"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the subscription_customer */
          id: string;
        };
        body: {
          data?: components["schemas"]["SubscriptionCustomer"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SubscriptionCustomer"];
        };
        responseCode: 200;
      };
  "getSubscriptionIntervalList get /subscription-interval":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["SubscriptionInterval"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["SubscriptionInterval"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /subscription-interval?limit=25 */
            first?: unknown;
            /** @example /subscription-interval?limit=25&page=11 */
            last?: unknown;
            /** @example /subscription-interval?limit=25&page=4 */
            next?: unknown;
            /** @example /subscription-interval?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createSubscriptionInterval post /subscription-interval":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SubscriptionInterval"];
        response: {
          data: components["schemas"]["SubscriptionInterval"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SubscriptionInterval"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SubscriptionInterval"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SubscriptionInterval"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SubscriptionInterval"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SubscriptionInterval"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SubscriptionInterval"];
        };
        responseCode: 200;
      };
  "getSubscriptionInterval get /subscription-interval/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the subscription_interval */
          id: string;
        };
        response: {
          data: components["schemas"]["SubscriptionInterval"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the subscription_interval */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SubscriptionInterval"];
        };
        responseCode: 200;
      };
  "deleteSubscriptionInterval delete /subscription-interval/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the subscription_interval */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateSubscriptionInterval patch /subscription-interval/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the subscription_interval */
          id: string;
        };
        body: components["schemas"]["SubscriptionInterval"];
        response: {
          data: components["schemas"]["SubscriptionInterval"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the subscription_interval */
          id: string;
        };
        body: components["schemas"]["SubscriptionInterval"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SubscriptionInterval"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the subscription_interval */
          id: string;
        };
        body: {
          data?: components["schemas"]["SubscriptionInterval"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SubscriptionInterval"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the subscription_interval */
          id: string;
        };
        body: {
          data?: components["schemas"]["SubscriptionInterval"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SubscriptionInterval"];
        };
        responseCode: 200;
      };
  "getSubscriptionPlanList get /subscription-plan":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["SubscriptionPlan"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["SubscriptionPlan"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /subscription-plan?limit=25 */
            first?: unknown;
            /** @example /subscription-plan?limit=25&page=11 */
            last?: unknown;
            /** @example /subscription-plan?limit=25&page=4 */
            next?: unknown;
            /** @example /subscription-plan?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createSubscriptionPlan post /subscription-plan":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SubscriptionPlan"];
        response: {
          data: components["schemas"]["SubscriptionPlan"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SubscriptionPlan"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SubscriptionPlan"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SubscriptionPlan"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SubscriptionPlan"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SubscriptionPlan"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SubscriptionPlan"];
        };
        responseCode: 200;
      };
  "getSubscriptionPlan get /subscription-plan/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the subscription_plan */
          id: string;
        };
        response: {
          data: components["schemas"]["SubscriptionPlan"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the subscription_plan */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SubscriptionPlan"];
        };
        responseCode: 200;
      };
  "deleteSubscriptionPlan delete /subscription-plan/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the subscription_plan */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateSubscriptionPlan patch /subscription-plan/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the subscription_plan */
          id: string;
        };
        body: components["schemas"]["SubscriptionPlan"];
        response: {
          data: components["schemas"]["SubscriptionPlan"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the subscription_plan */
          id: string;
        };
        body: components["schemas"]["SubscriptionPlan"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SubscriptionPlan"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the subscription_plan */
          id: string;
        };
        body: {
          data?: components["schemas"]["SubscriptionPlan"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SubscriptionPlan"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the subscription_plan */
          id: string;
        };
        body: {
          data?: components["schemas"]["SubscriptionPlan"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SubscriptionPlan"];
        };
        responseCode: 200;
      };
  "getSubscription get /subscription/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the subscription */
          id: string;
        };
        response: {
          data: components["schemas"]["Subscription"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the subscription */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Subscription"];
        };
        responseCode: 200;
      };
  "deleteSubscription delete /subscription/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the subscription */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateSubscription patch /subscription/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the subscription */
          id: string;
        };
        body: components["schemas"]["Subscription"];
        response: {
          data: components["schemas"]["Subscription"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the subscription */
          id: string;
        };
        body: components["schemas"]["Subscription"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Subscription"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the subscription */
          id: string;
        };
        body: {
          data?: components["schemas"]["Subscription"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["Subscription"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the subscription */
          id: string;
        };
        body: {
          data?: components["schemas"]["Subscription"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Subscription"];
        };
        responseCode: 200;
      };
  "getSwagCmsExtensionsBlockRuleList get /swag-cms-extensions-block-rule":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["SwagCmsExtensionsBlockRule"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["SwagCmsExtensionsBlockRule"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /swag-cms-extensions-block-rule?limit=25 */
            first?: unknown;
            /** @example /swag-cms-extensions-block-rule?limit=25&page=11 */
            last?: unknown;
            /** @example /swag-cms-extensions-block-rule?limit=25&page=4 */
            next?: unknown;
            /** @example /swag-cms-extensions-block-rule?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createSwagCmsExtensionsBlockRule post /swag-cms-extensions-block-rule":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagCmsExtensionsBlockRule"];
        response: {
          data: components["schemas"]["SwagCmsExtensionsBlockRule"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagCmsExtensionsBlockRule"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCmsExtensionsBlockRule"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagCmsExtensionsBlockRule"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagCmsExtensionsBlockRule"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagCmsExtensionsBlockRule"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCmsExtensionsBlockRule"];
        };
        responseCode: 200;
      };
  "getSwagCmsExtensionsBlockRule get /swag-cms-extensions-block-rule/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the swag_cms_extensions_block_rule */
          id: string;
        };
        response: {
          data: components["schemas"]["SwagCmsExtensionsBlockRule"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the swag_cms_extensions_block_rule */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCmsExtensionsBlockRule"];
        };
        responseCode: 200;
      };
  "deleteSwagCmsExtensionsBlockRule delete /swag-cms-extensions-block-rule/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the swag_cms_extensions_block_rule */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateSwagCmsExtensionsBlockRule patch /swag-cms-extensions-block-rule/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_cms_extensions_block_rule */
          id: string;
        };
        body: components["schemas"]["SwagCmsExtensionsBlockRule"];
        response: {
          data: components["schemas"]["SwagCmsExtensionsBlockRule"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_cms_extensions_block_rule */
          id: string;
        };
        body: components["schemas"]["SwagCmsExtensionsBlockRule"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCmsExtensionsBlockRule"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_cms_extensions_block_rule */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagCmsExtensionsBlockRule"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagCmsExtensionsBlockRule"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_cms_extensions_block_rule */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagCmsExtensionsBlockRule"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCmsExtensionsBlockRule"];
        };
        responseCode: 200;
      };
  "getSwagCmsExtensionsFormList get /swag-cms-extensions-form":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["SwagCmsExtensionsForm"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["SwagCmsExtensionsForm"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /swag-cms-extensions-form?limit=25 */
            first?: unknown;
            /** @example /swag-cms-extensions-form?limit=25&page=11 */
            last?: unknown;
            /** @example /swag-cms-extensions-form?limit=25&page=4 */
            next?: unknown;
            /** @example /swag-cms-extensions-form?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createSwagCmsExtensionsForm post /swag-cms-extensions-form":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagCmsExtensionsForm"];
        response: {
          data: components["schemas"]["SwagCmsExtensionsForm"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagCmsExtensionsForm"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCmsExtensionsForm"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagCmsExtensionsForm"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagCmsExtensionsForm"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagCmsExtensionsForm"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCmsExtensionsForm"];
        };
        responseCode: 200;
      };
  "getSwagCmsExtensionsFormGroupList get /swag-cms-extensions-form-group":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["SwagCmsExtensionsFormGroup"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["SwagCmsExtensionsFormGroup"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /swag-cms-extensions-form-group?limit=25 */
            first?: unknown;
            /** @example /swag-cms-extensions-form-group?limit=25&page=11 */
            last?: unknown;
            /** @example /swag-cms-extensions-form-group?limit=25&page=4 */
            next?: unknown;
            /** @example /swag-cms-extensions-form-group?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createSwagCmsExtensionsFormGroup post /swag-cms-extensions-form-group":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagCmsExtensionsFormGroup"];
        response: {
          data: components["schemas"]["SwagCmsExtensionsFormGroup"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagCmsExtensionsFormGroup"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCmsExtensionsFormGroup"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagCmsExtensionsFormGroup"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagCmsExtensionsFormGroup"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagCmsExtensionsFormGroup"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCmsExtensionsFormGroup"];
        };
        responseCode: 200;
      };
  "getSwagCmsExtensionsFormGroupFieldList get /swag-cms-extensions-form-group-field":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["SwagCmsExtensionsFormGroupField"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["SwagCmsExtensionsFormGroupField"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /swag-cms-extensions-form-group-field?limit=25 */
            first?: unknown;
            /** @example /swag-cms-extensions-form-group-field?limit=25&page=11 */
            last?: unknown;
            /** @example /swag-cms-extensions-form-group-field?limit=25&page=4 */
            next?: unknown;
            /** @example /swag-cms-extensions-form-group-field?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createSwagCmsExtensionsFormGroupField post /swag-cms-extensions-form-group-field":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagCmsExtensionsFormGroupField"];
        response: {
          data: components["schemas"]["SwagCmsExtensionsFormGroupField"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagCmsExtensionsFormGroupField"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCmsExtensionsFormGroupField"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagCmsExtensionsFormGroupField"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagCmsExtensionsFormGroupField"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagCmsExtensionsFormGroupField"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCmsExtensionsFormGroupField"];
        };
        responseCode: 200;
      };
  "getSwagCmsExtensionsFormGroupField get /swag-cms-extensions-form-group-field/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the swag_cms_extensions_form_group_field */
          id: string;
        };
        response: {
          data: components["schemas"]["SwagCmsExtensionsFormGroupField"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the swag_cms_extensions_form_group_field */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCmsExtensionsFormGroupField"];
        };
        responseCode: 200;
      };
  "deleteSwagCmsExtensionsFormGroupField delete /swag-cms-extensions-form-group-field/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the swag_cms_extensions_form_group_field */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateSwagCmsExtensionsFormGroupField patch /swag-cms-extensions-form-group-field/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_cms_extensions_form_group_field */
          id: string;
        };
        body: components["schemas"]["SwagCmsExtensionsFormGroupField"];
        response: {
          data: components["schemas"]["SwagCmsExtensionsFormGroupField"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_cms_extensions_form_group_field */
          id: string;
        };
        body: components["schemas"]["SwagCmsExtensionsFormGroupField"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCmsExtensionsFormGroupField"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_cms_extensions_form_group_field */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagCmsExtensionsFormGroupField"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagCmsExtensionsFormGroupField"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_cms_extensions_form_group_field */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagCmsExtensionsFormGroupField"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCmsExtensionsFormGroupField"];
        };
        responseCode: 200;
      };
  "getSwagCmsExtensionsFormGroup get /swag-cms-extensions-form-group/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the swag_cms_extensions_form_group */
          id: string;
        };
        response: {
          data: components["schemas"]["SwagCmsExtensionsFormGroup"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the swag_cms_extensions_form_group */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCmsExtensionsFormGroup"];
        };
        responseCode: 200;
      };
  "deleteSwagCmsExtensionsFormGroup delete /swag-cms-extensions-form-group/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the swag_cms_extensions_form_group */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateSwagCmsExtensionsFormGroup patch /swag-cms-extensions-form-group/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_cms_extensions_form_group */
          id: string;
        };
        body: components["schemas"]["SwagCmsExtensionsFormGroup"];
        response: {
          data: components["schemas"]["SwagCmsExtensionsFormGroup"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_cms_extensions_form_group */
          id: string;
        };
        body: components["schemas"]["SwagCmsExtensionsFormGroup"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCmsExtensionsFormGroup"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_cms_extensions_form_group */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagCmsExtensionsFormGroup"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagCmsExtensionsFormGroup"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_cms_extensions_form_group */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagCmsExtensionsFormGroup"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCmsExtensionsFormGroup"];
        };
        responseCode: 200;
      };
  "getSwagCmsExtensionsForm get /swag-cms-extensions-form/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the swag_cms_extensions_form */
          id: string;
        };
        response: {
          data: components["schemas"]["SwagCmsExtensionsForm"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the swag_cms_extensions_form */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCmsExtensionsForm"];
        };
        responseCode: 200;
      };
  "deleteSwagCmsExtensionsForm delete /swag-cms-extensions-form/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the swag_cms_extensions_form */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateSwagCmsExtensionsForm patch /swag-cms-extensions-form/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_cms_extensions_form */
          id: string;
        };
        body: components["schemas"]["SwagCmsExtensionsForm"];
        response: {
          data: components["schemas"]["SwagCmsExtensionsForm"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_cms_extensions_form */
          id: string;
        };
        body: components["schemas"]["SwagCmsExtensionsForm"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCmsExtensionsForm"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_cms_extensions_form */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagCmsExtensionsForm"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagCmsExtensionsForm"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_cms_extensions_form */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagCmsExtensionsForm"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCmsExtensionsForm"];
        };
        responseCode: 200;
      };
  "getSwagCmsExtensionsQuickviewList get /swag-cms-extensions-quickview":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["SwagCmsExtensionsQuickview"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["SwagCmsExtensionsQuickview"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /swag-cms-extensions-quickview?limit=25 */
            first?: unknown;
            /** @example /swag-cms-extensions-quickview?limit=25&page=11 */
            last?: unknown;
            /** @example /swag-cms-extensions-quickview?limit=25&page=4 */
            next?: unknown;
            /** @example /swag-cms-extensions-quickview?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createSwagCmsExtensionsQuickview post /swag-cms-extensions-quickview":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagCmsExtensionsQuickview"];
        response: {
          data: components["schemas"]["SwagCmsExtensionsQuickview"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagCmsExtensionsQuickview"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCmsExtensionsQuickview"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagCmsExtensionsQuickview"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagCmsExtensionsQuickview"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagCmsExtensionsQuickview"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCmsExtensionsQuickview"];
        };
        responseCode: 200;
      };
  "getSwagCmsExtensionsQuickview get /swag-cms-extensions-quickview/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the swag_cms_extensions_quickview */
          id: string;
        };
        response: {
          data: components["schemas"]["SwagCmsExtensionsQuickview"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the swag_cms_extensions_quickview */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCmsExtensionsQuickview"];
        };
        responseCode: 200;
      };
  "deleteSwagCmsExtensionsQuickview delete /swag-cms-extensions-quickview/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the swag_cms_extensions_quickview */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateSwagCmsExtensionsQuickview patch /swag-cms-extensions-quickview/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_cms_extensions_quickview */
          id: string;
        };
        body: components["schemas"]["SwagCmsExtensionsQuickview"];
        response: {
          data: components["schemas"]["SwagCmsExtensionsQuickview"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_cms_extensions_quickview */
          id: string;
        };
        body: components["schemas"]["SwagCmsExtensionsQuickview"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCmsExtensionsQuickview"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_cms_extensions_quickview */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagCmsExtensionsQuickview"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagCmsExtensionsQuickview"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_cms_extensions_quickview */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagCmsExtensionsQuickview"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCmsExtensionsQuickview"];
        };
        responseCode: 200;
      };
  "getSwagCmsExtensionsScrollNavigationList get /swag-cms-extensions-scroll-navigation":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["SwagCmsExtensionsScrollNavigation"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["SwagCmsExtensionsScrollNavigation"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /swag-cms-extensions-scroll-navigation?limit=25 */
            first?: unknown;
            /** @example /swag-cms-extensions-scroll-navigation?limit=25&page=11 */
            last?: unknown;
            /** @example /swag-cms-extensions-scroll-navigation?limit=25&page=4 */
            next?: unknown;
            /** @example /swag-cms-extensions-scroll-navigation?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createSwagCmsExtensionsScrollNavigation post /swag-cms-extensions-scroll-navigation":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagCmsExtensionsScrollNavigation"];
        response: {
          data: components["schemas"]["SwagCmsExtensionsScrollNavigation"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagCmsExtensionsScrollNavigation"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCmsExtensionsScrollNavigation"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagCmsExtensionsScrollNavigation"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagCmsExtensionsScrollNavigation"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagCmsExtensionsScrollNavigation"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCmsExtensionsScrollNavigation"];
        };
        responseCode: 200;
      };
  "getSwagCmsExtensionsScrollNavigationPageSettingsList get /swag-cms-extensions-scroll-navigation-page-settings":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["SwagCmsExtensionsScrollNavigationPageSettings"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["SwagCmsExtensionsScrollNavigationPageSettings"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /swag-cms-extensions-scroll-navigation-page-settings?limit=25 */
            first?: unknown;
            /** @example /swag-cms-extensions-scroll-navigation-page-settings?limit=25&page=11 */
            last?: unknown;
            /** @example /swag-cms-extensions-scroll-navigation-page-settings?limit=25&page=4 */
            next?: unknown;
            /** @example /swag-cms-extensions-scroll-navigation-page-settings?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createSwagCmsExtensionsScrollNavigationPageSettings post /swag-cms-extensions-scroll-navigation-page-settings":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagCmsExtensionsScrollNavigationPageSettings"];
        response: {
          data: components["schemas"]["SwagCmsExtensionsScrollNavigationPageSettings"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagCmsExtensionsScrollNavigationPageSettings"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCmsExtensionsScrollNavigationPageSettings"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagCmsExtensionsScrollNavigationPageSettings"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagCmsExtensionsScrollNavigationPageSettings"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagCmsExtensionsScrollNavigationPageSettings"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCmsExtensionsScrollNavigationPageSettings"];
        };
        responseCode: 200;
      };
  "getSwagCmsExtensionsScrollNavigationPageSettings get /swag-cms-extensions-scroll-navigation-page-settings/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the swag_cms_extensions_scroll_navigation_page_settings */
          id: string;
        };
        response: {
          data: components["schemas"]["SwagCmsExtensionsScrollNavigationPageSettings"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the swag_cms_extensions_scroll_navigation_page_settings */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCmsExtensionsScrollNavigationPageSettings"];
        };
        responseCode: 200;
      };
  "deleteSwagCmsExtensionsScrollNavigationPageSettings delete /swag-cms-extensions-scroll-navigation-page-settings/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the swag_cms_extensions_scroll_navigation_page_settings */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateSwagCmsExtensionsScrollNavigationPageSettings patch /swag-cms-extensions-scroll-navigation-page-settings/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_cms_extensions_scroll_navigation_page_settings */
          id: string;
        };
        body: components["schemas"]["SwagCmsExtensionsScrollNavigationPageSettings"];
        response: {
          data: components["schemas"]["SwagCmsExtensionsScrollNavigationPageSettings"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_cms_extensions_scroll_navigation_page_settings */
          id: string;
        };
        body: components["schemas"]["SwagCmsExtensionsScrollNavigationPageSettings"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCmsExtensionsScrollNavigationPageSettings"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_cms_extensions_scroll_navigation_page_settings */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagCmsExtensionsScrollNavigationPageSettings"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagCmsExtensionsScrollNavigationPageSettings"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_cms_extensions_scroll_navigation_page_settings */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagCmsExtensionsScrollNavigationPageSettings"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCmsExtensionsScrollNavigationPageSettings"];
        };
        responseCode: 200;
      };
  "getSwagCmsExtensionsScrollNavigation get /swag-cms-extensions-scroll-navigation/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the swag_cms_extensions_scroll_navigation */
          id: string;
        };
        response: {
          data: components["schemas"]["SwagCmsExtensionsScrollNavigation"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the swag_cms_extensions_scroll_navigation */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCmsExtensionsScrollNavigation"];
        };
        responseCode: 200;
      };
  "deleteSwagCmsExtensionsScrollNavigation delete /swag-cms-extensions-scroll-navigation/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the swag_cms_extensions_scroll_navigation */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateSwagCmsExtensionsScrollNavigation patch /swag-cms-extensions-scroll-navigation/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_cms_extensions_scroll_navigation */
          id: string;
        };
        body: components["schemas"]["SwagCmsExtensionsScrollNavigation"];
        response: {
          data: components["schemas"]["SwagCmsExtensionsScrollNavigation"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_cms_extensions_scroll_navigation */
          id: string;
        };
        body: components["schemas"]["SwagCmsExtensionsScrollNavigation"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCmsExtensionsScrollNavigation"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_cms_extensions_scroll_navigation */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagCmsExtensionsScrollNavigation"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagCmsExtensionsScrollNavigation"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_cms_extensions_scroll_navigation */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagCmsExtensionsScrollNavigation"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCmsExtensionsScrollNavigation"];
        };
        responseCode: 200;
      };
  "getSwagCustomizedProductsTemplateList get /swag-customized-products-template":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["SwagCustomizedProductsTemplate"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["SwagCustomizedProductsTemplate"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /swag-customized-products-template?limit=25 */
            first?: unknown;
            /** @example /swag-customized-products-template?limit=25&page=11 */
            last?: unknown;
            /** @example /swag-customized-products-template?limit=25&page=4 */
            next?: unknown;
            /** @example /swag-customized-products-template?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createSwagCustomizedProductsTemplate post /swag-customized-products-template":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagCustomizedProductsTemplate"];
        response: {
          data: components["schemas"]["SwagCustomizedProductsTemplate"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagCustomizedProductsTemplate"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplate"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagCustomizedProductsTemplate"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagCustomizedProductsTemplate"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagCustomizedProductsTemplate"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplate"];
        };
        responseCode: 200;
      };
  "getSwagCustomizedProductsTemplateConfigurationList get /swag-customized-products-template-configuration":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateConfiguration"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["SwagCustomizedProductsTemplateConfiguration"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /swag-customized-products-template-configuration?limit=25 */
            first?: unknown;
            /** @example /swag-customized-products-template-configuration?limit=25&page=11 */
            last?: unknown;
            /** @example /swag-customized-products-template-configuration?limit=25&page=4 */
            next?: unknown;
            /** @example /swag-customized-products-template-configuration?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createSwagCustomizedProductsTemplateConfiguration post /swag-customized-products-template-configuration":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagCustomizedProductsTemplateConfiguration"];
        response: {
          data: components["schemas"]["SwagCustomizedProductsTemplateConfiguration"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagCustomizedProductsTemplateConfiguration"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateConfiguration"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateConfiguration"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagCustomizedProductsTemplateConfiguration"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateConfiguration"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateConfiguration"];
        };
        responseCode: 200;
      };
  "getSwagCustomizedProductsTemplateConfigurationShareList get /swag-customized-products-template-configuration-share":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateConfigurationShare"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["SwagCustomizedProductsTemplateConfigurationShare"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /swag-customized-products-template-configuration-share?limit=25 */
            first?: unknown;
            /** @example /swag-customized-products-template-configuration-share?limit=25&page=11 */
            last?: unknown;
            /** @example /swag-customized-products-template-configuration-share?limit=25&page=4 */
            next?: unknown;
            /** @example /swag-customized-products-template-configuration-share?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createSwagCustomizedProductsTemplateConfigurationShare post /swag-customized-products-template-configuration-share":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagCustomizedProductsTemplateConfigurationShare"];
        response: {
          data: components["schemas"]["SwagCustomizedProductsTemplateConfigurationShare"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagCustomizedProductsTemplateConfigurationShare"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateConfigurationShare"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateConfigurationShare"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagCustomizedProductsTemplateConfigurationShare"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateConfigurationShare"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateConfigurationShare"];
        };
        responseCode: 200;
      };
  "getSwagCustomizedProductsTemplateConfigurationShare get /swag-customized-products-template-configuration-share/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the swag_customized_products_template_configuration_share */
          id: string;
        };
        response: {
          data: components["schemas"]["SwagCustomizedProductsTemplateConfigurationShare"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the swag_customized_products_template_configuration_share */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateConfigurationShare"];
        };
        responseCode: 200;
      };
  "deleteSwagCustomizedProductsTemplateConfigurationShare delete /swag-customized-products-template-configuration-share/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the swag_customized_products_template_configuration_share */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateSwagCustomizedProductsTemplateConfigurationShare patch /swag-customized-products-template-configuration-share/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_customized_products_template_configuration_share */
          id: string;
        };
        body: components["schemas"]["SwagCustomizedProductsTemplateConfigurationShare"];
        response: {
          data: components["schemas"]["SwagCustomizedProductsTemplateConfigurationShare"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_customized_products_template_configuration_share */
          id: string;
        };
        body: components["schemas"]["SwagCustomizedProductsTemplateConfigurationShare"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateConfigurationShare"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_customized_products_template_configuration_share */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateConfigurationShare"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagCustomizedProductsTemplateConfigurationShare"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_customized_products_template_configuration_share */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateConfigurationShare"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateConfigurationShare"];
        };
        responseCode: 200;
      };
  "getSwagCustomizedProductsTemplateConfiguration get /swag-customized-products-template-configuration/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the swag_customized_products_template_configuration */
          id: string;
        };
        response: {
          data: components["schemas"]["SwagCustomizedProductsTemplateConfiguration"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the swag_customized_products_template_configuration */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateConfiguration"];
        };
        responseCode: 200;
      };
  "deleteSwagCustomizedProductsTemplateConfiguration delete /swag-customized-products-template-configuration/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the swag_customized_products_template_configuration */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateSwagCustomizedProductsTemplateConfiguration patch /swag-customized-products-template-configuration/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_customized_products_template_configuration */
          id: string;
        };
        body: components["schemas"]["SwagCustomizedProductsTemplateConfiguration"];
        response: {
          data: components["schemas"]["SwagCustomizedProductsTemplateConfiguration"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_customized_products_template_configuration */
          id: string;
        };
        body: components["schemas"]["SwagCustomizedProductsTemplateConfiguration"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateConfiguration"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_customized_products_template_configuration */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateConfiguration"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagCustomizedProductsTemplateConfiguration"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_customized_products_template_configuration */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateConfiguration"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateConfiguration"];
        };
        responseCode: 200;
      };
  "getSwagCustomizedProductsTemplateExclusionList get /swag-customized-products-template-exclusion":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateExclusion"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["SwagCustomizedProductsTemplateExclusion"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /swag-customized-products-template-exclusion?limit=25 */
            first?: unknown;
            /** @example /swag-customized-products-template-exclusion?limit=25&page=11 */
            last?: unknown;
            /** @example /swag-customized-products-template-exclusion?limit=25&page=4 */
            next?: unknown;
            /** @example /swag-customized-products-template-exclusion?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createSwagCustomizedProductsTemplateExclusion post /swag-customized-products-template-exclusion":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagCustomizedProductsTemplateExclusion"];
        response: {
          data: components["schemas"]["SwagCustomizedProductsTemplateExclusion"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagCustomizedProductsTemplateExclusion"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateExclusion"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateExclusion"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagCustomizedProductsTemplateExclusion"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateExclusion"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateExclusion"];
        };
        responseCode: 200;
      };
  "getSwagCustomizedProductsTemplateExclusionConditionList get /swag-customized-products-template-exclusion-condition":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateExclusionCondition"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["SwagCustomizedProductsTemplateExclusionCondition"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /swag-customized-products-template-exclusion-condition?limit=25 */
            first?: unknown;
            /** @example /swag-customized-products-template-exclusion-condition?limit=25&page=11 */
            last?: unknown;
            /** @example /swag-customized-products-template-exclusion-condition?limit=25&page=4 */
            next?: unknown;
            /** @example /swag-customized-products-template-exclusion-condition?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createSwagCustomizedProductsTemplateExclusionCondition post /swag-customized-products-template-exclusion-condition":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagCustomizedProductsTemplateExclusionCondition"];
        response: {
          data: components["schemas"]["SwagCustomizedProductsTemplateExclusionCondition"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagCustomizedProductsTemplateExclusionCondition"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateExclusionCondition"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateExclusionCondition"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagCustomizedProductsTemplateExclusionCondition"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateExclusionCondition"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateExclusionCondition"];
        };
        responseCode: 200;
      };
  "getSwagCustomizedProductsTemplateExclusionCondition get /swag-customized-products-template-exclusion-condition/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the swag_customized_products_template_exclusion_condition */
          id: string;
        };
        response: {
          data: components["schemas"]["SwagCustomizedProductsTemplateExclusionCondition"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the swag_customized_products_template_exclusion_condition */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateExclusionCondition"];
        };
        responseCode: 200;
      };
  "deleteSwagCustomizedProductsTemplateExclusionCondition delete /swag-customized-products-template-exclusion-condition/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the swag_customized_products_template_exclusion_condition */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateSwagCustomizedProductsTemplateExclusionCondition patch /swag-customized-products-template-exclusion-condition/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_customized_products_template_exclusion_condition */
          id: string;
        };
        body: components["schemas"]["SwagCustomizedProductsTemplateExclusionCondition"];
        response: {
          data: components["schemas"]["SwagCustomizedProductsTemplateExclusionCondition"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_customized_products_template_exclusion_condition */
          id: string;
        };
        body: components["schemas"]["SwagCustomizedProductsTemplateExclusionCondition"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateExclusionCondition"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_customized_products_template_exclusion_condition */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateExclusionCondition"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagCustomizedProductsTemplateExclusionCondition"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_customized_products_template_exclusion_condition */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateExclusionCondition"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateExclusionCondition"];
        };
        responseCode: 200;
      };
  "getSwagCustomizedProductsTemplateExclusionOperatorList get /swag-customized-products-template-exclusion-operator":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateExclusionOperator"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["SwagCustomizedProductsTemplateExclusionOperator"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /swag-customized-products-template-exclusion-operator?limit=25 */
            first?: unknown;
            /** @example /swag-customized-products-template-exclusion-operator?limit=25&page=11 */
            last?: unknown;
            /** @example /swag-customized-products-template-exclusion-operator?limit=25&page=4 */
            next?: unknown;
            /** @example /swag-customized-products-template-exclusion-operator?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createSwagCustomizedProductsTemplateExclusionOperator post /swag-customized-products-template-exclusion-operator":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagCustomizedProductsTemplateExclusionOperator"];
        response: {
          data: components["schemas"]["SwagCustomizedProductsTemplateExclusionOperator"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagCustomizedProductsTemplateExclusionOperator"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateExclusionOperator"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateExclusionOperator"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagCustomizedProductsTemplateExclusionOperator"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateExclusionOperator"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateExclusionOperator"];
        };
        responseCode: 200;
      };
  "getSwagCustomizedProductsTemplateExclusionOperator get /swag-customized-products-template-exclusion-operator/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the swag_customized_products_template_exclusion_operator */
          id: string;
        };
        response: {
          data: components["schemas"]["SwagCustomizedProductsTemplateExclusionOperator"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the swag_customized_products_template_exclusion_operator */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateExclusionOperator"];
        };
        responseCode: 200;
      };
  "deleteSwagCustomizedProductsTemplateExclusionOperator delete /swag-customized-products-template-exclusion-operator/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the swag_customized_products_template_exclusion_operator */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateSwagCustomizedProductsTemplateExclusionOperator patch /swag-customized-products-template-exclusion-operator/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_customized_products_template_exclusion_operator */
          id: string;
        };
        body: components["schemas"]["SwagCustomizedProductsTemplateExclusionOperator"];
        response: {
          data: components["schemas"]["SwagCustomizedProductsTemplateExclusionOperator"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_customized_products_template_exclusion_operator */
          id: string;
        };
        body: components["schemas"]["SwagCustomizedProductsTemplateExclusionOperator"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateExclusionOperator"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_customized_products_template_exclusion_operator */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateExclusionOperator"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagCustomizedProductsTemplateExclusionOperator"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_customized_products_template_exclusion_operator */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateExclusionOperator"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateExclusionOperator"];
        };
        responseCode: 200;
      };
  "getSwagCustomizedProductsTemplateExclusion get /swag-customized-products-template-exclusion/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the swag_customized_products_template_exclusion */
          id: string;
        };
        response: {
          data: components["schemas"]["SwagCustomizedProductsTemplateExclusion"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the swag_customized_products_template_exclusion */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateExclusion"];
        };
        responseCode: 200;
      };
  "deleteSwagCustomizedProductsTemplateExclusion delete /swag-customized-products-template-exclusion/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the swag_customized_products_template_exclusion */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateSwagCustomizedProductsTemplateExclusion patch /swag-customized-products-template-exclusion/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_customized_products_template_exclusion */
          id: string;
        };
        body: components["schemas"]["SwagCustomizedProductsTemplateExclusion"];
        response: {
          data: components["schemas"]["SwagCustomizedProductsTemplateExclusion"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_customized_products_template_exclusion */
          id: string;
        };
        body: components["schemas"]["SwagCustomizedProductsTemplateExclusion"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateExclusion"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_customized_products_template_exclusion */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateExclusion"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagCustomizedProductsTemplateExclusion"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_customized_products_template_exclusion */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateExclusion"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateExclusion"];
        };
        responseCode: 200;
      };
  "getSwagCustomizedProductsTemplateOptionList get /swag-customized-products-template-option":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateOption"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["SwagCustomizedProductsTemplateOption"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /swag-customized-products-template-option?limit=25 */
            first?: unknown;
            /** @example /swag-customized-products-template-option?limit=25&page=11 */
            last?: unknown;
            /** @example /swag-customized-products-template-option?limit=25&page=4 */
            next?: unknown;
            /** @example /swag-customized-products-template-option?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createSwagCustomizedProductsTemplateOption post /swag-customized-products-template-option":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagCustomizedProductsTemplateOption"];
        response: {
          data: components["schemas"]["SwagCustomizedProductsTemplateOption"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagCustomizedProductsTemplateOption"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateOption"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateOption"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagCustomizedProductsTemplateOption"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateOption"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateOption"];
        };
        responseCode: 200;
      };
  "getSwagCustomizedProductsTemplateOptionPriceList get /swag-customized-products-template-option-price":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateOptionPrice"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["SwagCustomizedProductsTemplateOptionPrice"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /swag-customized-products-template-option-price?limit=25 */
            first?: unknown;
            /** @example /swag-customized-products-template-option-price?limit=25&page=11 */
            last?: unknown;
            /** @example /swag-customized-products-template-option-price?limit=25&page=4 */
            next?: unknown;
            /** @example /swag-customized-products-template-option-price?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createSwagCustomizedProductsTemplateOptionPrice post /swag-customized-products-template-option-price":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagCustomizedProductsTemplateOptionPrice"];
        response: {
          data: components["schemas"]["SwagCustomizedProductsTemplateOptionPrice"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagCustomizedProductsTemplateOptionPrice"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateOptionPrice"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateOptionPrice"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagCustomizedProductsTemplateOptionPrice"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateOptionPrice"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateOptionPrice"];
        };
        responseCode: 200;
      };
  "getSwagCustomizedProductsTemplateOptionPrice get /swag-customized-products-template-option-price/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the swag_customized_products_template_option_price */
          id: string;
        };
        response: {
          data: components["schemas"]["SwagCustomizedProductsTemplateOptionPrice"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the swag_customized_products_template_option_price */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateOptionPrice"];
        };
        responseCode: 200;
      };
  "deleteSwagCustomizedProductsTemplateOptionPrice delete /swag-customized-products-template-option-price/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the swag_customized_products_template_option_price */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateSwagCustomizedProductsTemplateOptionPrice patch /swag-customized-products-template-option-price/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_customized_products_template_option_price */
          id: string;
        };
        body: components["schemas"]["SwagCustomizedProductsTemplateOptionPrice"];
        response: {
          data: components["schemas"]["SwagCustomizedProductsTemplateOptionPrice"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_customized_products_template_option_price */
          id: string;
        };
        body: components["schemas"]["SwagCustomizedProductsTemplateOptionPrice"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateOptionPrice"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_customized_products_template_option_price */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateOptionPrice"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagCustomizedProductsTemplateOptionPrice"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_customized_products_template_option_price */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateOptionPrice"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateOptionPrice"];
        };
        responseCode: 200;
      };
  "getSwagCustomizedProductsTemplateOptionValueList get /swag-customized-products-template-option-value":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateOptionValue"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["SwagCustomizedProductsTemplateOptionValue"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /swag-customized-products-template-option-value?limit=25 */
            first?: unknown;
            /** @example /swag-customized-products-template-option-value?limit=25&page=11 */
            last?: unknown;
            /** @example /swag-customized-products-template-option-value?limit=25&page=4 */
            next?: unknown;
            /** @example /swag-customized-products-template-option-value?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createSwagCustomizedProductsTemplateOptionValue post /swag-customized-products-template-option-value":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagCustomizedProductsTemplateOptionValue"];
        response: {
          data: components["schemas"]["SwagCustomizedProductsTemplateOptionValue"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagCustomizedProductsTemplateOptionValue"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateOptionValue"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateOptionValue"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagCustomizedProductsTemplateOptionValue"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateOptionValue"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateOptionValue"];
        };
        responseCode: 200;
      };
  "getSwagCustomizedProductsTemplateOptionValuePriceList get /swag-customized-products-template-option-value-price":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateOptionValuePrice"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["SwagCustomizedProductsTemplateOptionValuePrice"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /swag-customized-products-template-option-value-price?limit=25 */
            first?: unknown;
            /** @example /swag-customized-products-template-option-value-price?limit=25&page=11 */
            last?: unknown;
            /** @example /swag-customized-products-template-option-value-price?limit=25&page=4 */
            next?: unknown;
            /** @example /swag-customized-products-template-option-value-price?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createSwagCustomizedProductsTemplateOptionValuePrice post /swag-customized-products-template-option-value-price":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagCustomizedProductsTemplateOptionValuePrice"];
        response: {
          data: components["schemas"]["SwagCustomizedProductsTemplateOptionValuePrice"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagCustomizedProductsTemplateOptionValuePrice"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateOptionValuePrice"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateOptionValuePrice"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagCustomizedProductsTemplateOptionValuePrice"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateOptionValuePrice"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateOptionValuePrice"];
        };
        responseCode: 200;
      };
  "getSwagCustomizedProductsTemplateOptionValuePrice get /swag-customized-products-template-option-value-price/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the swag_customized_products_template_option_value_price */
          id: string;
        };
        response: {
          data: components["schemas"]["SwagCustomizedProductsTemplateOptionValuePrice"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the swag_customized_products_template_option_value_price */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateOptionValuePrice"];
        };
        responseCode: 200;
      };
  "deleteSwagCustomizedProductsTemplateOptionValuePrice delete /swag-customized-products-template-option-value-price/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the swag_customized_products_template_option_value_price */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateSwagCustomizedProductsTemplateOptionValuePrice patch /swag-customized-products-template-option-value-price/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_customized_products_template_option_value_price */
          id: string;
        };
        body: components["schemas"]["SwagCustomizedProductsTemplateOptionValuePrice"];
        response: {
          data: components["schemas"]["SwagCustomizedProductsTemplateOptionValuePrice"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_customized_products_template_option_value_price */
          id: string;
        };
        body: components["schemas"]["SwagCustomizedProductsTemplateOptionValuePrice"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateOptionValuePrice"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_customized_products_template_option_value_price */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateOptionValuePrice"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagCustomizedProductsTemplateOptionValuePrice"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_customized_products_template_option_value_price */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateOptionValuePrice"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateOptionValuePrice"];
        };
        responseCode: 200;
      };
  "getSwagCustomizedProductsTemplateOptionValue get /swag-customized-products-template-option-value/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the swag_customized_products_template_option_value */
          id: string;
        };
        response: {
          data: components["schemas"]["SwagCustomizedProductsTemplateOptionValue"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the swag_customized_products_template_option_value */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateOptionValue"];
        };
        responseCode: 200;
      };
  "deleteSwagCustomizedProductsTemplateOptionValue delete /swag-customized-products-template-option-value/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the swag_customized_products_template_option_value */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateSwagCustomizedProductsTemplateOptionValue patch /swag-customized-products-template-option-value/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_customized_products_template_option_value */
          id: string;
        };
        body: components["schemas"]["SwagCustomizedProductsTemplateOptionValue"];
        response: {
          data: components["schemas"]["SwagCustomizedProductsTemplateOptionValue"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_customized_products_template_option_value */
          id: string;
        };
        body: components["schemas"]["SwagCustomizedProductsTemplateOptionValue"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateOptionValue"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_customized_products_template_option_value */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateOptionValue"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagCustomizedProductsTemplateOptionValue"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_customized_products_template_option_value */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateOptionValue"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateOptionValue"];
        };
        responseCode: 200;
      };
  "getSwagCustomizedProductsTemplateOption get /swag-customized-products-template-option/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the swag_customized_products_template_option */
          id: string;
        };
        response: {
          data: components["schemas"]["SwagCustomizedProductsTemplateOption"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the swag_customized_products_template_option */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateOption"];
        };
        responseCode: 200;
      };
  "deleteSwagCustomizedProductsTemplateOption delete /swag-customized-products-template-option/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the swag_customized_products_template_option */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateSwagCustomizedProductsTemplateOption patch /swag-customized-products-template-option/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_customized_products_template_option */
          id: string;
        };
        body: components["schemas"]["SwagCustomizedProductsTemplateOption"];
        response: {
          data: components["schemas"]["SwagCustomizedProductsTemplateOption"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_customized_products_template_option */
          id: string;
        };
        body: components["schemas"]["SwagCustomizedProductsTemplateOption"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateOption"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_customized_products_template_option */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateOption"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagCustomizedProductsTemplateOption"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_customized_products_template_option */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagCustomizedProductsTemplateOption"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplateOption"];
        };
        responseCode: 200;
      };
  "getSwagCustomizedProductsTemplate get /swag-customized-products-template/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the swag_customized_products_template */
          id: string;
        };
        response: {
          data: components["schemas"]["SwagCustomizedProductsTemplate"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the swag_customized_products_template */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplate"];
        };
        responseCode: 200;
      };
  "deleteSwagCustomizedProductsTemplate delete /swag-customized-products-template/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the swag_customized_products_template */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateSwagCustomizedProductsTemplate patch /swag-customized-products-template/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_customized_products_template */
          id: string;
        };
        body: components["schemas"]["SwagCustomizedProductsTemplate"];
        response: {
          data: components["schemas"]["SwagCustomizedProductsTemplate"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_customized_products_template */
          id: string;
        };
        body: components["schemas"]["SwagCustomizedProductsTemplate"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplate"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_customized_products_template */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagCustomizedProductsTemplate"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagCustomizedProductsTemplate"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_customized_products_template */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagCustomizedProductsTemplate"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagCustomizedProductsTemplate"];
        };
        responseCode: 200;
      };
  "getSwagDelayActionList get /swag-delay-action":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["SwagDelayAction"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["SwagDelayAction"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /swag-delay-action?limit=25 */
            first?: unknown;
            /** @example /swag-delay-action?limit=25&page=11 */
            last?: unknown;
            /** @example /swag-delay-action?limit=25&page=4 */
            next?: unknown;
            /** @example /swag-delay-action?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createSwagDelayAction post /swag-delay-action":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagDelayAction"];
        response: {
          data: components["schemas"]["SwagDelayAction"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagDelayAction"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagDelayAction"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagDelayAction"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagDelayAction"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagDelayAction"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagDelayAction"];
        };
        responseCode: 200;
      };
  "getSwagDelayAction get /swag-delay-action/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the swag_delay_action */
          id: string;
        };
        response: {
          data: components["schemas"]["SwagDelayAction"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the swag_delay_action */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagDelayAction"];
        };
        responseCode: 200;
      };
  "deleteSwagDelayAction delete /swag-delay-action/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the swag_delay_action */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateSwagDelayAction patch /swag-delay-action/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_delay_action */
          id: string;
        };
        body: components["schemas"]["SwagDelayAction"];
        response: {
          data: components["schemas"]["SwagDelayAction"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_delay_action */
          id: string;
        };
        body: components["schemas"]["SwagDelayAction"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagDelayAction"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_delay_action */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagDelayAction"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagDelayAction"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_delay_action */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagDelayAction"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagDelayAction"];
        };
        responseCode: 200;
      };
  "getSwagLanguagePackLanguageList get /swag-language-pack-language":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["SwagLanguagePackLanguage"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["SwagLanguagePackLanguage"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /swag-language-pack-language?limit=25 */
            first?: unknown;
            /** @example /swag-language-pack-language?limit=25&page=11 */
            last?: unknown;
            /** @example /swag-language-pack-language?limit=25&page=4 */
            next?: unknown;
            /** @example /swag-language-pack-language?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createSwagLanguagePackLanguage post /swag-language-pack-language":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagLanguagePackLanguage"];
        response: {
          data: components["schemas"]["SwagLanguagePackLanguage"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagLanguagePackLanguage"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagLanguagePackLanguage"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagLanguagePackLanguage"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagLanguagePackLanguage"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagLanguagePackLanguage"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagLanguagePackLanguage"];
        };
        responseCode: 200;
      };
  "getSwagLanguagePackLanguage get /swag-language-pack-language/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the swag_language_pack_language */
          id: string;
        };
        response: {
          data: components["schemas"]["SwagLanguagePackLanguage"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the swag_language_pack_language */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagLanguagePackLanguage"];
        };
        responseCode: 200;
      };
  "deleteSwagLanguagePackLanguage delete /swag-language-pack-language/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the swag_language_pack_language */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateSwagLanguagePackLanguage patch /swag-language-pack-language/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_language_pack_language */
          id: string;
        };
        body: components["schemas"]["SwagLanguagePackLanguage"];
        response: {
          data: components["schemas"]["SwagLanguagePackLanguage"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_language_pack_language */
          id: string;
        };
        body: components["schemas"]["SwagLanguagePackLanguage"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagLanguagePackLanguage"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_language_pack_language */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagLanguagePackLanguage"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagLanguagePackLanguage"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_language_pack_language */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagLanguagePackLanguage"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagLanguagePackLanguage"];
        };
        responseCode: 200;
      };
  "getSwagMigrationConnectionList get /swag-migration-connection":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["SwagMigrationConnection"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["SwagMigrationConnection"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /swag-migration-connection?limit=25 */
            first?: unknown;
            /** @example /swag-migration-connection?limit=25&page=11 */
            last?: unknown;
            /** @example /swag-migration-connection?limit=25&page=4 */
            next?: unknown;
            /** @example /swag-migration-connection?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createSwagMigrationConnection post /swag-migration-connection":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagMigrationConnection"];
        response: {
          data: components["schemas"]["SwagMigrationConnection"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagMigrationConnection"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagMigrationConnection"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagMigrationConnection"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagMigrationConnection"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagMigrationConnection"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagMigrationConnection"];
        };
        responseCode: 200;
      };
  "getSwagMigrationConnection get /swag-migration-connection/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the swag_migration_connection */
          id: string;
        };
        response: {
          data: components["schemas"]["SwagMigrationConnection"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the swag_migration_connection */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagMigrationConnection"];
        };
        responseCode: 200;
      };
  "deleteSwagMigrationConnection delete /swag-migration-connection/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the swag_migration_connection */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateSwagMigrationConnection patch /swag-migration-connection/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_migration_connection */
          id: string;
        };
        body: components["schemas"]["SwagMigrationConnection"];
        response: {
          data: components["schemas"]["SwagMigrationConnection"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_migration_connection */
          id: string;
        };
        body: components["schemas"]["SwagMigrationConnection"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagMigrationConnection"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_migration_connection */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagMigrationConnection"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagMigrationConnection"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_migration_connection */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagMigrationConnection"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagMigrationConnection"];
        };
        responseCode: 200;
      };
  "getSwagMigrationDataList get /swag-migration-data":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["SwagMigrationData"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["SwagMigrationData"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /swag-migration-data?limit=25 */
            first?: unknown;
            /** @example /swag-migration-data?limit=25&page=11 */
            last?: unknown;
            /** @example /swag-migration-data?limit=25&page=4 */
            next?: unknown;
            /** @example /swag-migration-data?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createSwagMigrationData post /swag-migration-data":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagMigrationData"];
        response: {
          data: components["schemas"]["SwagMigrationData"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagMigrationData"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagMigrationData"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagMigrationData"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagMigrationData"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagMigrationData"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagMigrationData"];
        };
        responseCode: 200;
      };
  "getSwagMigrationData get /swag-migration-data/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the swag_migration_data */
          id: string;
        };
        response: {
          data: components["schemas"]["SwagMigrationData"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the swag_migration_data */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagMigrationData"];
        };
        responseCode: 200;
      };
  "deleteSwagMigrationData delete /swag-migration-data/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the swag_migration_data */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateSwagMigrationData patch /swag-migration-data/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_migration_data */
          id: string;
        };
        body: components["schemas"]["SwagMigrationData"];
        response: {
          data: components["schemas"]["SwagMigrationData"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_migration_data */
          id: string;
        };
        body: components["schemas"]["SwagMigrationData"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagMigrationData"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_migration_data */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagMigrationData"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagMigrationData"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_migration_data */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagMigrationData"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagMigrationData"];
        };
        responseCode: 200;
      };
  "getSwagMigrationGeneralSettingList get /swag-migration-general-setting":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["SwagMigrationGeneralSetting"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["SwagMigrationGeneralSetting"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /swag-migration-general-setting?limit=25 */
            first?: unknown;
            /** @example /swag-migration-general-setting?limit=25&page=11 */
            last?: unknown;
            /** @example /swag-migration-general-setting?limit=25&page=4 */
            next?: unknown;
            /** @example /swag-migration-general-setting?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createSwagMigrationGeneralSetting post /swag-migration-general-setting":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagMigrationGeneralSetting"];
        response: {
          data: components["schemas"]["SwagMigrationGeneralSetting"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagMigrationGeneralSetting"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagMigrationGeneralSetting"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagMigrationGeneralSetting"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagMigrationGeneralSetting"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagMigrationGeneralSetting"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagMigrationGeneralSetting"];
        };
        responseCode: 200;
      };
  "getSwagMigrationGeneralSetting get /swag-migration-general-setting/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the swag_migration_general_setting */
          id: string;
        };
        response: {
          data: components["schemas"]["SwagMigrationGeneralSetting"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the swag_migration_general_setting */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagMigrationGeneralSetting"];
        };
        responseCode: 200;
      };
  "deleteSwagMigrationGeneralSetting delete /swag-migration-general-setting/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the swag_migration_general_setting */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateSwagMigrationGeneralSetting patch /swag-migration-general-setting/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_migration_general_setting */
          id: string;
        };
        body: components["schemas"]["SwagMigrationGeneralSetting"];
        response: {
          data: components["schemas"]["SwagMigrationGeneralSetting"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_migration_general_setting */
          id: string;
        };
        body: components["schemas"]["SwagMigrationGeneralSetting"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagMigrationGeneralSetting"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_migration_general_setting */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagMigrationGeneralSetting"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagMigrationGeneralSetting"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_migration_general_setting */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagMigrationGeneralSetting"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagMigrationGeneralSetting"];
        };
        responseCode: 200;
      };
  "getSwagMigrationLoggingList get /swag-migration-logging":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["SwagMigrationLogging"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["SwagMigrationLogging"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /swag-migration-logging?limit=25 */
            first?: unknown;
            /** @example /swag-migration-logging?limit=25&page=11 */
            last?: unknown;
            /** @example /swag-migration-logging?limit=25&page=4 */
            next?: unknown;
            /** @example /swag-migration-logging?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createSwagMigrationLogging post /swag-migration-logging":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagMigrationLogging"];
        response: {
          data: components["schemas"]["SwagMigrationLogging"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagMigrationLogging"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagMigrationLogging"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagMigrationLogging"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagMigrationLogging"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagMigrationLogging"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagMigrationLogging"];
        };
        responseCode: 200;
      };
  "getSwagMigrationLogging get /swag-migration-logging/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the swag_migration_logging */
          id: string;
        };
        response: {
          data: components["schemas"]["SwagMigrationLogging"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the swag_migration_logging */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagMigrationLogging"];
        };
        responseCode: 200;
      };
  "deleteSwagMigrationLogging delete /swag-migration-logging/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the swag_migration_logging */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateSwagMigrationLogging patch /swag-migration-logging/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_migration_logging */
          id: string;
        };
        body: components["schemas"]["SwagMigrationLogging"];
        response: {
          data: components["schemas"]["SwagMigrationLogging"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_migration_logging */
          id: string;
        };
        body: components["schemas"]["SwagMigrationLogging"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagMigrationLogging"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_migration_logging */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagMigrationLogging"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagMigrationLogging"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_migration_logging */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagMigrationLogging"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagMigrationLogging"];
        };
        responseCode: 200;
      };
  "getSwagMigrationMappingList get /swag-migration-mapping":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["SwagMigrationMapping"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["SwagMigrationMapping"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /swag-migration-mapping?limit=25 */
            first?: unknown;
            /** @example /swag-migration-mapping?limit=25&page=11 */
            last?: unknown;
            /** @example /swag-migration-mapping?limit=25&page=4 */
            next?: unknown;
            /** @example /swag-migration-mapping?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createSwagMigrationMapping post /swag-migration-mapping":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagMigrationMapping"];
        response: {
          data: components["schemas"]["SwagMigrationMapping"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagMigrationMapping"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagMigrationMapping"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagMigrationMapping"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagMigrationMapping"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagMigrationMapping"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagMigrationMapping"];
        };
        responseCode: 200;
      };
  "getSwagMigrationMapping get /swag-migration-mapping/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the swag_migration_mapping */
          id: string;
        };
        response: {
          data: components["schemas"]["SwagMigrationMapping"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the swag_migration_mapping */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagMigrationMapping"];
        };
        responseCode: 200;
      };
  "deleteSwagMigrationMapping delete /swag-migration-mapping/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the swag_migration_mapping */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateSwagMigrationMapping patch /swag-migration-mapping/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_migration_mapping */
          id: string;
        };
        body: components["schemas"]["SwagMigrationMapping"];
        response: {
          data: components["schemas"]["SwagMigrationMapping"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_migration_mapping */
          id: string;
        };
        body: components["schemas"]["SwagMigrationMapping"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagMigrationMapping"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_migration_mapping */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagMigrationMapping"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagMigrationMapping"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_migration_mapping */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagMigrationMapping"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagMigrationMapping"];
        };
        responseCode: 200;
      };
  "getSwagMigrationMediaFileList get /swag-migration-media-file":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["SwagMigrationMediaFile"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["SwagMigrationMediaFile"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /swag-migration-media-file?limit=25 */
            first?: unknown;
            /** @example /swag-migration-media-file?limit=25&page=11 */
            last?: unknown;
            /** @example /swag-migration-media-file?limit=25&page=4 */
            next?: unknown;
            /** @example /swag-migration-media-file?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createSwagMigrationMediaFile post /swag-migration-media-file":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagMigrationMediaFile"];
        response: {
          data: components["schemas"]["SwagMigrationMediaFile"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagMigrationMediaFile"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagMigrationMediaFile"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagMigrationMediaFile"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagMigrationMediaFile"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagMigrationMediaFile"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagMigrationMediaFile"];
        };
        responseCode: 200;
      };
  "getSwagMigrationMediaFile get /swag-migration-media-file/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the swag_migration_media_file */
          id: string;
        };
        response: {
          data: components["schemas"]["SwagMigrationMediaFile"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the swag_migration_media_file */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagMigrationMediaFile"];
        };
        responseCode: 200;
      };
  "deleteSwagMigrationMediaFile delete /swag-migration-media-file/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the swag_migration_media_file */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateSwagMigrationMediaFile patch /swag-migration-media-file/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_migration_media_file */
          id: string;
        };
        body: components["schemas"]["SwagMigrationMediaFile"];
        response: {
          data: components["schemas"]["SwagMigrationMediaFile"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_migration_media_file */
          id: string;
        };
        body: components["schemas"]["SwagMigrationMediaFile"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagMigrationMediaFile"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_migration_media_file */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagMigrationMediaFile"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagMigrationMediaFile"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_migration_media_file */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagMigrationMediaFile"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagMigrationMediaFile"];
        };
        responseCode: 200;
      };
  "getSwagMigrationRunList get /swag-migration-run":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["SwagMigrationRun"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["SwagMigrationRun"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /swag-migration-run?limit=25 */
            first?: unknown;
            /** @example /swag-migration-run?limit=25&page=11 */
            last?: unknown;
            /** @example /swag-migration-run?limit=25&page=4 */
            next?: unknown;
            /** @example /swag-migration-run?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createSwagMigrationRun post /swag-migration-run":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagMigrationRun"];
        response: {
          data: components["schemas"]["SwagMigrationRun"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagMigrationRun"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagMigrationRun"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagMigrationRun"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagMigrationRun"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagMigrationRun"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagMigrationRun"];
        };
        responseCode: 200;
      };
  "getSwagMigrationRun get /swag-migration-run/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the swag_migration_run */
          id: string;
        };
        response: {
          data: components["schemas"]["SwagMigrationRun"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the swag_migration_run */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagMigrationRun"];
        };
        responseCode: 200;
      };
  "deleteSwagMigrationRun delete /swag-migration-run/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the swag_migration_run */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateSwagMigrationRun patch /swag-migration-run/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_migration_run */
          id: string;
        };
        body: components["schemas"]["SwagMigrationRun"];
        response: {
          data: components["schemas"]["SwagMigrationRun"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_migration_run */
          id: string;
        };
        body: components["schemas"]["SwagMigrationRun"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagMigrationRun"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_migration_run */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagMigrationRun"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagMigrationRun"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_migration_run */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagMigrationRun"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagMigrationRun"];
        };
        responseCode: 200;
      };
  "getSwagPaypalPosSalesChannelList get /swag-paypal-pos-sales-channel":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["SwagPaypalPosSalesChannel"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["SwagPaypalPosSalesChannel"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /swag-paypal-pos-sales-channel?limit=25 */
            first?: unknown;
            /** @example /swag-paypal-pos-sales-channel?limit=25&page=11 */
            last?: unknown;
            /** @example /swag-paypal-pos-sales-channel?limit=25&page=4 */
            next?: unknown;
            /** @example /swag-paypal-pos-sales-channel?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createSwagPaypalPosSalesChannel post /swag-paypal-pos-sales-channel":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagPaypalPosSalesChannel"];
        response: {
          data: components["schemas"]["SwagPaypalPosSalesChannel"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagPaypalPosSalesChannel"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagPaypalPosSalesChannel"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagPaypalPosSalesChannel"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagPaypalPosSalesChannel"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagPaypalPosSalesChannel"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagPaypalPosSalesChannel"];
        };
        responseCode: 200;
      };
  "getSwagPaypalPosSalesChannelRunList get /swag-paypal-pos-sales-channel-run":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["SwagPaypalPosSalesChannelRun"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["SwagPaypalPosSalesChannelRun"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /swag-paypal-pos-sales-channel-run?limit=25 */
            first?: unknown;
            /** @example /swag-paypal-pos-sales-channel-run?limit=25&page=11 */
            last?: unknown;
            /** @example /swag-paypal-pos-sales-channel-run?limit=25&page=4 */
            next?: unknown;
            /** @example /swag-paypal-pos-sales-channel-run?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createSwagPaypalPosSalesChannelRun post /swag-paypal-pos-sales-channel-run":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagPaypalPosSalesChannelRun"];
        response: {
          data: components["schemas"]["SwagPaypalPosSalesChannelRun"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagPaypalPosSalesChannelRun"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagPaypalPosSalesChannelRun"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagPaypalPosSalesChannelRun"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagPaypalPosSalesChannelRun"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagPaypalPosSalesChannelRun"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagPaypalPosSalesChannelRun"];
        };
        responseCode: 200;
      };
  "getSwagPaypalPosSalesChannelRunLogList get /swag-paypal-pos-sales-channel-run-log":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["SwagPaypalPosSalesChannelRunLog"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["SwagPaypalPosSalesChannelRunLog"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /swag-paypal-pos-sales-channel-run-log?limit=25 */
            first?: unknown;
            /** @example /swag-paypal-pos-sales-channel-run-log?limit=25&page=11 */
            last?: unknown;
            /** @example /swag-paypal-pos-sales-channel-run-log?limit=25&page=4 */
            next?: unknown;
            /** @example /swag-paypal-pos-sales-channel-run-log?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createSwagPaypalPosSalesChannelRunLog post /swag-paypal-pos-sales-channel-run-log":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagPaypalPosSalesChannelRunLog"];
        response: {
          data: components["schemas"]["SwagPaypalPosSalesChannelRunLog"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagPaypalPosSalesChannelRunLog"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagPaypalPosSalesChannelRunLog"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagPaypalPosSalesChannelRunLog"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagPaypalPosSalesChannelRunLog"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagPaypalPosSalesChannelRunLog"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagPaypalPosSalesChannelRunLog"];
        };
        responseCode: 200;
      };
  "getSwagPaypalPosSalesChannelRunLog get /swag-paypal-pos-sales-channel-run-log/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the swag_paypal_pos_sales_channel_run_log */
          id: string;
        };
        response: {
          data: components["schemas"]["SwagPaypalPosSalesChannelRunLog"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the swag_paypal_pos_sales_channel_run_log */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagPaypalPosSalesChannelRunLog"];
        };
        responseCode: 200;
      };
  "deleteSwagPaypalPosSalesChannelRunLog delete /swag-paypal-pos-sales-channel-run-log/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the swag_paypal_pos_sales_channel_run_log */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateSwagPaypalPosSalesChannelRunLog patch /swag-paypal-pos-sales-channel-run-log/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_paypal_pos_sales_channel_run_log */
          id: string;
        };
        body: components["schemas"]["SwagPaypalPosSalesChannelRunLog"];
        response: {
          data: components["schemas"]["SwagPaypalPosSalesChannelRunLog"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_paypal_pos_sales_channel_run_log */
          id: string;
        };
        body: components["schemas"]["SwagPaypalPosSalesChannelRunLog"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagPaypalPosSalesChannelRunLog"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_paypal_pos_sales_channel_run_log */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagPaypalPosSalesChannelRunLog"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagPaypalPosSalesChannelRunLog"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_paypal_pos_sales_channel_run_log */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagPaypalPosSalesChannelRunLog"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagPaypalPosSalesChannelRunLog"];
        };
        responseCode: 200;
      };
  "getSwagPaypalPosSalesChannelRun get /swag-paypal-pos-sales-channel-run/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the swag_paypal_pos_sales_channel_run */
          id: string;
        };
        response: {
          data: components["schemas"]["SwagPaypalPosSalesChannelRun"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the swag_paypal_pos_sales_channel_run */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagPaypalPosSalesChannelRun"];
        };
        responseCode: 200;
      };
  "deleteSwagPaypalPosSalesChannelRun delete /swag-paypal-pos-sales-channel-run/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the swag_paypal_pos_sales_channel_run */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateSwagPaypalPosSalesChannelRun patch /swag-paypal-pos-sales-channel-run/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_paypal_pos_sales_channel_run */
          id: string;
        };
        body: components["schemas"]["SwagPaypalPosSalesChannelRun"];
        response: {
          data: components["schemas"]["SwagPaypalPosSalesChannelRun"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_paypal_pos_sales_channel_run */
          id: string;
        };
        body: components["schemas"]["SwagPaypalPosSalesChannelRun"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagPaypalPosSalesChannelRun"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_paypal_pos_sales_channel_run */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagPaypalPosSalesChannelRun"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagPaypalPosSalesChannelRun"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_paypal_pos_sales_channel_run */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagPaypalPosSalesChannelRun"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagPaypalPosSalesChannelRun"];
        };
        responseCode: 200;
      };
  "getSwagPaypalPosSalesChannel get /swag-paypal-pos-sales-channel/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the swag_paypal_pos_sales_channel */
          id: string;
        };
        response: {
          data: components["schemas"]["SwagPaypalPosSalesChannel"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the swag_paypal_pos_sales_channel */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagPaypalPosSalesChannel"];
        };
        responseCode: 200;
      };
  "deleteSwagPaypalPosSalesChannel delete /swag-paypal-pos-sales-channel/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the swag_paypal_pos_sales_channel */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateSwagPaypalPosSalesChannel patch /swag-paypal-pos-sales-channel/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_paypal_pos_sales_channel */
          id: string;
        };
        body: components["schemas"]["SwagPaypalPosSalesChannel"];
        response: {
          data: components["schemas"]["SwagPaypalPosSalesChannel"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_paypal_pos_sales_channel */
          id: string;
        };
        body: components["schemas"]["SwagPaypalPosSalesChannel"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagPaypalPosSalesChannel"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_paypal_pos_sales_channel */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagPaypalPosSalesChannel"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagPaypalPosSalesChannel"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_paypal_pos_sales_channel */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagPaypalPosSalesChannel"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagPaypalPosSalesChannel"];
        };
        responseCode: 200;
      };
  "getSwagPaypalTransactionReportList get /swag-paypal-transaction-report":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["SwagPaypalTransactionReport"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["SwagPaypalTransactionReport"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /swag-paypal-transaction-report?limit=25 */
            first?: unknown;
            /** @example /swag-paypal-transaction-report?limit=25&page=11 */
            last?: unknown;
            /** @example /swag-paypal-transaction-report?limit=25&page=4 */
            next?: unknown;
            /** @example /swag-paypal-transaction-report?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createSwagPaypalTransactionReport post /swag-paypal-transaction-report":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagPaypalTransactionReport"];
        response: {
          data: components["schemas"]["SwagPaypalTransactionReport"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagPaypalTransactionReport"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagPaypalTransactionReport"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagPaypalTransactionReport"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagPaypalTransactionReport"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagPaypalTransactionReport"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagPaypalTransactionReport"];
        };
        responseCode: 200;
      };
  "getSwagPaypalTransactionReport get /swag-paypal-transaction-report/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the swag_paypal_transaction_report */
          id: string;
        };
        response: {
          data: components["schemas"]["SwagPaypalTransactionReport"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the swag_paypal_transaction_report */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagPaypalTransactionReport"];
        };
        responseCode: 200;
      };
  "deleteSwagPaypalTransactionReport delete /swag-paypal-transaction-report/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the swag_paypal_transaction_report */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateSwagPaypalTransactionReport patch /swag-paypal-transaction-report/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_paypal_transaction_report */
          id: string;
        };
        body: components["schemas"]["SwagPaypalTransactionReport"];
        response: {
          data: components["schemas"]["SwagPaypalTransactionReport"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_paypal_transaction_report */
          id: string;
        };
        body: components["schemas"]["SwagPaypalTransactionReport"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagPaypalTransactionReport"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_paypal_transaction_report */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagPaypalTransactionReport"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagPaypalTransactionReport"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_paypal_transaction_report */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagPaypalTransactionReport"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagPaypalTransactionReport"];
        };
        responseCode: 200;
      };
  "getSwagPaypalVaultTokenList get /swag-paypal-vault-token":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["SwagPaypalVaultToken"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["SwagPaypalVaultToken"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /swag-paypal-vault-token?limit=25 */
            first?: unknown;
            /** @example /swag-paypal-vault-token?limit=25&page=11 */
            last?: unknown;
            /** @example /swag-paypal-vault-token?limit=25&page=4 */
            next?: unknown;
            /** @example /swag-paypal-vault-token?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createSwagPaypalVaultToken post /swag-paypal-vault-token":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagPaypalVaultToken"];
        response: {
          data: components["schemas"]["SwagPaypalVaultToken"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagPaypalVaultToken"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagPaypalVaultToken"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagPaypalVaultToken"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagPaypalVaultToken"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagPaypalVaultToken"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagPaypalVaultToken"];
        };
        responseCode: 200;
      };
  "getSwagPaypalVaultTokenMappingList get /swag-paypal-vault-token-mapping":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["SwagPaypalVaultTokenMapping"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["SwagPaypalVaultTokenMapping"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /swag-paypal-vault-token-mapping?limit=25 */
            first?: unknown;
            /** @example /swag-paypal-vault-token-mapping?limit=25&page=11 */
            last?: unknown;
            /** @example /swag-paypal-vault-token-mapping?limit=25&page=4 */
            next?: unknown;
            /** @example /swag-paypal-vault-token-mapping?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createSwagPaypalVaultTokenMapping post /swag-paypal-vault-token-mapping":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagPaypalVaultTokenMapping"];
        response: {
          data: components["schemas"]["SwagPaypalVaultTokenMapping"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagPaypalVaultTokenMapping"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagPaypalVaultTokenMapping"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagPaypalVaultTokenMapping"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagPaypalVaultTokenMapping"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagPaypalVaultTokenMapping"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagPaypalVaultTokenMapping"];
        };
        responseCode: 200;
      };
  "getSwagPaypalVaultTokenMapping get /swag-paypal-vault-token-mapping/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the swag_paypal_vault_token_mapping */
          id: string;
        };
        response: {
          data: components["schemas"]["SwagPaypalVaultTokenMapping"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the swag_paypal_vault_token_mapping */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagPaypalVaultTokenMapping"];
        };
        responseCode: 200;
      };
  "deleteSwagPaypalVaultTokenMapping delete /swag-paypal-vault-token-mapping/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the swag_paypal_vault_token_mapping */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateSwagPaypalVaultTokenMapping patch /swag-paypal-vault-token-mapping/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_paypal_vault_token_mapping */
          id: string;
        };
        body: components["schemas"]["SwagPaypalVaultTokenMapping"];
        response: {
          data: components["schemas"]["SwagPaypalVaultTokenMapping"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_paypal_vault_token_mapping */
          id: string;
        };
        body: components["schemas"]["SwagPaypalVaultTokenMapping"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagPaypalVaultTokenMapping"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_paypal_vault_token_mapping */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagPaypalVaultTokenMapping"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagPaypalVaultTokenMapping"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_paypal_vault_token_mapping */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagPaypalVaultTokenMapping"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagPaypalVaultTokenMapping"];
        };
        responseCode: 200;
      };
  "getSwagPaypalVaultToken get /swag-paypal-vault-token/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the swag_paypal_vault_token */
          id: string;
        };
        response: {
          data: components["schemas"]["SwagPaypalVaultToken"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the swag_paypal_vault_token */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagPaypalVaultToken"];
        };
        responseCode: 200;
      };
  "deleteSwagPaypalVaultToken delete /swag-paypal-vault-token/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the swag_paypal_vault_token */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateSwagPaypalVaultToken patch /swag-paypal-vault-token/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_paypal_vault_token */
          id: string;
        };
        body: components["schemas"]["SwagPaypalVaultToken"];
        response: {
          data: components["schemas"]["SwagPaypalVaultToken"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_paypal_vault_token */
          id: string;
        };
        body: components["schemas"]["SwagPaypalVaultToken"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagPaypalVaultToken"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_paypal_vault_token */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagPaypalVaultToken"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagPaypalVaultToken"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_paypal_vault_token */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagPaypalVaultToken"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagPaypalVaultToken"];
        };
        responseCode: 200;
      };
  "getSwagSocialShoppingCustomerList get /swag-social-shopping-customer":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["SwagSocialShoppingCustomer"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["SwagSocialShoppingCustomer"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /swag-social-shopping-customer?limit=25 */
            first?: unknown;
            /** @example /swag-social-shopping-customer?limit=25&page=11 */
            last?: unknown;
            /** @example /swag-social-shopping-customer?limit=25&page=4 */
            next?: unknown;
            /** @example /swag-social-shopping-customer?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createSwagSocialShoppingCustomer post /swag-social-shopping-customer":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagSocialShoppingCustomer"];
        response: {
          data: components["schemas"]["SwagSocialShoppingCustomer"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagSocialShoppingCustomer"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagSocialShoppingCustomer"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagSocialShoppingCustomer"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagSocialShoppingCustomer"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagSocialShoppingCustomer"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagSocialShoppingCustomer"];
        };
        responseCode: 200;
      };
  "getSwagSocialShoppingCustomer get /swag-social-shopping-customer/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the swag_social_shopping_customer */
          id: string;
        };
        response: {
          data: components["schemas"]["SwagSocialShoppingCustomer"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the swag_social_shopping_customer */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagSocialShoppingCustomer"];
        };
        responseCode: 200;
      };
  "deleteSwagSocialShoppingCustomer delete /swag-social-shopping-customer/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the swag_social_shopping_customer */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateSwagSocialShoppingCustomer patch /swag-social-shopping-customer/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_social_shopping_customer */
          id: string;
        };
        body: components["schemas"]["SwagSocialShoppingCustomer"];
        response: {
          data: components["schemas"]["SwagSocialShoppingCustomer"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_social_shopping_customer */
          id: string;
        };
        body: components["schemas"]["SwagSocialShoppingCustomer"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagSocialShoppingCustomer"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_social_shopping_customer */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagSocialShoppingCustomer"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagSocialShoppingCustomer"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_social_shopping_customer */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagSocialShoppingCustomer"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagSocialShoppingCustomer"];
        };
        responseCode: 200;
      };
  "getSwagSocialShoppingOrderList get /swag-social-shopping-order":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["SwagSocialShoppingOrder"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["SwagSocialShoppingOrder"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /swag-social-shopping-order?limit=25 */
            first?: unknown;
            /** @example /swag-social-shopping-order?limit=25&page=11 */
            last?: unknown;
            /** @example /swag-social-shopping-order?limit=25&page=4 */
            next?: unknown;
            /** @example /swag-social-shopping-order?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createSwagSocialShoppingOrder post /swag-social-shopping-order":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagSocialShoppingOrder"];
        response: {
          data: components["schemas"]["SwagSocialShoppingOrder"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagSocialShoppingOrder"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagSocialShoppingOrder"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagSocialShoppingOrder"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagSocialShoppingOrder"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagSocialShoppingOrder"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagSocialShoppingOrder"];
        };
        responseCode: 200;
      };
  "getSwagSocialShoppingOrder get /swag-social-shopping-order/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the swag_social_shopping_order */
          id: string;
        };
        response: {
          data: components["schemas"]["SwagSocialShoppingOrder"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the swag_social_shopping_order */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagSocialShoppingOrder"];
        };
        responseCode: 200;
      };
  "deleteSwagSocialShoppingOrder delete /swag-social-shopping-order/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the swag_social_shopping_order */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateSwagSocialShoppingOrder patch /swag-social-shopping-order/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_social_shopping_order */
          id: string;
        };
        body: components["schemas"]["SwagSocialShoppingOrder"];
        response: {
          data: components["schemas"]["SwagSocialShoppingOrder"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_social_shopping_order */
          id: string;
        };
        body: components["schemas"]["SwagSocialShoppingOrder"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagSocialShoppingOrder"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_social_shopping_order */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagSocialShoppingOrder"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagSocialShoppingOrder"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_social_shopping_order */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagSocialShoppingOrder"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagSocialShoppingOrder"];
        };
        responseCode: 200;
      };
  "getSwagSocialShoppingProductErrorList get /swag-social-shopping-product-error":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["SwagSocialShoppingProductError"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["SwagSocialShoppingProductError"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /swag-social-shopping-product-error?limit=25 */
            first?: unknown;
            /** @example /swag-social-shopping-product-error?limit=25&page=11 */
            last?: unknown;
            /** @example /swag-social-shopping-product-error?limit=25&page=4 */
            next?: unknown;
            /** @example /swag-social-shopping-product-error?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createSwagSocialShoppingProductError post /swag-social-shopping-product-error":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagSocialShoppingProductError"];
        response: {
          data: components["schemas"]["SwagSocialShoppingProductError"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagSocialShoppingProductError"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagSocialShoppingProductError"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagSocialShoppingProductError"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagSocialShoppingProductError"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagSocialShoppingProductError"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagSocialShoppingProductError"];
        };
        responseCode: 200;
      };
  "getSwagSocialShoppingProductError get /swag-social-shopping-product-error/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the swag_social_shopping_product_error */
          id: string;
        };
        response: {
          data: components["schemas"]["SwagSocialShoppingProductError"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the swag_social_shopping_product_error */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagSocialShoppingProductError"];
        };
        responseCode: 200;
      };
  "deleteSwagSocialShoppingProductError delete /swag-social-shopping-product-error/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the swag_social_shopping_product_error */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateSwagSocialShoppingProductError patch /swag-social-shopping-product-error/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_social_shopping_product_error */
          id: string;
        };
        body: components["schemas"]["SwagSocialShoppingProductError"];
        response: {
          data: components["schemas"]["SwagSocialShoppingProductError"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_social_shopping_product_error */
          id: string;
        };
        body: components["schemas"]["SwagSocialShoppingProductError"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagSocialShoppingProductError"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_social_shopping_product_error */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagSocialShoppingProductError"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagSocialShoppingProductError"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_social_shopping_product_error */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagSocialShoppingProductError"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagSocialShoppingProductError"];
        };
        responseCode: 200;
      };
  "getSwagSocialShoppingSalesChannelList get /swag-social-shopping-sales-channel":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["SwagSocialShoppingSalesChannel"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["SwagSocialShoppingSalesChannel"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /swag-social-shopping-sales-channel?limit=25 */
            first?: unknown;
            /** @example /swag-social-shopping-sales-channel?limit=25&page=11 */
            last?: unknown;
            /** @example /swag-social-shopping-sales-channel?limit=25&page=4 */
            next?: unknown;
            /** @example /swag-social-shopping-sales-channel?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createSwagSocialShoppingSalesChannel post /swag-social-shopping-sales-channel":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagSocialShoppingSalesChannel"];
        response: {
          data: components["schemas"]["SwagSocialShoppingSalesChannel"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SwagSocialShoppingSalesChannel"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagSocialShoppingSalesChannel"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagSocialShoppingSalesChannel"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagSocialShoppingSalesChannel"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SwagSocialShoppingSalesChannel"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagSocialShoppingSalesChannel"];
        };
        responseCode: 200;
      };
  "getSwagSocialShoppingSalesChannel get /swag-social-shopping-sales-channel/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the swag_social_shopping_sales_channel */
          id: string;
        };
        response: {
          data: components["schemas"]["SwagSocialShoppingSalesChannel"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the swag_social_shopping_sales_channel */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagSocialShoppingSalesChannel"];
        };
        responseCode: 200;
      };
  "deleteSwagSocialShoppingSalesChannel delete /swag-social-shopping-sales-channel/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the swag_social_shopping_sales_channel */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateSwagSocialShoppingSalesChannel patch /swag-social-shopping-sales-channel/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_social_shopping_sales_channel */
          id: string;
        };
        body: components["schemas"]["SwagSocialShoppingSalesChannel"];
        response: {
          data: components["schemas"]["SwagSocialShoppingSalesChannel"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_social_shopping_sales_channel */
          id: string;
        };
        body: components["schemas"]["SwagSocialShoppingSalesChannel"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagSocialShoppingSalesChannel"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_social_shopping_sales_channel */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagSocialShoppingSalesChannel"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SwagSocialShoppingSalesChannel"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the swag_social_shopping_sales_channel */
          id: string;
        };
        body: {
          data?: components["schemas"]["SwagSocialShoppingSalesChannel"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SwagSocialShoppingSalesChannel"];
        };
        responseCode: 200;
      };
  "getSystemConfigList get /system-config":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["SystemConfig"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["SystemConfig"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /system-config?limit=25 */
            first?: unknown;
            /** @example /system-config?limit=25&page=11 */
            last?: unknown;
            /** @example /system-config?limit=25&page=4 */
            next?: unknown;
            /** @example /system-config?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createSystemConfig post /system-config":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SystemConfig"];
        response: {
          data: components["schemas"]["SystemConfig"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["SystemConfig"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SystemConfig"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SystemConfig"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SystemConfig"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["SystemConfig"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SystemConfig"];
        };
        responseCode: 200;
      };
  "getSystemConfig get /system-config/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the system_config */
          id: string;
        };
        response: {
          data: components["schemas"]["SystemConfig"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the system_config */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SystemConfig"];
        };
        responseCode: 200;
      };
  "deleteSystemConfig delete /system-config/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the system_config */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateSystemConfig patch /system-config/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the system_config */
          id: string;
        };
        body: components["schemas"]["SystemConfig"];
        response: {
          data: components["schemas"]["SystemConfig"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the system_config */
          id: string;
        };
        body: components["schemas"]["SystemConfig"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SystemConfig"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the system_config */
          id: string;
        };
        body: {
          data?: components["schemas"]["SystemConfig"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["SystemConfig"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the system_config */
          id: string;
        };
        body: {
          data?: components["schemas"]["SystemConfig"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["SystemConfig"];
        };
        responseCode: 200;
      };
  "getTagList get /tag":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["Tag"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] & components["schemas"]["Tag"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /tag?limit=25 */
            first?: unknown;
            /** @example /tag?limit=25&page=11 */
            last?: unknown;
            /** @example /tag?limit=25&page=4 */
            next?: unknown;
            /** @example /tag?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createTag post /tag":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["Tag"];
        response: {
          data: components["schemas"]["Tag"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["Tag"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Tag"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["Tag"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["Tag"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["Tag"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Tag"];
        };
        responseCode: 200;
      };
  "getTag get /tag/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the tag */
          id: string;
        };
        response: {
          data: components["schemas"]["Tag"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the tag */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Tag"];
        };
        responseCode: 200;
      };
  "deleteTag delete /tag/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the tag */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateTag patch /tag/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the tag */
          id: string;
        };
        body: components["schemas"]["Tag"];
        response: {
          data: components["schemas"]["Tag"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the tag */
          id: string;
        };
        body: components["schemas"]["Tag"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Tag"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the tag */
          id: string;
        };
        body: {
          data?: components["schemas"]["Tag"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["Tag"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the tag */
          id: string;
        };
        body: {
          data?: components["schemas"]["Tag"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Tag"];
        };
        responseCode: 200;
      };
  "getTaxList get /tax":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["Tax"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] & components["schemas"]["Tax"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /tax?limit=25 */
            first?: unknown;
            /** @example /tax?limit=25&page=11 */
            last?: unknown;
            /** @example /tax?limit=25&page=4 */
            next?: unknown;
            /** @example /tax?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createTax post /tax":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["Tax"];
        response: {
          data: components["schemas"]["Tax"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["Tax"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Tax"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["Tax"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["Tax"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["Tax"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Tax"];
        };
        responseCode: 200;
      };
  "getTaxProviderList get /tax-provider":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["TaxProvider"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["TaxProvider"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /tax-provider?limit=25 */
            first?: unknown;
            /** @example /tax-provider?limit=25&page=11 */
            last?: unknown;
            /** @example /tax-provider?limit=25&page=4 */
            next?: unknown;
            /** @example /tax-provider?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createTaxProvider post /tax-provider":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["TaxProvider"];
        response: {
          data: components["schemas"]["TaxProvider"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["TaxProvider"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["TaxProvider"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["TaxProvider"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["TaxProvider"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["TaxProvider"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["TaxProvider"];
        };
        responseCode: 200;
      };
  "getTaxProvider get /tax-provider/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the tax_provider */
          id: string;
        };
        response: {
          data: components["schemas"]["TaxProvider"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the tax_provider */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["TaxProvider"];
        };
        responseCode: 200;
      };
  "deleteTaxProvider delete /tax-provider/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the tax_provider */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateTaxProvider patch /tax-provider/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the tax_provider */
          id: string;
        };
        body: components["schemas"]["TaxProvider"];
        response: {
          data: components["schemas"]["TaxProvider"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the tax_provider */
          id: string;
        };
        body: components["schemas"]["TaxProvider"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["TaxProvider"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the tax_provider */
          id: string;
        };
        body: {
          data?: components["schemas"]["TaxProvider"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["TaxProvider"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the tax_provider */
          id: string;
        };
        body: {
          data?: components["schemas"]["TaxProvider"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["TaxProvider"];
        };
        responseCode: 200;
      };
  "getTaxRuleList get /tax-rule":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["TaxRule"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["TaxRule"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /tax-rule?limit=25 */
            first?: unknown;
            /** @example /tax-rule?limit=25&page=11 */
            last?: unknown;
            /** @example /tax-rule?limit=25&page=4 */
            next?: unknown;
            /** @example /tax-rule?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createTaxRule post /tax-rule":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["TaxRule"];
        response: {
          data: components["schemas"]["TaxRule"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["TaxRule"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["TaxRule"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["TaxRule"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["TaxRule"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["TaxRule"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["TaxRule"];
        };
        responseCode: 200;
      };
  "getTaxRuleTypeList get /tax-rule-type":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["TaxRuleType"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["TaxRuleType"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /tax-rule-type?limit=25 */
            first?: unknown;
            /** @example /tax-rule-type?limit=25&page=11 */
            last?: unknown;
            /** @example /tax-rule-type?limit=25&page=4 */
            next?: unknown;
            /** @example /tax-rule-type?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createTaxRuleType post /tax-rule-type":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["TaxRuleType"];
        response: {
          data: components["schemas"]["TaxRuleType"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["TaxRuleType"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["TaxRuleType"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["TaxRuleType"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["TaxRuleType"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["TaxRuleType"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["TaxRuleType"];
        };
        responseCode: 200;
      };
  "getTaxRuleType get /tax-rule-type/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the tax_rule_type */
          id: string;
        };
        response: {
          data: components["schemas"]["TaxRuleType"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the tax_rule_type */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["TaxRuleType"];
        };
        responseCode: 200;
      };
  "deleteTaxRuleType delete /tax-rule-type/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the tax_rule_type */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateTaxRuleType patch /tax-rule-type/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the tax_rule_type */
          id: string;
        };
        body: components["schemas"]["TaxRuleType"];
        response: {
          data: components["schemas"]["TaxRuleType"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the tax_rule_type */
          id: string;
        };
        body: components["schemas"]["TaxRuleType"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["TaxRuleType"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the tax_rule_type */
          id: string;
        };
        body: {
          data?: components["schemas"]["TaxRuleType"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["TaxRuleType"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the tax_rule_type */
          id: string;
        };
        body: {
          data?: components["schemas"]["TaxRuleType"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["TaxRuleType"];
        };
        responseCode: 200;
      };
  "getTaxRule get /tax-rule/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the tax_rule */
          id: string;
        };
        response: {
          data: components["schemas"]["TaxRule"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the tax_rule */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["TaxRule"];
        };
        responseCode: 200;
      };
  "deleteTaxRule delete /tax-rule/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the tax_rule */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateTaxRule patch /tax-rule/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the tax_rule */
          id: string;
        };
        body: components["schemas"]["TaxRule"];
        response: {
          data: components["schemas"]["TaxRule"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the tax_rule */
          id: string;
        };
        body: components["schemas"]["TaxRule"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["TaxRule"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the tax_rule */
          id: string;
        };
        body: {
          data?: components["schemas"]["TaxRule"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["TaxRule"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the tax_rule */
          id: string;
        };
        body: {
          data?: components["schemas"]["TaxRule"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["TaxRule"];
        };
        responseCode: 200;
      };
  "getTax get /tax/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the tax */
          id: string;
        };
        response: {
          data: components["schemas"]["Tax"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the tax */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Tax"];
        };
        responseCode: 200;
      };
  "deleteTax delete /tax/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the tax */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateTax patch /tax/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the tax */
          id: string;
        };
        body: components["schemas"]["Tax"];
        response: {
          data: components["schemas"]["Tax"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the tax */
          id: string;
        };
        body: components["schemas"]["Tax"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Tax"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the tax */
          id: string;
        };
        body: {
          data?: components["schemas"]["Tax"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["Tax"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the tax */
          id: string;
        };
        body: {
          data?: components["schemas"]["Tax"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Tax"];
        };
        responseCode: 200;
      };
  "getThemeList get /theme":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["Theme"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["Theme"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /theme?limit=25 */
            first?: unknown;
            /** @example /theme?limit=25&page=11 */
            last?: unknown;
            /** @example /theme?limit=25&page=4 */
            next?: unknown;
            /** @example /theme?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createTheme post /theme":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["Theme"];
        response: {
          data: components["schemas"]["Theme"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["Theme"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Theme"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["Theme"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["Theme"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["Theme"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Theme"];
        };
        responseCode: 200;
      };
  "getTheme get /theme/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the theme */
          id: string;
        };
        response: {
          data: components["schemas"]["Theme"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the theme */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Theme"];
        };
        responseCode: 200;
      };
  "deleteTheme delete /theme/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the theme */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateTheme patch /theme/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the theme */
          id: string;
        };
        body: components["schemas"]["Theme"];
        response: {
          data: components["schemas"]["Theme"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the theme */
          id: string;
        };
        body: components["schemas"]["Theme"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Theme"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the theme */
          id: string;
        };
        body: {
          data?: components["schemas"]["Theme"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["Theme"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the theme */
          id: string;
        };
        body: {
          data?: components["schemas"]["Theme"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Theme"];
        };
        responseCode: 200;
      };
  "getUnitList get /unit":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["Unit"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["Unit"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /unit?limit=25 */
            first?: unknown;
            /** @example /unit?limit=25&page=11 */
            last?: unknown;
            /** @example /unit?limit=25&page=4 */
            next?: unknown;
            /** @example /unit?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createUnit post /unit":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["Unit"];
        response: {
          data: components["schemas"]["Unit"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["Unit"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Unit"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["Unit"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["Unit"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["Unit"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Unit"];
        };
        responseCode: 200;
      };
  "getUnit get /unit/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the unit */
          id: string;
        };
        response: {
          data: components["schemas"]["Unit"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the unit */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Unit"];
        };
        responseCode: 200;
      };
  "deleteUnit delete /unit/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the unit */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateUnit patch /unit/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the unit */
          id: string;
        };
        body: components["schemas"]["Unit"];
        response: {
          data: components["schemas"]["Unit"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the unit */
          id: string;
        };
        body: components["schemas"]["Unit"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Unit"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the unit */
          id: string;
        };
        body: {
          data?: components["schemas"]["Unit"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["Unit"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the unit */
          id: string;
        };
        body: {
          data?: components["schemas"]["Unit"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Unit"];
        };
        responseCode: 200;
      };
  "getUserList get /user":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["User"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["User"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /user?limit=25 */
            first?: unknown;
            /** @example /user?limit=25&page=11 */
            last?: unknown;
            /** @example /user?limit=25&page=4 */
            next?: unknown;
            /** @example /user?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createUser post /user":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["User"];
        response: {
          data: components["schemas"]["User"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["User"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["User"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["User"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["User"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["User"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["User"];
        };
        responseCode: 200;
      };
  "getUserAccessKeyList get /user-access-key":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["UserAccessKey"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["UserAccessKey"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /user-access-key?limit=25 */
            first?: unknown;
            /** @example /user-access-key?limit=25&page=11 */
            last?: unknown;
            /** @example /user-access-key?limit=25&page=4 */
            next?: unknown;
            /** @example /user-access-key?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createUserAccessKey post /user-access-key":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["UserAccessKey"];
        response: {
          data: components["schemas"]["UserAccessKey"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["UserAccessKey"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["UserAccessKey"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["UserAccessKey"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["UserAccessKey"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["UserAccessKey"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["UserAccessKey"];
        };
        responseCode: 200;
      };
  "getUserAccessKey get /user-access-key/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the user_access_key */
          id: string;
        };
        response: {
          data: components["schemas"]["UserAccessKey"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the user_access_key */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["UserAccessKey"];
        };
        responseCode: 200;
      };
  "deleteUserAccessKey delete /user-access-key/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the user_access_key */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateUserAccessKey patch /user-access-key/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the user_access_key */
          id: string;
        };
        body: components["schemas"]["UserAccessKey"];
        response: {
          data: components["schemas"]["UserAccessKey"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the user_access_key */
          id: string;
        };
        body: components["schemas"]["UserAccessKey"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["UserAccessKey"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the user_access_key */
          id: string;
        };
        body: {
          data?: components["schemas"]["UserAccessKey"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["UserAccessKey"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the user_access_key */
          id: string;
        };
        body: {
          data?: components["schemas"]["UserAccessKey"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["UserAccessKey"];
        };
        responseCode: 200;
      };
  "getUserConfigList get /user-config":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["UserConfig"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["UserConfig"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /user-config?limit=25 */
            first?: unknown;
            /** @example /user-config?limit=25&page=11 */
            last?: unknown;
            /** @example /user-config?limit=25&page=4 */
            next?: unknown;
            /** @example /user-config?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createUserConfig post /user-config":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["UserConfig"];
        response: {
          data: components["schemas"]["UserConfig"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["UserConfig"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["UserConfig"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["UserConfig"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["UserConfig"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["UserConfig"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["UserConfig"];
        };
        responseCode: 200;
      };
  "getUserConfig get /user-config/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the user_config */
          id: string;
        };
        response: {
          data: components["schemas"]["UserConfig"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the user_config */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["UserConfig"];
        };
        responseCode: 200;
      };
  "deleteUserConfig delete /user-config/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the user_config */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateUserConfig patch /user-config/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the user_config */
          id: string;
        };
        body: components["schemas"]["UserConfig"];
        response: {
          data: components["schemas"]["UserConfig"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the user_config */
          id: string;
        };
        body: components["schemas"]["UserConfig"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["UserConfig"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the user_config */
          id: string;
        };
        body: {
          data?: components["schemas"]["UserConfig"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["UserConfig"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the user_config */
          id: string;
        };
        body: {
          data?: components["schemas"]["UserConfig"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["UserConfig"];
        };
        responseCode: 200;
      };
  "getUserRecoveryList get /user-recovery":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["UserRecovery"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["UserRecovery"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /user-recovery?limit=25 */
            first?: unknown;
            /** @example /user-recovery?limit=25&page=11 */
            last?: unknown;
            /** @example /user-recovery?limit=25&page=4 */
            next?: unknown;
            /** @example /user-recovery?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createUserRecovery post /user-recovery":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["UserRecovery"];
        response: {
          data: components["schemas"]["UserRecovery"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["UserRecovery"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["UserRecovery"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["UserRecovery"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["UserRecovery"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["UserRecovery"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["UserRecovery"];
        };
        responseCode: 200;
      };
  "getUserRecovery get /user-recovery/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the user_recovery */
          id: string;
        };
        response: {
          data: components["schemas"]["UserRecovery"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the user_recovery */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["UserRecovery"];
        };
        responseCode: 200;
      };
  "deleteUserRecovery delete /user-recovery/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the user_recovery */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateUserRecovery patch /user-recovery/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the user_recovery */
          id: string;
        };
        body: components["schemas"]["UserRecovery"];
        response: {
          data: components["schemas"]["UserRecovery"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the user_recovery */
          id: string;
        };
        body: components["schemas"]["UserRecovery"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["UserRecovery"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the user_recovery */
          id: string;
        };
        body: {
          data?: components["schemas"]["UserRecovery"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["UserRecovery"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the user_recovery */
          id: string;
        };
        body: {
          data?: components["schemas"]["UserRecovery"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["UserRecovery"];
        };
        responseCode: 200;
      };
  "getUser get /user/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the user */
          id: string;
        };
        response: {
          data: components["schemas"]["User"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the user */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["User"];
        };
        responseCode: 200;
      };
  "deleteUser delete /user/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the user */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateUser patch /user/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the user */
          id: string;
        };
        body: components["schemas"]["User"];
        response: {
          data: components["schemas"]["User"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the user */
          id: string;
        };
        body: components["schemas"]["User"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["User"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the user */
          id: string;
        };
        body: {
          data?: components["schemas"]["User"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["User"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the user */
          id: string;
        };
        body: {
          data?: components["schemas"]["User"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["User"];
        };
        responseCode: 200;
      };
  "getWarehouseList get /warehouse":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["Warehouse"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["Warehouse"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /warehouse?limit=25 */
            first?: unknown;
            /** @example /warehouse?limit=25&page=11 */
            last?: unknown;
            /** @example /warehouse?limit=25&page=4 */
            next?: unknown;
            /** @example /warehouse?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createWarehouse post /warehouse":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["Warehouse"];
        response: {
          data: components["schemas"]["Warehouse"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["Warehouse"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Warehouse"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["Warehouse"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["Warehouse"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["Warehouse"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Warehouse"];
        };
        responseCode: 200;
      };
  "getWarehouseGroupList get /warehouse-group":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["WarehouseGroup"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["WarehouseGroup"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /warehouse-group?limit=25 */
            first?: unknown;
            /** @example /warehouse-group?limit=25&page=11 */
            last?: unknown;
            /** @example /warehouse-group?limit=25&page=4 */
            next?: unknown;
            /** @example /warehouse-group?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createWarehouseGroup post /warehouse-group":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["WarehouseGroup"];
        response: {
          data: components["schemas"]["WarehouseGroup"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["WarehouseGroup"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["WarehouseGroup"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["WarehouseGroup"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["WarehouseGroup"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["WarehouseGroup"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["WarehouseGroup"];
        };
        responseCode: 200;
      };
  "getWarehouseGroup get /warehouse-group/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the warehouse_group */
          id: string;
        };
        response: {
          data: components["schemas"]["WarehouseGroup"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the warehouse_group */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["WarehouseGroup"];
        };
        responseCode: 200;
      };
  "deleteWarehouseGroup delete /warehouse-group/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the warehouse_group */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateWarehouseGroup patch /warehouse-group/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the warehouse_group */
          id: string;
        };
        body: components["schemas"]["WarehouseGroup"];
        response: {
          data: components["schemas"]["WarehouseGroup"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the warehouse_group */
          id: string;
        };
        body: components["schemas"]["WarehouseGroup"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["WarehouseGroup"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the warehouse_group */
          id: string;
        };
        body: {
          data?: components["schemas"]["WarehouseGroup"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["WarehouseGroup"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the warehouse_group */
          id: string;
        };
        body: {
          data?: components["schemas"]["WarehouseGroup"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["WarehouseGroup"];
        };
        responseCode: 200;
      };
  "getWarehouse get /warehouse/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the warehouse */
          id: string;
        };
        response: {
          data: components["schemas"]["Warehouse"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the warehouse */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Warehouse"];
        };
        responseCode: 200;
      };
  "deleteWarehouse delete /warehouse/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the warehouse */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateWarehouse patch /warehouse/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the warehouse */
          id: string;
        };
        body: components["schemas"]["Warehouse"];
        response: {
          data: components["schemas"]["Warehouse"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the warehouse */
          id: string;
        };
        body: components["schemas"]["Warehouse"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Warehouse"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the warehouse */
          id: string;
        };
        body: {
          data?: components["schemas"]["Warehouse"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["Warehouse"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the warehouse */
          id: string;
        };
        body: {
          data?: components["schemas"]["Warehouse"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Warehouse"];
        };
        responseCode: 200;
      };
  "getWebhookList get /webhook":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["Webhook"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["Webhook"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /webhook?limit=25 */
            first?: unknown;
            /** @example /webhook?limit=25&page=11 */
            last?: unknown;
            /** @example /webhook?limit=25&page=4 */
            next?: unknown;
            /** @example /webhook?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createWebhook post /webhook":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["Webhook"];
        response: {
          data: components["schemas"]["Webhook"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["Webhook"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Webhook"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["Webhook"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["Webhook"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["Webhook"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Webhook"];
        };
        responseCode: 200;
      };
  "getWebhookEventLogList get /webhook-event-log":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: {
          data?: components["schemas"]["WebhookEventLog"][];
          total?: number;
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Max amount of resources to be returned in a page */
          limit?: number;
          /** The page to be returned */
          page?: number;
          /** Encoded SwagQL in JSON */
          query?: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["data"] &
            components["schemas"]["WebhookEventLog"][];
          links?: components["schemas"]["pagination"] & {
            /** @example /webhook-event-log?limit=25 */
            first?: unknown;
            /** @example /webhook-event-log?limit=25&page=11 */
            last?: unknown;
            /** @example /webhook-event-log?limit=25&page=4 */
            next?: unknown;
            /** @example /webhook-event-log?limit=25&page=2 */
            prev?: unknown;
          };
        };
        responseCode: 200;
      };
  "createWebhookEventLog post /webhook-event-log":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["WebhookEventLog"];
        response: {
          data: components["schemas"]["WebhookEventLog"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: components["schemas"]["WebhookEventLog"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["WebhookEventLog"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["WebhookEventLog"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["WebhookEventLog"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: "basic" | "detail";
        };
        body: {
          data?: components["schemas"]["WebhookEventLog"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["WebhookEventLog"];
        };
        responseCode: 200;
      };
  "getWebhookEventLog get /webhook-event-log/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the webhook_event_log */
          id: string;
        };
        response: {
          data: components["schemas"]["WebhookEventLog"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the webhook_event_log */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["WebhookEventLog"];
        };
        responseCode: 200;
      };
  "deleteWebhookEventLog delete /webhook-event-log/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the webhook_event_log */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateWebhookEventLog patch /webhook-event-log/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the webhook_event_log */
          id: string;
        };
        body: components["schemas"]["WebhookEventLog"];
        response: {
          data: components["schemas"]["WebhookEventLog"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the webhook_event_log */
          id: string;
        };
        body: components["schemas"]["WebhookEventLog"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["WebhookEventLog"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the webhook_event_log */
          id: string;
        };
        body: {
          data?: components["schemas"]["WebhookEventLog"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["WebhookEventLog"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the webhook_event_log */
          id: string;
        };
        body: {
          data?: components["schemas"]["WebhookEventLog"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["WebhookEventLog"];
        };
        responseCode: 200;
      };
  "getWebhook get /webhook/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        pathParams: {
          /** Identifier for the webhook */
          id: string;
        };
        response: {
          data: components["schemas"]["Webhook"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        pathParams: {
          /** Identifier for the webhook */
          id: string;
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Webhook"];
        };
        responseCode: 200;
      };
  "deleteWebhook delete /webhook/{id}": {
    contentType?: "application/json";
    accept?: "application/json";
    query?: {
      /** Data format for response. Empty if none is provided. */
      _response?: string;
    };
    pathParams: {
      /** Identifier for the webhook */
      id: string;
    };
    response: never;
    responseCode: 204;
  };
  "updateWebhook patch /webhook/{id}":
    | {
        contentType?: "application/json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the webhook */
          id: string;
        };
        body: components["schemas"]["Webhook"];
        response: {
          data: components["schemas"]["Webhook"];
        };
        responseCode: 200;
      }
    | {
        contentType?: "application/json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the webhook */
          id: string;
        };
        body: components["schemas"]["Webhook"];
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Webhook"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept?: "application/json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the webhook */
          id: string;
        };
        body: {
          data?: components["schemas"]["Webhook"];
          included?: components["schemas"]["resource"][];
        };
        response: {
          data: components["schemas"]["Webhook"];
        };
        responseCode: 200;
      }
    | {
        contentType: "application/vnd.api+json";
        accept: "application/vnd.api+json";
        query?: {
          /** Data format for response. Empty if none is provided. */
          _response?: string;
        };
        pathParams: {
          /** Identifier for the webhook */
          id: string;
        };
        body: {
          data?: components["schemas"]["Webhook"];
          included?: components["schemas"]["resource"][];
        };
        response: components["schemas"]["success"] & {
          data?: components["schemas"]["Webhook"];
        };
        responseCode: 200;
      };
};

type SimpleUnionOmit<T, K extends string | number | symbol> = T extends unknown ? Omit<T, K> : never;
type SimpleUnionPick<T, K extends keyof T> = T extends unknown ? Pick<T, K> : never;
type RenameByT<T, U> = {
    [K in keyof U as K extends keyof T ? T[K] extends string ? T[K] : never : K]: K extends keyof U ? U[K] : never;
};
/**
 * Session data entity for admin API client.
 */
type AdminSessionData = {
    accessToken: string;
    refreshToken?: string;
    expirationTime: number;
};
type RequestReturnType<CURRENT_OPERATION extends {
    response: unknown;
    responseCode: number;
}> = RenameByT<{
    response: "data";
    responseCode: "status";
}, SimpleUnionPick<CURRENT_OPERATION, "response" | "responseCode">>;
type AdminApiClientHooks = {
    onAuthChange: (authData: AdminSessionData) => void;
    onResponseError: (response: FetchResponse<ResponseType>) => void;
    onSuccessResponse: (response: FetchResponse<ResponseType>) => void;
    onDefaultHeaderChanged: <T>(headerName: string, value?: T) => void;
};
declare function createAdminAPIClient<OPERATIONS extends Record<string, any> = operations, PATHS extends string | number | symbol = keyof OPERATIONS>(params: {
    baseURL?: string;
    /**
     * If you pass `credentials` object, it will be used to authenticate the client whenever session expires.
     * You don't need to manually invoke `/token` endpoint first.
     */
    credentials?: OPERATIONS["token post /oauth/token"]["body"];
    sessionData?: AdminSessionData;
    defaultHeaders?: ClientHeaders;
    fetchOptions?: GlobalFetchOptions;
}): {
    invoke: <INVOKE_PATH extends PATHS, OPERATION_NAME extends string = INVOKE_PATH extends `${infer R}` ? R extends string ? R : never : never, CURRENT_OPERATION extends OPERATIONS[OPERATION_NAME] = OPERATION_NAME extends keyof OPERATIONS ? OPERATIONS[OPERATION_NAME] : never>(pathParam: OPERATION_NAME extends keyof OPERATIONS ? OPERATION_NAME : never, ...params: SimpleUnionOmit<CURRENT_OPERATION, "response" | "responseCode"> extends {
        body: unknown;
    } | {
        query: unknown;
    } | {
        header: unknown;
    } | {
        pathParams: unknown;
    } ? [InvokeParameters<CURRENT_OPERATION>] : [InvokeParameters<CURRENT_OPERATION>?]) => Promise<RequestReturnType<CURRENT_OPERATION>>;
    /**
     * Enables to change session data in runtime. Useful for testing purposes.
     * Setting session data with this method will **not** fire `onAuthChange` hook.
     */
    setSessionData: (data: AdminSessionData) => AdminSessionData;
    /**
     * Returns current session data. Useful for testing purposes, as in most cases you'll want to use `onAuthChange` hook for that.
     */
    getSessionData: () => {
        accessToken: string;
        refreshToken?: string;
        expirationTime: number;
    };
    /**
     * Default headers used in every client request (if not overriden in specific request).
     */
    defaultHeaders: ClientHeadersProxy;
    /**
     * Available hooks for the client.
     */
    hook: <NameT extends hookable.HookKeys<AdminApiClientHooks>>(name: NameT, function_: AdminApiClientHooks[NameT] extends hookable.HookCallback ? AdminApiClientHooks[NameT] : never, options?: {
        allowDeprecated?: boolean;
    }) => () => void;
};

type ApiError = {
    title?: string;
    detail?: string;
    code?: string;
    status?: string;
    source?: {
        pointer?: string;
    };
    meta?: {
        parameters?: Record<string, string> | [];
    };
};
declare class ApiClientError<T extends {
    errors: Array<ApiError>;
}> extends Error {
    /**
     * Flag to indicate if the request was successful.
     */
    ok: boolean;
    /**
     * HTTP status code of the response.
     */
    status: number;
    /**
     * HTTP status text of the response.
     */
    statusText?: string;
    /**
     * URL of the request.
     */
    url: string;
    /**
     * Details of the error.
     */
    details: T;
    /**
     * Headers of the response.
     */
    headers: Headers;
    constructor(response: FetchResponse<T>);
}

export { ApiClientError, type ApiError, createAPIClient, createAdminAPIClient };
